CKEDITOR.plugins.setLang("docprops","et",{bgColor:"Taustavärv",bgFixed:"Mittekeritav tagataust",bgImage:"Taustapildi URL",charset:"Märgistiku kodeering",charsetASCII:"ASCII",charsetCE:"Kesk-Euroopa",charsetCR:"Kirillisa",charsetCT:"Hiina traditsiooniline (Big5)",charsetGR:"Kreeka",charsetJP:"Jaapani",charsetKR:"Korea",charsetOther:"Ülejäänud märgistike kodeeringud",charsetTR:"Türgi",charsetUN:"Unicode (UTF-8)",charsetWE:"Lääne-Euroopa",chooseColor:"Vali",design:"Disain",docTitle:"Lehekülje tiitel",
docType:"Dokumendi tüüppäis",docTypeOther:"Teised dokumendi tüüppäised",label:"Dokumendi omadused",margin:"Lehekülje äärised",marginBottom:"Alaserv",marginLeft:"Vasakserv",marginRight:"Paremserv",marginTop:"Ülaserv",meta:"Meta andmed",metaAuthor:"Autor",metaCopyright:"Autoriõigus",metaDescription:"Dokumendi kirjeldus",metaKeywords:"Dokumendi võtmesõnad (eraldatud komadega)",other:"<muu>",previewHtml:'<p>See on <strong>näidistekst</strong>. Sa kasutad <a href="javascript:void(0)">CKEditori</a>.</p>',
title:"Dokumendi omadused",txtColor:"Teksti värv",xhtmlDec:"Arva kaasa XHTML deklaratsioonid"});