/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","zh-cn",{abort:"上传已被用户中止。",doneOne:"文件上传成功。",doneMany:"成功上传了 %1 个文件。",uploadOne:"正在上传文件（{percentage}%）……",uploadMany:"正在上传文件，{max} 中的 {current}（{percentage}%）……"});