CKEDITOR.plugins.setLang("docprops","sk",{bgColor:"Farba pozadia",bgFixed:"Fixné pozadie",bgImage:"URL obrázka na pozadí",charset:"Znaková sada",charsetASCII:"ASCII",charsetCE:"Stredoeurópska",charsetCR:"Cyrillika",charsetCT:"Čínština tradičná (Big5)",charsetGR:"Gréčtina",charsetJP:"Japončina",charsetKR:"Korejčina",charsetOther:"Iná znaková sada",charsetTR:"Turečtina",charsetUN:"Unicode (UTF-8)",charsetWE:"Západná európa",chooseColor:"Vybrať",design:"Design",docTitle:"Titulok stránky",docType:"Typ záhlavia dokumentu",
docTypeOther:"Iný typ záhlavia dokumentu",label:"Vlastnosti dokumentu",margin:"Okraje stránky (margins)",marginBottom:"Dolný",marginLeft:"Ľavý",marginRight:"Pravý",marginTop:"Horný",meta:"Meta značky",metaAuthor:"Autor",metaCopyright:"Autorské práva (copyright)",metaDescription:"Popis dokumentu",metaKeywords:"Indexované kľúčové slová dokumentu (oddelené čiarkou)",other:"Iný...",previewHtml:'<p>Toto je nejaký <strong>ukážkový text</strong>. Používate <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Vlastnosti dokumentu",txtColor:"Farba textu",xhtmlDec:"Vložiť deklarácie XHTML"});