CKEDITOR.plugins.setLang("docprops","ro",{bgColor:"Culoarea fundalului (Background Color)",bgFixed:"Fundal neflotant, fix (Non-scrolling Background)",bgImage:"URL-ul imaginii din fundal (Background Image URL)",charset:"Encoding setului de caractere",charsetASCII:"ASCII",charsetCE:"Europa Centrală",charsetCR:"Chirilic",charsetCT:"Chinezesc tradiţional (Big5)",charsetGR:"Grecesc",charsetJP:"Japonez",charsetKR:"Corean",charsetOther:"Alt encoding al setului de caractere",charsetTR:"Turcesc",charsetUN:"Unicode (UTF-8)",
charsetWE:"Vest european",chooseColor:"Alege",design:"Proiect",docTitle:"Titlul paginii",docType:"Tip de document de antet",docTypeOther:"Alt Document Type Heading",label:"Proprietăţile documentului",margin:"Marginile paginii",marginBottom:"Jos",marginLeft:"Stânga",marginRight:"Dreapta",marginTop:"Sus",meta:"Tag-uri Meta",metaAuthor:"Autor",metaCopyright:"Drepturi de autor",metaDescription:"Descrierea documentului",metaKeywords:"Cuvinte cheie după care se va indexa documentul (separate prin virgulă)",
other:"Altele...",previewHtml:'<p>Acesta este un <strong>text exemplu</strong>. Folosiți <a href="javascript:void(0)">CKEditor</a>.</p>',title:"Proprietăţile documentului",txtColor:"Culoarea textului",xhtmlDec:"Include declaraţii XHTML"});