/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","ru",{abort:"Загрузка отменена пользователем",doneOne:"Файл успешно загружен",doneMany:"Успешно загружено файлов: %1",uploadOne:"Загрузка файла ({percentage}%)",uploadMany:"Загрузка файлов, {current} из {max} загружено ({percentage}%)..."});