/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","sv",{title:"UI Färgväljare",preview:"Live förhandsgranskning",config:"Klistra in den här strängen i din config.js-fil",predefined:"Fördefinierade färguppsättningar"});