CKEDITOR.plugins.setLang("docprops","cy",{bgColor:"Lliw Cefndir",bgFixed:"Cefndir Sefydlog (Ddim yn Sgrolio)",bgImage:"URL Delwedd Cefndir",charset:"Amgodio Set Nodau",charsetASCII:"ASCII",charsetCE:"Ewropeaidd Canol",charsetCR:"Syrilig",charsetCT:"Tsieinëeg Traddodiadol (Big5)",charsetGR:"Groeg",charsetJP:"Siapanëeg",charsetKR:"Corëeg",charsetOther:"Amgodio Set Nodau Arall",charsetTR:"Tyrceg",charsetUN:"Unicode (UTF-8)",charsetWE:"Ewropeaidd Gorllewinol",chooseColor:"Dewis",design:"Cynllunio",docTitle:"Teitl y Dudalen",
docType:"Pennawd Math y Ddogfen",docTypeOther:"Pennawd Math y Ddogfen Arall",label:"Priodweddau Dogfen",margin:"Ffin y Dudalen",marginBottom:"Gwaelod",marginLeft:"Chwith",marginRight:"Dde",marginTop:"Brig",meta:"Tagiau Meta",metaAuthor:"Awdur",metaCopyright:"Hawlfraint",metaDescription:"Disgrifiad y Ddogfen",metaKeywords:"Allweddeiriau Indecsio Dogfen (gwahanu gyda choma)",other:"Arall...",previewHtml:'<p>Dyma ychydig o <strong>destun sampl</strong>. Rydych chi\'n defnyddio <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Priodweddau Dogfen",txtColor:"Lliw y Testun",xhtmlDec:"Cynnwys Datganiadau XHTML"});