CKEDITOR.plugins.setLang("mathjax","bg",{title:"Формули в TeX формат",button:"Формули",dialogInput:"Въведете вашите данни с TeX форматиране тук",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX документация",loading:"зареждане...",pathName:"формули"});