/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","he",{title:"בחירת צבע ממשק משתמש",preview:"תצוגה מקדימה",config:"הדבק את הטקסט הבא לתוך הקובץ config.js",predefined:"קבוצות צבעים מוגדרות מראש"});