/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'wsc', 'zh', {
	btnIgnore: '忽略',
	btnIgnoreAll: '全部忽略',
	btnReplace: '取代',
	btnReplaceAll: '全部取代',
	btnUndo: '復原',
	changeTo: '更改為',
	errorLoading: '無法聯系侍服器: %s.',
	ieSpellDownload: '尚未安裝拼字檢查元件。您是否想要現在下載？',
	manyChanges: '拼字檢查完成：更改了 %1 個單字',
	noChanges: '拼字檢查完成：未更改任何單字',
	noMispell: '拼字檢查完成：未發現拼字錯誤',
	noSuggestions: '- 無建議值 -',
	notAvailable: '抱歉，服務目前暫不可用',
	notInDic: '不在字典中',
	oneChange: '拼字檢查完成：更改了 1 個單字',
	progress: '進行拼字檢查中…',
	title: '拼字檢查',
	toolbar: '拼字檢查'
});
