/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","nb",{loadError:"Feil oppsto under filinnlesing.",networkError:"Nettverksfeil oppsto under filopplasting.",httpError404:"HTTP-feil oppsto under filopplasting (404: Fant ikke filen).",httpError403:"HTTP-feil oppsto under filopplasting (403: Ikke tillatt).",httpError:"HTTP-feil oppsto under filopplasting (feilstatus: %1).",noUrlError:"URL for opplasting er ikke oppgitt.",responseError:"Ukorrekt svar fra serveren."});