CKEDITOR.plugins.setLang("mathjax","he",{title:"מתמטיקה בTeX",button:"מתמטיקה",dialogInput:"כתוב את הTeX שלך כאן",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"תיעוד TeX",loading:"טוען...",pathName:"מתמטיקה"});