/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","tr",{loadError:"Dosya okunurken hata oluştu.",networkError:"Dosya gönderilirken ağ hatası oluştu.",httpError404:"Dosya gönderilirken HTTP hatası oluştu (404: Dosya bulunamadı).",httpError403:"Dosya gönderilirken HTTP hatası oluştu (403: Yasaklı).",httpError:"Dosya gönderilirken HTTP hatası oluştu (hata durumu: %1).",noUrlError:"Gönderilecek URL belirtilmedi.",responseError:"Sunucu cevap veremedi."});