CKEDITOR.plugins.setLang("image2","eu",{alt:"Ordezko Testua",btnUpload:"Zerbitzarira bidalia",captioned:"Captioned image",captionPlaceholder:"Caption",infoTab:"Irudi informazioa",lockRatio:"Erlazioa Blokeatu",menu:"Irudi Ezaugarriak",pathName:"image",pathNameCaption:"caption",resetSize:"Tamaina Berrezarri",resizer:"Click and drag to resize",title:"Irudi Ezaugarriak",uploadTab:"Gora kargatu",urlMissing:"Irudiaren iturburu URL-a falta da."});