CKEDITOR.plugins.setLang("mathjax","en-gb",{title:"Mathematics in TeX",button:"Math",dialogInput:"Write you TeX here",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX documentation",loading:"loading...",pathName:"math"});