CKEDITOR.plugins.setLang("embedbase","it",{pathName:"oggetto multimediale",title:"Media incorporato",button:"Inserisci media incorporato",unsupportedUrlGiven:"L'URL specificato non è supportato.",unsupportedUrl:"L'URL {url} non è supportato da Media incorporato.",fetchingFailedGiven:"Non è stato possibile recuperareil contenuto per l'URL specificato.",fetchingFailed:"Non è stato possibile recuperare il contenuto per {url}.",fetchingOne:"Recupero della risposta oEmbed...",fetchingMany:"Recupero delle risposta oEmbed, {current} di {max} completati..."});