CKEDITOR.plugins.setLang("docprops","ka",{bgColor:"ფონის ფერი",bgFixed:"უმოძრაო (ფიქსირებული) ფონი",bgImage:"ფონური სურათის URL",charset:"კოდირება",charsetASCII:"ამერიკული (ASCII)",charsetCE:"ცენტრალურ ევროპული",charsetCR:"კირილური",charsetCT:"ტრადიციული ჩინური (Big5)",charsetGR:"ბერძნული",charsetJP:"იაპონური",charsetKR:"კორეული",charsetOther:"სხვა კოდირებები",charsetTR:"თურქული",charsetUN:"უნიკოდი (UTF-8)",charsetWE:"დასავლეთ ევროპული",chooseColor:"არჩევა",design:"დიზაინი",docTitle:"გვერდის სათაური",
docType:"დოკუმენტის ტიპი",docTypeOther:"სხვა ტიპის დოკუმენტი",label:"დოკუმენტის პარამეტრები",margin:"გვერდის კიდეები",marginBottom:"ქვედა",marginLeft:"მარცხენა",marginRight:"მარჯვენა",marginTop:"ზედა",meta:"მეტაTag-ები",metaAuthor:"ავტორი",metaCopyright:"Copyright",metaDescription:"დოკუმენტის აღწერა",metaKeywords:"დოკუმენტის საკვანძო სიტყვები (მძიმით გამოყოფილი)",other:"სხვა...",previewHtml:'<p>ეს არის <strong>საცდელი ტექსტი</strong>. თქვენ <a href="javascript:void(0)">CKEditor</a>-ით სარგებლობთ.</p>',
title:"დოკუმენტის პარამეტრები",txtColor:"ტექსტის ფერი",xhtmlDec:"XHTML დეკლარაციების ჩართვა"});