/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
(function(){if(!window.CKEDITOR||!window.CKEDITOR.dom)window.CKEDITOR||(window.CKEDITOR=function(){var a=/(^|.*[\\\/])ckeditor\.js(?:\?.*|;.*)?$/i,e={timestamp:"F7OI",version:"4.5.3",revision:"6c70c82",rnd:Math.floor(900*Math.random())+100,_:{pending:[],basePathSrcPattern:a},status:"unloaded",basePath:function(){var b=window.CKEDITOR_BASEPATH||"";if(!b)for(var c=document.getElementsByTagName("script"),e=0;e<c.length;e++){var d=c[e].src.match(a);if(d){b=d[1];break}}-1==b.indexOf(":/")&&"//"!=b.slice(0,
2)&&(b=0===b.indexOf("/")?location.href.match(/^.*?:\/\/[^\/]*/)[0]+b:location.href.match(/^[^\?]*\/(?:)/)[0]+b);if(!b)throw'The CKEditor installation path could not be automatically detected. Please set the global variable "CKEDITOR_BASEPATH" before creating editor instances.';return b}(),getUrl:function(a){-1==a.indexOf(":/")&&0!==a.indexOf("/")&&(a=this.basePath+a);this.timestamp&&("/"!=a.charAt(a.length-1)&&!/[&?]t=/.test(a))&&(a+=(0<=a.indexOf("?")?"&":"?")+"t="+this.timestamp);return a},domReady:function(){function a(){try{document.addEventListener?
(document.removeEventListener("DOMContentLoaded",a,!1),b()):document.attachEvent&&"complete"===document.readyState&&(document.detachEvent("onreadystatechange",a),b())}catch(d){}}function b(){for(var d;d=c.shift();)d()}var c=[];return function(d){function b(){try{document.documentElement.doScroll("left")}catch(g){setTimeout(b,1);return}a()}c.push(d);"complete"===document.readyState&&setTimeout(a,1);if(1==c.length)if(document.addEventListener)document.addEventListener("DOMContentLoaded",a,!1),window.addEventListener("load",
a,!1);else if(document.attachEvent){document.attachEvent("onreadystatechange",a);window.attachEvent("onload",a);d=!1;try{d=!window.frameElement}catch(h){}document.documentElement.doScroll&&d&&b()}}}()},b=window.CKEDITOR_GETURL;if(b){var c=e.getUrl;e.getUrl=function(a){return b.call(e,a)||c.call(e,a)}}return e}()),CKEDITOR.event||(CKEDITOR.event=function(){},CKEDITOR.event.implementOn=function(a){var e=CKEDITOR.event.prototype,b;for(b in e)a[b]==null&&(a[b]=e[b])},CKEDITOR.event.prototype=function(){function a(a){var f=
e(this);return f[a]||(f[a]=new b(a))}var e=function(a){a=a.getPrivate&&a.getPrivate()||a._||(a._={});return a.events||(a.events={})},b=function(a){this.name=a;this.listeners=[]};b.prototype={getListenerIndex:function(a){for(var b=0,e=this.listeners;b<e.length;b++)if(e[b].fn==a)return b;return-1}};return{define:function(b,f){var e=a.call(this,b);CKEDITOR.tools.extend(e,f,true)},on:function(b,f,e,i,d){function j(g,a,d,j){g={name:b,sender:this,editor:g,data:a,listenerData:i,stop:d,cancel:j,removeListener:h};
return f.call(e,g)===false?false:g.data}function h(){m.removeListener(b,f)}var g=a.call(this,b);if(g.getListenerIndex(f)<0){g=g.listeners;e||(e=this);isNaN(d)&&(d=10);var m=this;j.fn=f;j.priority=d;for(var p=g.length-1;p>=0;p--)if(g[p].priority<=d){g.splice(p+1,0,j);return{removeListener:h}}g.unshift(j)}return{removeListener:h}},once:function(){var a=Array.prototype.slice.call(arguments),b=a[1];a[1]=function(a){a.removeListener();return b.apply(this,arguments)};return this.on.apply(this,a)},capture:function(){CKEDITOR.event.useCapture=
1;var a=this.on.apply(this,arguments);CKEDITOR.event.useCapture=0;return a},fire:function(){var a=0,b=function(){a=1},k=0,i=function(){k=1};return function(d,j,h){var g=e(this)[d],d=a,m=k;a=k=0;if(g){var p=g.listeners;if(p.length)for(var p=p.slice(0),r,o=0;o<p.length;o++){if(g.errorProof)try{r=p[o].call(this,h,j,b,i)}catch(n){}else r=p[o].call(this,h,j,b,i);r===false?k=1:typeof r!="undefined"&&(j=r);if(a||k)break}}j=k?false:typeof j=="undefined"?true:j;a=d;k=m;return j}}(),fireOnce:function(a,b,k){b=
this.fire(a,b,k);delete e(this)[a];return b},removeListener:function(a,b){var k=e(this)[a];if(k){var i=k.getListenerIndex(b);i>=0&&k.listeners.splice(i,1)}},removeAllListeners:function(){var a=e(this),b;for(b in a)delete a[b]},hasListeners:function(a){return(a=e(this)[a])&&a.listeners.length>0}}}()),CKEDITOR.editor||(CKEDITOR.editor=function(){CKEDITOR._.pending.push([this,arguments]);CKEDITOR.event.call(this)},CKEDITOR.editor.prototype.fire=function(a,e){a in{instanceReady:1,loaded:1}&&(this[a]=
true);return CKEDITOR.event.prototype.fire.call(this,a,e,this)},CKEDITOR.editor.prototype.fireOnce=function(a,e){a in{instanceReady:1,loaded:1}&&(this[a]=true);return CKEDITOR.event.prototype.fireOnce.call(this,a,e,this)},CKEDITOR.event.implementOn(CKEDITOR.editor.prototype)),CKEDITOR.env||(CKEDITOR.env=function(){var a=navigator.userAgent.toLowerCase(),e=a.match(/edge[ \/](\d+.?\d*)/),b=a.indexOf("trident/")>-1,b=!(!e&&!b),b={ie:b,edge:!!e,webkit:!b&&a.indexOf(" applewebkit/")>-1,air:a.indexOf(" adobeair/")>
-1,mac:a.indexOf("macintosh")>-1,quirks:document.compatMode=="BackCompat"&&(!document.documentMode||document.documentMode<10),mobile:a.indexOf("mobile")>-1,iOS:/(ipad|iphone|ipod)/.test(a),isCustomDomain:function(){if(!this.ie)return false;var a=document.domain,b=window.location.hostname;return a!=b&&a!="["+b+"]"},secure:location.protocol=="https:"};b.gecko=navigator.product=="Gecko"&&!b.webkit&&!b.ie;if(b.webkit)a.indexOf("chrome")>-1?b.chrome=true:b.safari=true;var c=0;if(b.ie){c=e?parseFloat(e[1]):
b.quirks||!document.documentMode?parseFloat(a.match(/msie (\d+)/)[1]):document.documentMode;b.ie9Compat=c==9;b.ie8Compat=c==8;b.ie7Compat=c==7;b.ie6Compat=c<7||b.quirks}if(b.gecko)if(e=a.match(/rv:([\d\.]+)/)){e=e[1].split(".");c=e[0]*1E4+(e[1]||0)*100+(e[2]||0)*1}b.air&&(c=parseFloat(a.match(/ adobeair\/(\d+)/)[1]));b.webkit&&(c=parseFloat(a.match(/ applewebkit\/(\d+)/)[1]));b.version=c;b.isCompatible=!(b.ie&&c<7)&&!(b.gecko&&c<4E4)&&!(b.webkit&&c<534);b.hidpi=window.devicePixelRatio>=2;b.needsBrFiller=
b.gecko||b.webkit||b.ie&&c>10;b.needsNbspFiller=b.ie&&c<11;b.cssClass="cke_browser_"+(b.ie?"ie":b.gecko?"gecko":b.webkit?"webkit":"unknown");if(b.quirks)b.cssClass=b.cssClass+" cke_browser_quirks";if(b.ie)b.cssClass=b.cssClass+(" cke_browser_ie"+(b.quirks?"6 cke_browser_iequirks":b.version));if(b.air)b.cssClass=b.cssClass+" cke_browser_air";if(b.iOS)b.cssClass=b.cssClass+" cke_browser_ios";if(b.hidpi)b.cssClass=b.cssClass+" cke_hidpi";return b}()),"unloaded"==CKEDITOR.status&&function(){CKEDITOR.event.implementOn(CKEDITOR);
CKEDITOR.loadFullCore=function(){if(CKEDITOR.status!="basic_ready")CKEDITOR.loadFullCore._load=1;else{delete CKEDITOR.loadFullCore;var a=document.createElement("script");a.type="text/javascript";a.src=CKEDITOR.basePath+"ckeditor.js";document.getElementsByTagName("head")[0].appendChild(a)}};CKEDITOR.loadFullCoreTimeout=0;CKEDITOR.add=function(a){(this._.pending||(this._.pending=[])).push(a)};(function(){CKEDITOR.domReady(function(){var a=CKEDITOR.loadFullCore,e=CKEDITOR.loadFullCoreTimeout;if(a){CKEDITOR.status=
"basic_ready";a&&a._load?a():e&&setTimeout(function(){CKEDITOR.loadFullCore&&CKEDITOR.loadFullCore()},e*1E3)}})})();CKEDITOR.status="basic_loaded"}(),CKEDITOR.dom={},function(){var a=[],e=CKEDITOR.env.gecko?"-moz-":CKEDITOR.env.webkit?"-webkit-":CKEDITOR.env.ie?"-ms-":"",b=/&/g,c=/>/g,f=/</g,k=/"/g,i=/&(lt|gt|amp|quot|nbsp|shy|#\d{1,5});/g,d={lt:"<",gt:">",amp:"&",quot:'"',nbsp:" ",shy:"­"},j=function(a,g){return g[0]=="#"?String.fromCharCode(parseInt(g.slice(1),10)):d[g]};CKEDITOR.on("reset",function(){a=
[]});CKEDITOR.tools={arrayCompare:function(a,g){if(!a&&!g)return true;if(!a||!g||a.length!=g.length)return false;for(var d=0;d<a.length;d++)if(a[d]!=g[d])return false;return true},getIndex:function(a,g){for(var d=0;d<a.length;++d)if(g(a[d]))return d;return-1},clone:function(a){var g;if(a&&a instanceof Array){g=[];for(var d=0;d<a.length;d++)g[d]=CKEDITOR.tools.clone(a[d]);return g}if(a===null||typeof a!="object"||a instanceof String||a instanceof Number||a instanceof Boolean||a instanceof Date||a instanceof
RegExp||a.nodeType||a.window===a)return a;g=new a.constructor;for(d in a)g[d]=CKEDITOR.tools.clone(a[d]);return g},capitalize:function(a,g){return a.charAt(0).toUpperCase()+(g?a.slice(1):a.slice(1).toLowerCase())},extend:function(a){var g=arguments.length,d,b;if(typeof(d=arguments[g-1])=="boolean")g--;else if(typeof(d=arguments[g-2])=="boolean"){b=arguments[g-1];g=g-2}for(var j=1;j<g;j++){var c=arguments[j],f;for(f in c)if(d===true||a[f]==null)if(!b||f in b)a[f]=c[f]}return a},prototypedCopy:function(a){var g=
function(){};g.prototype=a;return new g},copy:function(a){var g={},d;for(d in a)g[d]=a[d];return g},isArray:function(a){return Object.prototype.toString.call(a)=="[object Array]"},isEmpty:function(a){for(var g in a)if(a.hasOwnProperty(g))return false;return true},cssVendorPrefix:function(a,g,d){if(d)return e+a+":"+g+";"+a+":"+g;d={};d[a]=g;d[e+a]=g;return d},cssStyleToDomStyle:function(){var a=document.createElement("div").style,g=typeof a.cssFloat!="undefined"?"cssFloat":typeof a.styleFloat!="undefined"?
"styleFloat":"float";return function(a){return a=="float"?g:a.replace(/-./g,function(g){return g.substr(1).toUpperCase()})}}(),buildStyleHtml:function(a){for(var a=[].concat(a),g,d=[],b=0;b<a.length;b++)if(g=a[b])/@import|[{}]/.test(g)?d.push("<style>"+g+"</style>"):d.push('<link type="text/css" rel=stylesheet href="'+g+'">');return d.join("")},htmlEncode:function(a){return a===void 0||a===null?"":(""+a).replace(b,"&amp;").replace(c,"&gt;").replace(f,"&lt;")},htmlDecode:function(a){return a.replace(i,
j)},htmlEncodeAttr:function(a){return CKEDITOR.tools.htmlEncode(a).replace(k,"&quot;")},htmlDecodeAttr:function(a){return CKEDITOR.tools.htmlDecode(a)},transformPlainTextToHtml:function(a,g){var d=g==CKEDITOR.ENTER_BR,b=this.htmlEncode(a.replace(/\r\n/g,"\n")),b=b.replace(/\t/g,"&nbsp;&nbsp; &nbsp;"),j=g==CKEDITOR.ENTER_P?"p":"div";if(!d){var c=/\n{2}/g;if(c.test(b))var f="<"+j+">",e="</"+j+">",b=f+b.replace(c,function(){return e+f})+e}b=b.replace(/\n/g,"<br>");d||(b=b.replace(RegExp("<br>(?=</"+
j+">)"),function(g){return CKEDITOR.tools.repeat(g,2)}));b=b.replace(/^ | $/g,"&nbsp;");return b=b.replace(/(>|\s) /g,function(g,a){return a+"&nbsp;"}).replace(/ (?=<)/g,"&nbsp;")},getNextNumber:function(){var a=0;return function(){return++a}}(),getNextId:function(){return"cke_"+this.getNextNumber()},getUniqueId:function(){for(var a="e",g=0;g<8;g++)a=a+Math.floor((1+Math.random())*65536).toString(16).substring(1);return a},override:function(a,g){var d=g(a);d.prototype=a.prototype;return d},setTimeout:function(a,
g,d,b,j){j||(j=window);d||(d=j);return j.setTimeout(function(){b?a.apply(d,[].concat(b)):a.apply(d)},g||0)},trim:function(){var a=/(?:^[ \t\n\r]+)|(?:[ \t\n\r]+$)/g;return function(g){return g.replace(a,"")}}(),ltrim:function(){var a=/^[ \t\n\r]+/g;return function(g){return g.replace(a,"")}}(),rtrim:function(){var a=/[ \t\n\r]+$/g;return function(g){return g.replace(a,"")}}(),indexOf:function(a,g){if(typeof g=="function")for(var d=0,b=a.length;d<b;d++){if(g(a[d]))return d}else{if(a.indexOf)return a.indexOf(g);
d=0;for(b=a.length;d<b;d++)if(a[d]===g)return d}return-1},search:function(a,g){var d=CKEDITOR.tools.indexOf(a,g);return d>=0?a[d]:null},bind:function(a,g){return function(){return a.apply(g,arguments)}},createClass:function(a){var g=a.$,d=a.base,b=a.privates||a._,j=a.proto,a=a.statics;!g&&(g=function(){d&&this.base.apply(this,arguments)});if(b)var c=g,g=function(){var g=this._||(this._={}),a;for(a in b){var d=b[a];g[a]=typeof d=="function"?CKEDITOR.tools.bind(d,this):d}c.apply(this,arguments)};if(d){g.prototype=
this.prototypedCopy(d.prototype);g.prototype.constructor=g;g.base=d;g.baseProto=d.prototype;g.prototype.base=function(){this.base=d.prototype.base;d.apply(this,arguments);this.base=arguments.callee}}j&&this.extend(g.prototype,j,true);a&&this.extend(g,a,true);return g},addFunction:function(d,g){return a.push(function(){return d.apply(g||this,arguments)})-1},removeFunction:function(d){a[d]=null},callFunction:function(d){var g=a[d];return g&&g.apply(window,Array.prototype.slice.call(arguments,1))},cssLength:function(){var a=
/^-?\d+\.?\d*px$/,g;return function(d){g=CKEDITOR.tools.trim(d+"")+"px";return a.test(g)?g:d||""}}(),convertToPx:function(){var a;return function(g){if(!a){a=CKEDITOR.dom.element.createFromHtml('<div style="position:absolute;left:-9999px;top:-9999px;margin:0px;padding:0px;border:0px;"></div>',CKEDITOR.document);CKEDITOR.document.getBody().append(a)}if(!/%$/.test(g)){a.setStyle("width",g);return a.$.clientWidth}return g}}(),repeat:function(a,g){return Array(g+1).join(a)},tryThese:function(){for(var a,
g=0,d=arguments.length;g<d;g++){var b=arguments[g];try{a=b();break}catch(j){}}return a},genKey:function(){return Array.prototype.slice.call(arguments).join("-")},defer:function(a){return function(){var g=arguments,d=this;window.setTimeout(function(){a.apply(d,g)},0)}},normalizeCssText:function(a,g){var d=[],b,j=CKEDITOR.tools.parseCssText(a,true,g);for(b in j)d.push(b+":"+j[b]);d.sort();return d.length?d.join(";")+";":""},convertRgbToHex:function(a){return a.replace(/(?:rgb\(\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*\))/gi,
function(g,a,d,b){g=[a,d,b];for(a=0;a<3;a++)g[a]=("0"+parseInt(g[a],10).toString(16)).slice(-2);return"#"+g.join("")})},parseCssText:function(a,g,d){var b={};if(d){d=new CKEDITOR.dom.element("span");d.setAttribute("style",a);a=CKEDITOR.tools.convertRgbToHex(d.getAttribute("style")||"")}if(!a||a==";")return b;a.replace(/&quot;/g,'"').replace(/\s*([^:;\s]+)\s*:\s*([^;]+)\s*(?=;|$)/g,function(a,d,j){if(g){d=d.toLowerCase();d=="font-family"&&(j=j.toLowerCase().replace(/["']/g,"").replace(/\s*,\s*/g,","));
j=CKEDITOR.tools.trim(j)}b[d]=j});return b},writeCssText:function(a,g){var d,b=[];for(d in a)b.push(d+":"+a[d]);g&&b.sort();return b.join("; ")},objectCompare:function(a,g,d){var b;if(!a&&!g)return true;if(!a||!g)return false;for(b in a)if(a[b]!=g[b])return false;if(!d)for(b in g)if(a[b]!=g[b])return false;return true},objectKeys:function(a){var g=[],d;for(d in a)g.push(d);return g},convertArrayToObject:function(a,g){var d={};arguments.length==1&&(g=true);for(var b=0,j=a.length;b<j;++b)d[a[b]]=g;
return d},fixDomain:function(){for(var a;;)try{a=window.parent.document.domain;break}catch(g){a=a?a.replace(/.+?(?:\.|$)/,""):document.domain;if(!a)break;document.domain=a}return!!a},eventsBuffer:function(a,g,d){function b(){c=(new Date).getTime();j=false;d?g.call(d):g()}var j,c=0;return{input:function(){if(!j){var g=(new Date).getTime()-c;g<a?j=setTimeout(b,a-g):b()}},reset:function(){j&&clearTimeout(j);j=c=0}}},enableHtml5Elements:function(a,g){for(var d=["abbr","article","aside","audio","bdi",
"canvas","data","datalist","details","figcaption","figure","footer","header","hgroup","main","mark","meter","nav","output","progress","section","summary","time","video"],b=d.length,j;b--;){j=a.createElement(d[b]);g&&a.appendChild(j)}},checkIfAnyArrayItemMatches:function(a,g){for(var d=0,b=a.length;d<b;++d)if(a[d].match(g))return true;return false},checkIfAnyObjectPropertyMatches:function(a,g){for(var d in a)if(d.match(g))return true;return false},transparentImageData:"data:image/gif;base64,R0lGODlhAQABAPABAP///wAAACH5BAEKAAAALAAAAAABAAEAAAICRAEAOw=="}}(),
CKEDITOR.dtd=function(){var a=CKEDITOR.tools.extend,e=function(a,g){for(var d=CKEDITOR.tools.clone(a),b=1;b<arguments.length;b++){var g=arguments[b],j;for(j in g)delete d[j]}return d},b={},c={},f={address:1,article:1,aside:1,blockquote:1,details:1,div:1,dl:1,fieldset:1,figure:1,footer:1,form:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,header:1,hgroup:1,hr:1,main:1,menu:1,nav:1,ol:1,p:1,pre:1,section:1,table:1,ul:1},k={command:1,link:1,meta:1,noscript:1,script:1,style:1},i={},d={"#":1},j={center:1,dir:1,noframes:1};
a(b,{a:1,abbr:1,area:1,audio:1,b:1,bdi:1,bdo:1,br:1,button:1,canvas:1,cite:1,code:1,command:1,datalist:1,del:1,dfn:1,em:1,embed:1,i:1,iframe:1,img:1,input:1,ins:1,kbd:1,keygen:1,label:1,map:1,mark:1,meter:1,noscript:1,object:1,output:1,progress:1,q:1,ruby:1,s:1,samp:1,script:1,select:1,small:1,span:1,strong:1,sub:1,sup:1,textarea:1,time:1,u:1,"var":1,video:1,wbr:1},d,{acronym:1,applet:1,basefont:1,big:1,font:1,isindex:1,strike:1,style:1,tt:1});a(c,f,b,j);e={a:e(b,{a:1,button:1}),abbr:b,address:c,
area:i,article:c,aside:c,audio:a({source:1,track:1},c),b:b,base:i,bdi:b,bdo:b,blockquote:c,body:c,br:i,button:e(b,{a:1,button:1}),canvas:b,caption:c,cite:b,code:b,col:i,colgroup:{col:1},command:i,datalist:a({option:1},b),dd:c,del:b,details:a({summary:1},c),dfn:b,div:c,dl:{dt:1,dd:1},dt:c,em:b,embed:i,fieldset:a({legend:1},c),figcaption:c,figure:a({figcaption:1},c),footer:c,form:c,h1:b,h2:b,h3:b,h4:b,h5:b,h6:b,head:a({title:1,base:1},k),header:c,hgroup:{h1:1,h2:1,h3:1,h4:1,h5:1,h6:1},hr:i,html:a({head:1,
body:1},c,k),i:b,iframe:d,img:i,input:i,ins:b,kbd:b,keygen:i,label:b,legend:b,li:c,link:i,main:c,map:c,mark:b,menu:a({li:1},c),meta:i,meter:e(b,{meter:1}),nav:c,noscript:a({link:1,meta:1,style:1},b),object:a({param:1},b),ol:{li:1},optgroup:{option:1},option:d,output:b,p:b,param:i,pre:b,progress:e(b,{progress:1}),q:b,rp:b,rt:b,ruby:a({rp:1,rt:1},b),s:b,samp:b,script:d,section:c,select:{optgroup:1,option:1},small:b,source:i,span:b,strong:b,style:d,sub:b,summary:b,sup:b,table:{caption:1,colgroup:1,thead:1,
tfoot:1,tbody:1,tr:1},tbody:{tr:1},td:c,textarea:d,tfoot:{tr:1},th:c,thead:{tr:1},time:e(b,{time:1}),title:d,tr:{th:1,td:1},track:i,u:b,ul:{li:1},"var":b,video:a({source:1,track:1},c),wbr:i,acronym:b,applet:a({param:1},c),basefont:i,big:b,center:c,dialog:i,dir:{li:1},font:b,isindex:i,noframes:c,strike:b,tt:b};a(e,{$block:a({audio:1,dd:1,dt:1,figcaption:1,li:1,video:1},f,j),$blockLimit:{article:1,aside:1,audio:1,body:1,caption:1,details:1,dir:1,div:1,dl:1,fieldset:1,figcaption:1,figure:1,footer:1,
form:1,header:1,hgroup:1,main:1,menu:1,nav:1,ol:1,section:1,table:1,td:1,th:1,tr:1,ul:1,video:1},$cdata:{script:1,style:1},$editable:{address:1,article:1,aside:1,blockquote:1,body:1,details:1,div:1,fieldset:1,figcaption:1,footer:1,form:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,header:1,hgroup:1,main:1,nav:1,p:1,pre:1,section:1},$empty:{area:1,base:1,basefont:1,br:1,col:1,command:1,dialog:1,embed:1,hr:1,img:1,input:1,isindex:1,keygen:1,link:1,meta:1,param:1,source:1,track:1,wbr:1},$inline:b,$list:{dl:1,ol:1,
ul:1},$listItem:{dd:1,dt:1,li:1},$nonBodyContent:a({body:1,head:1,html:1},e.head),$nonEditable:{applet:1,audio:1,button:1,embed:1,iframe:1,map:1,object:1,option:1,param:1,script:1,textarea:1,video:1},$object:{applet:1,audio:1,button:1,hr:1,iframe:1,img:1,input:1,object:1,select:1,table:1,textarea:1,video:1},$removeEmpty:{abbr:1,acronym:1,b:1,bdi:1,bdo:1,big:1,cite:1,code:1,del:1,dfn:1,em:1,font:1,i:1,ins:1,label:1,kbd:1,mark:1,meter:1,output:1,q:1,ruby:1,s:1,samp:1,small:1,span:1,strike:1,strong:1,
sub:1,sup:1,time:1,tt:1,u:1,"var":1},$tabIndex:{a:1,area:1,button:1,input:1,object:1,select:1,textarea:1},$tableContent:{caption:1,col:1,colgroup:1,tbody:1,td:1,tfoot:1,th:1,thead:1,tr:1},$transparent:{a:1,audio:1,canvas:1,del:1,ins:1,map:1,noscript:1,object:1,video:1},$intermediate:{caption:1,colgroup:1,dd:1,dt:1,figcaption:1,legend:1,li:1,optgroup:1,option:1,rp:1,rt:1,summary:1,tbody:1,td:1,tfoot:1,th:1,thead:1,tr:1}});return e}(),CKEDITOR.dom.event=function(a){this.$=a},CKEDITOR.dom.event.prototype=
{getKey:function(){return this.$.keyCode||this.$.which},getKeystroke:function(){var a=this.getKey();if(this.$.ctrlKey||this.$.metaKey)a=a+CKEDITOR.CTRL;this.$.shiftKey&&(a=a+CKEDITOR.SHIFT);this.$.altKey&&(a=a+CKEDITOR.ALT);return a},preventDefault:function(a){var e=this.$;e.preventDefault?e.preventDefault():e.returnValue=false;a&&this.stopPropagation()},stopPropagation:function(){var a=this.$;a.stopPropagation?a.stopPropagation():a.cancelBubble=true},getTarget:function(){var a=this.$.target||this.$.srcElement;
return a?new CKEDITOR.dom.node(a):null},getPhase:function(){return this.$.eventPhase||2},getPageOffset:function(){var a=this.getTarget().getDocument().$;return{x:this.$.pageX||this.$.clientX+(a.documentElement.scrollLeft||a.body.scrollLeft),y:this.$.pageY||this.$.clientY+(a.documentElement.scrollTop||a.body.scrollTop)}}},CKEDITOR.CTRL=1114112,CKEDITOR.SHIFT=2228224,CKEDITOR.ALT=4456448,CKEDITOR.EVENT_PHASE_CAPTURING=1,CKEDITOR.EVENT_PHASE_AT_TARGET=2,CKEDITOR.EVENT_PHASE_BUBBLING=3,CKEDITOR.dom.domObject=
function(a){if(a)this.$=a},CKEDITOR.dom.domObject.prototype=function(){var a=function(a,b){return function(c){typeof CKEDITOR!="undefined"&&a.fire(b,new CKEDITOR.dom.event(c))}};return{getPrivate:function(){var a;if(!(a=this.getCustomData("_")))this.setCustomData("_",a={});return a},on:function(e){var b=this.getCustomData("_cke_nativeListeners");if(!b){b={};this.setCustomData("_cke_nativeListeners",b)}if(!b[e]){b=b[e]=a(this,e);this.$.addEventListener?this.$.addEventListener(e,b,!!CKEDITOR.event.useCapture):
this.$.attachEvent&&this.$.attachEvent("on"+e,b)}return CKEDITOR.event.prototype.on.apply(this,arguments)},removeListener:function(a){CKEDITOR.event.prototype.removeListener.apply(this,arguments);if(!this.hasListeners(a)){var b=this.getCustomData("_cke_nativeListeners"),c=b&&b[a];if(c){this.$.removeEventListener?this.$.removeEventListener(a,c,false):this.$.detachEvent&&this.$.detachEvent("on"+a,c);delete b[a]}}},removeAllListeners:function(){var a=this.getCustomData("_cke_nativeListeners"),b;for(b in a){var c=
a[b];this.$.detachEvent?this.$.detachEvent("on"+b,c):this.$.removeEventListener&&this.$.removeEventListener(b,c,false);delete a[b]}CKEDITOR.event.prototype.removeAllListeners.call(this)}}}(),function(a){var e={};CKEDITOR.on("reset",function(){e={}});a.equals=function(a){try{return a&&a.$===this.$}catch(c){return false}};a.setCustomData=function(a,c){var f=this.getUniqueId();(e[f]||(e[f]={}))[a]=c;return this};a.getCustomData=function(a){var c=this.$["data-cke-expando"];return(c=c&&e[c])&&a in c?c[a]:
null};a.removeCustomData=function(a){var c=this.$["data-cke-expando"],c=c&&e[c],f,k;if(c){f=c[a];k=a in c;delete c[a]}return k?f:null};a.clearCustomData=function(){this.removeAllListeners();var a=this.$["data-cke-expando"];a&&delete e[a]};a.getUniqueId=function(){return this.$["data-cke-expando"]||(this.$["data-cke-expando"]=CKEDITOR.tools.getNextNumber())};CKEDITOR.event.implementOn(a)}(CKEDITOR.dom.domObject.prototype),CKEDITOR.dom.node=function(a){return a?new CKEDITOR.dom[a.nodeType==CKEDITOR.NODE_DOCUMENT?
"document":a.nodeType==CKEDITOR.NODE_ELEMENT?"element":a.nodeType==CKEDITOR.NODE_TEXT?"text":a.nodeType==CKEDITOR.NODE_COMMENT?"comment":a.nodeType==CKEDITOR.NODE_DOCUMENT_FRAGMENT?"documentFragment":"domObject"](a):this},CKEDITOR.dom.node.prototype=new CKEDITOR.dom.domObject,CKEDITOR.NODE_ELEMENT=1,CKEDITOR.NODE_DOCUMENT=9,CKEDITOR.NODE_TEXT=3,CKEDITOR.NODE_COMMENT=8,CKEDITOR.NODE_DOCUMENT_FRAGMENT=11,CKEDITOR.POSITION_IDENTICAL=0,CKEDITOR.POSITION_DISCONNECTED=1,CKEDITOR.POSITION_FOLLOWING=2,CKEDITOR.POSITION_PRECEDING=
4,CKEDITOR.POSITION_IS_CONTAINED=8,CKEDITOR.POSITION_CONTAINS=16,CKEDITOR.tools.extend(CKEDITOR.dom.node.prototype,{appendTo:function(a,e){a.append(this,e);return a},clone:function(a,e){function b(c){c["data-cke-expando"]&&(c["data-cke-expando"]=false);if(!(c.nodeType!=CKEDITOR.NODE_ELEMENT&&c.nodeType!=CKEDITOR.NODE_DOCUMENT_FRAGMENT)){!e&&c.nodeType==CKEDITOR.NODE_ELEMENT&&c.removeAttribute("id",false);if(a)for(var c=c.childNodes,f=0;f<c.length;f++)b(c[f])}}function c(b){if(!(b.type!=CKEDITOR.NODE_ELEMENT&&
b.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT)){if(b.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var f=b.getName();f[0]==":"&&b.renameNode(f.substring(1))}if(a)for(f=0;f<b.getChildCount();f++)c(b.getChild(f))}}var f=this.$.cloneNode(a);b(f);f=new CKEDITOR.dom.node(f);CKEDITOR.env.ie&&(CKEDITOR.env.version<9&&(this.type==CKEDITOR.NODE_ELEMENT||this.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT))&&c(f);return f},hasPrevious:function(){return!!this.$.previousSibling},hasNext:function(){return!!this.$.nextSibling},insertAfter:function(a){a.$.parentNode.insertBefore(this.$,
a.$.nextSibling);return a},insertBefore:function(a){a.$.parentNode.insertBefore(this.$,a.$);return a},insertBeforeMe:function(a){this.$.parentNode.insertBefore(a.$,this.$);return a},getAddress:function(a){for(var e=[],b=this.getDocument().$.documentElement,c=this.$;c&&c!=b;){var f=c.parentNode;f&&e.unshift(this.getIndex.call({$:c},a));c=f}return e},getDocument:function(){return new CKEDITOR.dom.document(this.$.ownerDocument||this.$.parentNode.ownerDocument)},getIndex:function(a){function e(a,b){var d=
b?a.nextSibling:a.previousSibling;return!d||d.nodeType!=CKEDITOR.NODE_TEXT?null:d.nodeValue?d:e(d,b)}var b=this.$,c=-1,f;if(!this.$.parentNode||a&&b.nodeType==CKEDITOR.NODE_TEXT&&!b.nodeValue&&!e(b)&&!e(b,true))return-1;do if(!a||!(b!=this.$&&b.nodeType==CKEDITOR.NODE_TEXT&&(f||!b.nodeValue))){c++;f=b.nodeType==CKEDITOR.NODE_TEXT}while(b=b.previousSibling);return c},getNextSourceNode:function(a,e,b){if(b&&!b.call)var c=b,b=function(a){return!a.equals(c)};var a=!a&&this.getFirst&&this.getFirst(),f;
if(!a){if(this.type==CKEDITOR.NODE_ELEMENT&&b&&b(this,true)===false)return null;a=this.getNext()}for(;!a&&(f=(f||this).getParent());){if(b&&b(f,true)===false)return null;a=f.getNext()}return!a||b&&b(a)===false?null:e&&e!=a.type?a.getNextSourceNode(false,e,b):a},getPreviousSourceNode:function(a,e,b){if(b&&!b.call)var c=b,b=function(a){return!a.equals(c)};var a=!a&&this.getLast&&this.getLast(),f;if(!a){if(this.type==CKEDITOR.NODE_ELEMENT&&b&&b(this,true)===false)return null;a=this.getPrevious()}for(;!a&&
(f=(f||this).getParent());){if(b&&b(f,true)===false)return null;a=f.getPrevious()}return!a||b&&b(a)===false?null:e&&a.type!=e?a.getPreviousSourceNode(false,e,b):a},getPrevious:function(a){var e=this.$,b;do b=(e=e.previousSibling)&&e.nodeType!=10&&new CKEDITOR.dom.node(e);while(b&&a&&!a(b));return b},getNext:function(a){var e=this.$,b;do b=(e=e.nextSibling)&&new CKEDITOR.dom.node(e);while(b&&a&&!a(b));return b},getParent:function(a){var e=this.$.parentNode;return e&&(e.nodeType==CKEDITOR.NODE_ELEMENT||
a&&e.nodeType==CKEDITOR.NODE_DOCUMENT_FRAGMENT)?new CKEDITOR.dom.node(e):null},getParents:function(a){var e=this,b=[];do b[a?"push":"unshift"](e);while(e=e.getParent());return b},getCommonAncestor:function(a){if(a.equals(this))return this;if(a.contains&&a.contains(this))return a;var e=this.contains?this:this.getParent();do if(e.contains(a))return e;while(e=e.getParent());return null},getPosition:function(a){var e=this.$,b=a.$;if(e.compareDocumentPosition)return e.compareDocumentPosition(b);if(e==
b)return CKEDITOR.POSITION_IDENTICAL;if(this.type==CKEDITOR.NODE_ELEMENT&&a.type==CKEDITOR.NODE_ELEMENT){if(e.contains){if(e.contains(b))return CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_PRECEDING;if(b.contains(e))return CKEDITOR.POSITION_IS_CONTAINED+CKEDITOR.POSITION_FOLLOWING}if("sourceIndex"in e)return e.sourceIndex<0||b.sourceIndex<0?CKEDITOR.POSITION_DISCONNECTED:e.sourceIndex<b.sourceIndex?CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_FOLLOWING}for(var e=this.getAddress(),a=a.getAddress(),
b=Math.min(e.length,a.length),c=0;c<b;c++)if(e[c]!=a[c])return e[c]<a[c]?CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_FOLLOWING;return e.length<a.length?CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_PRECEDING:CKEDITOR.POSITION_IS_CONTAINED+CKEDITOR.POSITION_FOLLOWING},getAscendant:function(a,e){var b=this.$,c,f;if(!e)b=b.parentNode;if(typeof a=="function"){f=true;c=a}else{f=false;c=function(b){b=typeof b.nodeName=="string"?b.nodeName.toLowerCase():"";return typeof a=="string"?b==a:b in a}}for(;b;){if(c(f?
new CKEDITOR.dom.node(b):b))return new CKEDITOR.dom.node(b);try{b=b.parentNode}catch(k){b=null}}return null},hasAscendant:function(a,e){var b=this.$;if(!e)b=b.parentNode;for(;b;){if(b.nodeName&&b.nodeName.toLowerCase()==a)return true;b=b.parentNode}return false},move:function(a,e){a.append(this.remove(),e)},remove:function(a){var e=this.$,b=e.parentNode;if(b){if(a)for(;a=e.firstChild;)b.insertBefore(e.removeChild(a),e);b.removeChild(e)}return this},replace:function(a){this.insertBefore(a);a.remove()},
trim:function(){this.ltrim();this.rtrim()},ltrim:function(){for(var a;this.getFirst&&(a=this.getFirst());){if(a.type==CKEDITOR.NODE_TEXT){var e=CKEDITOR.tools.ltrim(a.getText()),b=a.getLength();if(e){if(e.length<b){a.split(b-e.length);this.$.removeChild(this.$.firstChild)}}else{a.remove();continue}}break}},rtrim:function(){for(var a;this.getLast&&(a=this.getLast());){if(a.type==CKEDITOR.NODE_TEXT){var e=CKEDITOR.tools.rtrim(a.getText()),b=a.getLength();if(e){if(e.length<b){a.split(e.length);this.$.lastChild.parentNode.removeChild(this.$.lastChild)}}else{a.remove();
continue}}break}if(CKEDITOR.env.needsBrFiller)(a=this.$.lastChild)&&(a.type==1&&a.nodeName.toLowerCase()=="br")&&a.parentNode.removeChild(a)},isReadOnly:function(a){var e=this;this.type!=CKEDITOR.NODE_ELEMENT&&(e=this.getParent());CKEDITOR.env.edge&&(e&&e.is("textarea"))&&(a=true);if(!a&&e&&typeof e.$.isContentEditable!="undefined")return!(e.$.isContentEditable||e.data("cke-editable"));for(;e;){if(e.data("cke-editable"))return false;if(e.hasAttribute("contenteditable"))return e.getAttribute("contenteditable")==
"false";e=e.getParent()}return true}}),CKEDITOR.dom.window=function(a){CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.window.prototype=new CKEDITOR.dom.domObject,CKEDITOR.tools.extend(CKEDITOR.dom.window.prototype,{focus:function(){this.$.focus()},getViewPaneSize:function(){var a=this.$.document,e=a.compatMode=="CSS1Compat";return{width:(e?a.documentElement.clientWidth:a.body.clientWidth)||0,height:(e?a.documentElement.clientHeight:a.body.clientHeight)||0}},getScrollPosition:function(){var a=this.$;
if("pageXOffset"in a)return{x:a.pageXOffset||0,y:a.pageYOffset||0};a=a.document;return{x:a.documentElement.scrollLeft||a.body.scrollLeft||0,y:a.documentElement.scrollTop||a.body.scrollTop||0}},getFrame:function(){var a=this.$.frameElement;return a?new CKEDITOR.dom.element.get(a):null}}),CKEDITOR.dom.document=function(a){CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.document.prototype=new CKEDITOR.dom.domObject,CKEDITOR.tools.extend(CKEDITOR.dom.document.prototype,{type:CKEDITOR.NODE_DOCUMENT,
appendStyleSheet:function(a){if(this.$.createStyleSheet)this.$.createStyleSheet(a);else{var e=new CKEDITOR.dom.element("link");e.setAttributes({rel:"stylesheet",type:"text/css",href:a});this.getHead().append(e)}},appendStyleText:function(a){if(this.$.createStyleSheet){var e=this.$.createStyleSheet("");e.cssText=a}else{var b=new CKEDITOR.dom.element("style",this);b.append(new CKEDITOR.dom.text(a,this));this.getHead().append(b)}return e||b.$.sheet},createElement:function(a,e){var b=new CKEDITOR.dom.element(a,
this);if(e){e.attributes&&b.setAttributes(e.attributes);e.styles&&b.setStyles(e.styles)}return b},createText:function(a){return new CKEDITOR.dom.text(a,this)},focus:function(){this.getWindow().focus()},getActive:function(){var a;try{a=this.$.activeElement}catch(e){return null}return new CKEDITOR.dom.element(a)},getById:function(a){return(a=this.$.getElementById(a))?new CKEDITOR.dom.element(a):null},getByAddress:function(a,e){for(var b=this.$.documentElement,c=0;b&&c<a.length;c++){var f=a[c];if(e)for(var k=
-1,i=0;i<b.childNodes.length;i++){var d=b.childNodes[i];if(!(e===true&&d.nodeType==3&&d.previousSibling&&d.previousSibling.nodeType==3)){k++;if(k==f){b=d;break}}}else b=b.childNodes[f]}return b?new CKEDITOR.dom.node(b):null},getElementsByTag:function(a,e){!(CKEDITOR.env.ie&&document.documentMode<=8)&&e&&(a=e+":"+a);return new CKEDITOR.dom.nodeList(this.$.getElementsByTagName(a))},getHead:function(){var a=this.$.getElementsByTagName("head")[0];return a=a?new CKEDITOR.dom.element(a):this.getDocumentElement().append(new CKEDITOR.dom.element("head"),
true)},getBody:function(){return new CKEDITOR.dom.element(this.$.body)},getDocumentElement:function(){return new CKEDITOR.dom.element(this.$.documentElement)},getWindow:function(){return new CKEDITOR.dom.window(this.$.parentWindow||this.$.defaultView)},write:function(a){this.$.open("text/html","replace");CKEDITOR.env.ie&&(a=a.replace(/(?:^\s*<!DOCTYPE[^>]*?>)|^/i,'$&\n<script data-cke-temp="1">('+CKEDITOR.tools.fixDomain+")();<\/script>"));this.$.write(a);this.$.close()},find:function(a){return new CKEDITOR.dom.nodeList(this.$.querySelectorAll(a))},
findOne:function(a){return(a=this.$.querySelector(a))?new CKEDITOR.dom.element(a):null},_getHtml5ShivFrag:function(){var a=this.getCustomData("html5ShivFrag");if(!a){a=this.$.createDocumentFragment();CKEDITOR.tools.enableHtml5Elements(a,true);this.setCustomData("html5ShivFrag",a)}return a}}),CKEDITOR.dom.nodeList=function(a){this.$=a},CKEDITOR.dom.nodeList.prototype={count:function(){return this.$.length},getItem:function(a){if(a<0||a>=this.$.length)return null;return(a=this.$[a])?new CKEDITOR.dom.node(a):
null}},CKEDITOR.dom.element=function(a,e){typeof a=="string"&&(a=(e?e.$:document).createElement(a));CKEDITOR.dom.domObject.call(this,a)},CKEDITOR.dom.element.get=function(a){return(a=typeof a=="string"?document.getElementById(a)||document.getElementsByName(a)[0]:a)&&(a.$?a:new CKEDITOR.dom.element(a))},CKEDITOR.dom.element.prototype=new CKEDITOR.dom.node,CKEDITOR.dom.element.createFromHtml=function(a,e){var b=new CKEDITOR.dom.element("div",e);b.setHtml(a);return b.getFirst().remove()},CKEDITOR.dom.element.setMarker=
function(a,e,b,c){var f=e.getCustomData("list_marker_id")||e.setCustomData("list_marker_id",CKEDITOR.tools.getNextNumber()).getCustomData("list_marker_id"),k=e.getCustomData("list_marker_names")||e.setCustomData("list_marker_names",{}).getCustomData("list_marker_names");a[f]=e;k[b]=1;return e.setCustomData(b,c)},CKEDITOR.dom.element.clearAllMarkers=function(a){for(var e in a)CKEDITOR.dom.element.clearMarkers(a,a[e],1)},CKEDITOR.dom.element.clearMarkers=function(a,e,b){var c=e.getCustomData("list_marker_names"),
f=e.getCustomData("list_marker_id"),k;for(k in c)e.removeCustomData(k);e.removeCustomData("list_marker_names");if(b){e.removeCustomData("list_marker_id");delete a[f]}},function(){function a(a,b){return(" "+a+" ").replace(k," ").indexOf(" "+b+" ")>-1}function e(a){var b=true;if(!a.$.id){a.$.id="cke_tmp_"+CKEDITOR.tools.getNextNumber();b=false}return function(){b||a.removeAttribute("id")}}function b(a,b){return"#"+a.$.id+" "+b.split(/,\s*/).join(", #"+a.$.id+" ")}function c(a){for(var b=0,c=0,g=i[a].length;c<
g;c++)b=b+(parseInt(this.getComputedStyle(i[a][c])||0,10)||0);return b}var f=!!document.createElement("span").classList,k=/[\n\t\r]/g;CKEDITOR.tools.extend(CKEDITOR.dom.element.prototype,{type:CKEDITOR.NODE_ELEMENT,addClass:f?function(a){this.$.classList.add(a);return this}:function(d){var b=this.$.className;b&&(a(b,d)||(b=b+(" "+d)));this.$.className=b||d;return this},removeClass:f?function(a){var b=this.$;b.classList.remove(a);b.className||b.removeAttribute("class");return this}:function(d){var b=
this.getAttribute("class");if(b&&a(b,d))(b=b.replace(RegExp("(?:^|\\s+)"+d+"(?=\\s|$)"),"").replace(/^\s+/,""))?this.setAttribute("class",b):this.removeAttribute("class");return this},hasClass:function(d){return a(this.$.className,d)},append:function(a,b){typeof a=="string"&&(a=this.getDocument().createElement(a));b?this.$.insertBefore(a.$,this.$.firstChild):this.$.appendChild(a.$);return a},appendHtml:function(a){if(this.$.childNodes.length){var b=new CKEDITOR.dom.element("div",this.getDocument());
b.setHtml(a);b.moveChildren(this)}else this.setHtml(a)},appendText:function(a){this.$.text!=null&&CKEDITOR.env.ie&&CKEDITOR.env.version<9?this.$.text=this.$.text+a:this.append(new CKEDITOR.dom.text(a))},appendBogus:function(a){if(a||CKEDITOR.env.needsBrFiller){for(a=this.getLast();a&&a.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.rtrim(a.getText());)a=a.getPrevious();if(!a||!a.is||!a.is("br")){a=this.getDocument().createElement("br");CKEDITOR.env.gecko&&a.setAttribute("type","_moz");this.append(a)}}},
breakParent:function(a,b){var c=new CKEDITOR.dom.range(this.getDocument());c.setStartAfter(this);c.setEndAfter(a);var g=c.extractContents(false,b||false);c.insertNode(this.remove());g.insertAfterNode(this)},contains:!document.compareDocumentPosition?function(a){var b=this.$;return a.type!=CKEDITOR.NODE_ELEMENT?b.contains(a.getParent().$):b!=a.$&&b.contains(a.$)}:function(a){return!!(this.$.compareDocumentPosition(a.$)&16)},focus:function(){function a(){try{this.$.focus()}catch(d){}}return function(b){b?
CKEDITOR.tools.setTimeout(a,100,this):a.call(this)}}(),getHtml:function(){var a=this.$.innerHTML;return CKEDITOR.env.ie?a.replace(/<\?[^>]*>/g,""):a},getOuterHtml:function(){if(this.$.outerHTML)return this.$.outerHTML.replace(/<\?[^>]*>/,"");var a=this.$.ownerDocument.createElement("div");a.appendChild(this.$.cloneNode(true));return a.innerHTML},getClientRect:function(){var a=CKEDITOR.tools.extend({},this.$.getBoundingClientRect());!a.width&&(a.width=a.right-a.left);!a.height&&(a.height=a.bottom-
a.top);return a},setHtml:CKEDITOR.env.ie&&CKEDITOR.env.version<9?function(a){try{var b=this.$;if(this.getParent())return b.innerHTML=a;var c=this.getDocument()._getHtml5ShivFrag();c.appendChild(b);b.innerHTML=a;c.removeChild(b);return a}catch(g){this.$.innerHTML="";b=new CKEDITOR.dom.element("body",this.getDocument());b.$.innerHTML=a;for(b=b.getChildren();b.count();)this.append(b.getItem(0));return a}}:function(a){return this.$.innerHTML=a},setText:function(){var a=document.createElement("p");a.innerHTML=
"x";a=a.textContent;return function(b){this.$[a?"textContent":"innerText"]=b}}(),getAttribute:function(){var a=function(a){return this.$.getAttribute(a,2)};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(a){switch(a){case "class":a="className";break;case "http-equiv":a="httpEquiv";break;case "name":return this.$.name;case "tabindex":a=this.$.getAttribute(a,2);a!==0&&this.$.tabIndex===0&&(a=null);return a;case "checked":a=this.$.attributes.getNamedItem(a);return(a.specified?
a.nodeValue:this.$.checked)?"checked":null;case "hspace":case "value":return this.$[a];case "style":return this.$.style.cssText;case "contenteditable":case "contentEditable":return this.$.attributes.getNamedItem("contentEditable").specified?this.$.getAttribute("contentEditable"):null}return this.$.getAttribute(a,2)}:a}(),getChildren:function(){return new CKEDITOR.dom.nodeList(this.$.childNodes)},getComputedStyle:document.defaultView&&document.defaultView.getComputedStyle?function(a){var b=this.getWindow().$.getComputedStyle(this.$,
null);return b?b.getPropertyValue(a):""}:function(a){return this.$.currentStyle[CKEDITOR.tools.cssStyleToDomStyle(a)]},getDtd:function(){var a=CKEDITOR.dtd[this.getName()];this.getDtd=function(){return a};return a},getElementsByTag:CKEDITOR.dom.document.prototype.getElementsByTag,getTabIndex:function(){var a=this.$.tabIndex;return a===0&&!CKEDITOR.dtd.$tabIndex[this.getName()]&&parseInt(this.getAttribute("tabindex"),10)!==0?-1:a},getText:function(){return this.$.textContent||this.$.innerText||""},
getWindow:function(){return this.getDocument().getWindow()},getId:function(){return this.$.id||null},getNameAtt:function(){return this.$.name||null},getName:function(){var a=this.$.nodeName.toLowerCase();if(CKEDITOR.env.ie&&document.documentMode<=8){var b=this.$.scopeName;b!="HTML"&&(a=b.toLowerCase()+":"+a)}this.getName=function(){return a};return this.getName()},getValue:function(){return this.$.value},getFirst:function(a){var b=this.$.firstChild;(b=b&&new CKEDITOR.dom.node(b))&&(a&&!a(b))&&(b=
b.getNext(a));return b},getLast:function(a){var b=this.$.lastChild;(b=b&&new CKEDITOR.dom.node(b))&&(a&&!a(b))&&(b=b.getPrevious(a));return b},getStyle:function(a){return this.$.style[CKEDITOR.tools.cssStyleToDomStyle(a)]},is:function(){var a=this.getName();if(typeof arguments[0]=="object")return!!arguments[0][a];for(var b=0;b<arguments.length;b++)if(arguments[b]==a)return true;return false},isEditable:function(a){var b=this.getName();if(this.isReadOnly()||this.getComputedStyle("display")=="none"||
this.getComputedStyle("visibility")=="hidden"||CKEDITOR.dtd.$nonEditable[b]||CKEDITOR.dtd.$empty[b]||this.is("a")&&(this.data("cke-saved-name")||this.hasAttribute("name"))&&!this.getChildCount())return false;if(a!==false){a=CKEDITOR.dtd[b]||CKEDITOR.dtd.span;return!(!a||!a["#"])}return true},isIdentical:function(a){var b=this.clone(0,1),a=a.clone(0,1);b.removeAttributes(["_moz_dirty","data-cke-expando","data-cke-saved-href","data-cke-saved-name"]);a.removeAttributes(["_moz_dirty","data-cke-expando",
"data-cke-saved-href","data-cke-saved-name"]);if(b.$.isEqualNode){b.$.style.cssText=CKEDITOR.tools.normalizeCssText(b.$.style.cssText);a.$.style.cssText=CKEDITOR.tools.normalizeCssText(a.$.style.cssText);return b.$.isEqualNode(a.$)}b=b.getOuterHtml();a=a.getOuterHtml();if(CKEDITOR.env.ie&&CKEDITOR.env.version<9&&this.is("a")){var c=this.getParent();if(c.type==CKEDITOR.NODE_ELEMENT){c=c.clone();c.setHtml(b);b=c.getHtml();c.setHtml(a);a=c.getHtml()}}return b==a},isVisible:function(){var a=(this.$.offsetHeight||
this.$.offsetWidth)&&this.getComputedStyle("visibility")!="hidden",b,c;if(a&&CKEDITOR.env.webkit){b=this.getWindow();if(!b.equals(CKEDITOR.document.getWindow())&&(c=b.$.frameElement))a=(new CKEDITOR.dom.element(c)).isVisible()}return!!a},isEmptyInlineRemoveable:function(){if(!CKEDITOR.dtd.$removeEmpty[this.getName()])return false;for(var a=this.getChildren(),b=0,c=a.count();b<c;b++){var g=a.getItem(b);if(!(g.type==CKEDITOR.NODE_ELEMENT&&g.data("cke-bookmark"))&&(g.type==CKEDITOR.NODE_ELEMENT&&!g.isEmptyInlineRemoveable()||
g.type==CKEDITOR.NODE_TEXT&&CKEDITOR.tools.trim(g.getText())))return false}return true},hasAttributes:CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(){for(var a=this.$.attributes,b=0;b<a.length;b++){var c=a[b];switch(c.nodeName){case "class":if(this.getAttribute("class"))return true;case "data-cke-expando":continue;default:if(c.specified)return true}}return false}:function(){var a=this.$.attributes,b=a.length,c={"data-cke-expando":1,_moz_dirty:1};return b>0&&(b>2||!c[a[0].nodeName]||
b==2&&!c[a[1].nodeName])},hasAttribute:function(){function a(b){var d=this.$.attributes.getNamedItem(b);if(this.getName()=="input")switch(b){case "class":return this.$.className.length>0;case "checked":return!!this.$.checked;case "value":b=this.getAttribute("type");return b=="checkbox"||b=="radio"?this.$.value!="on":!!this.$.value}return!d?false:d.specified}return CKEDITOR.env.ie?CKEDITOR.env.version<8?function(b){return b=="name"?!!this.$.name:a.call(this,b)}:a:function(a){return!!this.$.attributes.getNamedItem(a)}}(),
hide:function(){this.setStyle("display","none")},moveChildren:function(a,b){var c=this.$,a=a.$;if(c!=a){var g;if(b)for(;g=c.lastChild;)a.insertBefore(c.removeChild(g),a.firstChild);else for(;g=c.firstChild;)a.appendChild(c.removeChild(g))}},mergeSiblings:function(){function a(b,d,g){if(d&&d.type==CKEDITOR.NODE_ELEMENT){for(var c=[];d.data("cke-bookmark")||d.isEmptyInlineRemoveable();){c.push(d);d=g?d.getNext():d.getPrevious();if(!d||d.type!=CKEDITOR.NODE_ELEMENT)return}if(b.isIdentical(d)){for(var f=
g?b.getLast():b.getFirst();c.length;)c.shift().move(b,!g);d.moveChildren(b,!g);d.remove();f&&f.type==CKEDITOR.NODE_ELEMENT&&f.mergeSiblings()}}}return function(b){if(b===false||CKEDITOR.dtd.$removeEmpty[this.getName()]||this.is("a")){a(this,this.getNext(),true);a(this,this.getPrevious())}}}(),show:function(){this.setStyles({display:"",visibility:""})},setAttribute:function(){var a=function(a,b){this.$.setAttribute(a,b);return this};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?
function(b,c){b=="class"?this.$.className=c:b=="style"?this.$.style.cssText=c:b=="tabindex"?this.$.tabIndex=c:b=="checked"?this.$.checked=c:b=="contenteditable"?a.call(this,"contentEditable",c):a.apply(this,arguments);return this}:CKEDITOR.env.ie8Compat&&CKEDITOR.env.secure?function(b,c){if(b=="src"&&c.match(/^http:\/\//))try{a.apply(this,arguments)}catch(g){}else a.apply(this,arguments);return this}:a}(),setAttributes:function(a){for(var b in a)this.setAttribute(b,a[b]);return this},setValue:function(a){this.$.value=
a;return this},removeAttribute:function(){var a=function(a){this.$.removeAttribute(a)};return CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)?function(a){a=="class"?a="className":a=="tabindex"?a="tabIndex":a=="contenteditable"&&(a="contentEditable");this.$.removeAttribute(a)}:a}(),removeAttributes:function(a){if(CKEDITOR.tools.isArray(a))for(var b=0;b<a.length;b++)this.removeAttribute(a[b]);else for(b in a)a.hasOwnProperty(b)&&this.removeAttribute(b)},removeStyle:function(a){var b=
this.$.style;if(!b.removeProperty&&(a=="border"||a=="margin"||a=="padding")){var c=["top","left","right","bottom"],g;a=="border"&&(g=["color","style","width"]);for(var b=[],f=0;f<c.length;f++)if(g)for(var e=0;e<g.length;e++)b.push([a,c[f],g[e]].join("-"));else b.push([a,c[f]].join("-"));for(a=0;a<b.length;a++)this.removeStyle(b[a])}else{b.removeProperty?b.removeProperty(a):b.removeAttribute(CKEDITOR.tools.cssStyleToDomStyle(a));this.$.style.cssText||this.removeAttribute("style")}},setStyle:function(a,
b){this.$.style[CKEDITOR.tools.cssStyleToDomStyle(a)]=b;return this},setStyles:function(a){for(var b in a)this.setStyle(b,a[b]);return this},setOpacity:function(a){if(CKEDITOR.env.ie&&CKEDITOR.env.version<9){a=Math.round(a*100);this.setStyle("filter",a>=100?"":"progid:DXImageTransform.Microsoft.Alpha(opacity="+a+")")}else this.setStyle("opacity",a)},unselectable:function(){this.setStyles(CKEDITOR.tools.cssVendorPrefix("user-select","none"));if(CKEDITOR.env.ie){this.setAttribute("unselectable","on");
for(var a,b=this.getElementsByTag("*"),c=0,g=b.count();c<g;c++){a=b.getItem(c);a.setAttribute("unselectable","on")}}},getPositionedAncestor:function(){for(var a=this;a.getName()!="html";){if(a.getComputedStyle("position")!="static")return a;a=a.getParent()}return null},getDocumentPosition:function(a){var b=0,c=0,g=this.getDocument(),f=g.getBody(),e=g.$.compatMode=="BackCompat";if(document.documentElement.getBoundingClientRect){var k=this.$.getBoundingClientRect(),o=g.$.documentElement,i=o.clientTop||
f.$.clientTop||0,l=o.clientLeft||f.$.clientLeft||0,s=true;if(CKEDITOR.env.ie){s=g.getDocumentElement().contains(this);g=g.getBody().contains(this);s=e&&g||!e&&s}if(s){if(CKEDITOR.env.webkit||CKEDITOR.env.ie&&CKEDITOR.env.version>=12){b=f.$.scrollLeft||o.scrollLeft;c=f.$.scrollTop||o.scrollTop}else{c=e?f.$:o;b=c.scrollLeft;c=c.scrollTop}b=k.left+b-l;c=k.top+c-i}}else{i=this;for(l=null;i&&!(i.getName()=="body"||i.getName()=="html");){b=b+(i.$.offsetLeft-i.$.scrollLeft);c=c+(i.$.offsetTop-i.$.scrollTop);
if(!i.equals(this)){b=b+(i.$.clientLeft||0);c=c+(i.$.clientTop||0)}for(;l&&!l.equals(i);){b=b-l.$.scrollLeft;c=c-l.$.scrollTop;l=l.getParent()}l=i;i=(k=i.$.offsetParent)?new CKEDITOR.dom.element(k):null}}if(a){k=this.getWindow();i=a.getWindow();if(!k.equals(i)&&k.$.frameElement){a=(new CKEDITOR.dom.element(k.$.frameElement)).getDocumentPosition(a);b=b+a.x;c=c+a.y}}if(!document.documentElement.getBoundingClientRect&&CKEDITOR.env.gecko&&!e){b=b+(this.$.clientLeft?1:0);c=c+(this.$.clientTop?1:0)}return{x:b,
y:c}},scrollIntoView:function(a){var b=this.getParent();if(b){do{(b.$.clientWidth&&b.$.clientWidth<b.$.scrollWidth||b.$.clientHeight&&b.$.clientHeight<b.$.scrollHeight)&&!b.is("body")&&this.scrollIntoParent(b,a,1);if(b.is("html")){var c=b.getWindow();try{var g=c.$.frameElement;g&&(b=new CKEDITOR.dom.element(g))}catch(f){}}}while(b=b.getParent())}},scrollIntoParent:function(a,b,c){var g,f,e,k;function o(b,g){if(/body|html/.test(a.getName()))a.getWindow().$.scrollBy(b,g);else{a.$.scrollLeft=a.$.scrollLeft+
b;a.$.scrollTop=a.$.scrollTop+g}}function i(a,b){var g={x:0,y:0};if(!a.is(s?"body":"html")){var c=a.$.getBoundingClientRect();g.x=c.left;g.y=c.top}c=a.getWindow();if(!c.equals(b)){c=i(CKEDITOR.dom.element.get(c.$.frameElement),b);g.x=g.x+c.x;g.y=g.y+c.y}return g}function l(a,g){return parseInt(a.getComputedStyle("margin-"+g)||0,10)||0}!a&&(a=this.getWindow());e=a.getDocument();var s=e.$.compatMode=="BackCompat";a instanceof CKEDITOR.dom.window&&(a=s?e.getBody():e.getDocumentElement());e=a.getWindow();
f=i(this,e);var t=i(a,e),w=this.$.offsetHeight;g=this.$.offsetWidth;var u=a.$.clientHeight,x=a.$.clientWidth;e=f.x-l(this,"left")-t.x||0;k=f.y-l(this,"top")-t.y||0;g=f.x+g+l(this,"right")-(t.x+x)||0;f=f.y+w+l(this,"bottom")-(t.y+u)||0;if(k<0||f>0)o(0,b===true?k:b===false?f:k<0?k:f);if(c&&(e<0||g>0))o(e<0?e:g,0)},setState:function(a,b,c){b=b||"cke";switch(a){case CKEDITOR.TRISTATE_ON:this.addClass(b+"_on");this.removeClass(b+"_off");this.removeClass(b+"_disabled");c&&this.setAttribute("aria-pressed",
true);c&&this.removeAttribute("aria-disabled");break;case CKEDITOR.TRISTATE_DISABLED:this.addClass(b+"_disabled");this.removeClass(b+"_off");this.removeClass(b+"_on");c&&this.setAttribute("aria-disabled",true);c&&this.removeAttribute("aria-pressed");break;default:this.addClass(b+"_off");this.removeClass(b+"_on");this.removeClass(b+"_disabled");c&&this.removeAttribute("aria-pressed");c&&this.removeAttribute("aria-disabled")}},getFrameDocument:function(){var a=this.$;try{a.contentWindow.document}catch(b){a.src=
a.src}return a&&new CKEDITOR.dom.document(a.contentWindow.document)},copyAttributes:function(a,b){for(var c=this.$.attributes,b=b||{},g=0;g<c.length;g++){var f=c[g],e=f.nodeName.toLowerCase(),k;if(!(e in b))if(e=="checked"&&(k=this.getAttribute(e)))a.setAttribute(e,k);else if(!CKEDITOR.env.ie||this.hasAttribute(e)){k=this.getAttribute(e);if(k===null)k=f.nodeValue;a.setAttribute(e,k)}}if(this.$.style.cssText!=="")a.$.style.cssText=this.$.style.cssText},renameNode:function(a){if(this.getName()!=a){var b=
this.getDocument(),a=new CKEDITOR.dom.element(a,b);this.copyAttributes(a);this.moveChildren(a);this.getParent(true)&&this.$.parentNode.replaceChild(a.$,this.$);a.$["data-cke-expando"]=this.$["data-cke-expando"];this.$=a.$;delete this.getName}},getChild:function(){function a(b,c){var g=b.childNodes;if(c>=0&&c<g.length)return g[c]}return function(b){var c=this.$;if(b.slice)for(b=b.slice();b.length>0&&c;)c=a(c,b.shift());else c=a(c,b);return c?new CKEDITOR.dom.node(c):null}}(),getChildCount:function(){return this.$.childNodes.length},
disableContextMenu:function(){this.on("contextmenu",function(a){a.data.getTarget().hasClass("cke_enable_context_menu")||a.data.preventDefault()})},getDirection:function(a){return a?this.getComputedStyle("direction")||this.getDirection()||this.getParent()&&this.getParent().getDirection(1)||this.getDocument().$.dir||"ltr":this.getStyle("direction")||this.getAttribute("dir")},data:function(a,b){a="data-"+a;if(b===void 0)return this.getAttribute(a);b===false?this.removeAttribute(a):this.setAttribute(a,
b);return null},getEditor:function(){var a=CKEDITOR.instances,b,c;for(b in a){c=a[b];if(c.element.equals(this)&&c.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO)return c}return null},find:function(a){var c=e(this),a=new CKEDITOR.dom.nodeList(this.$.querySelectorAll(b(this,a)));c();return a},findOne:function(a){var c=e(this),a=this.$.querySelector(b(this,a));c();return a?new CKEDITOR.dom.element(a):null},forEach:function(a,b,c){if(!c&&(!b||this.type==b))var g=a(this);if(g!==false)for(var c=this.getChildren(),
f=0;f<c.count();f++){g=c.getItem(f);g.type==CKEDITOR.NODE_ELEMENT?g.forEach(a,b):(!b||g.type==b)&&a(g)}}});var i={width:["border-left-width","border-right-width","padding-left","padding-right"],height:["border-top-width","border-bottom-width","padding-top","padding-bottom"]};CKEDITOR.dom.element.prototype.setSize=function(a,b,f){if(typeof b=="number"){if(f&&(!CKEDITOR.env.ie||!CKEDITOR.env.quirks))b=b-c.call(this,a);this.setStyle(a,b+"px")}};CKEDITOR.dom.element.prototype.getSize=function(a,b){var f=
Math.max(this.$["offset"+CKEDITOR.tools.capitalize(a)],this.$["client"+CKEDITOR.tools.capitalize(a)])||0;b&&(f=f-c.call(this,a));return f}}(),CKEDITOR.dom.documentFragment=function(a){a=a||CKEDITOR.document;this.$=a.type==CKEDITOR.NODE_DOCUMENT?a.$.createDocumentFragment():a},CKEDITOR.tools.extend(CKEDITOR.dom.documentFragment.prototype,CKEDITOR.dom.element.prototype,{type:CKEDITOR.NODE_DOCUMENT_FRAGMENT,insertAfterNode:function(a){a=a.$;a.parentNode.insertBefore(this.$,a.nextSibling)},getHtml:function(){var a=
new CKEDITOR.dom.element("div");this.clone(1,1).appendTo(a);return a.getHtml().replace(/\s*data-cke-expando=".*?"/g,"")}},!0,{append:1,appendBogus:1,clone:1,getFirst:1,getHtml:1,getLast:1,getParent:1,getNext:1,getPrevious:1,appendTo:1,moveChildren:1,insertBefore:1,insertAfterNode:1,replace:1,trim:1,type:1,ltrim:1,rtrim:1,getDocument:1,getChildCount:1,getChild:1,getChildren:1}),function(){function a(a,b){var g=this.range;if(this._.end)return null;if(!this._.start){this._.start=1;if(g.collapsed){this.end();
return null}g.optimize()}var c,d=g.startContainer;c=g.endContainer;var f=g.startOffset,e=g.endOffset,h,k=this.guard,j=this.type,i=a?"getPreviousSourceNode":"getNextSourceNode";if(!a&&!this._.guardLTR){var v=c.type==CKEDITOR.NODE_ELEMENT?c:c.getParent(),q=c.type==CKEDITOR.NODE_ELEMENT?c.getChild(e):c.getNext();this._.guardLTR=function(a,b){return(!b||!v.equals(a))&&(!q||!a.equals(q))&&(a.type!=CKEDITOR.NODE_ELEMENT||!b||!a.equals(g.root))}}if(a&&!this._.guardRTL){var y=d.type==CKEDITOR.NODE_ELEMENT?
d:d.getParent(),z=d.type==CKEDITOR.NODE_ELEMENT?f?d.getChild(f-1):null:d.getPrevious();this._.guardRTL=function(a,b){return(!b||!y.equals(a))&&(!z||!a.equals(z))&&(a.type!=CKEDITOR.NODE_ELEMENT||!b||!a.equals(g.root))}}var B=a?this._.guardRTL:this._.guardLTR;h=k?function(a,b){return B(a,b)===false?false:k(a,b)}:B;if(this.current)c=this.current[i](false,j,h);else{if(a)c.type==CKEDITOR.NODE_ELEMENT&&(c=e>0?c.getChild(e-1):h(c,true)===false?null:c.getPreviousSourceNode(true,j,h));else{c=d;if(c.type==
CKEDITOR.NODE_ELEMENT&&!(c=c.getChild(f)))c=h(d,true)===false?null:d.getNextSourceNode(true,j,h)}c&&h(c)===false&&(c=null)}for(;c&&!this._.end;){this.current=c;if(!this.evaluator||this.evaluator(c)!==false){if(!b)return c}else if(b&&this.evaluator)return false;c=c[i](false,j,h)}this.end();return this.current=null}function e(b){for(var g,c=null;g=a.call(this,b);)c=g;return c}CKEDITOR.dom.walker=CKEDITOR.tools.createClass({$:function(a){this.range=a;this._={}},proto:{end:function(){this._.end=1},next:function(){return a.call(this)},
previous:function(){return a.call(this,1)},checkForward:function(){return a.call(this,0,1)!==false},checkBackward:function(){return a.call(this,1,1)!==false},lastForward:function(){return e.call(this)},lastBackward:function(){return e.call(this,1)},reset:function(){delete this.current;this._={}}}});var b={block:1,"list-item":1,table:1,"table-row-group":1,"table-header-group":1,"table-footer-group":1,"table-row":1,"table-column-group":1,"table-column":1,"table-cell":1,"table-caption":1},c={absolute:1,
fixed:1};CKEDITOR.dom.element.prototype.isBlockBoundary=function(a){return this.getComputedStyle("float")=="none"&&!(this.getComputedStyle("position")in c)&&b[this.getComputedStyle("display")]?true:!!(this.is(CKEDITOR.dtd.$block)||a&&this.is(a))};CKEDITOR.dom.walker.blockBoundary=function(a){return function(b){return!(b.type==CKEDITOR.NODE_ELEMENT&&b.isBlockBoundary(a))}};CKEDITOR.dom.walker.listItemBoundary=function(){return this.blockBoundary({br:1})};CKEDITOR.dom.walker.bookmark=function(a,b){function g(a){return a&&
a.getName&&a.getName()=="span"&&a.data("cke-bookmark")}return function(c){var d,f;d=c&&c.type!=CKEDITOR.NODE_ELEMENT&&(f=c.getParent())&&g(f);d=a?d:d||g(c);return!!(b^d)}};CKEDITOR.dom.walker.whitespaces=function(a){return function(b){var g;b&&b.type==CKEDITOR.NODE_TEXT&&(g=!CKEDITOR.tools.trim(b.getText())||CKEDITOR.env.webkit&&b.getText()=="​");return!!(a^g)}};CKEDITOR.dom.walker.invisible=function(a){var b=CKEDITOR.dom.walker.whitespaces(),g=CKEDITOR.env.webkit?1:0;return function(c){if(b(c))c=
1;else{c.type==CKEDITOR.NODE_TEXT&&(c=c.getParent());c=c.$.offsetWidth<=g}return!!(a^c)}};CKEDITOR.dom.walker.nodeType=function(a,b){return function(g){return!!(b^g.type==a)}};CKEDITOR.dom.walker.bogus=function(a){function b(a){return!k(a)&&!i(a)}return function(g){var c=CKEDITOR.env.needsBrFiller?g.is&&g.is("br"):g.getText&&f.test(g.getText());if(c){c=g.getParent();g=g.getNext(b);c=c.isBlockBoundary()&&(!g||g.type==CKEDITOR.NODE_ELEMENT&&g.isBlockBoundary())}return!!(a^c)}};CKEDITOR.dom.walker.temp=
function(a){return function(b){b.type!=CKEDITOR.NODE_ELEMENT&&(b=b.getParent());b=b&&b.hasAttribute("data-cke-temp");return!!(a^b)}};var f=/^[\t\r\n ]*(?:&nbsp;|\xa0)$/,k=CKEDITOR.dom.walker.whitespaces(),i=CKEDITOR.dom.walker.bookmark(),d=CKEDITOR.dom.walker.temp();CKEDITOR.dom.walker.ignored=function(a){return function(b){b=k(b)||i(b)||d(b);return!!(a^b)}};var j=CKEDITOR.dom.walker.ignored();CKEDITOR.dom.walker.empty=function(a){return function(b){for(var g=0,c=b.getChildCount();g<c;++g)if(!j(b.getChild(g)))return!!a;
return!a}};var h=CKEDITOR.dom.walker.empty(),g=CKEDITOR.dom.walker.validEmptyBlockContainers=CKEDITOR.tools.extend(function(a){var b={},g;for(g in a)CKEDITOR.dtd[g]["#"]&&(b[g]=1);return b}(CKEDITOR.dtd.$block),{caption:1,td:1,th:1});CKEDITOR.dom.walker.editable=function(a){return function(b){return!!(a^(j(b)?0:b.type==CKEDITOR.NODE_TEXT||b.type==CKEDITOR.NODE_ELEMENT&&(b.is(CKEDITOR.dtd.$inline)||(b.is("hr")||b.getAttribute("contenteditable")=="false")||!CKEDITOR.env.needsBrFiller&&b.is(g)&&h(b))?
1:0))}};CKEDITOR.dom.element.prototype.getBogus=function(){var a=this;do a=a.getPreviousSourceNode();while(i(a)||k(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.is(CKEDITOR.dtd.$inline)&&!a.is(CKEDITOR.dtd.$empty));return a&&(CKEDITOR.env.needsBrFiller?a.is&&a.is("br"):a.getText&&f.test(a.getText()))?a:false}}(),CKEDITOR.dom.range=function(a){this.endOffset=this.endContainer=this.startOffset=this.startContainer=null;this.collapsed=true;var e=a instanceof CKEDITOR.dom.document;this.document=e?a:a.getDocument();
this.root=e?a.getBody():a},function(){function a(a){a.collapsed=a.startContainer&&a.endContainer&&a.startContainer.equals(a.endContainer)&&a.startOffset==a.endOffset}function e(a,b,c,d,f){function e(a,b,g,c){var d=g?a.getPrevious():a.getNext();if(c&&j)return d;if(u||c)b.append(a.clone(true,f),g);else{a.remove();i&&b.append(a)}return d}function h(){var a,b,g,c=Math.min(E.length,H.length);for(a=0;a<c;a++){b=E[a];g=H[a];if(!b.equals(g))return a}return a-1}function k(){var b=L-1,c=A&&D&&!x.equals(v);
if(b<J-1||b<P-1||c){c?a.moveToPosition(v,CKEDITOR.POSITION_BEFORE_START):P==b+1&&B?a.moveToPosition(H[b],CKEDITOR.POSITION_BEFORE_END):a.moveToPosition(H[b+1],CKEDITOR.POSITION_BEFORE_START);if(d)if((b=E[b+1])&&b.type==CKEDITOR.NODE_ELEMENT){c=CKEDITOR.dom.element.createFromHtml('<span data-cke-bookmark="1" style="display:none">&nbsp;</span>',a.document);c.insertAfter(b);b.mergeSiblings(false);a.moveToBookmark({startNode:c})}}else a.collapse(true)}a.optimizeBookmark();var j=b===0,i=b==1,u=b==2,b=
u||i,x=a.startContainer,v=a.endContainer,q=a.startOffset,y=a.endOffset,z,B,A,D,C,G;if(u&&v.type==CKEDITOR.NODE_TEXT&&x.equals(v)){x=a.document.createText(x.substring(q,y));c.append(x)}else{if(v.type==CKEDITOR.NODE_TEXT)u?G=true:v=v.split(y);else if(v.getChildCount()>0)if(y>=v.getChildCount()){v=v.getChild(y-1);B=true}else v=v.getChild(y);else D=B=true;if(x.type==CKEDITOR.NODE_TEXT)u?C=true:x.split(q);else if(x.getChildCount()>0)if(q===0){x=x.getChild(q);z=true}else x=x.getChild(q-1);else A=z=true;
for(var E=x.getParents(),H=v.getParents(),L=h(),J=E.length-1,P=H.length-1,I=c,R,T,X,ca=-1,S=L;S<=J;S++){T=E[S];X=T.getNext();for(S==J&&!(T.equals(H[S])&&J<P)?z?e(T,I,false,A):C&&I.append(a.document.createText(T.substring(q))):b&&(R=I.append(T.clone(0,f)));X;){if(X.equals(H[S])){ca=S;break}X=e(X,I)}I=R}I=c;for(S=L;S<=P;S++){c=H[S];X=c.getPrevious();if(c.equals(E[S]))b&&(I=I.getChild(0));else{S==P&&!(c.equals(E[S])&&P<J)?B?e(c,I,false,D):G&&I.append(a.document.createText(c.substring(0,y))):b&&(R=I.append(c.clone(0,
f)));if(S>ca)for(;X;)X=e(X,I,true);I=R}}u||k()}}function b(){var a=false,b=CKEDITOR.dom.walker.whitespaces(),c=CKEDITOR.dom.walker.bookmark(true),d=CKEDITOR.dom.walker.bogus();return function(f){if(c(f)||b(f))return true;if(d(f)&&!a)return a=true;return f.type==CKEDITOR.NODE_TEXT&&(f.hasAscendant("pre")||CKEDITOR.tools.trim(f.getText()).length)||f.type==CKEDITOR.NODE_ELEMENT&&!f.is(k)?false:true}}function c(a){var b=CKEDITOR.dom.walker.whitespaces(),c=CKEDITOR.dom.walker.bookmark(1);return function(d){return c(d)||
b(d)?true:!a&&i(d)||d.type==CKEDITOR.NODE_ELEMENT&&d.is(CKEDITOR.dtd.$removeEmpty)}}function f(a){return function(){var b;return this[a?"getPreviousNode":"getNextNode"](function(a){!b&&h(a)&&(b=a);return j(a)&&!(i(a)&&a.equals(b))})}}var k={abbr:1,acronym:1,b:1,bdo:1,big:1,cite:1,code:1,del:1,dfn:1,em:1,font:1,i:1,ins:1,label:1,kbd:1,q:1,samp:1,small:1,span:1,strike:1,strong:1,sub:1,sup:1,tt:1,u:1,"var":1},i=CKEDITOR.dom.walker.bogus(),d=/^[\t\r\n ]*(?:&nbsp;|\xa0)$/,j=CKEDITOR.dom.walker.editable(),
h=CKEDITOR.dom.walker.ignored(true);CKEDITOR.dom.range.prototype={clone:function(){var a=new CKEDITOR.dom.range(this.root);a._setStartContainer(this.startContainer);a.startOffset=this.startOffset;a._setEndContainer(this.endContainer);a.endOffset=this.endOffset;a.collapsed=this.collapsed;return a},collapse:function(a){if(a){this._setEndContainer(this.startContainer);this.endOffset=this.startOffset}else{this._setStartContainer(this.endContainer);this.startOffset=this.endOffset}this.collapsed=true},
cloneContents:function(a){var b=new CKEDITOR.dom.documentFragment(this.document);this.collapsed||e(this,2,b,false,typeof a=="undefined"?true:a);return b},deleteContents:function(a){this.collapsed||e(this,0,null,a)},extractContents:function(a,b){var c=new CKEDITOR.dom.documentFragment(this.document);this.collapsed||e(this,1,c,a,typeof b=="undefined"?true:b);return c},createBookmark:function(a){var b,c,d,f,e=this.collapsed;b=this.document.createElement("span");b.data("cke-bookmark",1);b.setStyle("display",
"none");b.setHtml("&nbsp;");if(a){d="cke_bm_"+CKEDITOR.tools.getNextNumber();b.setAttribute("id",d+(e?"C":"S"))}if(!e){c=b.clone();c.setHtml("&nbsp;");a&&c.setAttribute("id",d+"E");f=this.clone();f.collapse();f.insertNode(c)}f=this.clone();f.collapse(true);f.insertNode(b);if(c){this.setStartAfter(b);this.setEndBefore(c)}else this.moveToPosition(b,CKEDITOR.POSITION_AFTER_END);return{startNode:a?d+(e?"C":"S"):b,endNode:a?d+"E":c,serializable:a,collapsed:e}},createBookmark2:function(){function a(g){var c=
g.container,d=g.offset,f;f=c;var e=d;f=f.type!=CKEDITOR.NODE_ELEMENT||e===0||e==f.getChildCount()?0:f.getChild(e-1).type==CKEDITOR.NODE_TEXT&&f.getChild(e).type==CKEDITOR.NODE_TEXT;if(f){c=c.getChild(d-1);d=c.getLength()}c.type==CKEDITOR.NODE_ELEMENT&&d>1&&(d=c.getChild(d-1).getIndex(true)+1);if(c.type==CKEDITOR.NODE_TEXT){f=c;for(e=0;(f=f.getPrevious())&&f.type==CKEDITOR.NODE_TEXT;)e=e+f.getLength();f=e;if(c.getText())d=d+f;else{e=c.getPrevious(b);if(f){d=f;c=e?e.getNext():c.getParent().getFirst()}else{c=
c.getParent();d=e?e.getIndex(true)+1:0}}}g.container=c;g.offset=d}var b=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_TEXT,true);return function(b){var c=this.collapsed,d={container:this.startContainer,offset:this.startOffset},f={container:this.endContainer,offset:this.endOffset};if(b){a(d);c||a(f)}return{start:d.container.getAddress(b),end:c?null:f.container.getAddress(b),startOffset:d.offset,endOffset:f.offset,normalized:b,collapsed:c,is2:true}}}(),moveToBookmark:function(a){if(a.is2){var b=this.document.getByAddress(a.start,
a.normalized),c=a.startOffset,d=a.end&&this.document.getByAddress(a.end,a.normalized),a=a.endOffset;this.setStart(b,c);d?this.setEnd(d,a):this.collapse(true)}else{b=(c=a.serializable)?this.document.getById(a.startNode):a.startNode;a=c?this.document.getById(a.endNode):a.endNode;this.setStartBefore(b);b.remove();if(a){this.setEndBefore(a);a.remove()}else this.collapse(true)}},getBoundaryNodes:function(){var a=this.startContainer,b=this.endContainer,c=this.startOffset,d=this.endOffset,f;if(a.type==CKEDITOR.NODE_ELEMENT){f=
a.getChildCount();if(f>c)a=a.getChild(c);else if(f<1)a=a.getPreviousSourceNode();else{for(a=a.$;a.lastChild;)a=a.lastChild;a=new CKEDITOR.dom.node(a);a=a.getNextSourceNode()||a}}if(b.type==CKEDITOR.NODE_ELEMENT){f=b.getChildCount();if(f>d)b=b.getChild(d).getPreviousSourceNode(true);else if(f<1)b=b.getPreviousSourceNode();else{for(b=b.$;b.lastChild;)b=b.lastChild;b=new CKEDITOR.dom.node(b)}}a.getPosition(b)&CKEDITOR.POSITION_FOLLOWING&&(a=b);return{startNode:a,endNode:b}},getCommonAncestor:function(a,
b){var c=this.startContainer,d=this.endContainer,c=c.equals(d)?a&&c.type==CKEDITOR.NODE_ELEMENT&&this.startOffset==this.endOffset-1?c.getChild(this.startOffset):c:c.getCommonAncestor(d);return b&&!c.is?c.getParent():c},optimize:function(){var a=this.startContainer,b=this.startOffset;a.type!=CKEDITOR.NODE_ELEMENT&&(b?b>=a.getLength()&&this.setStartAfter(a):this.setStartBefore(a));a=this.endContainer;b=this.endOffset;a.type!=CKEDITOR.NODE_ELEMENT&&(b?b>=a.getLength()&&this.setEndAfter(a):this.setEndBefore(a))},
optimizeBookmark:function(){var a=this.startContainer,b=this.endContainer;a.is&&(a.is("span")&&a.data("cke-bookmark"))&&this.setStartAt(a,CKEDITOR.POSITION_BEFORE_START);b&&(b.is&&b.is("span")&&b.data("cke-bookmark"))&&this.setEndAt(b,CKEDITOR.POSITION_AFTER_END)},trim:function(a,b){var c=this.startContainer,d=this.startOffset,f=this.collapsed;if((!a||f)&&c&&c.type==CKEDITOR.NODE_TEXT){if(d)if(d>=c.getLength()){d=c.getIndex()+1;c=c.getParent()}else{var e=c.split(d),d=c.getIndex()+1,c=c.getParent();
if(this.startContainer.equals(this.endContainer))this.setEnd(e,this.endOffset-this.startOffset);else if(c.equals(this.endContainer))this.endOffset=this.endOffset+1}else{d=c.getIndex();c=c.getParent()}this.setStart(c,d);if(f){this.collapse(true);return}}c=this.endContainer;d=this.endOffset;if(!b&&!f&&c&&c.type==CKEDITOR.NODE_TEXT){if(d){d>=c.getLength()||c.split(d);d=c.getIndex()+1}else d=c.getIndex();c=c.getParent();this.setEnd(c,d)}},enlarge:function(a,b){function c(a){return a&&a.type==CKEDITOR.NODE_ELEMENT&&
a.hasAttribute("contenteditable")?null:a}var d=RegExp(/[^\s\ufeff]/);switch(a){case CKEDITOR.ENLARGE_INLINE:var f=1;case CKEDITOR.ENLARGE_ELEMENT:if(this.collapsed)break;var e=this.getCommonAncestor(),h=this.root,k,j,i,u,x,v=false,q,y;q=this.startContainer;var z=this.startOffset;if(q.type==CKEDITOR.NODE_TEXT){if(z){q=!CKEDITOR.tools.trim(q.substring(0,z)).length&&q;v=!!q}if(q&&!(u=q.getPrevious()))i=q.getParent()}else{z&&(u=q.getChild(z-1)||q.getLast());u||(i=q)}for(i=c(i);i||u;){if(i&&!u){!x&&i.equals(e)&&
(x=true);if(f?i.isBlockBoundary():!h.contains(i))break;if(!v||i.getComputedStyle("display")!="inline"){v=false;x?k=i:this.setStartBefore(i)}u=i.getPrevious()}for(;u;){q=false;if(u.type==CKEDITOR.NODE_COMMENT)u=u.getPrevious();else{if(u.type==CKEDITOR.NODE_TEXT){y=u.getText();d.test(y)&&(u=null);q=/[\s\ufeff]$/.test(y)}else if((u.$.offsetWidth>(CKEDITOR.env.webkit?1:0)||b&&u.is("br"))&&!u.data("cke-bookmark"))if(v&&CKEDITOR.dtd.$removeEmpty[u.getName()]){y=u.getText();if(d.test(y))u=null;else for(var z=
u.$.getElementsByTagName("*"),B=0,A;A=z[B++];)if(!CKEDITOR.dtd.$removeEmpty[A.nodeName.toLowerCase()]){u=null;break}u&&(q=!!y.length)}else u=null;q&&(v?x?k=i:i&&this.setStartBefore(i):v=true);if(u){q=u.getPrevious();if(!i&&!q){i=u;u=null;break}u=q}else i=null}}i&&(i=c(i.getParent()))}q=this.endContainer;z=this.endOffset;i=u=null;x=v=false;var D=function(a,b){var g=new CKEDITOR.dom.range(h);g.setStart(a,b);g.setEndAt(h,CKEDITOR.POSITION_BEFORE_END);var g=new CKEDITOR.dom.walker(g),c;for(g.guard=function(a){return!(a.type==
CKEDITOR.NODE_ELEMENT&&a.isBlockBoundary())};c=g.next();){if(c.type!=CKEDITOR.NODE_TEXT)return false;y=c!=a?c.getText():c.substring(b);if(d.test(y))return false}return true};if(q.type==CKEDITOR.NODE_TEXT)if(CKEDITOR.tools.trim(q.substring(z)).length)v=true;else{v=!q.getLength();if(z==q.getLength()){if(!(u=q.getNext()))i=q.getParent()}else D(q,z)&&(i=q.getParent())}else(u=q.getChild(z))||(i=q);for(;i||u;){if(i&&!u){!x&&i.equals(e)&&(x=true);if(f?i.isBlockBoundary():!h.contains(i))break;if(!v||i.getComputedStyle("display")!=
"inline"){v=false;x?j=i:i&&this.setEndAfter(i)}u=i.getNext()}for(;u;){q=false;if(u.type==CKEDITOR.NODE_TEXT){y=u.getText();D(u,0)||(u=null);q=/^[\s\ufeff]/.test(y)}else if(u.type==CKEDITOR.NODE_ELEMENT){if((u.$.offsetWidth>0||b&&u.is("br"))&&!u.data("cke-bookmark"))if(v&&CKEDITOR.dtd.$removeEmpty[u.getName()]){y=u.getText();if(d.test(y))u=null;else{z=u.$.getElementsByTagName("*");for(B=0;A=z[B++];)if(!CKEDITOR.dtd.$removeEmpty[A.nodeName.toLowerCase()]){u=null;break}}u&&(q=!!y.length)}else u=null}else q=
1;q&&v&&(x?j=i:this.setEndAfter(i));if(u){q=u.getNext();if(!i&&!q){i=u;u=null;break}u=q}else i=null}i&&(i=c(i.getParent()))}if(k&&j){e=k.contains(j)?j:k;this.setStartBefore(e);this.setEndAfter(e)}break;case CKEDITOR.ENLARGE_BLOCK_CONTENTS:case CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:i=new CKEDITOR.dom.range(this.root);h=this.root;i.setStartAt(h,CKEDITOR.POSITION_AFTER_START);i.setEnd(this.startContainer,this.startOffset);i=new CKEDITOR.dom.walker(i);var C,G,E=CKEDITOR.dom.walker.blockBoundary(a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS?
{br:1}:null),H=null,L=function(a){if(a.type==CKEDITOR.NODE_ELEMENT&&a.getAttribute("contenteditable")=="false")if(H){if(H.equals(a)){H=null;return}}else H=a;else if(H)return;var b=E(a);b||(C=a);return b},f=function(a){var b=L(a);!b&&(a.is&&a.is("br"))&&(G=a);return b};i.guard=L;i=i.lastBackward();C=C||h;this.setStartAt(C,!C.is("br")&&(!i&&this.checkStartOfBlock()||i&&C.contains(i))?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_AFTER_END);if(a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS){i=this.clone();
i=new CKEDITOR.dom.walker(i);var J=CKEDITOR.dom.walker.whitespaces(),P=CKEDITOR.dom.walker.bookmark();i.evaluator=function(a){return!J(a)&&!P(a)};if((i=i.previous())&&i.type==CKEDITOR.NODE_ELEMENT&&i.is("br"))break}i=this.clone();i.collapse();i.setEndAt(h,CKEDITOR.POSITION_BEFORE_END);i=new CKEDITOR.dom.walker(i);i.guard=a==CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS?f:L;C=H=G=null;i=i.lastForward();C=C||h;this.setEndAt(C,!i&&this.checkEndOfBlock()||i&&C.contains(i)?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_BEFORE_START);
G&&this.setEndAfter(G)}},shrink:function(a,b,c){if(!this.collapsed){var a=a||CKEDITOR.SHRINK_TEXT,d=this.clone(),f=this.startContainer,e=this.endContainer,h=this.startOffset,k=this.endOffset,i=1,j=1;if(f&&f.type==CKEDITOR.NODE_TEXT)if(h)if(h>=f.getLength())d.setStartAfter(f);else{d.setStartBefore(f);i=0}else d.setStartBefore(f);if(e&&e.type==CKEDITOR.NODE_TEXT)if(k)if(k>=e.getLength())d.setEndAfter(e);else{d.setEndAfter(e);j=0}else d.setEndBefore(e);var d=new CKEDITOR.dom.walker(d),u=CKEDITOR.dom.walker.bookmark();
d.evaluator=function(b){return b.type==(a==CKEDITOR.SHRINK_ELEMENT?CKEDITOR.NODE_ELEMENT:CKEDITOR.NODE_TEXT)};var x;d.guard=function(b,d){if(u(b))return true;if(a==CKEDITOR.SHRINK_ELEMENT&&b.type==CKEDITOR.NODE_TEXT||d&&b.equals(x)||c===false&&b.type==CKEDITOR.NODE_ELEMENT&&b.isBlockBoundary()||b.type==CKEDITOR.NODE_ELEMENT&&b.hasAttribute("contenteditable"))return false;!d&&b.type==CKEDITOR.NODE_ELEMENT&&(x=b);return true};if(i)(f=d[a==CKEDITOR.SHRINK_ELEMENT?"lastForward":"next"]())&&this.setStartAt(f,
b?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_START);if(j){d.reset();(d=d[a==CKEDITOR.SHRINK_ELEMENT?"lastBackward":"previous"]())&&this.setEndAt(d,b?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_AFTER_END)}return!(!i&&!j)}},insertNode:function(a){this.optimizeBookmark();this.trim(false,true);var b=this.startContainer,c=b.getChild(this.startOffset);c?a.insertBefore(c):b.append(a);a.getParent()&&a.getParent().equals(this.endContainer)&&this.endOffset++;this.setStartBefore(a)},moveToPosition:function(a,
b){this.setStartAt(a,b);this.collapse(true)},moveToRange:function(a){this.setStart(a.startContainer,a.startOffset);this.setEnd(a.endContainer,a.endOffset)},selectNodeContents:function(a){this.setStart(a,0);this.setEnd(a,a.type==CKEDITOR.NODE_TEXT?a.getLength():a.getChildCount())},setStart:function(b,c){if(b.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$empty[b.getName()]){c=b.getIndex();b=b.getParent()}this._setStartContainer(b);this.startOffset=c;if(!this.endContainer){this._setEndContainer(b);this.endOffset=
c}a(this)},setEnd:function(b,c){if(b.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$empty[b.getName()]){c=b.getIndex()+1;b=b.getParent()}this._setEndContainer(b);this.endOffset=c;if(!this.startContainer){this._setStartContainer(b);this.startOffset=c}a(this)},setStartAfter:function(a){this.setStart(a.getParent(),a.getIndex()+1)},setStartBefore:function(a){this.setStart(a.getParent(),a.getIndex())},setEndAfter:function(a){this.setEnd(a.getParent(),a.getIndex()+1)},setEndBefore:function(a){this.setEnd(a.getParent(),
a.getIndex())},setStartAt:function(b,c){switch(c){case CKEDITOR.POSITION_AFTER_START:this.setStart(b,0);break;case CKEDITOR.POSITION_BEFORE_END:b.type==CKEDITOR.NODE_TEXT?this.setStart(b,b.getLength()):this.setStart(b,b.getChildCount());break;case CKEDITOR.POSITION_BEFORE_START:this.setStartBefore(b);break;case CKEDITOR.POSITION_AFTER_END:this.setStartAfter(b)}a(this)},setEndAt:function(b,c){switch(c){case CKEDITOR.POSITION_AFTER_START:this.setEnd(b,0);break;case CKEDITOR.POSITION_BEFORE_END:b.type==
CKEDITOR.NODE_TEXT?this.setEnd(b,b.getLength()):this.setEnd(b,b.getChildCount());break;case CKEDITOR.POSITION_BEFORE_START:this.setEndBefore(b);break;case CKEDITOR.POSITION_AFTER_END:this.setEndAfter(b)}a(this)},fixBlock:function(a,b){var c=this.createBookmark(),d=this.document.createElement(b);this.collapse(a);this.enlarge(CKEDITOR.ENLARGE_BLOCK_CONTENTS);this.extractContents().appendTo(d);d.trim();this.insertNode(d);var f=d.getBogus();f&&f.remove();d.appendBogus();this.moveToBookmark(c);return d},
splitBlock:function(a,b){var c=new CKEDITOR.dom.elementPath(this.startContainer,this.root),d=new CKEDITOR.dom.elementPath(this.endContainer,this.root),f=c.block,e=d.block,h=null;if(!c.blockLimit.equals(d.blockLimit))return null;if(a!="br"){if(!f){f=this.fixBlock(true,a);e=(new CKEDITOR.dom.elementPath(this.endContainer,this.root)).block}e||(e=this.fixBlock(false,a))}c=f&&this.checkStartOfBlock();d=e&&this.checkEndOfBlock();this.deleteContents();if(f&&f.equals(e))if(d){h=new CKEDITOR.dom.elementPath(this.startContainer,
this.root);this.moveToPosition(e,CKEDITOR.POSITION_AFTER_END);e=null}else if(c){h=new CKEDITOR.dom.elementPath(this.startContainer,this.root);this.moveToPosition(f,CKEDITOR.POSITION_BEFORE_START);f=null}else{e=this.splitElement(f,b||false);f.is("ul","ol")||f.appendBogus()}return{previousBlock:f,nextBlock:e,wasStartOfBlock:c,wasEndOfBlock:d,elementPath:h}},splitElement:function(a,b){if(!this.collapsed)return null;this.setEndAt(a,CKEDITOR.POSITION_BEFORE_END);var c=this.extractContents(false,b||false),
d=a.clone(false,b||false);c.appendTo(d);d.insertAfter(a);this.moveToPosition(a,CKEDITOR.POSITION_AFTER_END);return d},removeEmptyBlocksAtEnd:function(){function a(g){return function(a){return b(a)||(c(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.isEmptyInlineRemoveable())||g.is("table")&&a.is("caption")?false:true}}var b=CKEDITOR.dom.walker.whitespaces(),c=CKEDITOR.dom.walker.bookmark(false);return function(b){for(var c=this.createBookmark(),d=this[b?"endPath":"startPath"](),f=d.block||d.blockLimit,e;f&&
!f.equals(d.root)&&!f.getFirst(a(f));){e=f.getParent();this[b?"setEndAt":"setStartAt"](f,CKEDITOR.POSITION_AFTER_END);f.remove(1);f=e}this.moveToBookmark(c)}}(),startPath:function(){return new CKEDITOR.dom.elementPath(this.startContainer,this.root)},endPath:function(){return new CKEDITOR.dom.elementPath(this.endContainer,this.root)},checkBoundaryOfElement:function(a,b){var d=b==CKEDITOR.START,f=this.clone();f.collapse(d);f[d?"setStartAt":"setEndAt"](a,d?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_END);
f=new CKEDITOR.dom.walker(f);f.evaluator=c(d);return f[d?"checkBackward":"checkForward"]()},checkStartOfBlock:function(){var a=this.startContainer,c=this.startOffset;if(CKEDITOR.env.ie&&c&&a.type==CKEDITOR.NODE_TEXT){a=CKEDITOR.tools.ltrim(a.substring(0,c));d.test(a)&&this.trim(0,1)}this.trim();a=new CKEDITOR.dom.elementPath(this.startContainer,this.root);c=this.clone();c.collapse(true);c.setStartAt(a.block||a.blockLimit,CKEDITOR.POSITION_AFTER_START);a=new CKEDITOR.dom.walker(c);a.evaluator=b();
return a.checkBackward()},checkEndOfBlock:function(){var a=this.endContainer,c=this.endOffset;if(CKEDITOR.env.ie&&a.type==CKEDITOR.NODE_TEXT){a=CKEDITOR.tools.rtrim(a.substring(c));d.test(a)&&this.trim(1,0)}this.trim();a=new CKEDITOR.dom.elementPath(this.endContainer,this.root);c=this.clone();c.collapse(false);c.setEndAt(a.block||a.blockLimit,CKEDITOR.POSITION_BEFORE_END);a=new CKEDITOR.dom.walker(c);a.evaluator=b();return a.checkForward()},getPreviousNode:function(a,b,c){var d=this.clone();d.collapse(1);
d.setStartAt(c||this.root,CKEDITOR.POSITION_AFTER_START);c=new CKEDITOR.dom.walker(d);c.evaluator=a;c.guard=b;return c.previous()},getNextNode:function(a,b,c){var d=this.clone();d.collapse();d.setEndAt(c||this.root,CKEDITOR.POSITION_BEFORE_END);c=new CKEDITOR.dom.walker(d);c.evaluator=a;c.guard=b;return c.next()},checkReadOnly:function(){function a(b,c){for(;b;){if(b.type==CKEDITOR.NODE_ELEMENT){if(b.getAttribute("contentEditable")=="false"&&!b.data("cke-editable"))return 0;if(b.is("html")||b.getAttribute("contentEditable")==
"true"&&(b.contains(c)||b.equals(c)))break}b=b.getParent()}return 1}return function(){var b=this.startContainer,c=this.endContainer;return!(a(b,c)&&a(c,b))}}(),moveToElementEditablePosition:function(a,b){if(a.type==CKEDITOR.NODE_ELEMENT&&!a.isEditable(false)){this.moveToPosition(a,b?CKEDITOR.POSITION_AFTER_END:CKEDITOR.POSITION_BEFORE_START);return true}for(var c=0;a;){if(a.type==CKEDITOR.NODE_TEXT){b&&this.endContainer&&this.checkEndOfBlock()&&d.test(a.getText())?this.moveToPosition(a,CKEDITOR.POSITION_BEFORE_START):
this.moveToPosition(a,b?CKEDITOR.POSITION_AFTER_END:CKEDITOR.POSITION_BEFORE_START);c=1;break}if(a.type==CKEDITOR.NODE_ELEMENT)if(a.isEditable()){this.moveToPosition(a,b?CKEDITOR.POSITION_BEFORE_END:CKEDITOR.POSITION_AFTER_START);c=1}else if(b&&a.is("br")&&this.endContainer&&this.checkEndOfBlock())this.moveToPosition(a,CKEDITOR.POSITION_BEFORE_START);else if(a.getAttribute("contenteditable")=="false"&&a.is(CKEDITOR.dtd.$block)){this.setStartBefore(a);this.setEndAfter(a);return true}var f=a,e=c,k=
void 0;f.type==CKEDITOR.NODE_ELEMENT&&f.isEditable(false)&&(k=f[b?"getLast":"getFirst"](h));!e&&!k&&(k=f[b?"getPrevious":"getNext"](h));a=k}return!!c},moveToClosestEditablePosition:function(a,b){var c,d=0,f,e,h=[CKEDITOR.POSITION_AFTER_END,CKEDITOR.POSITION_BEFORE_START];if(a){c=new CKEDITOR.dom.range(this.root);c.moveToPosition(a,h[b?0:1])}else c=this.clone();if(a&&!a.is(CKEDITOR.dtd.$block))d=1;else if(f=c[b?"getNextEditableNode":"getPreviousEditableNode"]()){d=1;if((e=f.type==CKEDITOR.NODE_ELEMENT)&&
f.is(CKEDITOR.dtd.$block)&&f.getAttribute("contenteditable")=="false"){c.setStartAt(f,CKEDITOR.POSITION_BEFORE_START);c.setEndAt(f,CKEDITOR.POSITION_AFTER_END)}else if(!CKEDITOR.env.needsBrFiller&&e&&f.is(CKEDITOR.dom.walker.validEmptyBlockContainers)){c.setEnd(f,0);c.collapse()}else c.moveToPosition(f,h[b?1:0])}d&&this.moveToRange(c);return!!d},moveToElementEditStart:function(a){return this.moveToElementEditablePosition(a)},moveToElementEditEnd:function(a){return this.moveToElementEditablePosition(a,
true)},getEnclosedNode:function(){var a=this.clone();a.optimize();if(a.startContainer.type!=CKEDITOR.NODE_ELEMENT||a.endContainer.type!=CKEDITOR.NODE_ELEMENT)return null;var a=new CKEDITOR.dom.walker(a),b=CKEDITOR.dom.walker.bookmark(false,true),c=CKEDITOR.dom.walker.whitespaces(true);a.evaluator=function(a){return c(a)&&b(a)};var d=a.next();a.reset();return d&&d.equals(a.previous())?d:null},getTouchedStartNode:function(){var a=this.startContainer;return this.collapsed||a.type!=CKEDITOR.NODE_ELEMENT?
a:a.getChild(this.startOffset)||a},getTouchedEndNode:function(){var a=this.endContainer;return this.collapsed||a.type!=CKEDITOR.NODE_ELEMENT?a:a.getChild(this.endOffset-1)||a},getNextEditableNode:f(),getPreviousEditableNode:f(1),scrollIntoView:function(){var a=new CKEDITOR.dom.element.createFromHtml("<span>&nbsp;</span>",this.document),b,c,d,f=this.clone();f.optimize();if(d=f.startContainer.type==CKEDITOR.NODE_TEXT){c=f.startContainer.getText();b=f.startContainer.split(f.startOffset);a.insertAfter(f.startContainer)}else f.insertNode(a);
a.scrollIntoView();if(d){f.startContainer.setText(c);b.remove()}a.remove()},_setStartContainer:function(a){this.startContainer=a},_setEndContainer:function(a){this.endContainer=a}}}(),CKEDITOR.POSITION_AFTER_START=1,CKEDITOR.POSITION_BEFORE_END=2,CKEDITOR.POSITION_BEFORE_START=3,CKEDITOR.POSITION_AFTER_END=4,CKEDITOR.ENLARGE_ELEMENT=1,CKEDITOR.ENLARGE_BLOCK_CONTENTS=2,CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS=3,CKEDITOR.ENLARGE_INLINE=4,CKEDITOR.START=1,CKEDITOR.END=2,CKEDITOR.SHRINK_ELEMENT=1,CKEDITOR.SHRINK_TEXT=
2,"use strict",function(){function a(a){if(!(arguments.length<1)){this.range=a;this.forceBrBreak=0;this.enlargeBr=1;this.enforceRealBlocks=0;this._||(this._={})}}function e(a){var b=[];a.forEach(function(a){if(a.getAttribute("contenteditable")=="true"){b.push(a);return false}},CKEDITOR.NODE_ELEMENT,true);return b}function b(a,c,d,f){a:{f==null&&(f=e(d));for(var k;k=f.shift();)if(k.getDtd().p){f={element:k,remaining:f};break a}f=null}if(!f)return 0;if((k=CKEDITOR.filter.instances[f.element.data("cke-filter")])&&
!k.check(c))return b(a,c,d,f.remaining);c=new CKEDITOR.dom.range(f.element);c.selectNodeContents(f.element);c=c.createIterator();c.enlargeBr=a.enlargeBr;c.enforceRealBlocks=a.enforceRealBlocks;c.activeFilter=c.filter=k;a._.nestedEditable={element:f.element,container:d,remaining:f.remaining,iterator:c};return 1}function c(a,b,c){if(!b)return false;a=a.clone();a.collapse(!c);return a.checkBoundaryOfElement(b,c?CKEDITOR.START:CKEDITOR.END)}var f=/^[\r\n\t ]+$/,k=CKEDITOR.dom.walker.bookmark(false,true),
i=CKEDITOR.dom.walker.whitespaces(true),d=function(a){return k(a)&&i(a)},j={dd:1,dt:1,li:1};a.prototype={getNextParagraph:function(a){var g,e,i,r,o,a=a||"p";if(this._.nestedEditable){if(g=this._.nestedEditable.iterator.getNextParagraph(a)){this.activeFilter=this._.nestedEditable.iterator.activeFilter;return g}this.activeFilter=this.filter;if(b(this,a,this._.nestedEditable.container,this._.nestedEditable.remaining)){this.activeFilter=this._.nestedEditable.iterator.activeFilter;return this._.nestedEditable.iterator.getNextParagraph(a)}this._.nestedEditable=
null}if(!this.range.root.getDtd()[a])return null;if(!this._.started){var n=this.range.clone();e=n.startPath();var l=n.endPath(),s=!n.collapsed&&c(n,e.block),t=!n.collapsed&&c(n,l.block,1);n.shrink(CKEDITOR.SHRINK_ELEMENT,true);s&&n.setStartAt(e.block,CKEDITOR.POSITION_BEFORE_END);t&&n.setEndAt(l.block,CKEDITOR.POSITION_AFTER_START);e=n.endContainer.hasAscendant("pre",true)||n.startContainer.hasAscendant("pre",true);n.enlarge(this.forceBrBreak&&!e||!this.enlargeBr?CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:
CKEDITOR.ENLARGE_BLOCK_CONTENTS);if(!n.collapsed){e=new CKEDITOR.dom.walker(n.clone());l=CKEDITOR.dom.walker.bookmark(true,true);e.evaluator=l;this._.nextNode=e.next();e=new CKEDITOR.dom.walker(n.clone());e.evaluator=l;e=e.previous();this._.lastNode=e.getNextSourceNode(true,null,n.root);if(this._.lastNode&&this._.lastNode.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.trim(this._.lastNode.getText())&&this._.lastNode.getParent().isBlockBoundary()){l=this.range.clone();l.moveToPosition(this._.lastNode,CKEDITOR.POSITION_AFTER_END);
if(l.checkEndOfBlock()){l=new CKEDITOR.dom.elementPath(l.endContainer,l.root);this._.lastNode=(l.block||l.blockLimit).getNextSourceNode(true)}}if(!this._.lastNode||!n.root.contains(this._.lastNode)){this._.lastNode=this._.docEndMarker=n.document.createText("");this._.lastNode.insertAfter(e)}n=null}this._.started=1;e=n}l=this._.nextNode;n=this._.lastNode;for(this._.nextNode=null;l;){var s=0,t=l.hasAscendant("pre"),w=l.type!=CKEDITOR.NODE_ELEMENT,u=0;if(w)l.type==CKEDITOR.NODE_TEXT&&f.test(l.getText())&&
(w=0);else{var x=l.getName();if(CKEDITOR.dtd.$block[x]&&l.getAttribute("contenteditable")=="false"){g=l;b(this,a,g);break}else if(l.isBlockBoundary(this.forceBrBreak&&!t&&{br:1})){if(x=="br")w=1;else if(!e&&!l.getChildCount()&&x!="hr"){g=l;i=l.equals(n);break}if(e){e.setEndAt(l,CKEDITOR.POSITION_BEFORE_START);if(x!="br")this._.nextNode=l}s=1}else{if(l.getFirst()){if(!e){e=this.range.clone();e.setStartAt(l,CKEDITOR.POSITION_BEFORE_START)}l=l.getFirst();continue}w=1}}if(w&&!e){e=this.range.clone();
e.setStartAt(l,CKEDITOR.POSITION_BEFORE_START)}i=(!s||w)&&l.equals(n);if(e&&!s)for(;!l.getNext(d)&&!i;){x=l.getParent();if(x.isBlockBoundary(this.forceBrBreak&&!t&&{br:1})){s=1;w=0;i||x.equals(n);e.setEndAt(x,CKEDITOR.POSITION_BEFORE_END);break}l=x;w=1;i=l.equals(n);u=1}w&&e.setEndAt(l,CKEDITOR.POSITION_AFTER_END);l=this._getNextSourceNode(l,u,n);if((i=!l)||s&&e)break}if(!g){if(!e){this._.docEndMarker&&this._.docEndMarker.remove();return this._.nextNode=null}g=new CKEDITOR.dom.elementPath(e.startContainer,
e.root);l=g.blockLimit;s={div:1,th:1,td:1};g=g.block;if(!g&&l&&!this.enforceRealBlocks&&s[l.getName()]&&e.checkStartOfBlock()&&e.checkEndOfBlock()&&!l.equals(e.root))g=l;else if(!g||this.enforceRealBlocks&&g.is(j)){g=this.range.document.createElement(a);e.extractContents().appendTo(g);g.trim();e.insertNode(g);r=o=true}else if(g.getName()!="li"){if(!e.checkStartOfBlock()||!e.checkEndOfBlock()){g=g.clone(false);e.extractContents().appendTo(g);g.trim();o=e.splitBlock();r=!o.wasStartOfBlock;o=!o.wasEndOfBlock;
e.insertNode(g)}}else if(!i)this._.nextNode=g.equals(n)?null:this._getNextSourceNode(e.getBoundaryNodes().endNode,1,n)}if(r)(r=g.getPrevious())&&r.type==CKEDITOR.NODE_ELEMENT&&(r.getName()=="br"?r.remove():r.getLast()&&r.getLast().$.nodeName.toLowerCase()=="br"&&r.getLast().remove());if(o)(r=g.getLast())&&r.type==CKEDITOR.NODE_ELEMENT&&r.getName()=="br"&&(!CKEDITOR.env.needsBrFiller||r.getPrevious(k)||r.getNext(k))&&r.remove();if(!this._.nextNode)this._.nextNode=i||g.equals(n)||!n?null:this._getNextSourceNode(g,
1,n);return g},_getNextSourceNode:function(a,b,c){function d(a){return!(a.equals(c)||a.equals(f))}for(var f=this.range.root,a=a.getNextSourceNode(b,null,d);!k(a);)a=a.getNextSourceNode(b,null,d);return a}};CKEDITOR.dom.range.prototype.createIterator=function(){return new a(this)}}(),CKEDITOR.command=function(a,e){this.uiItems=[];this.exec=function(b){if(this.state==CKEDITOR.TRISTATE_DISABLED||!this.checkAllowed())return false;this.editorFocus&&a.focus();return this.fire("exec")===false?true:e.exec.call(this,
a,b)!==false};this.refresh=function(a,b){if(!this.readOnly&&a.readOnly)return true;if(this.context&&!b.isContextFor(this.context)){this.disable();return true}if(!this.checkAllowed(true)){this.disable();return true}this.startDisabled||this.enable();this.modes&&!this.modes[a.mode]&&this.disable();return this.fire("refresh",{editor:a,path:b})===false?true:e.refresh&&e.refresh.apply(this,arguments)!==false};var b;this.checkAllowed=function(c){return!c&&typeof b=="boolean"?b:b=a.activeFilter.checkFeature(this)};
CKEDITOR.tools.extend(this,e,{modes:{wysiwyg:1},editorFocus:1,contextSensitive:!!e.context,state:CKEDITOR.TRISTATE_DISABLED});CKEDITOR.event.call(this)},CKEDITOR.command.prototype={enable:function(){this.state==CKEDITOR.TRISTATE_DISABLED&&this.checkAllowed()&&this.setState(!this.preserveState||typeof this.previousState=="undefined"?CKEDITOR.TRISTATE_OFF:this.previousState)},disable:function(){this.setState(CKEDITOR.TRISTATE_DISABLED)},setState:function(a){if(this.state==a||a!=CKEDITOR.TRISTATE_DISABLED&&
!this.checkAllowed())return false;this.previousState=this.state;this.state=a;this.fire("state");return true},toggleState:function(){this.state==CKEDITOR.TRISTATE_OFF?this.setState(CKEDITOR.TRISTATE_ON):this.state==CKEDITOR.TRISTATE_ON&&this.setState(CKEDITOR.TRISTATE_OFF)}},CKEDITOR.event.implementOn(CKEDITOR.command.prototype),CKEDITOR.ENTER_P=1,CKEDITOR.ENTER_BR=2,CKEDITOR.ENTER_DIV=3,CKEDITOR.config={customConfig:"config.js",autoUpdateElement:!0,language:"",defaultLanguage:"en",contentsLangDirection:"",
enterMode:CKEDITOR.ENTER_P,forceEnterMode:!1,shiftEnterMode:CKEDITOR.ENTER_BR,docType:"<!DOCTYPE html>",bodyId:"",bodyClass:"",fullPage:!1,height:200,extraPlugins:"",removePlugins:"",protectedSource:[],tabIndex:0,width:"",baseFloatZIndex:1E4,blockedKeystrokes:[CKEDITOR.CTRL+66,CKEDITOR.CTRL+73,CKEDITOR.CTRL+85]},function(){function a(a,b,c,d,f){var g,e,a=[];for(g in b){e=b[g];e=typeof e=="boolean"?{}:typeof e=="function"?{match:e}:D(e);if(g.charAt(0)!="$")e.elements=g;if(c)e.featureName=c.toLowerCase();
var h=e;h.elements=i(h.elements,/\s+/)||null;h.propertiesOnly=h.propertiesOnly||h.elements===true;var k=/\s*,\s*/,j=void 0;for(j in H){h[j]=i(h[j],k)||null;var o=h,v=L[j],m=i(h[L[j]],k),l=h[j],n=[],E=true,q=void 0;m?E=false:m={};for(q in l)if(q.charAt(0)=="!"){q=q.slice(1);n.push(q);m[q]=true;E=false}for(;q=n.pop();){l[q]=l["!"+q];delete l["!"+q]}o[v]=(E?false:m)||null}h.match=h.match||null;d.push(e);a.push(e)}for(var b=f.elements,f=f.generic,t,c=0,d=a.length;c<d;++c){g=D(a[c]);e=g.classes===true||
g.styles===true||g.attributes===true;h=g;j=v=k=void 0;for(k in H)h[k]=s(h[k]);o=true;for(j in L){k=L[j];v=h[k];m=[];l=void 0;for(l in v)l.indexOf("*")>-1?m.push(RegExp("^"+l.replace(/\*/g,".*")+"$")):m.push(l);v=m;if(v.length){h[k]=v;o=false}}h.nothingRequired=o;h.noProperties=!(h.attributes||h.classes||h.styles);if(g.elements===true||g.elements===null)f[e?"unshift":"push"](g);else{h=g.elements;delete g.elements;for(t in h)if(b[t])b[t][e?"unshift":"push"](g);else b[t]=[g]}}}function e(a,c,g,f){if(!a.match||
a.match(c))if(f||d(a,c)){if(!a.propertiesOnly)g.valid=true;if(!g.allAttributes)g.allAttributes=b(a.attributes,c.attributes,g.validAttributes);if(!g.allStyles)g.allStyles=b(a.styles,c.styles,g.validStyles);if(!g.allClasses){a=a.classes;c=c.classes;f=g.validClasses;if(a)if(a===true)a=true;else{for(var e=0,h=c.length,k;e<h;++e){k=c[e];f[k]||(f[k]=a(k))}a=false}else a=false;g.allClasses=a}}}function b(a,b,c){if(!a)return false;if(a===true)return true;for(var g in b)c[g]||(c[g]=a(g));return false}function c(a,
b,c){if(!a.match||a.match(b)){if(a.noProperties)return false;c.hadInvalidAttribute=f(a.attributes,b.attributes)||c.hadInvalidAttribute;c.hadInvalidStyle=f(a.styles,b.styles)||c.hadInvalidStyle;a=a.classes;b=b.classes;if(a){for(var g=false,d=a===true,e=b.length;e--;)if(d||a(b[e])){b.splice(e,1);g=true}a=g}else a=false;c.hadInvalidClass=a||c.hadInvalidClass}}function f(a,b){if(!a)return false;var c=false,g=a===true,d;for(d in b)if(g||a(d)){delete b[d];c=true}return c}function k(a,b,c){if(a.disabled||
a.customConfig&&!c||!b)return false;a._.cachedChecks={};return true}function i(a,b){if(!a)return false;if(a===true)return a;if(typeof a=="string"){a=C(a);return a=="*"?true:CKEDITOR.tools.convertArrayToObject(a.split(b))}if(CKEDITOR.tools.isArray(a))return a.length?CKEDITOR.tools.convertArrayToObject(a):false;var c={},g=0,d;for(d in a){c[d]=a[d];g++}return g?c:false}function d(a,b){if(a.nothingRequired)return true;var c,g,d,f;if(d=a.requiredClasses){f=b.classes;for(c=0;c<d.length;++c){g=d[c];if(typeof g==
"string"){if(CKEDITOR.tools.indexOf(f,g)==-1)return false}else if(!CKEDITOR.tools.checkIfAnyArrayItemMatches(f,g))return false}}return j(b.styles,a.requiredStyles)&&j(b.attributes,a.requiredAttributes)}function j(a,b){if(!b)return true;for(var c=0,g;c<b.length;++c){g=b[c];if(typeof g=="string"){if(!(g in a))return false}else if(!CKEDITOR.tools.checkIfAnyObjectPropertyMatches(a,g))return false}return true}function h(a){if(!a)return{};for(var a=a.split(/\s*,\s*/).sort(),b={};a.length;)b[a.shift()]=
G;return b}function g(a){for(var b,c,g,d,f={},e=1,a=C(a);b=a.match(J);){if(c=b[2]){g=m(c,"styles");d=m(c,"attrs");c=m(c,"classes")}else g=d=c=null;f["$"+e++]={elements:b[1],classes:c,styles:g,attributes:d};a=a.slice(b[0].length)}return f}function m(a,b){var c=a.match(P[b]);return c?C(c[1]):null}function p(a){var b=a.styleBackup=a.attributes.style,c=a.classBackup=a.attributes["class"];if(!a.styles)a.styles=CKEDITOR.tools.parseCssText(b||"",1);if(!a.classes)a.classes=c?c.split(/\s+/):[]}function r(a,
b,g,d){var f=0,h;if(d.toHtml)b.name=b.name.replace(I,"$1");if(d.doCallbacks&&a.elementCallbacks){a:for(var k=a.elementCallbacks,i=0,j=k.length,o;i<j;++i)if(o=k[i](b)){h=o;break a}if(h)return h}if(d.doTransform)if(h=a._.transformations[b.name]){p(b);for(k=0;k<h.length;++k)x(a,b,h[k]);n(b)}if(d.doFilter){a:{k=b.name;i=a._;a=i.allowedRules.elements[k];h=i.allowedRules.generic;k=i.disallowedRules.elements[k];i=i.disallowedRules.generic;j=d.skipRequired;o={valid:false,validAttributes:{},validClasses:{},
validStyles:{},allAttributes:false,allClasses:false,allStyles:false,hadInvalidAttribute:false,hadInvalidClass:false,hadInvalidStyle:false};var v,m;if(!a&&!h)a=null;else{p(b);if(k){v=0;for(m=k.length;v<m;++v)if(c(k[v],b,o)===false){a=null;break a}}if(i){v=0;for(m=i.length;v<m;++v)c(i[v],b,o)}if(a){v=0;for(m=a.length;v<m;++v)e(a[v],b,o,j)}if(h){v=0;for(m=h.length;v<m;++v)e(h[v],b,o,j)}a=o}}if(!a){g.push(b);return A}if(!a.valid){g.push(b);return A}m=a.validAttributes;var s=a.validStyles;h=a.validClasses;
var k=b.attributes,q=b.styles,i=b.classes,j=b.classBackup,E=b.styleBackup,t,r,u=[];o=[];var H=/^data-cke-/;v=false;delete k.style;delete k["class"];delete b.classBackup;delete b.styleBackup;if(!a.allAttributes)for(t in k)if(!m[t])if(H.test(t)){if(t!=(r=t.replace(/^data-cke-saved-/,""))&&!m[r]){delete k[t];v=true}}else{delete k[t];v=true}if(!a.allStyles||a.hadInvalidStyle){for(t in q)a.allStyles||s[t]?u.push(t+":"+q[t]):v=true;if(u.length)k.style=u.sort().join("; ")}else if(E)k.style=E;if(!a.allClasses||
a.hadInvalidClass){for(t=0;t<i.length;++t)(a.allClasses||h[i[t]])&&o.push(i[t]);o.length&&(k["class"]=o.sort().join(" "));j&&o.length<j.split(/\s+/).length&&(v=true)}else j&&(k["class"]=j);v&&(f=A);if(!d.skipFinalValidation&&!l(b)){g.push(b);return A}}if(d.toHtml)b.name=b.name.replace(R,"cke:$1");return f}function o(a){var b=[],c;for(c in a)c.indexOf("*")>-1&&b.push(c.replace(/\*/g,".*"));return b.length?RegExp("^(?:"+b.join("|")+")$"):null}function n(a){var b=a.attributes,c;delete b.style;delete b["class"];
if(c=CKEDITOR.tools.writeCssText(a.styles,true))b.style=c;a.classes.length&&(b["class"]=a.classes.sort().join(" "))}function l(a){switch(a.name){case "a":if(!a.children.length&&!a.attributes.name)return false;break;case "img":if(!a.attributes.src)return false}return true}function s(a){if(!a)return false;if(a===true)return true;var b=o(a);return function(c){return c in a||b&&c.match(b)}}function t(){return new CKEDITOR.htmlParser.element("br")}function w(a){return a.type==CKEDITOR.NODE_ELEMENT&&(a.name==
"br"||B.$block[a.name])}function u(a,b,c){var g=a.name;if(B.$empty[g]||!a.children.length)if(g=="hr"&&b=="br")a.replaceWith(t());else{a.parent&&c.push({check:"it",el:a.parent});a.remove()}else if(B.$block[g]||g=="tr")if(b=="br"){if(a.previous&&!w(a.previous)){b=t();b.insertBefore(a)}if(a.next&&!w(a.next)){b=t();b.insertAfter(a)}a.replaceWithChildren()}else{var g=a.children,d;b:{d=B[b];for(var f=0,e=g.length,h;f<e;++f){h=g[f];if(h.type==CKEDITOR.NODE_ELEMENT&&!d[h.name]){d=false;break b}}d=true}if(d){a.name=
b;a.attributes={};c.push({check:"parent-down",el:a})}else{d=a.parent;for(var f=d.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT||d.name=="body",k,i,e=g.length;e>0;){h=g[--e];if(f&&(h.type==CKEDITOR.NODE_TEXT||h.type==CKEDITOR.NODE_ELEMENT&&B.$inline[h.name])){if(!k){k=new CKEDITOR.htmlParser.element(b);k.insertAfter(a);c.push({check:"parent-down",el:k})}k.add(h,0)}else{k=null;i=B[d.name]||B.span;h.insertAfter(a);d.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT&&(h.type==CKEDITOR.NODE_ELEMENT&&!i[h.name])&&c.push({check:"el-up",
el:h})}}a.remove()}}else if(g in{style:1,script:1})a.remove();else{a.parent&&c.push({check:"it",el:a.parent});a.replaceWithChildren()}}function x(a,b,c){var g,d;for(g=0;g<c.length;++g){d=c[g];if((!d.check||a.check(d.check,false))&&(!d.left||d.left(b))){d.right(b,T);break}}}function v(a,b){var c=b.getDefinition(),g=c.attributes,d=c.styles,f,e,h,k;if(a.name!=c.element)return false;for(f in g)if(f=="class"){c=g[f].split(/\s+/);for(h=a.classes.join("|");k=c.pop();)if(h.indexOf(k)==-1)return false}else if(a.attributes[f]!=
g[f])return false;for(e in d)if(a.styles[e]!=d[e])return false;return true}function q(a,b){var c,g;if(typeof a=="string")c=a;else if(a instanceof CKEDITOR.style)g=a;else{c=a[0];g=a[1]}return[{element:c,left:g,right:function(a,c){c.transform(a,b)}}]}function y(a){return function(b){return v(b,a)}}function z(a){return function(b,c){c[a](b)}}var B=CKEDITOR.dtd,A=1,D=CKEDITOR.tools.copy,C=CKEDITOR.tools.trim,G="cke-test",E=["","p","br","div"];CKEDITOR.FILTER_SKIP_TREE=2;CKEDITOR.filter=function(a){this.allowedContent=
[];this.disallowedContent=[];this.elementCallbacks=null;this.disabled=false;this.editor=null;this.id=CKEDITOR.tools.getNextNumber();this._={allowedRules:{elements:{},generic:[]},disallowedRules:{elements:{},generic:[]},transformations:{},cachedTests:{}};CKEDITOR.filter.instances[this.id]=this;if(a instanceof CKEDITOR.editor){a=this.editor=a;this.customConfig=true;var b=a.config.allowedContent;if(b===true)this.disabled=true;else{if(!b)this.customConfig=false;this.allow(b,"config",1);this.allow(a.config.extraAllowedContent,
"extra",1);this.allow(E[a.enterMode]+" "+E[a.shiftEnterMode],"default",1);this.disallow(a.config.disallowedContent)}}else{this.customConfig=false;this.allow(a,"default",1)}};CKEDITOR.filter.instances={};CKEDITOR.filter.prototype={allow:function(b,c,d){if(!k(this,b,d))return false;var f,e;if(typeof b=="string")b=g(b);else if(b instanceof CKEDITOR.style){if(b.toAllowedContentRules)return this.allow(b.toAllowedContentRules(this.editor),c,d);f=b.getDefinition();b={};d=f.attributes;b[f.element]=f={styles:f.styles,
requiredStyles:f.styles&&CKEDITOR.tools.objectKeys(f.styles)};if(d){d=D(d);f.classes=d["class"]?d["class"].split(/\s+/):null;f.requiredClasses=f.classes;delete d["class"];f.attributes=d;f.requiredAttributes=d&&CKEDITOR.tools.objectKeys(d)}}else if(CKEDITOR.tools.isArray(b)){for(f=0;f<b.length;++f)e=this.allow(b[f],c,d);return e}a(this,b,c,this.allowedContent,this._.allowedRules);return true},applyTo:function(a,b,c,d){if(this.disabled)return false;var g=this,f=[],e=this.editor&&this.editor.config.protectedSource,
h,k=false,i={doFilter:!c,doTransform:true,doCallbacks:true,toHtml:b};a.forEach(function(a){if(a.type==CKEDITOR.NODE_ELEMENT){if(a.attributes["data-cke-filter"]=="off")return false;if(!b||!(a.name=="span"&&~CKEDITOR.tools.objectKeys(a.attributes).join("|").indexOf("data-cke-"))){h=r(g,a,f,i);if(h&A)k=true;else if(h&2)return false}}else if(a.type==CKEDITOR.NODE_COMMENT&&a.value.match(/^\{cke_protected\}(?!\{C\})/)){var c;a:{var d=decodeURIComponent(a.value.replace(/^\{cke_protected\}/,""));c=[];var j,
o,v;if(e)for(o=0;o<e.length;++o)if((v=d.match(e[o]))&&v[0].length==d.length){c=true;break a}d=CKEDITOR.htmlParser.fragment.fromHtml(d);d.children.length==1&&(j=d.children[0]).type==CKEDITOR.NODE_ELEMENT&&r(g,j,c,i);c=!c.length}c||f.push(a)}},null,true);f.length&&(k=true);for(var j,a=[],d=E[d||(this.editor?this.editor.enterMode:CKEDITOR.ENTER_P)],o;c=f.pop();)c.type==CKEDITOR.NODE_ELEMENT?u(c,d,a):c.remove();for(;j=a.pop();){c=j.el;if(c.parent){o=B[c.parent.name]||B.span;switch(j.check){case "it":B.$removeEmpty[c.name]&&
!c.children.length?u(c,d,a):l(c)||u(c,d,a);break;case "el-up":c.parent.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT&&!o[c.name]&&u(c,d,a);break;case "parent-down":c.parent.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT&&!o[c.name]&&u(c.parent,d,a)}}}return k},checkFeature:function(a){if(this.disabled||!a)return true;a.toFeature&&(a=a.toFeature(this.editor));return!a.requiredContent||this.check(a.requiredContent)},disable:function(){this.disabled=true},disallow:function(b){if(!k(this,b,true))return false;typeof b==
"string"&&(b=g(b));a(this,b,null,this.disallowedContent,this._.disallowedRules);return true},addContentForms:function(a){if(!this.disabled&&a){var b,c,d=[],g;for(b=0;b<a.length&&!g;++b){c=a[b];if((typeof c=="string"||c instanceof CKEDITOR.style)&&this.check(c))g=c}if(g){for(b=0;b<a.length;++b)d.push(q(a[b],g));this.addTransformations(d)}}},addElementCallback:function(a){if(!this.elementCallbacks)this.elementCallbacks=[];this.elementCallbacks.push(a)},addFeature:function(a){if(this.disabled||!a)return true;
a.toFeature&&(a=a.toFeature(this.editor));this.allow(a.allowedContent,a.name);this.addTransformations(a.contentTransformations);this.addContentForms(a.contentForms);return a.requiredContent&&(this.customConfig||this.disallowedContent.length)?this.check(a.requiredContent):true},addTransformations:function(a){var b,c;if(!this.disabled&&a){var d=this._.transformations,g;for(g=0;g<a.length;++g){b=a[g];var f=void 0,e=void 0,h=void 0,k=void 0,i=void 0,j=void 0;c=[];for(e=0;e<b.length;++e){h=b[e];if(typeof h==
"string"){h=h.split(/\s*:\s*/);k=h[0];i=null;j=h[1]}else{k=h.check;i=h.left;j=h.right}if(!f){f=h;f=f.element?f.element:k?k.match(/^([a-z0-9]+)/i)[0]:f.left.getDefinition().element}i instanceof CKEDITOR.style&&(i=y(i));c.push({check:k==f?null:k,left:i,right:typeof j=="string"?z(j):j})}b=f;d[b]||(d[b]=[]);d[b].push(c)}}},check:function(a,b,c){if(this.disabled)return true;if(CKEDITOR.tools.isArray(a)){for(var d=a.length;d--;)if(this.check(a[d],b,c))return true;return false}var f,e;if(typeof a=="string"){e=
a+"<"+(b===false?"0":"1")+(c?"1":"0")+">";if(e in this._.cachedChecks)return this._.cachedChecks[e];d=g(a).$1;f=d.styles;var k=d.classes;d.name=d.elements;d.classes=k=k?k.split(/\s*,\s*/):[];d.styles=h(f);d.attributes=h(d.attributes);d.children=[];k.length&&(d.attributes["class"]=k.join(" "));if(f)d.attributes.style=CKEDITOR.tools.writeCssText(d.styles);f=d}else{d=a.getDefinition();f=d.styles;k=d.attributes||{};if(f){f=D(f);k.style=CKEDITOR.tools.writeCssText(f,true)}else f={};f={name:d.element,attributes:k,
classes:k["class"]?k["class"].split(/\s+/):[],styles:f,children:[]}}var k=CKEDITOR.tools.clone(f),i=[],j;if(b!==false&&(j=this._.transformations[f.name])){for(d=0;d<j.length;++d)x(this,f,j[d]);n(f)}r(this,k,i,{doFilter:true,doTransform:b!==false,skipRequired:!c,skipFinalValidation:!c});b=i.length>0?false:CKEDITOR.tools.objectCompare(f.attributes,k.attributes,true)?true:false;typeof a=="string"&&(this._.cachedChecks[e]=b);return b},getAllowedEnterMode:function(){var a=["p","div","br"],b={p:CKEDITOR.ENTER_P,
div:CKEDITOR.ENTER_DIV,br:CKEDITOR.ENTER_BR};return function(c,d){var g=a.slice(),f;if(this.check(E[c]))return c;for(d||(g=g.reverse());f=g.pop();)if(this.check(f))return b[f];return CKEDITOR.ENTER_BR}}(),destroy:function(){delete CKEDITOR.filter.instances[this.id];delete this._;delete this.allowedContent;delete this.disallowedContent}};var H={styles:1,attributes:1,classes:1},L={styles:"requiredStyles",attributes:"requiredAttributes",classes:"requiredClasses"},J=/^([a-z0-9\-*\s]+)((?:\s*\{[!\w\-,\s\*]+\}\s*|\s*\[[!\w\-,\s\*]+\]\s*|\s*\([!\w\-,\s\*]+\)\s*){0,3})(?:;\s*|$)/i,
P={styles:/{([^}]+)}/,attrs:/\[([^\]]+)\]/,classes:/\(([^\)]+)\)/},I=/^cke:(object|embed|param)$/,R=/^(object|embed|param)$/,T=CKEDITOR.filter.transformationsTools={sizeToStyle:function(a){this.lengthToStyle(a,"width");this.lengthToStyle(a,"height")},sizeToAttribute:function(a){this.lengthToAttribute(a,"width");this.lengthToAttribute(a,"height")},lengthToStyle:function(a,b,c){c=c||b;if(!(c in a.styles)){var d=a.attributes[b];if(d){/^\d+$/.test(d)&&(d=d+"px");a.styles[c]=d}}delete a.attributes[b]},
lengthToAttribute:function(a,b,c){c=c||b;if(!(c in a.attributes)){var d=a.styles[b],g=d&&d.match(/^(\d+)(?:\.\d*)?px$/);g?a.attributes[c]=g[1]:d==G&&(a.attributes[c]=G)}delete a.styles[b]},alignmentToStyle:function(a){if(!("float"in a.styles)){var b=a.attributes.align;if(b=="left"||b=="right")a.styles["float"]=b}delete a.attributes.align},alignmentToAttribute:function(a){if(!("align"in a.attributes)){var b=a.styles["float"];if(b=="left"||b=="right")a.attributes.align=b}delete a.styles["float"]},matchesStyle:v,
transform:function(a,b){if(typeof b=="string")a.name=b;else{var c=b.getDefinition(),d=c.styles,g=c.attributes,f,e,h,k;a.name=c.element;for(f in g)if(f=="class"){c=a.classes.join("|");for(h=g[f].split(/\s+/);k=h.pop();)c.indexOf(k)==-1&&a.classes.push(k)}else a.attributes[f]=g[f];for(e in d)a.styles[e]=d[e]}}}}(),function(){CKEDITOR.focusManager=function(a){if(a.focusManager)return a.focusManager;this.hasFocus=false;this.currentActive=null;this._={editor:a};return this};CKEDITOR.focusManager._={blurDelay:200};
CKEDITOR.focusManager.prototype={focus:function(a){this._.timer&&clearTimeout(this._.timer);if(a)this.currentActive=a;if(!this.hasFocus&&!this._.locked){(a=CKEDITOR.currentInstance)&&a.focusManager.blur(1);this.hasFocus=true;(a=this._.editor.container)&&a.addClass("cke_focus");this._.editor.fire("focus")}},lock:function(){this._.locked=1},unlock:function(){delete this._.locked},blur:function(a){function e(){if(this.hasFocus){this.hasFocus=false;var a=this._.editor.container;a&&a.removeClass("cke_focus");
this._.editor.fire("blur")}}if(!this._.locked){this._.timer&&clearTimeout(this._.timer);var b=CKEDITOR.focusManager._.blurDelay;a||!b?e.call(this):this._.timer=CKEDITOR.tools.setTimeout(function(){delete this._.timer;e.call(this)},b,this)}},add:function(a,e){var b=a.getCustomData("focusmanager");if(!b||b!=this){b&&b.remove(a);var b="focus",c="blur";if(e)if(CKEDITOR.env.ie){b="focusin";c="focusout"}else CKEDITOR.event.useCapture=1;var f={blur:function(){a.equals(this.currentActive)&&this.blur()},focus:function(){this.focus(a)}};
a.on(b,f.focus,this);a.on(c,f.blur,this);if(e)CKEDITOR.event.useCapture=0;a.setCustomData("focusmanager",this);a.setCustomData("focusmanager_handlers",f)}},remove:function(a){a.removeCustomData("focusmanager");var e=a.removeCustomData("focusmanager_handlers");a.removeListener("blur",e.blur);a.removeListener("focus",e.focus)}}}(),CKEDITOR.keystrokeHandler=function(a){if(a.keystrokeHandler)return a.keystrokeHandler;this.keystrokes={};this.blockedKeystrokes={};this._={editor:a};return this},function(){var a,
e=function(b){var b=b.data,f=b.getKeystroke(),e=this.keystrokes[f],i=this._.editor;a=i.fire("key",{keyCode:f,domEvent:b})===false;if(!a){e&&(a=i.execCommand(e,{from:"keystrokeHandler"})!==false);a||(a=!!this.blockedKeystrokes[f])}a&&b.preventDefault(true);return!a},b=function(b){if(a){a=false;b.data.preventDefault(true)}};CKEDITOR.keystrokeHandler.prototype={attach:function(a){a.on("keydown",e,this);if(CKEDITOR.env.gecko&&CKEDITOR.env.mac)a.on("keypress",b,this)}}}(),function(){CKEDITOR.lang={languages:{af:1,
ar:1,bg:1,bn:1,bs:1,ca:1,cs:1,cy:1,da:1,de:1,el:1,"en-au":1,"en-ca":1,"en-gb":1,en:1,eo:1,es:1,et:1,eu:1,fa:1,fi:1,fo:1,"fr-ca":1,fr:1,gl:1,gu:1,he:1,hi:1,hr:1,hu:1,id:1,is:1,it:1,ja:1,ka:1,km:1,ko:1,ku:1,lt:1,lv:1,mk:1,mn:1,ms:1,nb:1,nl:1,no:1,pl:1,"pt-br":1,pt:1,ro:1,ru:1,si:1,sk:1,sl:1,sq:1,"sr-latn":1,sr:1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,"zh-cn":1,zh:1},rtl:{ar:1,fa:1,he:1,ku:1,ug:1},load:function(a,e,b){if(!a||!CKEDITOR.lang.languages[a])a=this.detect(e,a);var c=this,e=function(){c[a].dir=
c.rtl[a]?"rtl":"ltr";b(a,c[a])};this[a]?e():CKEDITOR.scriptLoader.load(CKEDITOR.getUrl("lang/"+a+".js"),e,this)},detect:function(a,e){var b=this.languages,e=e||navigator.userLanguage||navigator.language||a,c=e.toLowerCase().match(/([a-z]+)(?:-([a-z]+))?/),f=c[1],c=c[2];b[f+"-"+c]?f=f+"-"+c:b[f]||(f=null);CKEDITOR.lang.detect=f?function(){return f}:function(a){return a};return f||a}}}(),CKEDITOR.scriptLoader=function(){var a={},e={};return{load:function(b,c,f,k){var i=typeof b=="string";i&&(b=[b]);
f||(f=CKEDITOR);var d=b.length,j=[],h=[],g=function(a){c&&(i?c.call(f,a):c.call(f,j,h))};if(d===0)g(true);else{var m=function(a,b){(b?j:h).push(a);if(--d<=0){k&&CKEDITOR.document.getDocumentElement().removeStyle("cursor");g(b)}},p=function(b,c){a[b]=1;var d=e[b];delete e[b];for(var g=0;g<d.length;g++)d[g](b,c)},r=function(b){if(a[b])m(b,true);else{var d=e[b]||(e[b]=[]);d.push(m);if(!(d.length>1)){var g=new CKEDITOR.dom.element("script");g.setAttributes({type:"text/javascript",src:b});if(c)if(CKEDITOR.env.ie&&
CKEDITOR.env.version<11)g.$.onreadystatechange=function(){if(g.$.readyState=="loaded"||g.$.readyState=="complete"){g.$.onreadystatechange=null;p(b,true)}};else{g.$.onload=function(){setTimeout(function(){p(b,true)},0)};g.$.onerror=function(){p(b,false)}}g.appendTo(CKEDITOR.document.getHead())}}};k&&CKEDITOR.document.getDocumentElement().setStyle("cursor","wait");for(var o=0;o<d;o++)r(b[o])}},queue:function(){function a(){var b;(b=c[0])&&this.load(b.scriptUrl,b.callback,CKEDITOR,0)}var c=[];return function(f,
e){var i=this;c.push({scriptUrl:f,callback:function(){e&&e.apply(this,arguments);c.shift();a.call(i)}});c.length==1&&a.call(this)}}()}}(),CKEDITOR.resourceManager=function(a,e){this.basePath=a;this.fileName=e;this.registered={};this.loaded={};this.externals={};this._={waitingList:{}}},CKEDITOR.resourceManager.prototype={add:function(a,e){if(this.registered[a])throw'[CKEDITOR.resourceManager.add] The resource name "'+a+'" is already registered.';var b=this.registered[a]=e||{};b.name=a;b.path=this.getPath(a);
CKEDITOR.fire(a+CKEDITOR.tools.capitalize(this.fileName)+"Ready",b);return this.get(a)},get:function(a){return this.registered[a]||null},getPath:function(a){var e=this.externals[a];return CKEDITOR.getUrl(e&&e.dir||this.basePath+a+"/")},getFilePath:function(a){var e=this.externals[a];return CKEDITOR.getUrl(this.getPath(a)+(e?e.file:this.fileName+".js"))},addExternal:function(a,e,b){for(var a=a.split(","),c=0;c<a.length;c++){var f=a[c];b||(e=e.replace(/[^\/]+$/,function(a){b=a;return""}));this.externals[f]=
{dir:e,file:b||this.fileName+".js"}}},load:function(a,e,b){CKEDITOR.tools.isArray(a)||(a=a?[a]:[]);for(var c=this.loaded,f=this.registered,k=[],i={},d={},j=0;j<a.length;j++){var h=a[j];if(h)if(!c[h]&&!f[h]){var g=this.getFilePath(h);k.push(g);g in i||(i[g]=[]);i[g].push(h)}else d[h]=this.get(h)}CKEDITOR.scriptLoader.load(k,function(a,g){if(g.length)throw'[CKEDITOR.resourceManager.load] Resource name "'+i[g[0]].join(",")+'" was not found at "'+g[0]+'".';for(var f=0;f<a.length;f++)for(var h=i[a[f]],
k=0;k<h.length;k++){var j=h[k];d[j]=this.get(j);c[j]=1}e.call(b,d)},this)}},CKEDITOR.plugins=new CKEDITOR.resourceManager("plugins/","plugin"),CKEDITOR.plugins.load=CKEDITOR.tools.override(CKEDITOR.plugins.load,function(a){var e={};return function(b,c,f){var k={},i=function(b){a.call(this,b,function(a){CKEDITOR.tools.extend(k,a);var b=[],d;for(d in a){var m=a[d],p=m&&m.requires;if(!e[d]){if(m.icons)for(var r=m.icons.split(","),o=r.length;o--;)CKEDITOR.skin.addIcon(r[o],m.path+"icons/"+(CKEDITOR.env.hidpi&&
m.hidpi?"hidpi/":"")+r[o]+".png");e[d]=1}if(p){p.split&&(p=p.split(","));for(m=0;m<p.length;m++)k[p[m]]||b.push(p[m])}}if(b.length)i.call(this,b);else{for(d in k){m=k[d];if(m.onLoad&&!m.onLoad._called){m.onLoad()===false&&delete k[d];m.onLoad._called=1}}c&&c.call(f||window,k)}},this)};i.call(this,b)}}),CKEDITOR.plugins.setLang=function(a,e,b){var c=this.get(a),a=c.langEntries||(c.langEntries={}),c=c.lang||(c.lang=[]);c.split&&(c=c.split(","));CKEDITOR.tools.indexOf(c,e)==-1&&c.push(e);a[e]=b},CKEDITOR.ui=
function(a){if(a.ui)return a.ui;this.items={};this.instances={};this.editor=a;this._={handlers:{}};return this},CKEDITOR.ui.prototype={add:function(a,e,b){b.name=a.toLowerCase();var c=this.items[a]={type:e,command:b.command||null,args:Array.prototype.slice.call(arguments,2)};CKEDITOR.tools.extend(c,b)},get:function(a){return this.instances[a]},create:function(a){var e=this.items[a],b=e&&this._.handlers[e.type],c=e&&e.command&&this.editor.getCommand(e.command),b=b&&b.create.apply(this,e.args);this.instances[a]=
b;c&&c.uiItems.push(b);if(b&&!b.type)b.type=e.type;return b},addHandler:function(a,e){this._.handlers[a]=e},space:function(a){return CKEDITOR.document.getById(this.spaceId(a))},spaceId:function(a){return this.editor.id+"_"+a}},CKEDITOR.event.implementOn(CKEDITOR.ui),function(){function a(a,c,d){CKEDITOR.event.call(this);a=a&&CKEDITOR.tools.clone(a);if(c!==void 0){if(c instanceof CKEDITOR.dom.element){if(!d)throw Error("One of the element modes must be specified.");}else throw Error("Expect element of type CKEDITOR.dom.element.");
if(CKEDITOR.env.ie&&CKEDITOR.env.quirks&&d==CKEDITOR.ELEMENT_MODE_INLINE)throw Error("Inline element mode is not supported on IE quirks.");if(!(d==CKEDITOR.ELEMENT_MODE_INLINE?c.is(CKEDITOR.dtd.$editable)||c.is("textarea"):d==CKEDITOR.ELEMENT_MODE_REPLACE?!c.is(CKEDITOR.dtd.$nonBodyContent):1))throw Error('The specified element mode is not supported on element: "'+c.getName()+'".');this.element=c;this.elementMode=d;this.name=this.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO&&(c.getId()||c.getNameAtt())}else this.elementMode=
CKEDITOR.ELEMENT_MODE_NONE;this._={};this.commands={};this.templates={};this.name=this.name||e();this.id=CKEDITOR.tools.getNextId();this.status="unloaded";this.config=CKEDITOR.tools.prototypedCopy(CKEDITOR.config);this.ui=new CKEDITOR.ui(this);this.focusManager=new CKEDITOR.focusManager(this);this.keystrokeHandler=new CKEDITOR.keystrokeHandler(this);this.on("readOnly",b);this.on("selectionChange",function(a){f(this,a.data.path)});this.on("activeFilterChange",function(){f(this,this.elementPath(),true)});
this.on("mode",b);this.on("instanceReady",function(){this.config.startupFocus&&this.focus()});CKEDITOR.fire("instanceCreated",null,this);CKEDITOR.add(this);CKEDITOR.tools.setTimeout(function(){i(this,a)},0,this)}function e(){do var a="editor"+ ++p;while(CKEDITOR.instances[a]);return a}function b(){var a=this.commands,b;for(b in a)c(this,a[b])}function c(a,b){b[b.startDisabled?"disable":a.readOnly&&!b.readOnly?"disable":b.modes[a.mode]?"enable":"disable"]()}function f(a,b,c){if(b){var d,g,f=a.commands;
for(g in f){d=f[g];(c||d.contextSensitive)&&d.refresh(a,b)}}}function k(a){var b=a.config.customConfig;if(!b)return false;var b=CKEDITOR.getUrl(b),c=r[b]||(r[b]={});if(c.fn){c.fn.call(a,a.config);(CKEDITOR.getUrl(a.config.customConfig)==b||!k(a))&&a.fireOnce("customConfigLoaded")}else CKEDITOR.scriptLoader.queue(b,function(){c.fn=CKEDITOR.editorConfig?CKEDITOR.editorConfig:function(){};k(a)});return true}function i(a,b){a.on("customConfigLoaded",function(){if(b){if(b.on)for(var c in b.on)a.on(c,b.on[c]);
CKEDITOR.tools.extend(a.config,b,true);delete a.config.on}c=a.config;a.readOnly=c.readOnly?true:a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?a.element.is("textarea")?a.element.hasAttribute("disabled")||a.element.hasAttribute("readonly"):a.element.isReadOnly():a.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE?a.element.hasAttribute("disabled")||a.element.hasAttribute("readonly"):false;a.blockless=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?!(a.element.is("textarea")||CKEDITOR.dtd[a.element.getName()].p):
false;a.tabIndex=c.tabIndex||a.element&&a.element.getAttribute("tabindex")||0;a.activeEnterMode=a.enterMode=a.blockless?CKEDITOR.ENTER_BR:c.enterMode;a.activeShiftEnterMode=a.shiftEnterMode=a.blockless?CKEDITOR.ENTER_BR:c.shiftEnterMode;if(c.skin)CKEDITOR.skinName=c.skin;a.fireOnce("configLoaded");a.dataProcessor=new CKEDITOR.htmlDataProcessor(a);a.filter=a.activeFilter=new CKEDITOR.filter(a);d(a)});if(b&&b.customConfig!=null)a.config.customConfig=b.customConfig;k(a)||a.fireOnce("customConfigLoaded")}
function d(a){CKEDITOR.skin.loadPart("editor",function(){j(a)})}function j(a){CKEDITOR.lang.load(a.config.language,a.config.defaultLanguage,function(b,c){var d=a.config.title;a.langCode=b;a.lang=CKEDITOR.tools.prototypedCopy(c);a.title=typeof d=="string"||d===false?d:[a.lang.editor,a.name].join(", ");if(!a.config.contentsLangDirection)a.config.contentsLangDirection=a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?a.element.getDirection(1):a.lang.dir;a.fire("langLoaded");h(a)})}function h(a){a.getStylesSet(function(b){a.once("loaded",
function(){a.fire("stylesSet",{styles:b})},null,null,1);g(a)})}function g(a){var b=a.config,c=b.plugins,d=b.extraPlugins,g=b.removePlugins;if(d)var f=RegExp("(?:^|,)(?:"+d.replace(/\s*,\s*/g,"|")+")(?=,|$)","g"),c=c.replace(f,""),c=c+(","+d);if(g)var e=RegExp("(?:^|,)(?:"+g.replace(/\s*,\s*/g,"|")+")(?=,|$)","g"),c=c.replace(e,"");CKEDITOR.env.air&&(c=c+",adobeair");CKEDITOR.plugins.load(c.split(","),function(c){var d=[],g=[],f=[];a.plugins=c;for(var h in c){var k=c[h],i=k.lang,j=null,m=k.requires,
l;CKEDITOR.tools.isArray(m)&&(m=m.join(","));if(m&&(l=m.match(e)))for(;m=l.pop();)CKEDITOR.tools.setTimeout(function(a,b){throw Error('Plugin "'+a.replace(",","")+'" cannot be removed from the plugins list, because it\'s required by "'+b+'" plugin.');},0,null,[m,h]);if(i&&!a.lang[h]){i.split&&(i=i.split(","));if(CKEDITOR.tools.indexOf(i,a.langCode)>=0)j=a.langCode;else{j=a.langCode.replace(/-.*/,"");j=j!=a.langCode&&CKEDITOR.tools.indexOf(i,j)>=0?j:CKEDITOR.tools.indexOf(i,"en")>=0?"en":i[0]}if(!k.langEntries||
!k.langEntries[j])f.push(CKEDITOR.getUrl(k.path+"lang/"+j+".js"));else{a.lang[h]=k.langEntries[j];j=null}}g.push(j);d.push(k)}CKEDITOR.scriptLoader.load(f,function(){for(var c=["beforeInit","init","afterInit"],f=0;f<c.length;f++)for(var e=0;e<d.length;e++){var h=d[e];f===0&&(g[e]&&h.lang&&h.langEntries)&&(a.lang[h.name]=h.langEntries[g[e]]);if(h[c[f]])h[c[f]](a)}a.fireOnce("pluginsLoaded");b.keystrokes&&a.setKeystroke(a.config.keystrokes);for(e=0;e<a.config.blockedKeystrokes.length;e++)a.keystrokeHandler.blockedKeystrokes[a.config.blockedKeystrokes[e]]=
1;a.status="loaded";a.fireOnce("loaded");CKEDITOR.fire("instanceLoaded",null,a)})})}function m(){var a=this.element;if(a&&this.elementMode!=CKEDITOR.ELEMENT_MODE_APPENDTO){var b=this.getData();this.config.htmlEncodeOutput&&(b=CKEDITOR.tools.htmlEncode(b));a.is("textarea")?a.setValue(b):a.setHtml(b);return true}return false}a.prototype=CKEDITOR.editor.prototype;CKEDITOR.editor=a;var p=0,r={};CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{addCommand:function(a,b){b.name=a.toLowerCase();var d=new CKEDITOR.command(this,
b);this.mode&&c(this,d);return this.commands[a]=d},_attachToForm:function(){function a(d){b.updateElement();b._.required&&(!c.getValue()&&b.fire("required")===false)&&d.data.preventDefault()}var b=this,c=b.element,d=new CKEDITOR.dom.element(c.$.form);if(c.is("textarea")&&d){d.on("submit",a);if(d.$.submit&&d.$.submit.call&&d.$.submit.apply)d.$.submit=CKEDITOR.tools.override(d.$.submit,function(b){return function(){a();b.apply?b.apply(this):b()}});b.on("destroy",function(){d.removeListener("submit",
a)})}},destroy:function(a){this.fire("beforeDestroy");!a&&m.call(this);this.editable(null);this.filter.destroy();delete this.filter;delete this.activeFilter;this.status="destroyed";this.fire("destroy");this.removeAllListeners();CKEDITOR.remove(this);CKEDITOR.fire("instanceDestroyed",null,this)},elementPath:function(a){if(!a){a=this.getSelection();if(!a)return null;a=a.getStartElement()}return a?new CKEDITOR.dom.elementPath(a,this.editable()):null},createRange:function(){var a=this.editable();return a?
new CKEDITOR.dom.range(a):null},execCommand:function(a,b){var c=this.getCommand(a),d={name:a,commandData:b,command:c};if(c&&c.state!=CKEDITOR.TRISTATE_DISABLED&&this.fire("beforeCommandExec",d)!==false){d.returnValue=c.exec(d.commandData);if(!c.async&&this.fire("afterCommandExec",d)!==false)return d.returnValue}return false},getCommand:function(a){return this.commands[a]},getData:function(a){!a&&this.fire("beforeGetData");var b=this._.data;if(typeof b!="string")b=(b=this.element)&&this.elementMode==
CKEDITOR.ELEMENT_MODE_REPLACE?b.is("textarea")?b.getValue():b.getHtml():"";b={dataValue:b};!a&&this.fire("getData",b);return b.dataValue},getSnapshot:function(){var a=this.fire("getSnapshot");if(typeof a!="string")a=(a=this.element)&&this.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE?a.is("textarea")?a.getValue():a.getHtml():"";return a},loadSnapshot:function(a){this.fire("loadSnapshot",a)},setData:function(a,b,c){var d=true,g=b;if(b&&typeof b=="object"){c=b.internal;g=b.callback;d=!b.noSnapshot}!c&&
d&&this.fire("saveSnapshot");if(g||!c)this.once("dataReady",function(a){!c&&d&&this.fire("saveSnapshot");g&&g.call(a.editor)});a={dataValue:a};!c&&this.fire("setData",a);this._.data=a.dataValue;!c&&this.fire("afterSetData",a)},setReadOnly:function(a){a=a==null||a;if(this.readOnly!=a){this.readOnly=a;this.keystrokeHandler.blockedKeystrokes[8]=+a;this.editable().setReadOnly(a);this.fire("readOnly")}},insertHtml:function(a,b,c){this.fire("insertHtml",{dataValue:a,mode:b,range:c})},insertText:function(a){this.fire("insertText",
a)},insertElement:function(a){this.fire("insertElement",a)},getSelectedHtml:function(a){var b=this.editable(),c=this.getSelection(),c=c&&c.getRanges();if(!b||!c||c.length===0)return null;b=b.getHtmlFromRange(c[0]);return a?b.getHtml():b},extractSelectedHtml:function(a,b){var c=this.editable(),d=this.getSelection().getRanges();if(!c||d.length===0)return null;d=d[0];c=c.extractHtmlFromRange(d,b);b||this.getSelection().selectRanges([d]);return a?c.getHtml():c},focus:function(){this.fire("beforeFocus")},
checkDirty:function(){return this.status=="ready"&&this._.previousValue!==this.getSnapshot()},resetDirty:function(){this._.previousValue=this.getSnapshot()},updateElement:function(){return m.call(this)},setKeystroke:function(){for(var a=this.keystrokeHandler.keystrokes,b=CKEDITOR.tools.isArray(arguments[0])?arguments[0]:[[].slice.call(arguments,0)],c,d,g=b.length;g--;){c=b[g];d=0;if(CKEDITOR.tools.isArray(c)){d=c[1];c=c[0]}d?a[c]=d:delete a[c]}},addFeature:function(a){return this.filter.addFeature(a)},
setActiveFilter:function(a){if(!a)a=this.filter;if(this.activeFilter!==a){this.activeFilter=a;this.fire("activeFilterChange");a===this.filter?this.setActiveEnterMode(null,null):this.setActiveEnterMode(a.getAllowedEnterMode(this.enterMode),a.getAllowedEnterMode(this.shiftEnterMode,true))}},setActiveEnterMode:function(a,b){a=a?this.blockless?CKEDITOR.ENTER_BR:a:this.enterMode;b=b?this.blockless?CKEDITOR.ENTER_BR:b:this.shiftEnterMode;if(this.activeEnterMode!=a||this.activeShiftEnterMode!=b){this.activeEnterMode=
a;this.activeShiftEnterMode=b;this.fire("activeEnterModeChange")}},showNotification:function(a){alert(a)}})}(),CKEDITOR.ELEMENT_MODE_NONE=0,CKEDITOR.ELEMENT_MODE_REPLACE=1,CKEDITOR.ELEMENT_MODE_APPENDTO=2,CKEDITOR.ELEMENT_MODE_INLINE=3,CKEDITOR.htmlParser=function(){this._={htmlPartsRegex:/<(?:(?:\/([^>]+)>)|(?:!--([\S|\s]*?)--\>)|(?:([^\/\s>]+)((?:\s+[\w\-:.]+(?:\s*=\s*?(?:(?:"[^"]*")|(?:'[^']*')|[^\s"'\/>]+))?)*)[\S\s]*?(\/?)>))/g}},function(){var a=/([\w\-:.]+)(?:(?:\s*=\s*(?:(?:"([^"]*)")|(?:'([^']*)')|([^\s>]+)))|(?=\s|$))/g,
e={checked:1,compact:1,declare:1,defer:1,disabled:1,ismap:1,multiple:1,nohref:1,noresize:1,noshade:1,nowrap:1,readonly:1,selected:1};CKEDITOR.htmlParser.prototype={onTagOpen:function(){},onTagClose:function(){},onText:function(){},onCDATA:function(){},onComment:function(){},parse:function(b){for(var c,f,k=0,i;c=this._.htmlPartsRegex.exec(b);){f=c.index;if(f>k){k=b.substring(k,f);if(i)i.push(k);else this.onText(k)}k=this._.htmlPartsRegex.lastIndex;if(f=c[1]){f=f.toLowerCase();if(i&&CKEDITOR.dtd.$cdata[f]){this.onCDATA(i.join(""));
i=null}if(!i){this.onTagClose(f);continue}}if(i)i.push(c[0]);else if(f=c[3]){f=f.toLowerCase();if(!/="/.test(f)){var d={},j,h=c[4];c=!!c[5];if(h)for(;j=a.exec(h);){var g=j[1].toLowerCase();j=j[2]||j[3]||j[4]||"";d[g]=!j&&e[g]?g:CKEDITOR.tools.htmlDecodeAttr(j)}this.onTagOpen(f,d,c);!i&&CKEDITOR.dtd.$cdata[f]&&(i=[])}}else if(f=c[2])this.onComment(f)}if(b.length>k)this.onText(b.substring(k,b.length))}}}(),CKEDITOR.htmlParser.basicWriter=CKEDITOR.tools.createClass({$:function(){this._={output:[]}},
proto:{openTag:function(a){this._.output.push("<",a)},openTagClose:function(a,e){e?this._.output.push(" />"):this._.output.push(">")},attribute:function(a,e){typeof e=="string"&&(e=CKEDITOR.tools.htmlEncodeAttr(e));this._.output.push(" ",a,'="',e,'"')},closeTag:function(a){this._.output.push("</",a,">")},text:function(a){this._.output.push(a)},comment:function(a){this._.output.push("<\!--",a,"--\>")},write:function(a){this._.output.push(a)},reset:function(){this._.output=[];this._.indent=false},getHtml:function(a){var e=
this._.output.join("");a&&this.reset();return e}}}),"use strict",function(){CKEDITOR.htmlParser.node=function(){};CKEDITOR.htmlParser.node.prototype={remove:function(){var a=this.parent.children,e=CKEDITOR.tools.indexOf(a,this),b=this.previous,c=this.next;b&&(b.next=c);c&&(c.previous=b);a.splice(e,1);this.parent=null},replaceWith:function(a){var e=this.parent.children,b=CKEDITOR.tools.indexOf(e,this),c=a.previous=this.previous,f=a.next=this.next;c&&(c.next=a);f&&(f.previous=a);e[b]=a;a.parent=this.parent;
this.parent=null},insertAfter:function(a){var e=a.parent.children,b=CKEDITOR.tools.indexOf(e,a),c=a.next;e.splice(b+1,0,this);this.next=a.next;this.previous=a;a.next=this;c&&(c.previous=this);this.parent=a.parent},insertBefore:function(a){var e=a.parent.children,b=CKEDITOR.tools.indexOf(e,a);e.splice(b,0,this);this.next=a;(this.previous=a.previous)&&(a.previous.next=this);a.previous=this;this.parent=a.parent},getAscendant:function(a){var e=typeof a=="function"?a:typeof a=="string"?function(b){return b.name==
a}:function(b){return b.name in a},b=this.parent;for(;b&&b.type==CKEDITOR.NODE_ELEMENT;){if(e(b))return b;b=b.parent}return null},wrapWith:function(a){this.replaceWith(a);a.add(this);return a},getIndex:function(){return CKEDITOR.tools.indexOf(this.parent.children,this)},getFilterContext:function(a){return a||{}}}}(),"use strict",CKEDITOR.htmlParser.comment=function(a){this.value=a;this._={isBlockLike:false}},CKEDITOR.htmlParser.comment.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,
{type:CKEDITOR.NODE_COMMENT,filter:function(a,e){var b=this.value;if(!(b=a.onComment(e,b,this))){this.remove();return false}if(typeof b!="string"){this.replaceWith(b);return false}this.value=b;return true},writeHtml:function(a,e){e&&this.filter(e);a.comment(this.value)}}),"use strict",function(){CKEDITOR.htmlParser.text=function(a){this.value=a;this._={isBlockLike:false}};CKEDITOR.htmlParser.text.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_TEXT,filter:function(a,
e){if(!(this.value=a.onText(e,this.value,this))){this.remove();return false}},writeHtml:function(a,e){e&&this.filter(e);a.text(this.value)}})}(),"use strict",function(){CKEDITOR.htmlParser.cdata=function(a){this.value=a};CKEDITOR.htmlParser.cdata.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_TEXT,filter:function(){},writeHtml:function(a){a.write(this.value)}})}(),"use strict",CKEDITOR.htmlParser.fragment=function(){this.children=[];this.parent=null;this._={isBlockLike:true,
hasInlineStarted:false}},function(){function a(a){return a.attributes["data-cke-survive"]?false:a.name=="a"&&a.attributes.href||CKEDITOR.dtd.$removeEmpty[a.name]}var e=CKEDITOR.tools.extend({table:1,ul:1,ol:1,dl:1},CKEDITOR.dtd.table,CKEDITOR.dtd.ul,CKEDITOR.dtd.ol,CKEDITOR.dtd.dl),b={ol:1,ul:1},c=CKEDITOR.tools.extend({},{html:1},CKEDITOR.dtd.html,CKEDITOR.dtd.body,CKEDITOR.dtd.head,{style:1,script:1}),f={ul:"li",ol:"li",dl:"dd",table:"tbody",tbody:"tr",thead:"tr",tfoot:"tr",tr:"td"};CKEDITOR.htmlParser.fragment.fromHtml=
function(k,i,d){function j(a){var b;if(l.length>0)for(var c=0;c<l.length;c++){var d=l[c],g=d.name,f=CKEDITOR.dtd[g],e=t.name&&CKEDITOR.dtd[t.name];if((!e||e[g])&&(!a||!f||f[a]||!CKEDITOR.dtd[a])){if(!b){h();b=1}d=d.clone();d.parent=t;t=d;l.splice(c,1);c--}else if(g==t.name){m(t,t.parent,1);c--}}}function h(){for(;s.length;)m(s.shift(),t)}function g(a){if(a._.isBlockLike&&a.name!="pre"&&a.name!="textarea"){var b=a.children.length,c=a.children[b-1],d;if(c&&c.type==CKEDITOR.NODE_TEXT)(d=CKEDITOR.tools.rtrim(c.value))?
c.value=d:a.children.length=b-1}}function m(b,c,f){var c=c||t||n,e=t;if(b.previous===void 0){if(p(c,b)){t=c;o.onTagOpen(d,{});b.returnPoint=c=t}g(b);(!a(b)||b.children.length)&&c.add(b);b.name=="pre"&&(u=false);b.name=="textarea"&&(w=false)}if(b.returnPoint){t=b.returnPoint;delete b.returnPoint}else t=f?c:e}function p(a,b){if((a==n||a.name=="body")&&d&&(!a.name||CKEDITOR.dtd[a.name][d])){var c,g;return(c=b.attributes&&(g=b.attributes["data-cke-real-element-type"])?g:b.name)&&c in CKEDITOR.dtd.$inline&&
!(c in CKEDITOR.dtd.head)&&!b.isOrphan||b.type==CKEDITOR.NODE_TEXT}}function r(a,b){return a in CKEDITOR.dtd.$listItem||a in CKEDITOR.dtd.$tableContent?a==b||a=="dt"&&b=="dd"||a=="dd"&&b=="dt":false}var o=new CKEDITOR.htmlParser,n=i instanceof CKEDITOR.htmlParser.element?i:typeof i=="string"?new CKEDITOR.htmlParser.element(i):new CKEDITOR.htmlParser.fragment,l=[],s=[],t=n,w=n.name=="textarea",u=n.name=="pre";o.onTagOpen=function(d,g,f,k){g=new CKEDITOR.htmlParser.element(d,g);if(g.isUnknown&&f)g.isEmpty=
true;g.isOptionalClose=k;if(a(g))l.push(g);else{if(d=="pre")u=true;else{if(d=="br"&&u){t.add(new CKEDITOR.htmlParser.text("\n"));return}d=="textarea"&&(w=true)}if(d=="br")s.push(g);else{for(;;){k=(f=t.name)?CKEDITOR.dtd[f]||(t._.isBlockLike?CKEDITOR.dtd.div:CKEDITOR.dtd.span):c;if(!g.isUnknown&&!t.isUnknown&&!k[d])if(t.isOptionalClose)o.onTagClose(f);else if(d in b&&f in b){f=t.children;(f=f[f.length-1])&&f.name=="li"||m(f=new CKEDITOR.htmlParser.element("li"),t);!g.returnPoint&&(g.returnPoint=t);
t=f}else if(d in CKEDITOR.dtd.$listItem&&!r(d,f))o.onTagOpen(d=="li"?"ul":"dl",{},0,1);else if(f in e&&!r(d,f)){!g.returnPoint&&(g.returnPoint=t);t=t.parent}else{f in CKEDITOR.dtd.$inline&&l.unshift(t);if(t.parent)m(t,t.parent,1);else{g.isOrphan=1;break}}else break}j(d);h();g.parent=t;g.isEmpty?m(g):t=g}}};o.onTagClose=function(a){for(var b=l.length-1;b>=0;b--)if(a==l[b].name){l.splice(b,1);return}for(var c=[],g=[],f=t;f!=n&&f.name!=a;){f._.isBlockLike||g.unshift(f);c.push(f);f=f.returnPoint||f.parent}if(f!=
n){for(b=0;b<c.length;b++){var e=c[b];m(e,e.parent)}t=f;f._.isBlockLike&&h();m(f,f.parent);if(f==t)t=t.parent;l=l.concat(g)}a=="body"&&(d=false)};o.onText=function(a){if((!t._.hasInlineStarted||s.length)&&!u&&!w){a=CKEDITOR.tools.ltrim(a);if(a.length===0)return}var b=t.name,g=b?CKEDITOR.dtd[b]||(t._.isBlockLike?CKEDITOR.dtd.div:CKEDITOR.dtd.span):c;if(!w&&!g["#"]&&b in e){o.onTagOpen(f[b]||"");o.onText(a)}else{h();j();!u&&!w&&(a=a.replace(/[\t\r\n ]{2,}|[\t\r\n]/g," "));a=new CKEDITOR.htmlParser.text(a);
if(p(t,a))this.onTagOpen(d,{},0,1);t.add(a)}};o.onCDATA=function(a){t.add(new CKEDITOR.htmlParser.cdata(a))};o.onComment=function(a){h();j();t.add(new CKEDITOR.htmlParser.comment(a))};o.parse(k);for(h();t!=n;)m(t,t.parent,1);g(n);return n};CKEDITOR.htmlParser.fragment.prototype={type:CKEDITOR.NODE_DOCUMENT_FRAGMENT,add:function(a,b){isNaN(b)&&(b=this.children.length);var c=b>0?this.children[b-1]:null;if(c){if(a._.isBlockLike&&c.type==CKEDITOR.NODE_TEXT){c.value=CKEDITOR.tools.rtrim(c.value);if(c.value.length===
0){this.children.pop();this.add(a);return}}c.next=a}a.previous=c;a.parent=this;this.children.splice(b,0,a);if(!this._.hasInlineStarted)this._.hasInlineStarted=a.type==CKEDITOR.NODE_TEXT||a.type==CKEDITOR.NODE_ELEMENT&&!a._.isBlockLike},filter:function(a,b){b=this.getFilterContext(b);a.onRoot(b,this);this.filterChildren(a,false,b)},filterChildren:function(a,b,c){if(this.childrenFilteredBy!=a.id){c=this.getFilterContext(c);if(b&&!this.parent)a.onRoot(c,this);this.childrenFilteredBy=a.id;for(b=0;b<this.children.length;b++)this.children[b].filter(a,
c)===false&&b--}},writeHtml:function(a,b){b&&this.filter(b);this.writeChildrenHtml(a)},writeChildrenHtml:function(a,b,c){var f=this.getFilterContext();if(c&&!this.parent&&b)b.onRoot(f,this);b&&this.filterChildren(b,false,f);b=0;c=this.children;for(f=c.length;b<f;b++)c[b].writeHtml(a)},forEach:function(a,b,c){if(!c&&(!b||this.type==b))var f=a(this);if(f!==false)for(var c=this.children,e=0;e<c.length;e++){f=c[e];f.type==CKEDITOR.NODE_ELEMENT?f.forEach(a,b):(!b||f.type==b)&&a(f)}},getFilterContext:function(a){return a||
{}}}}(),"use strict",function(){function a(){this.rules=[]}function e(b,c,f,e){var i,d;for(i in c){(d=b[i])||(d=b[i]=new a);d.add(c[i],f,e)}}CKEDITOR.htmlParser.filter=CKEDITOR.tools.createClass({$:function(b){this.id=CKEDITOR.tools.getNextNumber();this.elementNameRules=new a;this.attributeNameRules=new a;this.elementsRules={};this.attributesRules={};this.textRules=new a;this.commentRules=new a;this.rootRules=new a;b&&this.addRules(b,10)},proto:{addRules:function(a,c){var f;if(typeof c=="number")f=
c;else if(c&&"priority"in c)f=c.priority;typeof f!="number"&&(f=10);typeof c!="object"&&(c={});a.elementNames&&this.elementNameRules.addMany(a.elementNames,f,c);a.attributeNames&&this.attributeNameRules.addMany(a.attributeNames,f,c);a.elements&&e(this.elementsRules,a.elements,f,c);a.attributes&&e(this.attributesRules,a.attributes,f,c);a.text&&this.textRules.add(a.text,f,c);a.comment&&this.commentRules.add(a.comment,f,c);a.root&&this.rootRules.add(a.root,f,c)},applyTo:function(a){a.filter(this)},onElementName:function(a,
c){return this.elementNameRules.execOnName(a,c)},onAttributeName:function(a,c){return this.attributeNameRules.execOnName(a,c)},onText:function(a,c,f){return this.textRules.exec(a,c,f)},onComment:function(a,c,f){return this.commentRules.exec(a,c,f)},onRoot:function(a,c){return this.rootRules.exec(a,c)},onElement:function(a,c){for(var f=[this.elementsRules["^"],this.elementsRules[c.name],this.elementsRules.$],e,i=0;i<3;i++)if(e=f[i]){e=e.exec(a,c,this);if(e===false)return null;if(e&&e!=c)return this.onNode(a,
e);if(c.parent&&!c.name)break}return c},onNode:function(a,c){var f=c.type;return f==CKEDITOR.NODE_ELEMENT?this.onElement(a,c):f==CKEDITOR.NODE_TEXT?new CKEDITOR.htmlParser.text(this.onText(a,c.value)):f==CKEDITOR.NODE_COMMENT?new CKEDITOR.htmlParser.comment(this.onComment(a,c.value)):null},onAttribute:function(a,c,f,e){return(f=this.attributesRules[f])?f.exec(a,e,c,this):e}}});CKEDITOR.htmlParser.filterRulesGroup=a;a.prototype={add:function(a,c,f){this.rules.splice(this.findIndex(c),0,{value:a,priority:c,
options:f})},addMany:function(a,c,f){for(var e=[this.findIndex(c),0],i=0,d=a.length;i<d;i++)e.push({value:a[i],priority:c,options:f});this.rules.splice.apply(this.rules,e)},findIndex:function(a){for(var c=this.rules,f=c.length-1;f>=0&&a<c[f].priority;)f--;return f+1},exec:function(a,c){var f=c instanceof CKEDITOR.htmlParser.node||c instanceof CKEDITOR.htmlParser.fragment,e=Array.prototype.slice.call(arguments,1),i=this.rules,d=i.length,j,h,g,m;for(m=0;m<d;m++){if(f){j=c.type;h=c.name}g=i[m];if(!(a.nonEditable&&
!g.options.applyToAll||a.nestedEditable&&g.options.excludeNestedEditable)){g=g.value.apply(null,e);if(g===false||f&&g&&(g.name!=h||g.type!=j))return g;g!=null&&(e[0]=c=g)}}return c},execOnName:function(a,c){for(var f=0,e=this.rules,i=e.length,d;c&&f<i;f++){d=e[f];!(a.nonEditable&&!d.options.applyToAll||a.nestedEditable&&d.options.excludeNestedEditable)&&(c=c.replace(d.value[0],d.value[1]))}return c}}}(),function(){function a(a,d){function g(a){return a||CKEDITOR.env.needsNbspFiller?new CKEDITOR.htmlParser.text(" "):
new CKEDITOR.htmlParser.element("br",{"data-cke-bogus":1})}function e(a,d){return function(f){if(f.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var e=[],j=b(f),i,m;if(j)for(h(j,1)&&e.push(j);j;){if(k(j)&&(i=c(j))&&h(i))if((m=c(i))&&!k(m))e.push(i);else{g(v).insertAfter(i);i.remove()}j=j.previous}for(j=0;j<e.length;j++)e[j].remove();if(e=!a||(typeof d=="function"?d(f):d)!==false)if(!v&&!CKEDITOR.env.needsBrFiller&&f.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT)e=false;else if(!v&&!CKEDITOR.env.needsBrFiller&&(document.documentMode>
7||f.name in CKEDITOR.dtd.tr||f.name in CKEDITOR.dtd.$listItem))e=false;else{e=b(f);e=!e||f.name=="form"&&e.name=="input"}e&&f.add(g(a))}}}function h(a,b){if((!v||CKEDITOR.env.needsBrFiller)&&a.type==CKEDITOR.NODE_ELEMENT&&a.name=="br"&&!a.attributes["data-cke-eol"])return true;var c;if(a.type==CKEDITOR.NODE_TEXT&&(c=a.value.match(l))){if(c.index){(new CKEDITOR.htmlParser.text(a.value.substring(0,c.index))).insertBefore(a);a.value=c[0]}if(!CKEDITOR.env.needsBrFiller&&v&&(!b||a.parent.name in m))return true;
if(!v)if((c=a.previous)&&c.name=="br"||!c||k(c))return true}return false}var j={elements:{}},v=d=="html",m=CKEDITOR.tools.extend({},u),E;for(E in m)"#"in t[E]||delete m[E];for(E in m)j.elements[E]=e(v,a.config.fillEmptyBlocks);j.root=e(v,false);j.elements.br=function(a){return function(b){if(b.parent.type!=CKEDITOR.NODE_DOCUMENT_FRAGMENT){var d=b.attributes;if("data-cke-bogus"in d||"data-cke-eol"in d)delete d["data-cke-bogus"];else{for(d=b.next;d&&f(d);)d=d.next;var e=c(b);!d&&k(b.parent)?i(b.parent,
g(a)):k(d)&&(e&&!k(e))&&g(a).insertBefore(d)}}}}(v);return j}function e(a,b){return a!=CKEDITOR.ENTER_BR&&b!==false?a==CKEDITOR.ENTER_DIV?"div":"p":false}function b(a){for(a=a.children[a.children.length-1];a&&f(a);)a=a.previous;return a}function c(a){for(a=a.previous;a&&f(a);)a=a.previous;return a}function f(a){return a.type==CKEDITOR.NODE_TEXT&&!CKEDITOR.tools.trim(a.value)||a.type==CKEDITOR.NODE_ELEMENT&&a.attributes["data-cke-bookmark"]}function k(a){return a&&(a.type==CKEDITOR.NODE_ELEMENT&&a.name in
u||a.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT)}function i(a,b){var c=a.children[a.children.length-1];a.children.push(b);b.parent=a;if(c){c.next=b;b.previous=c}}function d(a){a=a.attributes;a.contenteditable!="false"&&(a["data-cke-editable"]=a.contenteditable?"true":1);a.contenteditable="false"}function j(a){a=a.attributes;switch(a["data-cke-editable"]){case "true":a.contenteditable="true";break;case "1":delete a.contenteditable}}function h(a){return a.replace(z,function(a,b,c){return"<"+b+c.replace(B,
function(a,b){return A.test(b)&&c.indexOf("data-cke-saved-"+b)==-1?" data-cke-saved-"+a+" data-cke-"+CKEDITOR.rnd+"-"+a:a})+">"})}function g(a,b){return a.replace(b,function(a,b,c){a.indexOf("<textarea")===0&&(a=b+r(c).replace(/</g,"&lt;").replace(/>/g,"&gt;")+"</textarea>");return"<cke:encoded>"+encodeURIComponent(a)+"</cke:encoded>"})}function m(a){return a.replace(G,function(a,b){return decodeURIComponent(b)})}function p(a){return a.replace(/<\!--(?!{cke_protected})[\s\S]+?--\>/g,function(a){return"<\!--"+
s+"{C}"+encodeURIComponent(a).replace(/--/g,"%2D%2D")+"--\>"})}function r(a){return a.replace(/<\!--\{cke_protected\}\{C\}([\s\S]+?)--\>/g,function(a,b){return decodeURIComponent(b)})}function o(a,b){var c=b._.dataStore;return a.replace(/<\!--\{cke_protected\}([\s\S]+?)--\>/g,function(a,b){return decodeURIComponent(b)}).replace(/\{cke_protected_(\d+)\}/g,function(a,b){return c&&c[b]||""})}function n(a,b){for(var c=[],d=b.config.protectedSource,g=b._.dataStore||(b._.dataStore={id:1}),f=/<\!--\{cke_temp(comment)?\}(\d*?)--\>/g,
d=[/<script[\s\S]*?(<\/script>|$)/gi,/<noscript[\s\S]*?<\/noscript>/gi,/<meta[\s\S]*?\/?>/gi].concat(d),a=a.replace(/<\!--[\s\S]*?--\>/g,function(a){return"<\!--{cke_tempcomment}"+(c.push(a)-1)+"--\>"}),e=0;e<d.length;e++)a=a.replace(d[e],function(a){a=a.replace(f,function(a,b,d){return c[d]});return/cke_temp(comment)?/.test(a)?a:"<\!--{cke_temp}"+(c.push(a)-1)+"--\>"});a=a.replace(f,function(a,b,d){return"<\!--"+s+(b?"{C}":"")+encodeURIComponent(c[d]).replace(/--/g,"%2D%2D")+"--\>"});a=a.replace(/<\w+(?:\s+(?:(?:[^\s=>]+\s*=\s*(?:[^'"\s>]+|'[^']*'|"[^"]*"))|[^\s=\/>]+))+\s*\/?>/g,
function(a){return a.replace(/<\!--\{cke_protected\}([^>]*)--\>/g,function(a,b){g[g.id]=decodeURIComponent(b);return"{cke_protected_"+g.id++ +"}"})});return a=a.replace(/<(title|iframe|textarea)([^>]*)>([\s\S]*?)<\/\1>/g,function(a,c,d,g){return"<"+c+d+">"+o(r(g),b)+"</"+c+">"})}CKEDITOR.htmlDataProcessor=function(b){var c,d,f=this;this.editor=b;this.dataFilter=c=new CKEDITOR.htmlParser.filter;this.htmlFilter=d=new CKEDITOR.htmlParser.filter;this.writer=new CKEDITOR.htmlParser.basicWriter;c.addRules(x);
c.addRules(v,{applyToAll:true});c.addRules(a(b,"data"),{applyToAll:true});d.addRules(q);d.addRules(y,{applyToAll:true});d.addRules(a(b,"html"),{applyToAll:true});b.on("toHtml",function(a){var a=a.data,c=a.dataValue,d,c=n(c,b),c=g(c,C),c=h(c),c=g(c,D),c=c.replace(E,"$1cke:$2"),c=c.replace(L,"<cke:$1$2></cke:$1>"),c=c.replace(/(<pre\b[^>]*>)(\r\n|\n)/g,"$1$2$2"),c=c.replace(/([^a-z0-9<\-])(on\w{3,})(?!>)/gi,"$1data-cke-"+CKEDITOR.rnd+"-$2");d=a.context||b.editable().getName();var f;if(CKEDITOR.env.ie&&
CKEDITOR.env.version<9&&d=="pre"){d="div";c="<pre>"+c+"</pre>";f=1}d=b.document.createElement(d);d.setHtml("a"+c);c=d.getHtml().substr(1);c=c.replace(RegExp("data-cke-"+CKEDITOR.rnd+"-","ig"),"");f&&(c=c.replace(/^<pre>|<\/pre>$/gi,""));c=c.replace(H,"$1$2");c=m(c);c=r(c);d=a.fixForBody===false?false:e(a.enterMode,b.config.autoParagraph);c=CKEDITOR.htmlParser.fragment.fromHtml(c,a.context,d);if(d){f=c;if(!f.children.length&&CKEDITOR.dtd[f.name][d]){d=new CKEDITOR.htmlParser.element(d);f.add(d)}}a.dataValue=
c},null,null,5);b.on("toHtml",function(a){a.data.filter.applyTo(a.data.dataValue,true,a.data.dontFilter,a.data.enterMode)&&b.fire("dataFiltered")},null,null,6);b.on("toHtml",function(a){a.data.dataValue.filterChildren(f.dataFilter,true)},null,null,10);b.on("toHtml",function(a){var a=a.data,b=a.dataValue,c=new CKEDITOR.htmlParser.basicWriter;b.writeChildrenHtml(c);b=c.getHtml(true);a.dataValue=p(b)},null,null,15);b.on("toDataFormat",function(a){var c=a.data.dataValue;a.data.enterMode!=CKEDITOR.ENTER_BR&&
(c=c.replace(/^<br *\/?>/i,""));a.data.dataValue=CKEDITOR.htmlParser.fragment.fromHtml(c,a.data.context,e(a.data.enterMode,b.config.autoParagraph))},null,null,5);b.on("toDataFormat",function(a){a.data.dataValue.filterChildren(f.htmlFilter,true)},null,null,10);b.on("toDataFormat",function(a){a.data.filter.applyTo(a.data.dataValue,false,true)},null,null,11);b.on("toDataFormat",function(a){var c=a.data.dataValue,d=f.writer;d.reset();c.writeChildrenHtml(d);c=d.getHtml(true);c=r(c);c=o(c,b);a.data.dataValue=
c},null,null,15)};CKEDITOR.htmlDataProcessor.prototype={toHtml:function(a,b,c,d){var f=this.editor,g,e,h,k;if(b&&typeof b=="object"){g=b.context;c=b.fixForBody;d=b.dontFilter;e=b.filter;h=b.enterMode;k=b.protectedWhitespaces}else g=b;!g&&g!==null&&(g=f.editable().getName());return f.fire("toHtml",{dataValue:a,context:g,fixForBody:c,dontFilter:d,filter:e||f.filter,enterMode:h||f.enterMode,protectedWhitespaces:k}).dataValue},toDataFormat:function(a,b){var c,d,f;if(b){c=b.context;d=b.filter;f=b.enterMode}!c&&
c!==null&&(c=this.editor.editable().getName());return this.editor.fire("toDataFormat",{dataValue:a,filter:d||this.editor.filter,context:c,enterMode:f||this.editor.enterMode}).dataValue}};var l=/(?:&nbsp;|\xa0)$/,s="{cke_protected}",t=CKEDITOR.dtd,w=["caption","colgroup","col","thead","tfoot","tbody"],u=CKEDITOR.tools.extend({},t.$blockLimit,t.$block),x={elements:{input:d,textarea:d}},v={attributeNames:[[/^on/,"data-cke-pa-on"],[/^data-cke-expando$/,""]]},q={elements:{embed:function(a){var b=a.parent;
if(b&&b.name=="object"){var c=b.attributes.width,b=b.attributes.height;if(c)a.attributes.width=c;if(b)a.attributes.height=b}},a:function(a){if(!a.children.length&&!a.attributes.name&&!a.attributes["data-cke-saved-name"])return false}}},y={elementNames:[[/^cke:/,""],[/^\?xml:namespace$/,""]],attributeNames:[[/^data-cke-(saved|pa)-/,""],[/^data-cke-.*/,""],["hidefocus",""]],elements:{$:function(a){var b=a.attributes;if(b){if(b["data-cke-temp"])return false;for(var c=["name","href","src"],d,f=0;f<c.length;f++){d=
"data-cke-saved-"+c[f];d in b&&delete b[c[f]]}}return a},table:function(a){a.children.slice(0).sort(function(a,b){var c,d;if(a.type==CKEDITOR.NODE_ELEMENT&&b.type==a.type){c=CKEDITOR.tools.indexOf(w,a.name);d=CKEDITOR.tools.indexOf(w,b.name)}if(!(c>-1&&d>-1&&c!=d)){c=a.parent?a.getIndex():-1;d=b.parent?b.getIndex():-1}return c>d?1:-1})},param:function(a){a.children=[];a.isEmpty=true;return a},span:function(a){a.attributes["class"]=="Apple-style-span"&&delete a.name},html:function(a){delete a.attributes.contenteditable;
delete a.attributes["class"]},body:function(a){delete a.attributes.spellcheck;delete a.attributes.contenteditable},style:function(a){var b=a.children[0];if(b&&b.value)b.value=CKEDITOR.tools.trim(b.value);if(!a.attributes.type)a.attributes.type="text/css"},title:function(a){var b=a.children[0];!b&&i(a,b=new CKEDITOR.htmlParser.text);b.value=a.attributes["data-cke-title"]||""},input:j,textarea:j},attributes:{"class":function(a){return CKEDITOR.tools.ltrim(a.replace(/(?:^|\s+)cke_[^\s]*/g,""))||false}}};
if(CKEDITOR.env.ie)y.attributes.style=function(a){return a.replace(/(^|;)([^\:]+)/g,function(a){return a.toLowerCase()})};var z=/<(a|area|img|input|source)\b([^>]*)>/gi,B=/([\w-:]+)\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|(?:[^ "'>]+))/gi,A=/^(href|src|name)$/i,D=/(?:<style(?=[ >])[^>]*>[\s\S]*?<\/style>)|(?:<(:?link|meta|base)[^>]*>)/gi,C=/(<textarea(?=[ >])[^>]*>)([\s\S]*?)(?:<\/textarea>)/gi,G=/<cke:encoded>([^<]*)<\/cke:encoded>/gi,E=/(<\/?)((?:object|embed|param|html|body|head|title)[^>]*>)/gi,H=/(<\/?)cke:((?:html|body|head|title)[^>]*>)/gi,
L=/<cke:(param|embed)([^>]*?)\/?>(?!\s*<\/cke:\1)/gi}(),"use strict",CKEDITOR.htmlParser.element=function(a,e){this.name=a;this.attributes=e||{};this.children=[];var b=a||"",c=b.match(/^cke:(.*)/);c&&(b=c[1]);b=!(!CKEDITOR.dtd.$nonBodyContent[b]&&!CKEDITOR.dtd.$block[b]&&!CKEDITOR.dtd.$listItem[b]&&!CKEDITOR.dtd.$tableContent[b]&&!(CKEDITOR.dtd.$nonEditable[b]||b=="br"));this.isEmpty=!!CKEDITOR.dtd.$empty[a];this.isUnknown=!CKEDITOR.dtd[a];this._={isBlockLike:b,hasInlineStarted:this.isEmpty||!b}},
CKEDITOR.htmlParser.cssStyle=function(a){var e={};((a instanceof CKEDITOR.htmlParser.element?a.attributes.style:a)||"").replace(/&quot;/g,'"').replace(/\s*([^ :;]+)\s*:\s*([^;]+)\s*(?=;|$)/g,function(a,c,f){c=="font-family"&&(f=f.replace(/["']/g,""));e[c.toLowerCase()]=f});return{rules:e,populate:function(a){var c=this.toString();if(c)a instanceof CKEDITOR.dom.element?a.setAttribute("style",c):a instanceof CKEDITOR.htmlParser.element?a.attributes.style=c:a.style=c},toString:function(){var a=[],c;
for(c in e)e[c]&&a.push(c,":",e[c],";");return a.join("")}}},function(){function a(a){return function(b){return b.type==CKEDITOR.NODE_ELEMENT&&(typeof a=="string"?b.name==a:b.name in a)}}var e=function(a,b){a=a[0];b=b[0];return a<b?-1:a>b?1:0},b=CKEDITOR.htmlParser.fragment.prototype;CKEDITOR.htmlParser.element.prototype=CKEDITOR.tools.extend(new CKEDITOR.htmlParser.node,{type:CKEDITOR.NODE_ELEMENT,add:b.add,clone:function(){return new CKEDITOR.htmlParser.element(this.name,this.attributes)},filter:function(a,
b){var e=this,i,d,b=e.getFilterContext(b);if(b.off)return true;if(!e.parent)a.onRoot(b,e);for(;;){i=e.name;if(!(d=a.onElementName(b,i))){this.remove();return false}e.name=d;if(!(e=a.onElement(b,e))){this.remove();return false}if(e!==this){this.replaceWith(e);return false}if(e.name==i)break;if(e.type!=CKEDITOR.NODE_ELEMENT){this.replaceWith(e);return false}if(!e.name){this.replaceWithChildren();return false}}i=e.attributes;var j,h;for(j in i){h=j;for(d=i[j];;)if(h=a.onAttributeName(b,j))if(h!=j){delete i[j];
j=h}else break;else{delete i[j];break}h&&((d=a.onAttribute(b,e,h,d))===false?delete i[h]:i[h]=d)}e.isEmpty||this.filterChildren(a,false,b);return true},filterChildren:b.filterChildren,writeHtml:function(a,b){b&&this.filter(b);var k=this.name,i=[],d=this.attributes,j,h;a.openTag(k,d);for(j in d)i.push([j,d[j]]);a.sortAttributes&&i.sort(e);j=0;for(h=i.length;j<h;j++){d=i[j];a.attribute(d[0],d[1])}a.openTagClose(k,this.isEmpty);this.writeChildrenHtml(a);this.isEmpty||a.closeTag(k)},writeChildrenHtml:b.writeChildrenHtml,
replaceWithChildren:function(){for(var a=this.children,b=a.length;b;)a[--b].insertAfter(this);this.remove()},forEach:b.forEach,getFirst:function(b){if(!b)return this.children.length?this.children[0]:null;typeof b!="function"&&(b=a(b));for(var f=0,e=this.children.length;f<e;++f)if(b(this.children[f]))return this.children[f];return null},getHtml:function(){var a=new CKEDITOR.htmlParser.basicWriter;this.writeChildrenHtml(a);return a.getHtml()},setHtml:function(a){for(var a=this.children=CKEDITOR.htmlParser.fragment.fromHtml(a).children,
b=0,e=a.length;b<e;++b)a[b].parent=this},getOuterHtml:function(){var a=new CKEDITOR.htmlParser.basicWriter;this.writeHtml(a);return a.getHtml()},split:function(a){for(var b=this.children.splice(a,this.children.length-a),e=this.clone(),i=0;i<b.length;++i)b[i].parent=e;e.children=b;if(b[0])b[0].previous=null;if(a>0)this.children[a-1].next=null;this.parent.add(e,this.getIndex()+1);return e},addClass:function(a){if(!this.hasClass(a)){var b=this.attributes["class"]||"";this.attributes["class"]=b+(b?" ":
"")+a}},removeClass:function(a){var b=this.attributes["class"];if(b)(b=CKEDITOR.tools.trim(b.replace(RegExp("(?:\\s+|^)"+a+"(?:\\s+|$)")," ")))?this.attributes["class"]=b:delete this.attributes["class"]},hasClass:function(a){var b=this.attributes["class"];return!b?false:RegExp("(?:^|\\s)"+a+"(?=\\s|$)").test(b)},getFilterContext:function(a){var b=[];a||(a={off:false,nonEditable:false,nestedEditable:false});!a.off&&this.attributes["data-cke-processor"]=="off"&&b.push("off",true);!a.nonEditable&&this.attributes.contenteditable==
"false"?b.push("nonEditable",true):a.nonEditable&&(!a.nestedEditable&&this.attributes.contenteditable=="true")&&b.push("nestedEditable",true);if(b.length)for(var a=CKEDITOR.tools.copy(a),e=0;e<b.length;e=e+2)a[b[e]]=b[e+1];return a}},true)}(),function(){var a={},e=/{([^}]+)}/g,b=/([\\'])/g,c=/\n/g,f=/\r/g;CKEDITOR.template=function(k){if(a[k])this.output=a[k];else{var i=k.replace(b,"\\$1").replace(c,"\\n").replace(f,"\\r").replace(e,function(a,b){return"',data['"+b+"']==undefined?'{"+b+"}':data['"+
b+"'],'"});this.output=a[k]=Function("data","buffer","return buffer?buffer.push('"+i+"'):['"+i+"'].join('');")}}}(),delete CKEDITOR.loadFullCore,CKEDITOR.instances={},CKEDITOR.document=new CKEDITOR.dom.document(document),CKEDITOR.add=function(a){CKEDITOR.instances[a.name]=a;a.on("focus",function(){if(CKEDITOR.currentInstance!=a){CKEDITOR.currentInstance=a;CKEDITOR.fire("currentInstance")}});a.on("blur",function(){if(CKEDITOR.currentInstance==a){CKEDITOR.currentInstance=null;CKEDITOR.fire("currentInstance")}});
CKEDITOR.fire("instance",null,a)},CKEDITOR.remove=function(a){delete CKEDITOR.instances[a.name]},function(){var a={};CKEDITOR.addTemplate=function(e,b){var c=a[e];if(c)return c;c={name:e,source:b};CKEDITOR.fire("template",c);return a[e]=new CKEDITOR.template(c.source)};CKEDITOR.getTemplate=function(e){return a[e]}}(),function(){var a=[];CKEDITOR.addCss=function(e){a.push(e)};CKEDITOR.getCss=function(){return a.join("\n")}}(),CKEDITOR.on("instanceDestroyed",function(){CKEDITOR.tools.isEmpty(this.instances)&&
CKEDITOR.fire("reset")}),CKEDITOR.TRISTATE_ON=1,CKEDITOR.TRISTATE_OFF=2,CKEDITOR.TRISTATE_DISABLED=0,function(){CKEDITOR.inline=function(a,e){if(!CKEDITOR.env.isCompatible)return null;a=CKEDITOR.dom.element.get(a);if(a.getEditor())throw'The editor instance "'+a.getEditor().name+'" is already attached to the provided element.';var b=new CKEDITOR.editor(e,a,CKEDITOR.ELEMENT_MODE_INLINE),c=a.is("textarea")?a:null;if(c){b.setData(c.getValue(),null,true);a=CKEDITOR.dom.element.createFromHtml('<div contenteditable="'+
!!b.readOnly+'" class="cke_textarea_inline">'+c.getValue()+"</div>",CKEDITOR.document);a.insertAfter(c);c.hide();c.$.form&&b._attachToForm()}else b.setData(a.getHtml(),null,true);b.on("loaded",function(){b.fire("uiReady");b.editable(a);b.container=a;b.ui.contentsElement=a;b.setData(b.getData(1));b.resetDirty();b.fire("contentDom");b.mode="wysiwyg";b.fire("mode");b.status="ready";b.fireOnce("instanceReady");CKEDITOR.fire("instanceReady",null,b)},null,null,1E4);b.on("destroy",function(){if(c){b.container.clearCustomData();
b.container.remove();c.show()}b.element.clearCustomData();delete b.element});return b};CKEDITOR.inlineAll=function(){var a,e,b;for(b in CKEDITOR.dtd.$editable)for(var c=CKEDITOR.document.getElementsByTag(b),f=0,k=c.count();f<k;f++){a=c.getItem(f);if(a.getAttribute("contenteditable")=="true"){e={element:a,config:{}};CKEDITOR.fire("inline",e)!==false&&CKEDITOR.inline(a,e.config)}}};CKEDITOR.domReady(function(){!CKEDITOR.disableAutoInline&&CKEDITOR.inlineAll()})}(),CKEDITOR.replaceClass="ckeditor",function(){function a(a,
f,k,i){if(!CKEDITOR.env.isCompatible)return null;a=CKEDITOR.dom.element.get(a);if(a.getEditor())throw'The editor instance "'+a.getEditor().name+'" is already attached to the provided element.';var d=new CKEDITOR.editor(f,a,i);if(i==CKEDITOR.ELEMENT_MODE_REPLACE){a.setStyle("visibility","hidden");d._.required=a.hasAttribute("required");a.removeAttribute("required")}k&&d.setData(k,null,true);d.on("loaded",function(){b(d);i==CKEDITOR.ELEMENT_MODE_REPLACE&&(d.config.autoUpdateElement&&a.$.form)&&d._attachToForm();
d.setMode(d.config.startupMode,function(){d.resetDirty();d.status="ready";d.fireOnce("instanceReady");CKEDITOR.fire("instanceReady",null,d)})});d.on("destroy",e);return d}function e(){var a=this.container,b=this.element;if(a){a.clearCustomData();a.remove()}if(b){b.clearCustomData();if(this.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE){b.show();this._.required&&b.setAttribute("required","required")}delete this.element}}function b(a){var b=a.name,e=a.element,i=a.elementMode,d=a.fire("uiSpace",{space:"top",
html:""}).html,j=a.fire("uiSpace",{space:"bottom",html:""}).html,h=new CKEDITOR.template('<{outerEl} id="cke_{name}" class="{id} cke cke_reset cke_chrome cke_editor_{name} cke_{langDir} '+CKEDITOR.env.cssClass+'"  dir="{langDir}" lang="{langCode}" role="application"'+(a.title?' aria-labelledby="cke_{name}_arialbl"':"")+">"+(a.title?'<span id="cke_{name}_arialbl" class="cke_voice_label">{voiceLabel}</span>':"")+'<{outerEl} class="cke_inner cke_reset" role="presentation">{topHtml}<{outerEl} id="{contentId}" class="cke_contents cke_reset" role="presentation"></{outerEl}>{bottomHtml}</{outerEl}></{outerEl}>'),
b=CKEDITOR.dom.element.createFromHtml(h.output({id:a.id,name:b,langDir:a.lang.dir,langCode:a.langCode,voiceLabel:a.title,topHtml:d?'<span id="'+a.ui.spaceId("top")+'" class="cke_top cke_reset_all" role="presentation" style="height:auto">'+d+"</span>":"",contentId:a.ui.spaceId("contents"),bottomHtml:j?'<span id="'+a.ui.spaceId("bottom")+'" class="cke_bottom cke_reset_all" role="presentation">'+j+"</span>":"",outerEl:CKEDITOR.env.ie?"span":"div"}));if(i==CKEDITOR.ELEMENT_MODE_REPLACE){e.hide();b.insertAfter(e)}else e.append(b);
a.container=b;a.ui.contentsElement=a.ui.space("contents");d&&a.ui.space("top").unselectable();j&&a.ui.space("bottom").unselectable();e=a.config.width;i=a.config.height;e&&b.setStyle("width",CKEDITOR.tools.cssLength(e));i&&a.ui.space("contents").setStyle("height",CKEDITOR.tools.cssLength(i));b.disableContextMenu();CKEDITOR.env.webkit&&b.on("focus",function(){a.focus()});a.fireOnce("uiReady")}CKEDITOR.replace=function(b,f){return a(b,f,null,CKEDITOR.ELEMENT_MODE_REPLACE)};CKEDITOR.appendTo=function(b,
f,e){return a(b,f,e,CKEDITOR.ELEMENT_MODE_APPENDTO)};CKEDITOR.replaceAll=function(){for(var a=document.getElementsByTagName("textarea"),b=0;b<a.length;b++){var e=null,i=a[b];if(i.name||i.id){if(typeof arguments[0]=="string"){if(!RegExp("(?:^|\\s)"+arguments[0]+"(?:$|\\s)").test(i.className))continue}else if(typeof arguments[0]=="function"){e={};if(arguments[0](i,e)===false)continue}this.replace(i,e)}}};CKEDITOR.editor.prototype.addMode=function(a,b){(this._.modes||(this._.modes={}))[a]=b};CKEDITOR.editor.prototype.setMode=
function(a,b){var e=this,i=this._.modes;if(!(a==e.mode||!i||!i[a])){e.fire("beforeSetMode",a);if(e.mode){var d=e.checkDirty(),i=e._.previousModeData,j,h=0;e.fire("beforeModeUnload");e.editable(0);e._.previousMode=e.mode;e._.previousModeData=j=e.getData(1);if(e.mode=="source"&&i==j){e.fire("lockSnapshot",{forceUpdate:true});h=1}e.ui.space("contents").setHtml("");e.mode=""}else e._.previousModeData=e.getData(1);this._.modes[a](function(){e.mode=a;d!==void 0&&!d&&e.resetDirty();h?e.fire("unlockSnapshot"):
a=="wysiwyg"&&e.fire("saveSnapshot");setTimeout(function(){e.fire("mode");b&&b.call(e)},0)})}};CKEDITOR.editor.prototype.resize=function(a,b,e,i){var d=this.container,j=this.ui.space("contents"),h=CKEDITOR.env.webkit&&this.document&&this.document.getWindow().$.frameElement,i=i?this.container.getFirst(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasClass("cke_inner")}):d;i.setSize("width",a,true);h&&(h.style.width="1%");var g=(i.$.offsetHeight||0)-(j.$.clientHeight||0),d=Math.max(b-(e?0:g),
0),b=e?b+g:b;j.setStyle("height",d+"px");h&&(h.style.width="100%");this.fire("resize",{outerHeight:b,contentsHeight:d,outerWidth:a||i.getSize("width")})};CKEDITOR.editor.prototype.getResizable=function(a){return a?this.ui.space("contents"):this.container};CKEDITOR.domReady(function(){CKEDITOR.replaceClass&&CKEDITOR.replaceAll(CKEDITOR.replaceClass)})}(),CKEDITOR.config.startupMode="wysiwyg",function(){var a,e,b,c;function f(a){var b=a.editor,c=a.data.path,f=c.blockLimit,e=a.data.selection,h=e.getRanges()[0],
j;if(CKEDITOR.env.gecko||CKEDITOR.env.ie&&CKEDITOR.env.needsBrFiller)if(e=k(e,c)){e.appendBogus();j=CKEDITOR.env.ie}if(g(b,c.block,f)&&h.collapsed&&!h.getCommonAncestor().isReadOnly()){c=h.clone();c.enlarge(CKEDITOR.ENLARGE_BLOCK_CONTENTS);f=new CKEDITOR.dom.walker(c);f.guard=function(a){return!d(a)||a.type==CKEDITOR.NODE_COMMENT||a.isReadOnly()};if(!f.checkForward()||c.checkStartOfBlock()&&c.checkEndOfBlock()){b=h.fixBlock(true,b.activeEnterMode==CKEDITOR.ENTER_DIV?"div":"p");if(!CKEDITOR.env.needsBrFiller)(b=
b.getFirst(d))&&(b.type==CKEDITOR.NODE_TEXT&&CKEDITOR.tools.trim(b.getText()).match(/^(?:&nbsp;|\xa0)$/))&&b.remove();j=1;a.cancel()}}j&&h.select()}function k(a,b){if(a.isFake)return 0;var c=b.block||b.blockLimit,g=c&&c.getLast(d);if(c&&c.isBlockBoundary()&&(!g||!(g.type==CKEDITOR.NODE_ELEMENT&&g.isBlockBoundary()))&&!c.is("pre")&&!c.getBogus())return c}function i(a){var b=a.data.getTarget();if(b.is("input")){b=b.getAttribute("type");(b=="submit"||b=="reset")&&a.data.preventDefault()}}function d(a){return o(a)&&
n(a)}function j(a,b){return function(c){var d=c.data.$.toElement||c.data.$.fromElement||c.data.$.relatedTarget,d=d&&d.nodeType==CKEDITOR.NODE_ELEMENT?new CKEDITOR.dom.element(d):null;(!d||!b.equals(d)&&!b.contains(d))&&a.call(this,c)}}function h(a){function b(a){return function(b,g){g&&(b.type==CKEDITOR.NODE_ELEMENT&&b.is(f))&&(c=b);if(!g&&d(b)&&(!a||!s(b)))return false}}var c,g=a.getRanges()[0],a=a.root,f={table:1,ul:1,ol:1,dl:1};if(g.startPath().contains(f)){var e=g.clone();e.collapse(1);e.setStartAt(a,
CKEDITOR.POSITION_AFTER_START);a=new CKEDITOR.dom.walker(e);a.guard=b();a.checkBackward();if(c){e=g.clone();e.collapse();e.setEndAt(c,CKEDITOR.POSITION_AFTER_END);a=new CKEDITOR.dom.walker(e);a.guard=b(true);c=false;a.checkForward();return c}}return null}function g(a,b,c){return a.config.autoParagraph!==false&&a.activeEnterMode!=CKEDITOR.ENTER_BR&&(a.editable().equals(c)&&!b||b&&b.getAttribute("contenteditable")=="true")}function m(a){return a.activeEnterMode!=CKEDITOR.ENTER_BR&&a.config.autoParagraph!==
false?a.activeEnterMode==CKEDITOR.ENTER_DIV?"div":"p":false}function p(a){var b=a.editor;b.getSelection().scrollIntoView();setTimeout(function(){b.fire("saveSnapshot")},0)}function r(a,b,c){for(var d=a.getCommonAncestor(b),b=a=c?b:a;(a=a.getParent())&&!d.equals(a)&&a.getChildCount()==1;)b=a;b.remove()}CKEDITOR.editable=CKEDITOR.tools.createClass({base:CKEDITOR.dom.element,$:function(a,b){this.base(b.$||b);this.editor=a;this.status="unloaded";this.hasFocus=false;this.setup()},proto:{focus:function(){var a;
if(CKEDITOR.env.webkit&&!this.hasFocus){a=this.editor._.previousActive||this.getDocument().getActive();if(this.contains(a)){a.focus();return}}try{this.$[CKEDITOR.env.ie&&this.getDocument().equals(CKEDITOR.document)?"setActive":"focus"]()}catch(b){if(!CKEDITOR.env.ie)throw b;}if(CKEDITOR.env.safari&&!this.isInline()){a=CKEDITOR.document.getActive();a.equals(this.getWindow().getFrame())||this.getWindow().focus()}},on:function(a,b){var c=Array.prototype.slice.call(arguments,0);if(CKEDITOR.env.ie&&/^focus|blur$/.exec(a)){a=
a=="focus"?"focusin":"focusout";b=j(b,this);c[0]=a;c[1]=b}return CKEDITOR.dom.element.prototype.on.apply(this,c)},attachListener:function(a){!this._.listeners&&(this._.listeners=[]);var b=Array.prototype.slice.call(arguments,1),b=a.on.apply(a,b);this._.listeners.push(b);return b},clearListeners:function(){var a=this._.listeners;try{for(;a.length;)a.pop().removeListener()}catch(b){}},restoreAttrs:function(){var a=this._.attrChanges,b,c;for(c in a)if(a.hasOwnProperty(c)){b=a[c];b!==null?this.setAttribute(c,
b):this.removeAttribute(c)}},attachClass:function(a){var b=this.getCustomData("classes");if(!this.hasClass(a)){!b&&(b=[]);b.push(a);this.setCustomData("classes",b);this.addClass(a)}},changeAttr:function(a,b){var c=this.getAttribute(a);if(b!==c){!this._.attrChanges&&(this._.attrChanges={});a in this._.attrChanges||(this._.attrChanges[a]=c);this.setAttribute(a,b)}},insertText:function(a){this.editor.focus();this.insertHtml(this.transformPlainTextToHtml(a),"text")},transformPlainTextToHtml:function(a){var b=
this.editor.getSelection().getStartElement().hasAscendant("pre",true)?CKEDITOR.ENTER_BR:this.editor.activeEnterMode;return CKEDITOR.tools.transformPlainTextToHtml(a,b)},insertHtml:function(a,b,c){var d=this.editor;d.focus();d.fire("saveSnapshot");c||(c=d.getSelection().getRanges()[0]);w(this,b||"html",a,c);c.select();p(this);this.editor.fire("afterInsertHtml",{})},insertHtmlIntoRange:function(a,b,c){w(this,c||"html",a,b);this.editor.fire("afterInsertHtml",{intoRange:b})},insertElement:function(a,
b){var c=this.editor;c.focus();c.fire("saveSnapshot");var g=c.activeEnterMode,c=c.getSelection(),f=a.getName(),f=CKEDITOR.dtd.$block[f];b||(b=c.getRanges()[0]);if(this.insertElementIntoRange(a,b)){b.moveToPosition(a,CKEDITOR.POSITION_AFTER_END);if(f)if((f=a.getNext(function(a){return d(a)&&!s(a)}))&&f.type==CKEDITOR.NODE_ELEMENT&&f.is(CKEDITOR.dtd.$block))f.getDtd()["#"]?b.moveToElementEditStart(f):b.moveToElementEditEnd(a);else if(!f&&g!=CKEDITOR.ENTER_BR){f=b.fixBlock(true,g==CKEDITOR.ENTER_DIV?
"div":"p");b.moveToElementEditStart(f)}}c.selectRanges([b]);p(this)},insertElementIntoSelection:function(a){this.insertElement(a)},insertElementIntoRange:function(a,b){var c=this.editor,d=c.config.enterMode,g=a.getName(),f=CKEDITOR.dtd.$block[g];if(b.checkReadOnly())return false;b.deleteContents(1);b.startContainer.type==CKEDITOR.NODE_ELEMENT&&b.startContainer.is({tr:1,table:1,tbody:1,thead:1,tfoot:1})&&u(b);var e,h;if(f)for(;(e=b.getCommonAncestor(0,1))&&(h=CKEDITOR.dtd[e.getName()])&&(!h||!h[g]);)if(e.getName()in
CKEDITOR.dtd.span)b.splitElement(e);else if(b.checkStartOfBlock()&&b.checkEndOfBlock()){b.setStartBefore(e);b.collapse(true);e.remove()}else b.splitBlock(d==CKEDITOR.ENTER_DIV?"div":"p",c.editable());b.insertNode(a);return true},setData:function(a,b){b||(a=this.editor.dataProcessor.toHtml(a));this.setHtml(a);this.fixInitialSelection();if(this.status=="unloaded")this.status="ready";this.editor.fire("dataReady")},getData:function(a){var b=this.getHtml();a||(b=this.editor.dataProcessor.toDataFormat(b));
return b},setReadOnly:function(a){this.setAttribute("contenteditable",!a)},detach:function(){this.removeClass("cke_editable");this.status="detached";var a=this.editor;this._.detach();delete a.document;delete a.window},isInline:function(){return this.getDocument().equals(CKEDITOR.document)},fixInitialSelection:function(){function a(){var b=c.getDocument().$,d=b.getSelection(),g;if(d.anchorNode&&d.anchorNode==c.$)g=true;else if(CKEDITOR.env.webkit){var f=c.getDocument().getActive();f&&(f.equals(c)&&
!d.anchorNode)&&(g=true)}if(g){g=new CKEDITOR.dom.range(c);g.moveToElementEditStart(c);b=b.createRange();b.setStart(g.startContainer.$,g.startOffset);b.collapse(true);d.removeAllRanges();d.addRange(b)}}function b(){var a=c.getDocument().$,d=a.selection,g=c.getDocument().getActive();if(d.type=="None"&&g.equals(c)){d=new CKEDITOR.dom.range(c);a=a.body.createTextRange();d.moveToElementEditStart(c);d=d.startContainer;d.type!=CKEDITOR.NODE_ELEMENT&&(d=d.getParent());a.moveToElementText(d.$);a.collapse(true);
a.select()}}var c=this;if(CKEDITOR.env.ie&&(CKEDITOR.env.version<9||CKEDITOR.env.quirks)){if(this.hasFocus){this.focus();b()}}else if(this.hasFocus){this.focus();a()}else this.once("focus",function(){a()},null,null,-999)},getHtmlFromRange:function(d){if(d.collapsed)return new CKEDITOR.dom.documentFragment(d.document);d={doc:this.getDocument(),range:d.clone()};a.detect(d,this);e.exclude(d);b.shrink(d);d.fragment=d.range.cloneContents();c.rebuild(d,this);a.fix(d,this);return new CKEDITOR.dom.documentFragment(d.fragment.$)},
extractHtmlFromRange:function(a,b){var c=x,d={range:a,doc:a.document},g=this.getHtmlFromRange(a);if(a.collapsed){a.optimize();return g}a.enlarge(CKEDITOR.ENLARGE_INLINE,1);c.table.detectPurge(d);d.bookmark=a.createBookmark();delete d.range;var f=this.editor.createRange();f.moveToPosition(d.bookmark.startNode,CKEDITOR.POSITION_BEFORE_START);d.targetBookmark=f.createBookmark();c.list.detectMerge(d,this);c.table.detectRanges(d,this);c.block.detectMerge(d,this);if(d.tableContentsRanges){c.table.deleteRanges(d);
a.moveToBookmark(d.bookmark);d.range=a}else{a.moveToBookmark(d.bookmark);d.range=a;a.extractContents(c.detectExtractMerge(d))}a.moveToBookmark(d.targetBookmark);a.optimize();c.fixUneditableRangePosition(a);c.list.merge(d,this);c.table.purge(d,this);c.block.merge(d,this);if(b){c=a.startPath();if(d=a.checkStartOfBlock())if(d=a.checkEndOfBlock())if(d=c.block)if(d=!a.root.equals(c.block)){a:{var d=c.block.getElementsByTag("span"),f=0,e;if(d)for(;e=d.getItem(f++);)if(!n(e)){d=true;break a}d=false}d=!d}if(d){a.moveToPosition(c.block,
CKEDITOR.POSITION_BEFORE_START);c.block.remove()}}else{c.autoParagraph(this.editor,a);l(a.startContainer)&&a.startContainer.appendBogus()}a.startContainer.mergeSiblings();return g},setup:function(){var a=this.editor;this.attachListener(a,"beforeGetData",function(){var b=this.getData();this.is("textarea")||a.config.ignoreEmptyParagraph!==false&&(b=b.replace(t,function(a,b){return b}));a.setData(b,null,1)},this);this.attachListener(a,"getSnapshot",function(a){a.data=this.getData(1)},this);this.attachListener(a,
"afterSetData",function(){this.setData(a.getData(1))},this);this.attachListener(a,"loadSnapshot",function(a){this.setData(a.data,1)},this);this.attachListener(a,"beforeFocus",function(){var b=a.getSelection();(b=b&&b.getNative())&&b.type=="Control"||this.focus()},this);this.attachListener(a,"insertHtml",function(a){this.insertHtml(a.data.dataValue,a.data.mode,a.data.range)},this);this.attachListener(a,"insertElement",function(a){this.insertElement(a.data)},this);this.attachListener(a,"insertText",
function(a){this.insertText(a.data)},this);this.setReadOnly(a.readOnly);this.attachClass("cke_editable");a.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?this.attachClass("cke_editable_inline"):(a.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE||a.elementMode==CKEDITOR.ELEMENT_MODE_APPENDTO)&&this.attachClass("cke_editable_themed");this.attachClass("cke_contents_"+a.config.contentsLangDirection);a.keystrokeHandler.blockedKeystrokes[8]=+a.readOnly;a.keystrokeHandler.attach(this);this.on("blur",function(){this.hasFocus=
false},null,null,-1);this.on("focus",function(){this.hasFocus=true},null,null,-1);a.focusManager.add(this);if(this.equals(CKEDITOR.document.getActive())){this.hasFocus=true;a.once("contentDom",function(){a.focusManager.focus(this)},this)}this.isInline()&&this.changeAttr("tabindex",a.tabIndex);if(!this.is("textarea")){a.document=this.getDocument();a.window=this.getWindow();var b=a.document;this.changeAttr("spellcheck",!a.config.disableNativeSpellChecker);var c=a.config.contentsLangDirection;this.getDirection(1)!=
c&&this.changeAttr("dir",c);var g=CKEDITOR.getCss();if(g){c=b.getHead();if(!c.getCustomData("stylesheet")){g=b.appendStyleText(g);g=new CKEDITOR.dom.element(g.ownerNode||g.owningElement);c.setCustomData("stylesheet",g);g.data("cke-temp",1)}}c=b.getCustomData("stylesheet_ref")||0;b.setCustomData("stylesheet_ref",c+1);this.setCustomData("cke_includeReadonly",!a.config.disableReadonlyStyling);this.attachListener(this,"click",function(a){var a=a.data,b=(new CKEDITOR.dom.elementPath(a.getTarget(),this)).contains("a");
b&&(a.$.button!=2&&b.isReadOnly())&&a.preventDefault()});var f={8:1,46:1};this.attachListener(a,"key",function(b){if(a.readOnly)return true;var c=b.data.domEvent.getKey(),d;if(c in f){var b=a.getSelection(),g,e=b.getRanges()[0],j=e.startPath(),i,k,m,c=c==8;if(CKEDITOR.env.ie&&CKEDITOR.env.version<11&&(g=b.getSelectedElement())||(g=h(b))){a.fire("saveSnapshot");e.moveToPosition(g,CKEDITOR.POSITION_BEFORE_START);g.remove();e.select();a.fire("saveSnapshot");d=1}else if(e.collapsed)if((i=j.block)&&(m=
i[c?"getPrevious":"getNext"](o))&&m.type==CKEDITOR.NODE_ELEMENT&&m.is("table")&&e[c?"checkStartOfBlock":"checkEndOfBlock"]()){a.fire("saveSnapshot");e[c?"checkEndOfBlock":"checkStartOfBlock"]()&&i.remove();e["moveToElementEdit"+(c?"End":"Start")](m);e.select();a.fire("saveSnapshot");d=1}else if(j.blockLimit&&j.blockLimit.is("td")&&(k=j.blockLimit.getAscendant("table"))&&e.checkBoundaryOfElement(k,c?CKEDITOR.START:CKEDITOR.END)&&(m=k[c?"getPrevious":"getNext"](o))){a.fire("saveSnapshot");e["moveToElementEdit"+
(c?"End":"Start")](m);e.checkStartOfBlock()&&e.checkEndOfBlock()?m.remove():e.select();a.fire("saveSnapshot");d=1}else if((k=j.contains(["td","th","caption"]))&&e.checkBoundaryOfElement(k,c?CKEDITOR.START:CKEDITOR.END))d=1}return!d});a.blockless&&(CKEDITOR.env.ie&&CKEDITOR.env.needsBrFiller)&&this.attachListener(this,"keyup",function(b){if(b.data.getKeystroke()in f&&!this.getFirst(d)){this.appendBogus();b=a.createRange();b.moveToPosition(this,CKEDITOR.POSITION_AFTER_START);b.select()}});this.attachListener(this,
"dblclick",function(b){if(a.readOnly)return false;b={element:b.data.getTarget()};a.fire("doubleclick",b)});CKEDITOR.env.ie&&this.attachListener(this,"click",i);(!CKEDITOR.env.ie||CKEDITOR.env.edge)&&this.attachListener(this,"mousedown",function(b){var c=b.data.getTarget();if(c.is("img","hr","input","textarea","select")&&!c.isReadOnly()){a.getSelection().selectElement(c);c.is("input","textarea","select")&&b.data.preventDefault()}});CKEDITOR.env.edge&&this.attachListener(this,"mouseup",function(b){(b=
b.data.getTarget())&&b.is("img")&&a.getSelection().selectElement(b)});CKEDITOR.env.gecko&&this.attachListener(this,"mouseup",function(b){if(b.data.$.button==2){b=b.data.getTarget();if(!b.getOuterHtml().replace(t,"")){var c=a.createRange();c.moveToElementEditStart(b);c.select(true)}}});if(CKEDITOR.env.webkit){this.attachListener(this,"click",function(a){a.data.getTarget().is("input","select")&&a.data.preventDefault()});this.attachListener(this,"mouseup",function(a){a.data.getTarget().is("input","textarea")&&
a.data.preventDefault()})}CKEDITOR.env.webkit&&this.attachListener(a,"key",function(b){if(a.readOnly)return true;b=b.data.domEvent.getKey();if(b in f){var c=b==8,d=a.getSelection().getRanges()[0],b=d.startPath();if(d.collapsed){var g;a:{var e=b.block;if(e)if(d[c?"checkStartOfBlock":"checkEndOfBlock"]())if(!d.moveToClosestEditablePosition(e,!c)||!d.collapsed)g=false;else{if(d.startContainer.type==CKEDITOR.NODE_ELEMENT){var h=d.startContainer.getChild(d.startOffset-(c?1:0));if(h&&h.type==CKEDITOR.NODE_ELEMENT&&
h.is("hr")){a.fire("saveSnapshot");h.remove();g=true;break a}}if((d=d.startPath().block)&&(!d||!d.contains(e))){a.fire("saveSnapshot");var j;(j=(c?d:e).getBogus())&&j.remove();g=a.getSelection();j=g.createBookmarks();(c?e:d).moveChildren(c?d:e,false);b.lastElement.mergeSiblings();r(e,d,!c);g.selectBookmarks(j);g=true}}else g=false;else g=false}if(!g)return}else{c=d;g=b.block;j=c.endPath().block;if(!g||!j||g.equals(j))b=false;else{a.fire("saveSnapshot");(e=g.getBogus())&&e.remove();c.enlarge(CKEDITOR.ENLARGE_INLINE);
c.deleteContents();if(j.getParent()){j.moveChildren(g,false);b.lastElement.mergeSiblings();r(g,j,true)}c=a.getSelection().getRanges()[0];c.collapse(1);c.optimize();c.startContainer.getHtml()===""&&c.startContainer.appendBogus();c.select();b=true}if(!b)return}a.getSelection().scrollIntoView();a.fire("saveSnapshot");return false}},this,null,100)}}},_:{detach:function(){this.editor.setData(this.editor.getData(),0,1);this.clearListeners();this.restoreAttrs();var a;if(a=this.removeCustomData("classes"))for(;a.length;)this.removeClass(a.pop());
if(!this.is("textarea")){a=this.getDocument();var b=a.getHead();if(b.getCustomData("stylesheet")){var c=a.getCustomData("stylesheet_ref");if(--c)a.setCustomData("stylesheet_ref",c);else{a.removeCustomData("stylesheet_ref");b.removeCustomData("stylesheet").remove()}}}this.editor.fire("contentDomUnload");delete this.editor}}});CKEDITOR.editor.prototype.editable=function(a){var b=this._.editable;if(b&&a)return 0;if(arguments.length)b=this._.editable=a?a instanceof CKEDITOR.editable?a:new CKEDITOR.editable(this,
a):(b&&b.detach(),null);return b};CKEDITOR.on("instanceLoaded",function(a){var b=a.editor;b.on("insertElement",function(a){a=a.data;if(a.type==CKEDITOR.NODE_ELEMENT&&(a.is("input")||a.is("textarea"))){a.getAttribute("contentEditable")!="false"&&a.data("cke-editable",a.hasAttribute("contenteditable")?"true":"1");a.setAttribute("contentEditable",false)}});b.on("selectionChange",function(a){if(!b.readOnly){var c=b.getSelection();if(c&&!c.isLocked){c=b.checkDirty();b.fire("lockSnapshot");f(a);b.fire("unlockSnapshot");
!c&&b.resetDirty()}}})});CKEDITOR.on("instanceCreated",function(a){var b=a.editor;b.on("mode",function(){var a=b.editable();if(a&&a.isInline()){var c=b.title;a.changeAttr("role","textbox");a.changeAttr("aria-label",c);c&&a.changeAttr("title",c);var d=b.fire("ariaEditorHelpLabel",{}).label;if(d)if(c=this.ui.space(this.elementMode==CKEDITOR.ELEMENT_MODE_INLINE?"top":"contents")){var g=CKEDITOR.tools.getNextId(),d=CKEDITOR.dom.element.createFromHtml('<span id="'+g+'" class="cke_voice_label">'+d+"</span>");
c.append(d);a.changeAttr("aria-describedby",g)}}})});CKEDITOR.addCss(".cke_editable{cursor:text}.cke_editable img,.cke_editable input,.cke_editable textarea{cursor:default}");var o=CKEDITOR.dom.walker.whitespaces(true),n=CKEDITOR.dom.walker.bookmark(false,true),l=CKEDITOR.dom.walker.empty(),s=CKEDITOR.dom.walker.bogus(),t=/(^|<body\b[^>]*>)\s*<(p|div|address|h\d|center|pre)[^>]*>\s*(?:<br[^>]*>|&nbsp;|\u00A0|&#160;)?\s*(:?<\/\2>)?\s*(?=$|<\/body>)/gi,w=function(){function a(b){return b.type==CKEDITOR.NODE_ELEMENT}
function b(c,d){var g,f,e,h,i=[],k=d.range.startContainer;g=d.range.startPath();for(var k=j[k.getName()],m=0,o=c.getChildren(),E=o.count(),l=-1,s=-1,t=0,u=g.contains(j.$list);m<E;++m){g=o.getItem(m);if(a(g)){e=g.getName();if(u&&e in CKEDITOR.dtd.$list)i=i.concat(b(g,d));else{h=!!k[e];if(e=="br"&&g.data("cke-eol")&&(!m||m==E-1)){t=(f=m?i[m-1].node:o.getItem(m+1))&&(!a(f)||!f.is("br"));f=f&&a(f)&&j.$block[f.getName()]}l==-1&&!h&&(l=m);h||(s=m);i.push({isElement:1,isLineBreak:t,isBlock:g.isBlockBoundary(),
hasBlockSibling:f,node:g,name:e,allowed:h});f=t=0}}else i.push({isElement:0,node:g,allowed:1})}if(l>-1)i[l].firstNotAllowed=1;if(s>-1)i[s].lastNotAllowed=1;return i}function c(b,d){var g=[],f=b.getChildren(),e=f.count(),h,i=0,k=j[d],m=!b.is(j.$inline)||b.is("br");for(m&&g.push(" ");i<e;i++){h=f.getItem(i);a(h)&&!h.is(k)?g=g.concat(c(h,d)):g.push(h)}m&&g.push(" ");return g}function f(b){return b&&a(b)&&(b.is(j.$removeEmpty)||b.is("a")&&!b.isBlockBoundary())}function e(b,c,d,g){var f=b.clone(),h,j;
f.setEndAt(c,CKEDITOR.POSITION_BEFORE_END);if((h=(new CKEDITOR.dom.walker(f)).next())&&a(h)&&i[h.getName()]&&(j=h.getPrevious())&&a(j)&&!j.getParent().equals(b.startContainer)&&d.contains(j)&&g.contains(h)&&h.isIdentical(j)){h.moveChildren(j);h.remove();e(b,c,d,g)}}function h(b,c){function d(b,c){if(c.isBlock&&c.isElement&&!c.node.is("br")&&a(b)&&b.is("br")){b.remove();return 1}}var g=c.endContainer.getChild(c.endOffset),f=c.endContainer.getChild(c.endOffset-1);g&&d(g,b[b.length-1]);if(f&&d(f,b[0])){c.setEnd(c.endContainer,
c.endOffset-1);c.collapse()}}var j=CKEDITOR.dtd,i={p:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,ul:1,ol:1,li:1,pre:1,dl:1,blockquote:1},k={p:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1},o=CKEDITOR.tools.extend({},j.$inline);delete o.br;return function(i,l,s,t){var u=i.editor,r=false;if(l=="unfiltered_html"){l="html";r=true}if(!t.checkReadOnly()){var n=(new CKEDITOR.dom.elementPath(t.startContainer,t.root)).blockLimit||t.root,i={type:l,dontFilter:r,editable:i,editor:u,range:t,blockLimit:n,mergeCandidates:[],
zombies:[]},l=i.range,t=i.mergeCandidates,p,x;if(i.type=="text"&&l.shrink(CKEDITOR.SHRINK_ELEMENT,true,false)){p=CKEDITOR.dom.element.createFromHtml("<span>&nbsp;</span>",l.document);l.insertNode(p);l.setStartAfter(p)}r=new CKEDITOR.dom.elementPath(l.startContainer);i.endPath=n=new CKEDITOR.dom.elementPath(l.endContainer);if(!l.collapsed){var u=n.block||n.blockLimit,w=l.getCommonAncestor();u&&(!u.equals(w)&&!u.contains(w)&&l.checkEndOfBlock())&&i.zombies.push(u);l.deleteContents()}for(;(x=a(l.startContainer)&&
l.startContainer.getChild(l.startOffset-1))&&a(x)&&x.isBlockBoundary()&&r.contains(x);)l.moveToPosition(x,CKEDITOR.POSITION_BEFORE_END);e(l,i.blockLimit,r,n);if(p){l.setEndBefore(p);l.collapse();p.remove()}p=l.startPath();if(u=p.contains(f,false,1)){l.splitElement(u);i.inlineStylesRoot=u;i.inlineStylesPeak=p.lastElement}p=l.createBookmark();(u=p.startNode.getPrevious(d))&&a(u)&&f(u)&&t.push(u);(u=p.startNode.getNext(d))&&a(u)&&f(u)&&t.push(u);for(u=p.startNode;(u=u.getParent())&&f(u);)t.push(u);l.moveToBookmark(p);
if(p=s){p=i.range;if(i.type=="text"&&i.inlineStylesRoot){x=i.inlineStylesPeak;l=x.getDocument().createText("{cke-peak}");for(t=i.inlineStylesRoot.getParent();!x.equals(t);){l=l.appendTo(x.clone());x=x.getParent()}s=l.getOuterHtml().split("{cke-peak}").join(s)}x=i.blockLimit.getName();if(/^\s+|\s+$/.test(s)&&"span"in CKEDITOR.dtd[x])var C='<span data-cke-marker="1">&nbsp;</span>',s=C+s+C;s=i.editor.dataProcessor.toHtml(s,{context:null,fixForBody:false,protectedWhitespaces:!!C,dontFilter:i.dontFilter,
filter:i.editor.activeFilter,enterMode:i.editor.activeEnterMode});x=p.document.createElement("body");x.setHtml(s);if(C){x.getFirst().remove();x.getLast().remove()}if((C=p.startPath().block)&&!(C.getChildCount()==1&&C.getBogus()))a:{var K;if(x.getChildCount()==1&&a(K=x.getFirst())&&K.is(k)&&!K.hasAttribute("contenteditable")){C=K.getElementsByTag("*");p=0;for(t=C.count();p<t;p++){l=C.getItem(p);if(!l.is(o))break a}K.moveChildren(K.getParent(1));K.remove()}}i.dataWrapper=x;p=s}if(p){K=i.range;p=K.document;
var F;x=i.blockLimit;var t=0,M,C=[],N,U,s=u=0,Q,V,l=K.startContainer,r=i.endPath.elements[0],Z,n=r.getPosition(l),w=!!r.getCommonAncestor(l)&&n!=CKEDITOR.POSITION_IDENTICAL&&!(n&CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_IS_CONTAINED),l=b(i.dataWrapper,i);for(h(l,K);t<l.length;t++){n=l[t];if(F=n.isLineBreak){F=K;Q=x;var O=void 0,$=void 0;if(n.hasBlockSibling)F=1;else{O=F.startContainer.getAscendant(j.$block,1);if(!O||!O.is({div:1,p:1}))F=0;else{$=O.getPosition(Q);if($==CKEDITOR.POSITION_IDENTICAL||
$==CKEDITOR.POSITION_CONTAINS)F=0;else{Q=F.splitElement(O);F.moveToPosition(Q,CKEDITOR.POSITION_AFTER_START);F=1}}}}if(F)s=t>0;else{F=K.startPath();if(!n.isBlock&&g(i.editor,F.block,F.blockLimit)&&(U=m(i.editor))){U=p.createElement(U);U.appendBogus();K.insertNode(U);CKEDITOR.env.needsBrFiller&&(M=U.getBogus())&&M.remove();K.moveToPosition(U,CKEDITOR.POSITION_BEFORE_END)}if((F=K.startPath().block)&&!F.equals(N)){if(M=F.getBogus()){M.remove();C.push(F)}N=F}n.firstNotAllowed&&(u=1);if(u&&n.isElement){F=
K.startContainer;for(Q=null;F&&!j[F.getName()][n.name];){if(F.equals(x)){F=null;break}Q=F;F=F.getParent()}if(F){if(Q){V=K.splitElement(Q);i.zombies.push(V);i.zombies.push(Q)}}else{Q=x.getName();Z=!t;F=t==l.length-1;Q=c(n.node,Q);for(var O=[],$=Q.length,Y=0,W=void 0,aa=0,ea=-1;Y<$;Y++){W=Q[Y];if(W==" "){if(!aa&&(!Z||Y)){O.push(new CKEDITOR.dom.text(" "));ea=O.length}aa=1}else{O.push(W);aa=0}}F&&ea==O.length&&O.pop();Z=O}}if(Z){for(;F=Z.pop();)K.insertNode(F);Z=0}else K.insertNode(n.node);if(n.lastNotAllowed&&
t<l.length-1){(V=w?r:V)&&K.setEndAt(V,CKEDITOR.POSITION_AFTER_START);u=0}K.collapse()}}if(l.length!=1)M=false;else{M=l[0];M=M.isElement&&M.node.getAttribute("contenteditable")=="false"}if(M){s=true;F=l[0].node;K.setStartAt(F,CKEDITOR.POSITION_BEFORE_START);K.setEndAt(F,CKEDITOR.POSITION_AFTER_END)}i.dontMoveCaret=s;i.bogusNeededBlocks=C}M=i.range;var ba;V=i.bogusNeededBlocks;for(Z=M.createBookmark();N=i.zombies.pop();)if(N.getParent()){U=M.clone();U.moveToElementEditStart(N);U.removeEmptyBlocksAtEnd()}if(V)for(;N=
V.pop();)CKEDITOR.env.needsBrFiller?N.appendBogus():N.append(M.document.createText(" "));for(;N=i.mergeCandidates.pop();)N.mergeSiblings();M.moveToBookmark(Z);if(!i.dontMoveCaret){for(N=a(M.startContainer)&&M.startContainer.getChild(M.startOffset-1);N&&a(N)&&!N.is(j.$empty);){if(N.isBlockBoundary())M.moveToPosition(N,CKEDITOR.POSITION_BEFORE_END);else{if(f(N)&&N.getHtml().match(/(\s|&nbsp;)$/g)){ba=null;break}ba=M.clone();ba.moveToPosition(N,CKEDITOR.POSITION_BEFORE_END)}N=N.getLast(d)}ba&&M.moveToRange(ba)}}}}(),
u=function(){function a(b){b=new CKEDITOR.dom.walker(b);b.guard=function(a,b){if(b)return false;if(a.type==CKEDITOR.NODE_ELEMENT)return a.is(CKEDITOR.dtd.$tableContent)};b.evaluator=function(a){return a.type==CKEDITOR.NODE_ELEMENT};return b}function b(a,c,d){c=a.getDocument().createElement(c);a.append(c,d);return c}function c(a){var b=a.count(),d;for(b;b-- >0;){d=a.getItem(b);if(!CKEDITOR.tools.trim(d.getHtml())){d.appendBogus();CKEDITOR.env.ie&&(CKEDITOR.env.version<9&&d.getChildCount())&&d.getFirst().remove()}}}
return function(d){var g=d.startContainer,f=g.getAscendant("table",1),e=false;c(f.getElementsByTag("td"));c(f.getElementsByTag("th"));f=d.clone();f.setStart(g,0);f=a(f).lastBackward();if(!f){f=d.clone();f.setEndAt(g,CKEDITOR.POSITION_BEFORE_END);f=a(f).lastForward();e=true}f||(f=g);if(f.is("table")){d.setStartAt(f,CKEDITOR.POSITION_BEFORE_START);d.collapse(true);f.remove()}else{f.is({tbody:1,thead:1,tfoot:1})&&(f=b(f,"tr",e));f.is("tr")&&(f=b(f,f.getParent().is("thead")?"th":"td",e));(g=f.getBogus())&&
g.remove();d.moveToPosition(f,e?CKEDITOR.POSITION_AFTER_START:CKEDITOR.POSITION_BEFORE_END)}}}();a={detect:function(a,b){var c=a.range,d=c.clone(),g=c.clone(),f=new CKEDITOR.dom.elementPath(c.startContainer,b),e=new CKEDITOR.dom.elementPath(c.endContainer,b);d.collapse(1);g.collapse();if(f.block&&d.checkBoundaryOfElement(f.block,CKEDITOR.END)){c.setStartAfter(f.block);a.prependEolBr=1}if(e.block&&g.checkBoundaryOfElement(e.block,CKEDITOR.START)){c.setEndBefore(e.block);a.appendEolBr=1}},fix:function(a,
b){var c=b.getDocument(),d;if(a.appendEolBr){d=this.createEolBr(c);a.fragment.append(d)}a.prependEolBr&&(!d||d.getPrevious())&&a.fragment.append(this.createEolBr(c),1)},createEolBr:function(a){return a.createElement("br",{attributes:{"data-cke-eol":1}})}};e={exclude:function(a){var b=a.range.getBoundaryNodes(),c=b.startNode;(b=b.endNode)&&(s(b)&&(!c||!c.equals(b)))&&a.range.setEndBefore(b)}};c={rebuild:function(a,b){var c=a.range,d=c.getCommonAncestor(),g=new CKEDITOR.dom.elementPath(d,b),f=new CKEDITOR.dom.elementPath(c.startContainer,
b),c=new CKEDITOR.dom.elementPath(c.endContainer,b),e;d.type==CKEDITOR.NODE_TEXT&&(d=d.getParent());if(g.blockLimit.is({tr:1,table:1})){var h=g.contains("table").getParent();e=function(a){return!a.equals(h)}}else if(g.block&&g.block.is(CKEDITOR.dtd.$listItem)){f=f.contains(CKEDITOR.dtd.$list);c=c.contains(CKEDITOR.dtd.$list);if(!f.equals(c)){var i=g.contains(CKEDITOR.dtd.$list).getParent();e=function(a){return!a.equals(i)}}}e||(e=function(a){return!a.equals(g.block)&&!a.equals(g.blockLimit)});this.rebuildFragment(a,
b,d,e)},rebuildFragment:function(a,b,c,d){for(var g;c&&!c.equals(b)&&d(c);){g=c.clone(0,1);a.fragment.appendTo(g);a.fragment=g;c=c.getParent()}}};b={shrink:function(a){var a=a.range,b=a.startContainer,c=a.endContainer,d=a.startOffset,g=a.endOffset;b.type==CKEDITOR.NODE_ELEMENT&&(b.equals(c)&&b.is("tr")&&++d==g)&&a.shrink(CKEDITOR.SHRINK_TEXT)}};var x=function(){function a(b,c){var d=b.getParent();if(d.is(CKEDITOR.dtd.$inline))b[c?"insertBefore":"insertAfter"](d)}function b(c,d,g){a(d);a(g,1);for(var f;f=
g.getNext();){f.insertAfter(d);d=f}l(c)&&c.remove()}function c(a,b){var d=new CKEDITOR.dom.range(a);d.setStartAfter(b.startNode);d.setEndBefore(b.endNode);return d}return{list:{detectMerge:function(a,b){var d=c(b,a.bookmark),g=d.startPath(),f=d.endPath(),e=g.contains(CKEDITOR.dtd.$list),h=f.contains(CKEDITOR.dtd.$list);a.mergeList=e&&h&&e.getParent().equals(h.getParent())&&!e.equals(h);a.mergeListItems=g.block&&f.block&&g.block.is(CKEDITOR.dtd.$listItem)&&f.block.is(CKEDITOR.dtd.$listItem);if(a.mergeList||
a.mergeListItems){d=d.clone();d.setStartBefore(a.bookmark.startNode);d.setEndAfter(a.bookmark.endNode);a.mergeListBookmark=d.createBookmark()}},merge:function(a,c){if(a.mergeListBookmark){var d=a.mergeListBookmark.startNode,g=a.mergeListBookmark.endNode,f=new CKEDITOR.dom.elementPath(d,c),e=new CKEDITOR.dom.elementPath(g,c);if(a.mergeList){var h=f.contains(CKEDITOR.dtd.$list),i=e.contains(CKEDITOR.dtd.$list);if(!h.equals(i)){i.moveChildren(h);i.remove()}}if(a.mergeListItems){f=f.contains(CKEDITOR.dtd.$listItem);
e=e.contains(CKEDITOR.dtd.$listItem);f.equals(e)||b(e,d,g)}d.remove();g.remove()}}},block:{detectMerge:function(a,b){if(!a.tableContentsRanges&&!a.mergeListBookmark){var c=new CKEDITOR.dom.range(b);c.setStartBefore(a.bookmark.startNode);c.setEndAfter(a.bookmark.endNode);a.mergeBlockBookmark=c.createBookmark()}},merge:function(a,c){if(a.mergeBlockBookmark&&!a.purgeTableBookmark){var d=a.mergeBlockBookmark.startNode,g=a.mergeBlockBookmark.endNode,f=new CKEDITOR.dom.elementPath(d,c),e=new CKEDITOR.dom.elementPath(g,
c),f=f.block,e=e.block;f&&(e&&!f.equals(e))&&b(e,d,g);d.remove();g.remove()}}},table:function(){function a(c){var g=[],f,e=new CKEDITOR.dom.walker(c),h=c.startPath().contains(d),i=c.endPath().contains(d),j={};e.guard=function(a,e){if(a.type==CKEDITOR.NODE_ELEMENT){var k="visited_"+(e?"out":"in");if(a.getCustomData(k))return;CKEDITOR.dom.element.setMarker(j,a,k,1)}if(e&&h&&a.equals(h)){f=c.clone();f.setEndAt(h,CKEDITOR.POSITION_BEFORE_END);g.push(f)}else if(!e&&i&&a.equals(i)){f=c.clone();f.setStartAt(i,
CKEDITOR.POSITION_AFTER_START);g.push(f)}else if(!e&&a.type==CKEDITOR.NODE_ELEMENT&&a.is(d)&&(!h||b(a,h))&&(!i||b(a,i))){f=c.clone();f.selectNodeContents(a);g.push(f)}};e.lastForward();CKEDITOR.dom.element.clearAllMarkers(j);return g}function b(a,c){var d=CKEDITOR.POSITION_CONTAINS+CKEDITOR.POSITION_IS_CONTAINED,g=a.getPosition(c);return g===CKEDITOR.POSITION_IDENTICAL?false:(g&d)===0}var d={td:1,th:1,caption:1};return{detectPurge:function(a){var b=a.range,c=b.clone();c.enlarge(CKEDITOR.ENLARGE_ELEMENT);
var c=new CKEDITOR.dom.walker(c),g=0;c.evaluator=function(a){a.type==CKEDITOR.NODE_ELEMENT&&a.is(d)&&++g};c.checkForward();if(g>1){var c=b.startPath().contains("table"),f=b.endPath().contains("table");if(c&&f&&b.checkBoundaryOfElement(c,CKEDITOR.START)&&b.checkBoundaryOfElement(f,CKEDITOR.END)){b=a.range.clone();b.setStartBefore(c);b.setEndAfter(f);a.purgeTableBookmark=b.createBookmark()}}},detectRanges:function(g,f){var e=c(f,g.bookmark),h=e.clone(),i,j,k=e.getCommonAncestor();k.is(CKEDITOR.dtd.$tableContent)&&
!k.is(d)&&(k=k.getAscendant("table",true));j=k;k=new CKEDITOR.dom.elementPath(e.startContainer,j);j=new CKEDITOR.dom.elementPath(e.endContainer,j);k=k.contains("table");j=j.contains("table");if(k||j){if(k&&j&&b(k,j)){g.tableSurroundingRange=h;h.setStartAt(k,CKEDITOR.POSITION_AFTER_END);h.setEndAt(j,CKEDITOR.POSITION_BEFORE_START);h=e.clone();h.setEndAt(k,CKEDITOR.POSITION_AFTER_END);i=e.clone();i.setStartAt(j,CKEDITOR.POSITION_BEFORE_START);i=a(h).concat(a(i))}else if(k){if(!j){g.tableSurroundingRange=
h;h.setStartAt(k,CKEDITOR.POSITION_AFTER_END);e.setEndAt(k,CKEDITOR.POSITION_AFTER_END)}}else{g.tableSurroundingRange=h;h.setEndAt(j,CKEDITOR.POSITION_BEFORE_START);e.setStartAt(j,CKEDITOR.POSITION_AFTER_START)}g.tableContentsRanges=i?i:a(e)}},deleteRanges:function(a){for(var b;b=a.tableContentsRanges.pop();){b.extractContents();l(b.startContainer)&&b.startContainer.appendBogus()}a.tableSurroundingRange&&a.tableSurroundingRange.extractContents()},purge:function(a){if(a.purgeTableBookmark){var b=a.doc,
c=a.range.clone(),b=b.createElement("p");b.insertBefore(a.purgeTableBookmark.startNode);c.moveToBookmark(a.purgeTableBookmark);c.deleteContents();a.range.moveToPosition(b,CKEDITOR.POSITION_AFTER_START)}}}}(),detectExtractMerge:function(a){return!(a.range.startPath().contains(CKEDITOR.dtd.$listItem)&&a.range.endPath().contains(CKEDITOR.dtd.$listItem))},fixUneditableRangePosition:function(a){a.startContainer.getDtd()["#"]||a.moveToClosestEditablePosition(null,true)},autoParagraph:function(a,b){var c=
b.startPath(),d;if(g(a,c.block,c.blockLimit)&&(d=m(a))){d=b.document.createElement(d);d.appendBogus();b.insertNode(d);b.moveToPosition(d,CKEDITOR.POSITION_AFTER_START)}}}}()}(),function(){function a(){var a=this._.fakeSelection,b;if(a){b=this.getSelection(1);if(!b||!b.isHidden()){a.reset();a=0}}if(!a){a=b||this.getSelection(1);if(!a||a.getType()==CKEDITOR.SELECTION_NONE)return}this.fire("selectionCheck",a);b=this.elementPath();if(!b.compare(this._.selectionPreviousPath)){if(CKEDITOR.env.webkit)this._.previousActive=
this.document.getActive();this._.selectionPreviousPath=b;this.fire("selectionChange",{selection:a,path:b})}}function e(){o=true;if(!r){b.call(this);r=CKEDITOR.tools.setTimeout(b,200,this)}}function b(){r=null;if(o){CKEDITOR.tools.setTimeout(a,0,this);o=false}}function c(a){return n(a)||a.type==CKEDITOR.NODE_ELEMENT&&!a.is(CKEDITOR.dtd.$empty)?true:false}function f(a){function b(c,d){return!c||c.type==CKEDITOR.NODE_TEXT?false:a.clone()["moveToElementEdit"+(d?"End":"Start")](c)}if(!(a.root instanceof
CKEDITOR.editable))return false;var d=a.startContainer,g=a.getPreviousNode(c,null,d),f=a.getNextNode(c,null,d);return b(g)||b(f,1)||!g&&!f&&!(d.type==CKEDITOR.NODE_ELEMENT&&d.isBlockBoundary()&&d.getBogus())?true:false}function k(a){return a.getCustomData("cke-fillingChar")}function i(a,b){var c=a&&a.removeCustomData("cke-fillingChar");if(c){if(b!==false){var g,f=a.getDocument().getSelection().getNative(),e=f&&f.type!="None"&&f.getRangeAt(0);if(c.getLength()>1&&e&&e.intersectsNode(c.$)){g=j(f);e=
f.focusNode==c.$&&f.focusOffset>0;f.anchorNode==c.$&&f.anchorOffset>0&&g[0].offset--;e&&g[1].offset--}}c.setText(d(c.getText()));g&&h(a.getDocument().$,g)}}function d(a){return a.replace(/\u200B( )?/g,function(a){return a[1]?" ":""})}function j(a){return[{node:a.anchorNode,offset:a.anchorOffset},{node:a.focusNode,offset:a.focusOffset}]}function h(a,b){var c=a.getSelection(),d=a.createRange();d.setStart(b[0].node,b[0].offset);d.collapse(true);c.removeAllRanges();c.addRange(d);c.extend(b[1].node,b[1].offset)}
function g(a){var b=CKEDITOR.dom.element.createFromHtml('<div data-cke-hidden-sel="1" data-cke-temp="1" style="'+(CKEDITOR.env.ie?"display:none":"position:fixed;top:0;left:-1000px")+'">&nbsp;</div>',a.document);a.fire("lockSnapshot");a.editable().append(b);var c=a.getSelection(1),d=a.createRange(),g=c.root.on("selectionchange",function(a){a.cancel()},null,null,0);d.setStartAt(b,CKEDITOR.POSITION_AFTER_START);d.setEndAt(b,CKEDITOR.POSITION_BEFORE_END);c.selectRanges([d]);g.removeListener();a.fire("unlockSnapshot");
a._.hiddenSelectionContainer=b}function m(a){var b={37:1,39:1,8:1,46:1};return function(c){var d=c.data.getKeystroke();if(b[d]){var g=a.getSelection().getRanges(),f=g[0];if(g.length==1&&f.collapsed)if((d=f[d<38?"getPreviousEditableNode":"getNextEditableNode"]())&&d.type==CKEDITOR.NODE_ELEMENT&&d.getAttribute("contenteditable")=="false"){a.getSelection().fake(d);c.data.preventDefault();c.cancel()}}}}function p(a){for(var b=0;b<a.length;b++){var c=a[b];c.getCommonAncestor().isReadOnly()&&a.splice(b,
1);if(!c.collapsed){if(c.startContainer.isReadOnly())for(var d=c.startContainer,g;d;){if((g=d.type==CKEDITOR.NODE_ELEMENT)&&d.is("body")||!d.isReadOnly())break;g&&d.getAttribute("contentEditable")=="false"&&c.setStartAfter(d);d=d.getParent()}d=c.startContainer;g=c.endContainer;var f=c.startOffset,e=c.endOffset,h=c.clone();d&&d.type==CKEDITOR.NODE_TEXT&&(f>=d.getLength()?h.setStartAfter(d):h.setStartBefore(d));g&&g.type==CKEDITOR.NODE_TEXT&&(e?h.setEndAfter(g):h.setEndBefore(g));d=new CKEDITOR.dom.walker(h);
d.evaluator=function(d){if(d.type==CKEDITOR.NODE_ELEMENT&&d.isReadOnly()){var g=c.clone();c.setEndBefore(d);c.collapsed&&a.splice(b--,1);if(!(d.getPosition(h.endContainer)&CKEDITOR.POSITION_CONTAINS)){g.setStartAfter(d);g.collapsed||a.splice(b+1,0,g)}return true}return false};d.next()}}return a}var r,o,n=CKEDITOR.dom.walker.invisible(1),l=function(){function a(b){return function(a){var c=a.editor.createRange();c.moveToClosestEditablePosition(a.selected,b)&&a.editor.getSelection().selectRanges([c]);
return false}}function b(a){return function(b){var c=b.editor,d=c.createRange(),g;if(!(g=d.moveToClosestEditablePosition(b.selected,a)))g=d.moveToClosestEditablePosition(b.selected,!a);g&&c.getSelection().selectRanges([d]);c.fire("saveSnapshot");b.selected.remove();if(!g){d.moveToElementEditablePosition(c.editable());c.getSelection().selectRanges([d])}c.fire("saveSnapshot");return false}}var c=a(),d=a(1);return{37:c,38:c,39:d,40:d,8:b(),46:b(1)}}();CKEDITOR.on("instanceCreated",function(b){function c(){var a=
d.getSelection();a&&a.removeAllRanges()}var d=b.editor;d.on("contentDom",function(){function b(){t=new CKEDITOR.dom.selection(d.getSelection());t.lock()}function c(){f.removeListener("mouseup",c);k.removeListener("mouseup",c);var a=CKEDITOR.document.$.selection,b=a.createRange();a.type!="None"&&b.parentElement().ownerDocument==g.$&&b.select()}var g=d.document,f=CKEDITOR.document,h=d.editable(),j=g.getBody(),k=g.getDocumentElement(),l=h.isInline(),o,t;CKEDITOR.env.gecko&&h.attachListener(h,"focus",
function(a){a.removeListener();if(o!==0)if((a=d.getSelection().getNative())&&a.isCollapsed&&a.anchorNode==h.$){a=d.createRange();a.moveToElementEditStart(h);a.select()}},null,null,-2);h.attachListener(h,CKEDITOR.env.webkit?"DOMFocusIn":"focus",function(){o&&CKEDITOR.env.webkit&&(o=d._.previousActive&&d._.previousActive.equals(g.getActive()));d.unlockSelection(o);o=0},null,null,-1);h.attachListener(h,"mousedown",function(){o=0});if(CKEDITOR.env.ie||l){s?h.attachListener(h,"beforedeactivate",b,null,
null,-1):h.attachListener(d,"selectionCheck",b,null,null,-1);h.attachListener(h,CKEDITOR.env.webkit?"DOMFocusOut":"blur",function(){d.lockSelection(t);o=1},null,null,-1);h.attachListener(h,"mousedown",function(){o=0})}if(CKEDITOR.env.ie&&!l){var r;h.attachListener(h,"mousedown",function(a){if(a.data.$.button==2){a=d.document.getSelection();if(!a||a.getType()==CKEDITOR.SELECTION_NONE)r=d.window.getScrollPosition()}});h.attachListener(h,"mouseup",function(a){if(a.data.$.button==2&&r){d.document.$.documentElement.scrollLeft=
r.x;d.document.$.documentElement.scrollTop=r.y}r=null});if(g.$.compatMode!="BackCompat"){if(CKEDITOR.env.ie7Compat||CKEDITOR.env.ie6Compat)k.on("mousedown",function(a){function b(a){a=a.data.$;if(d){var c=j.$.createTextRange();try{c.moveToPoint(a.clientX,a.clientY)}catch(g){}d.setEndPoint(e.compareEndPoints("StartToStart",c)<0?"EndToEnd":"StartToStart",c);d.select()}}function c(){k.removeListener("mousemove",b);f.removeListener("mouseup",c);k.removeListener("mouseup",c);d.select()}a=a.data;if(a.getTarget().is("html")&&
a.$.y<k.$.clientHeight&&a.$.x<k.$.clientWidth){var d=j.$.createTextRange();try{d.moveToPoint(a.$.clientX,a.$.clientY)}catch(g){}var e=d.duplicate();k.on("mousemove",b);f.on("mouseup",c);k.on("mouseup",c)}});if(CKEDITOR.env.version>7&&CKEDITOR.env.version<11)k.on("mousedown",function(a){if(a.data.getTarget().is("html")){f.on("mouseup",c);k.on("mouseup",c)}})}}h.attachListener(h,"selectionchange",a,d);h.attachListener(h,"keyup",e,d);h.attachListener(h,CKEDITOR.env.webkit?"DOMFocusIn":"focus",function(){d.forceNextSelectionCheck();
d.selectionChange(1)});if(l&&(CKEDITOR.env.webkit||CKEDITOR.env.gecko)){var n;h.attachListener(h,"mousedown",function(){n=1});h.attachListener(g.getDocumentElement(),"mouseup",function(){n&&e.call(d);n=0})}else h.attachListener(CKEDITOR.env.ie?h:g.getDocumentElement(),"mouseup",e,d);CKEDITOR.env.webkit&&h.attachListener(g,"keydown",function(a){switch(a.data.getKey()){case 13:case 33:case 34:case 35:case 36:case 37:case 39:case 8:case 45:case 46:i(h)}},null,null,-1);h.attachListener(h,"keydown",m(d),
null,null,-1)});d.on("setData",function(){d.unlockSelection();CKEDITOR.env.webkit&&c()});d.on("contentDomUnload",function(){d.unlockSelection()});if(CKEDITOR.env.ie9Compat)d.on("beforeDestroy",c,null,null,9);d.on("dataReady",function(){delete d._.fakeSelection;delete d._.hiddenSelectionContainer;d.selectionChange(1)});d.on("loadSnapshot",function(){var a=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_ELEMENT),b=d.editable().getLast(a);if(b&&b.hasAttribute("data-cke-hidden-sel")){b.remove();if(CKEDITOR.env.gecko)(a=
d.editable().getFirst(a))&&(a.is("br")&&a.getAttribute("_moz_editor_bogus_node"))&&a.remove()}},null,null,100);d.on("key",function(a){if(d.mode=="wysiwyg"){var b=d.getSelection();if(b.isFake){var c=l[a.data.keyCode];if(c)return c({editor:d,selected:b.getSelectedElement(),selection:b,keyEvent:a})}}})});CKEDITOR.on("instanceReady",function(a){function b(){var a=g.editable();if(a)if(a=k(a)){var c=g.document.$.getSelection();if(c.type!="None"&&(c.anchorNode==a.$||c.focusNode==a.$))e=j(c);f=a.getText();
a.setText(d(f))}}function c(){var a=g.editable();if(a)if(a=k(a)){a.setText(f);if(e){h(g.document.$,e);e=null}}}var g=a.editor,f,e;if(CKEDITOR.env.webkit){g.on("selectionChange",function(){var a=g.editable(),b=k(a);b&&(b.getCustomData("ready")?i(a):b.setCustomData("ready",1))},null,null,-1);g.on("beforeSetMode",function(){i(g.editable())},null,null,-1);g.on("beforeUndoImage",b);g.on("afterUndoImage",c);g.on("beforeGetData",b,null,null,0);g.on("getData",c)}});CKEDITOR.editor.prototype.selectionChange=
function(b){(b?a:e).call(this)};CKEDITOR.editor.prototype.getSelection=function(a){if((this._.savedSelection||this._.fakeSelection)&&!a)return this._.savedSelection||this._.fakeSelection;return(a=this.editable())&&this.mode=="wysiwyg"?new CKEDITOR.dom.selection(a):null};CKEDITOR.editor.prototype.lockSelection=function(a){a=a||this.getSelection(1);if(a.getType()!=CKEDITOR.SELECTION_NONE){!a.isLocked&&a.lock();this._.savedSelection=a;return true}return false};CKEDITOR.editor.prototype.unlockSelection=
function(a){var b=this._.savedSelection;if(b){b.unlock(a);delete this._.savedSelection;return true}return false};CKEDITOR.editor.prototype.forceNextSelectionCheck=function(){delete this._.selectionPreviousPath};CKEDITOR.dom.document.prototype.getSelection=function(){return new CKEDITOR.dom.selection(this)};CKEDITOR.dom.range.prototype.select=function(){var a=this.root instanceof CKEDITOR.editable?this.root.editor.getSelection():new CKEDITOR.dom.selection(this.root);a.selectRanges([this]);return a};
CKEDITOR.SELECTION_NONE=1;CKEDITOR.SELECTION_TEXT=2;CKEDITOR.SELECTION_ELEMENT=3;var s=typeof window.getSelection!="function",t=1;CKEDITOR.dom.selection=function(a){if(a instanceof CKEDITOR.dom.selection)var b=a,a=a.root;var c=a instanceof CKEDITOR.dom.element;this.rev=b?b.rev:t++;this.document=a instanceof CKEDITOR.dom.document?a:a.getDocument();this.root=c?a:this.document.getBody();this.isLocked=0;this._={cache:{}};if(b){CKEDITOR.tools.extend(this._.cache,b._.cache);this.isFake=b.isFake;this.isLocked=
b.isLocked;return this}var a=this.getNative(),d,g;if(a)if(a.getRangeAt)d=(g=a.rangeCount&&a.getRangeAt(0))&&new CKEDITOR.dom.node(g.commonAncestorContainer);else{try{g=a.createRange()}catch(f){}d=g&&CKEDITOR.dom.element.get(g.item&&g.item(0)||g.parentElement())}if(!d||!(d.type==CKEDITOR.NODE_ELEMENT||d.type==CKEDITOR.NODE_TEXT)||!this.root.equals(d)&&!this.root.contains(d)){this._.cache.type=CKEDITOR.SELECTION_NONE;this._.cache.startElement=null;this._.cache.selectedElement=null;this._.cache.selectedText=
"";this._.cache.ranges=new CKEDITOR.dom.rangeList}return this};var w={img:1,hr:1,li:1,table:1,tr:1,td:1,th:1,embed:1,object:1,ol:1,ul:1,a:1,input:1,form:1,select:1,textarea:1,button:1,fieldset:1,thead:1,tfoot:1};CKEDITOR.dom.selection.prototype={getNative:function(){return this._.cache.nativeSel!==void 0?this._.cache.nativeSel:this._.cache.nativeSel=s?this.document.$.selection:this.document.getWindow().$.getSelection()},getType:s?function(){var a=this._.cache;if(a.type)return a.type;var b=CKEDITOR.SELECTION_NONE;
try{var c=this.getNative(),d=c.type;if(d=="Text")b=CKEDITOR.SELECTION_TEXT;if(d=="Control")b=CKEDITOR.SELECTION_ELEMENT;if(c.createRange().parentElement())b=CKEDITOR.SELECTION_TEXT}catch(g){}return a.type=b}:function(){var a=this._.cache;if(a.type)return a.type;var b=CKEDITOR.SELECTION_TEXT,c=this.getNative();if(!c||!c.rangeCount)b=CKEDITOR.SELECTION_NONE;else if(c.rangeCount==1){var c=c.getRangeAt(0),d=c.startContainer;if(d==c.endContainer&&d.nodeType==1&&c.endOffset-c.startOffset==1&&w[d.childNodes[c.startOffset].nodeName.toLowerCase()])b=
CKEDITOR.SELECTION_ELEMENT}return a.type=b},getRanges:function(){var a=s?function(){function a(b){return(new CKEDITOR.dom.node(b)).getIndex()}var b=function(b,c){b=b.duplicate();b.collapse(c);var d=b.parentElement();if(!d.hasChildNodes())return{container:d,offset:0};for(var g=d.children,f,e,h=b.duplicate(),i=0,j=g.length-1,k=-1,m,l;i<=j;){k=Math.floor((i+j)/2);f=g[k];h.moveToElementText(f);m=h.compareEndPoints("StartToStart",b);if(m>0)j=k-1;else if(m<0)i=k+1;else return{container:d,offset:a(f)}}if(k==
-1||k==g.length-1&&m<0){h.moveToElementText(d);h.setEndPoint("StartToStart",b);h=h.text.replace(/(\r\n|\r)/g,"\n").length;g=d.childNodes;if(!h){f=g[g.length-1];return f.nodeType!=CKEDITOR.NODE_TEXT?{container:d,offset:g.length}:{container:f,offset:f.nodeValue.length}}for(d=g.length;h>0&&d>0;){e=g[--d];if(e.nodeType==CKEDITOR.NODE_TEXT){l=e;h=h-e.nodeValue.length}}return{container:l,offset:-h}}h.collapse(m>0?true:false);h.setEndPoint(m>0?"StartToStart":"EndToStart",b);h=h.text.replace(/(\r\n|\r)/g,
"\n").length;if(!h)return{container:d,offset:a(f)+(m>0?0:1)};for(;h>0;)try{e=f[m>0?"previousSibling":"nextSibling"];if(e.nodeType==CKEDITOR.NODE_TEXT){h=h-e.nodeValue.length;l=e}f=e}catch(o){return{container:d,offset:a(f)}}return{container:l,offset:m>0?-h:l.nodeValue.length+h}};return function(){var a=this.getNative(),c=a&&a.createRange(),d=this.getType();if(!a)return[];if(d==CKEDITOR.SELECTION_TEXT){a=new CKEDITOR.dom.range(this.root);d=b(c,true);a.setStart(new CKEDITOR.dom.node(d.container),d.offset);
d=b(c);a.setEnd(new CKEDITOR.dom.node(d.container),d.offset);a.endContainer.getPosition(a.startContainer)&CKEDITOR.POSITION_PRECEDING&&a.endOffset<=a.startContainer.getIndex()&&a.collapse();return[a]}if(d==CKEDITOR.SELECTION_ELEMENT){for(var d=[],g=0;g<c.length;g++){for(var f=c.item(g),e=f.parentNode,h=0,a=new CKEDITOR.dom.range(this.root);h<e.childNodes.length&&e.childNodes[h]!=f;h++);a.setStart(new CKEDITOR.dom.node(e),h);a.setEnd(new CKEDITOR.dom.node(e),h+1);d.push(a)}return d}return[]}}():function(){var a=
[],b,c=this.getNative();if(!c)return a;for(var d=0;d<c.rangeCount;d++){var g=c.getRangeAt(d);b=new CKEDITOR.dom.range(this.root);b.setStart(new CKEDITOR.dom.node(g.startContainer),g.startOffset);b.setEnd(new CKEDITOR.dom.node(g.endContainer),g.endOffset);a.push(b)}return a};return function(b){var c=this._.cache,d=c.ranges;if(!d)c.ranges=d=new CKEDITOR.dom.rangeList(a.call(this));return!b?d:p(new CKEDITOR.dom.rangeList(d.slice()))}}(),getStartElement:function(){var a=this._.cache;if(a.startElement!==
void 0)return a.startElement;var b;switch(this.getType()){case CKEDITOR.SELECTION_ELEMENT:return this.getSelectedElement();case CKEDITOR.SELECTION_TEXT:var c=this.getRanges()[0];if(c){if(c.collapsed){b=c.startContainer;b.type!=CKEDITOR.NODE_ELEMENT&&(b=b.getParent())}else{for(c.optimize();;){b=c.startContainer;if(c.startOffset==(b.getChildCount?b.getChildCount():b.getLength())&&!b.isBlockBoundary())c.setStartAfter(b);else break}b=c.startContainer;if(b.type!=CKEDITOR.NODE_ELEMENT)return b.getParent();
b=b.getChild(c.startOffset);if(!b||b.type!=CKEDITOR.NODE_ELEMENT)b=c.startContainer;else for(c=b.getFirst();c&&c.type==CKEDITOR.NODE_ELEMENT;){b=c;c=c.getFirst()}}b=b.$}}return a.startElement=b?new CKEDITOR.dom.element(b):null},getSelectedElement:function(){var a=this._.cache;if(a.selectedElement!==void 0)return a.selectedElement;var b=this,c=CKEDITOR.tools.tryThese(function(){return b.getNative().createRange().item(0)},function(){for(var a=b.getRanges()[0].clone(),c,d,g=2;g&&(!(c=a.getEnclosedNode())||
!(c.type==CKEDITOR.NODE_ELEMENT&&w[c.getName()]&&(d=c)));g--)a.shrink(CKEDITOR.SHRINK_ELEMENT);return d&&d.$});return a.selectedElement=c?new CKEDITOR.dom.element(c):null},getSelectedText:function(){var a=this._.cache;if(a.selectedText!==void 0)return a.selectedText;var b=this.getNative(),b=s?b.type=="Control"?"":b.createRange().text:b.toString();return a.selectedText=b},lock:function(){this.getRanges();this.getStartElement();this.getSelectedElement();this.getSelectedText();this._.cache.nativeSel=
null;this.isLocked=1},unlock:function(a){if(this.isLocked){if(a)var b=this.getSelectedElement(),c=!b&&this.getRanges(),d=this.isFake;this.isLocked=0;this.reset();if(a)(a=b||c[0]&&c[0].getCommonAncestor())&&a.getAscendant("body",1)&&(d?this.fake(b):b?this.selectElement(b):this.selectRanges(c))}},reset:function(){this._.cache={};this.isFake=0;var a=this.root.editor;if(a&&a._.fakeSelection&&this.rev==a._.fakeSelection.rev){delete a._.fakeSelection;var b=a._.hiddenSelectionContainer;if(b){var c=a.checkDirty();
a.fire("lockSnapshot");b.remove();a.fire("unlockSnapshot");!c&&a.resetDirty()}delete a._.hiddenSelectionContainer}this.rev=t++},selectElement:function(a){var b=new CKEDITOR.dom.range(this.root);b.setStartBefore(a);b.setEndAfter(a);this.selectRanges([b])},selectRanges:function(a){var b=this.root.editor,b=b&&b._.hiddenSelectionContainer;this.reset();if(b)for(var b=this.root,c,d=0;d<a.length;++d){c=a[d];if(c.endContainer.equals(b))c.endOffset=Math.min(c.endOffset,b.getChildCount())}if(a.length)if(this.isLocked){var g=
CKEDITOR.document.getActive();this.unlock();this.selectRanges(a);this.lock();g&&!g.equals(this.root)&&g.focus()}else{var e;a:{var h,j;if(a.length==1&&!(j=a[0]).collapsed&&(e=j.getEnclosedNode())&&e.type==CKEDITOR.NODE_ELEMENT){j=j.clone();j.shrink(CKEDITOR.SHRINK_ELEMENT,true);if((h=j.getEnclosedNode())&&h.type==CKEDITOR.NODE_ELEMENT)e=h;if(e.getAttribute("contenteditable")=="false")break a}e=void 0}if(e)this.fake(e);else{if(s){j=CKEDITOR.dom.walker.whitespaces(true);h=/\ufeff|\u00a0/;b={table:1,
tbody:1,tr:1};if(a.length>1){e=a[a.length-1];a[0].setEnd(e.endContainer,e.endOffset)}e=a[0];var a=e.collapsed,k,m,l;if((c=e.getEnclosedNode())&&c.type==CKEDITOR.NODE_ELEMENT&&c.getName()in w&&(!c.is("a")||!c.getText()))try{l=c.$.createControlRange();l.addElement(c.$);l.select();return}catch(o){}if(e.startContainer.type==CKEDITOR.NODE_ELEMENT&&e.startContainer.getName()in b||e.endContainer.type==CKEDITOR.NODE_ELEMENT&&e.endContainer.getName()in b){e.shrink(CKEDITOR.NODE_ELEMENT,true);a=e.collapsed}l=
e.createBookmark();b=l.startNode;if(!a)g=l.endNode;l=e.document.$.body.createTextRange();l.moveToElementText(b.$);l.moveStart("character",1);if(g){h=e.document.$.body.createTextRange();h.moveToElementText(g.$);l.setEndPoint("EndToEnd",h);l.moveEnd("character",-1)}else{k=b.getNext(j);m=b.hasAscendant("pre");k=!(k&&k.getText&&k.getText().match(h))&&(m||!b.hasPrevious()||b.getPrevious().is&&b.getPrevious().is("br"));m=e.document.createElement("span");m.setHtml("&#65279;");m.insertBefore(b);k&&e.document.createText("﻿").insertBefore(b)}e.setStartBefore(b);
b.remove();if(a){if(k){l.moveStart("character",-1);l.select();e.document.$.selection.clear()}else l.select();e.moveToPosition(m,CKEDITOR.POSITION_BEFORE_START);m.remove()}else{e.setEndBefore(g);g.remove();l.select()}}else{g=this.getNative();if(!g)return;this.removeAllRanges();for(l=0;l<a.length;l++){if(l<a.length-1){k=a[l];m=a[l+1];h=k.clone();h.setStart(k.endContainer,k.endOffset);h.setEnd(m.startContainer,m.startOffset);if(!h.collapsed){h.shrink(CKEDITOR.NODE_ELEMENT,true);e=h.getCommonAncestor();
h=h.getEnclosedNode();if(e.isReadOnly()||h&&h.isReadOnly()){m.setStart(k.startContainer,k.startOffset);a.splice(l--,1);continue}}}e=a[l];m=this.document.$.createRange();if(e.collapsed&&CKEDITOR.env.webkit&&f(e)){k=this.root;i(k,false);h=k.getDocument().createText("​");k.setCustomData("cke-fillingChar",h);e.insertNode(h);if((k=h.getNext())&&!h.getPrevious()&&k.type==CKEDITOR.NODE_ELEMENT&&k.getName()=="br"){i(this.root);e.moveToPosition(k,CKEDITOR.POSITION_BEFORE_START)}else e.moveToPosition(h,CKEDITOR.POSITION_AFTER_END)}m.setStart(e.startContainer.$,
e.startOffset);try{m.setEnd(e.endContainer.$,e.endOffset)}catch(t){if(t.toString().indexOf("NS_ERROR_ILLEGAL_VALUE")>=0){e.collapse(1);m.setEnd(e.endContainer.$,e.endOffset)}else throw t;}g.addRange(m)}}this.reset();this.root.fire("selectionchange")}}},fake:function(a){var b=this.root.editor;this.reset();g(b);var c=this._.cache,d=new CKEDITOR.dom.range(this.root);d.setStartBefore(a);d.setEndAfter(a);c.ranges=new CKEDITOR.dom.rangeList(d);c.selectedElement=c.startElement=a;c.type=CKEDITOR.SELECTION_ELEMENT;
c.selectedText=c.nativeSel=null;this.isFake=1;this.rev=t++;b._.fakeSelection=this;this.root.fire("selectionchange")},isHidden:function(){var a=this.getCommonAncestor();a&&a.type==CKEDITOR.NODE_TEXT&&(a=a.getParent());return!(!a||!a.data("cke-hidden-sel"))},createBookmarks:function(a){a=this.getRanges().createBookmarks(a);this.isFake&&(a.isFake=1);return a},createBookmarks2:function(a){a=this.getRanges().createBookmarks2(a);this.isFake&&(a.isFake=1);return a},selectBookmarks:function(a){for(var b=
[],c,d=0;d<a.length;d++){var g=new CKEDITOR.dom.range(this.root);g.moveToBookmark(a[d]);b.push(g)}if(a.isFake){c=b[0].getEnclosedNode();if(!c||c.type!=CKEDITOR.NODE_ELEMENT)a.isFake=0}a.isFake?this.fake(c):this.selectRanges(b);return this},getCommonAncestor:function(){var a=this.getRanges();return!a.length?null:a[0].startContainer.getCommonAncestor(a[a.length-1].endContainer)},scrollIntoView:function(){this.type!=CKEDITOR.SELECTION_NONE&&this.getRanges()[0].scrollIntoView()},removeAllRanges:function(){if(this.getType()!=
CKEDITOR.SELECTION_NONE){var a=this.getNative();try{a&&a[s?"empty":"removeAllRanges"]()}catch(b){}this.reset()}}}}(),"use strict",CKEDITOR.STYLE_BLOCK=1,CKEDITOR.STYLE_INLINE=2,CKEDITOR.STYLE_OBJECT=3,function(){function a(a,b){for(var c,d;a=a.getParent();){if(a.equals(b))break;if(a.getAttribute("data-nostyle"))c=a;else if(!d){var g=a.getAttribute("contentEditable");g=="false"?c=a:g=="true"&&(d=1)}}return c}function e(b){var d=b.document;if(b.collapsed){d=l(this,d);b.insertNode(d);b.moveToPosition(d,
CKEDITOR.POSITION_BEFORE_END)}else{var g=this.element,f=this._.definition,h,j=f.ignoreReadonly,i=j||f.includeReadonly;i==null&&(i=b.root.getCustomData("cke_includeReadonly"));var k=CKEDITOR.dtd[g];if(!k){h=true;k=CKEDITOR.dtd.span}b.enlarge(CKEDITOR.ENLARGE_INLINE,1);b.trim();var m=b.createBookmark(),o=m.startNode,t=m.endNode,s=o,n;if(!j){var p=b.getCommonAncestor(),j=a(o,p),p=a(t,p);j&&(s=j.getNextSourceNode(true));p&&(t=p)}for(s.getPosition(t)==CKEDITOR.POSITION_FOLLOWING&&(s=0);s;){j=false;if(s.equals(t)){s=
null;j=true}else{var w=s.type==CKEDITOR.NODE_ELEMENT?s.getName():null,p=w&&s.getAttribute("contentEditable")=="false",u=w&&s.getAttribute("data-nostyle");if(w&&s.data("cke-bookmark")){s=s.getNextSourceNode(true);continue}if(p&&i&&CKEDITOR.dtd.$block[w])for(var x=s,v=c(x),q=void 0,y=v.length,z=0,x=y&&new CKEDITOR.dom.range(x.getDocument());z<y;++z){var q=v[z],A=CKEDITOR.filter.instances[q.data("cke-filter")];if(A?A.check(this):1){x.selectNodeContents(q);e.call(this,x)}}v=w?!k[w]||u?0:p&&!i?0:(s.getPosition(t)|
D)==D&&(!f.childRule||f.childRule(s)):1;if(v)if((v=s.getParent())&&((v.getDtd()||CKEDITOR.dtd.span)[g]||h)&&(!f.parentRule||f.parentRule(v))){if(!n&&(!w||!CKEDITOR.dtd.$removeEmpty[w]||(s.getPosition(t)|D)==D)){n=b.clone();n.setStartBefore(s)}w=s.type;if(w==CKEDITOR.NODE_TEXT||p||w==CKEDITOR.NODE_ELEMENT&&!s.getChildCount()){for(var w=s,$;(j=!w.getNext(B))&&($=w.getParent(),k[$.getName()])&&($.getPosition(o)|C)==C&&(!f.childRule||f.childRule($));)w=$;n.setEndAfter(w)}}else j=true;else j=true;s=s.getNextSourceNode(u||
p)}if(j&&n&&!n.collapsed){for(var j=l(this,d),p=j.hasAttributes(),u=n.getCommonAncestor(),w={},v={},q={},y={},Y,W,aa;j&&u;){if(u.getName()==g){for(Y in f.attributes)if(!y[Y]&&(aa=u.getAttribute(W)))j.getAttribute(Y)==aa?v[Y]=1:y[Y]=1;for(W in f.styles)if(!q[W]&&(aa=u.getStyle(W)))j.getStyle(W)==aa?w[W]=1:q[W]=1}u=u.getParent()}for(Y in v)j.removeAttribute(Y);for(W in w)j.removeStyle(W);p&&!j.hasAttributes()&&(j=null);if(j){n.extractContents().appendTo(j);n.insertNode(j);r.call(this,j);j.mergeSiblings();
CKEDITOR.env.ie||j.$.normalize()}else{j=new CKEDITOR.dom.element("span");n.extractContents().appendTo(j);n.insertNode(j);r.call(this,j);j.remove(true)}n=null}}b.moveToBookmark(m);b.shrink(CKEDITOR.SHRINK_TEXT);b.shrink(CKEDITOR.NODE_ELEMENT,true)}}function b(a){function b(){for(var a=new CKEDITOR.dom.elementPath(d.getParent()),c=new CKEDITOR.dom.elementPath(i.getParent()),g=null,f=null,e=0;e<a.elements.length;e++){var h=a.elements[e];if(h==a.block||h==a.blockLimit)break;k.checkElementRemovable(h,
true)&&(g=h)}for(e=0;e<c.elements.length;e++){h=c.elements[e];if(h==c.block||h==c.blockLimit)break;k.checkElementRemovable(h,true)&&(f=h)}f&&i.breakParent(f);g&&d.breakParent(g)}a.enlarge(CKEDITOR.ENLARGE_INLINE,1);var c=a.createBookmark(),d=c.startNode;if(a.collapsed){for(var g=new CKEDITOR.dom.elementPath(d.getParent(),a.root),f,e=0,h;e<g.elements.length&&(h=g.elements[e]);e++){if(h==g.block||h==g.blockLimit)break;if(this.checkElementRemovable(h)){var j;if(a.collapsed&&(a.checkBoundaryOfElement(h,
CKEDITOR.END)||(j=a.checkBoundaryOfElement(h,CKEDITOR.START)))){f=h;f.match=j?"start":"end"}else{h.mergeSiblings();h.is(this.element)?p.call(this,h):o(h,w(this)[h.getName()])}}}if(f){h=d;for(e=0;;e++){j=g.elements[e];if(j.equals(f))break;else if(j.match)continue;else j=j.clone();j.append(h);h=j}h[f.match=="start"?"insertBefore":"insertAfter"](f)}}else{var i=c.endNode,k=this;b();for(g=d;!g.equals(i);){f=g.getNextSourceNode();if(g.type==CKEDITOR.NODE_ELEMENT&&this.checkElementRemovable(g)){g.getName()==
this.element?p.call(this,g):o(g,w(this)[g.getName()]);if(f.type==CKEDITOR.NODE_ELEMENT&&f.contains(d)){b();f=d.getNext()}}g=f}}a.moveToBookmark(c);a.shrink(CKEDITOR.NODE_ELEMENT,true)}function c(a){var b=[];a.forEach(function(a){if(a.getAttribute("contenteditable")=="true"){b.push(a);return false}},CKEDITOR.NODE_ELEMENT,true);return b}function f(a){var b=a.getEnclosedNode()||a.getCommonAncestor(false,true);(a=(new CKEDITOR.dom.elementPath(b,a.root)).contains(this.element,1))&&!a.isReadOnly()&&s(a,
this)}function k(a){var b=a.getCommonAncestor(true,true);if(a=(new CKEDITOR.dom.elementPath(b,a.root)).contains(this.element,1)){var b=this._.definition,c=b.attributes;if(c)for(var d in c)a.removeAttribute(d,c[d]);if(b.styles)for(var g in b.styles)b.styles.hasOwnProperty(g)&&a.removeStyle(g)}}function i(a){var b=a.createBookmark(true),c=a.createIterator();c.enforceRealBlocks=true;if(this._.enterMode)c.enlargeBr=this._.enterMode!=CKEDITOR.ENTER_BR;for(var d,g=a.document,f;d=c.getNextParagraph();)if(!d.isReadOnly()&&
(c.activeFilter?c.activeFilter.check(this):1)){f=l(this,g,d);j(d,f)}a.moveToBookmark(b)}function d(a){var b=a.createBookmark(1),c=a.createIterator();c.enforceRealBlocks=true;c.enlargeBr=this._.enterMode!=CKEDITOR.ENTER_BR;for(var d,g;d=c.getNextParagraph();)if(this.checkElementRemovable(d))if(d.is("pre")){(g=this._.enterMode==CKEDITOR.ENTER_BR?null:a.document.createElement(this._.enterMode==CKEDITOR.ENTER_P?"p":"div"))&&d.copyAttributes(g);j(d,g)}else p.call(this,d);a.moveToBookmark(b)}function j(a,
b){var c=!b;if(c){b=a.getDocument().createElement("div");a.copyAttributes(b)}var d=b&&b.is("pre"),f=a.is("pre"),e=!d&&f;if(d&&!f){f=b;(e=a.getBogus())&&e.remove();e=a.getHtml();e=g(e,/(?:^[ \t\n\r]+)|(?:[ \t\n\r]+$)/g,"");e=e.replace(/[ \t\r\n]*(<br[^>]*>)[ \t\r\n]*/gi,"$1");e=e.replace(/([ \t\n\r]+|&nbsp;)/g," ");e=e.replace(/<br\b[^>]*>/gi,"\n");if(CKEDITOR.env.ie){var j=a.getDocument().createElement("div");j.append(f);f.$.outerHTML="<pre>"+e+"</pre>";f.copyAttributes(j.getFirst());f=j.getFirst().remove()}else f.setHtml(e);
b=f}else e?b=m(c?[a.getHtml()]:h(a),b):a.moveChildren(b);b.replace(a);if(d){var c=b,i;if((i=c.getPrevious(A))&&i.type==CKEDITOR.NODE_ELEMENT&&i.is("pre")){d=g(i.getHtml(),/\n$/,"")+"\n\n"+g(c.getHtml(),/^\n/,"");CKEDITOR.env.ie?c.$.outerHTML="<pre>"+d+"</pre>":c.setHtml(d);i.remove()}}else c&&n(b)}function h(a){var b=[];g(a.getOuterHtml(),/(\S\s*)\n(?:\s|(<span[^>]+data-cke-bookmark.*?\/span>))*\n(?!$)/gi,function(a,b,c){return b+"</pre>"+c+"<pre>"}).replace(/<pre\b.*?>([\s\S]*?)<\/pre>/gi,function(a,
c){b.push(c)});return b}function g(a,b,c){var d="",g="",a=a.replace(/(^<span[^>]+data-cke-bookmark.*?\/span>)|(<span[^>]+data-cke-bookmark.*?\/span>$)/gi,function(a,b,c){b&&(d=b);c&&(g=c);return""});return d+a.replace(b,c)+g}function m(a,b){var c;a.length>1&&(c=new CKEDITOR.dom.documentFragment(b.getDocument()));for(var d=0;d<a.length;d++){var f=a[d],f=f.replace(/(\r\n|\r)/g,"\n"),f=g(f,/^[ \t]*\n/,""),f=g(f,/\n$/,""),f=g(f,/^[ \t]+|[ \t]+$/g,function(a,b){return a.length==1?"&nbsp;":b?" "+CKEDITOR.tools.repeat("&nbsp;",
a.length-1):CKEDITOR.tools.repeat("&nbsp;",a.length-1)+" "}),f=f.replace(/\n/g,"<br>"),f=f.replace(/[ \t]{2,}/g,function(a){return CKEDITOR.tools.repeat("&nbsp;",a.length-1)+" "});if(c){var e=b.clone();e.setHtml(f);c.append(e)}else b.setHtml(f)}return c||b}function p(a,b){var c=this._.definition,d=c.attributes,c=c.styles,g=w(this)[a.getName()],f=CKEDITOR.tools.isEmpty(d)&&CKEDITOR.tools.isEmpty(c),e;for(e in d)if(!((e=="class"||this._.definition.fullMatch)&&a.getAttribute(e)!=u(e,d[e]))&&!(b&&e.slice(0,
5)=="data-")){f=a.hasAttribute(e);a.removeAttribute(e)}for(var h in c)if(!(this._.definition.fullMatch&&a.getStyle(h)!=u(h,c[h],true))){f=f||!!a.getStyle(h);a.removeStyle(h)}o(a,g,v[a.getName()]);f&&(this._.definition.alwaysRemoveElement?n(a,1):!CKEDITOR.dtd.$block[a.getName()]||this._.enterMode==CKEDITOR.ENTER_BR&&!a.hasAttributes()?n(a):a.renameNode(this._.enterMode==CKEDITOR.ENTER_P?"p":"div"))}function r(a){for(var b=w(this),c=a.getElementsByTag(this.element),d,g=c.count();--g>=0;){d=c.getItem(g);
d.isReadOnly()||p.call(this,d,true)}for(var f in b)if(f!=this.element){c=a.getElementsByTag(f);for(g=c.count()-1;g>=0;g--){d=c.getItem(g);d.isReadOnly()||o(d,b[f])}}}function o(a,b,c){if(b=b&&b.attributes)for(var d=0;d<b.length;d++){var g=b[d][0],f;if(f=a.getAttribute(g)){var e=b[d][1];(e===null||e.test&&e.test(f)||typeof e=="string"&&f==e)&&a.removeAttribute(g)}}c||n(a)}function n(a,b){if(!a.hasAttributes()||b)if(CKEDITOR.dtd.$block[a.getName()]){var c=a.getPrevious(A),d=a.getNext(A);c&&(c.type==
CKEDITOR.NODE_TEXT||!c.isBlockBoundary({br:1}))&&a.append("br",1);d&&(d.type==CKEDITOR.NODE_TEXT||!d.isBlockBoundary({br:1}))&&a.append("br");a.remove(true)}else{c=a.getFirst();d=a.getLast();a.remove(true);if(c){c.type==CKEDITOR.NODE_ELEMENT&&c.mergeSiblings();d&&(!c.equals(d)&&d.type==CKEDITOR.NODE_ELEMENT)&&d.mergeSiblings()}}}function l(a,b,c){var d;d=a.element;d=="*"&&(d="span");d=new CKEDITOR.dom.element(d,b);c&&c.copyAttributes(d);d=s(d,a);b.getCustomData("doc_processing_style")&&d.hasAttribute("id")?
d.removeAttribute("id"):b.setCustomData("doc_processing_style",1);return d}function s(a,b){var c=b._.definition,d=c.attributes,c=CKEDITOR.style.getStyleText(c);if(d)for(var g in d)a.setAttribute(g,d[g]);c&&a.setAttribute("style",c);return a}function t(a,b){for(var c in a)a[c]=a[c].replace(z,function(a,c){return b[c]})}function w(a){if(a._.overrides)return a._.overrides;var b=a._.overrides={},c=a._.definition.overrides;if(c){CKEDITOR.tools.isArray(c)||(c=[c]);for(var d=0;d<c.length;d++){var g=c[d],
f,e;if(typeof g=="string")f=g.toLowerCase();else{f=g.element?g.element.toLowerCase():a.element;e=g.attributes}g=b[f]||(b[f]={});if(e){var g=g.attributes=g.attributes||[],h;for(h in e)g.push([h.toLowerCase(),e[h]])}}}return b}function u(a,b,c){var d=new CKEDITOR.dom.element("span");d[c?"setStyle":"setAttribute"](a,b);return d[c?"getStyle":"getAttribute"](a)}function x(a,b,c){for(var d=a.document,g=a.getRanges(),b=b?this.removeFromRange:this.applyToRange,f,e=g.createIterator();f=e.getNextRange();)b.call(this,
f,c);a.selectRanges(g);d.removeCustomData("doc_processing_style")}var v={address:1,div:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,p:1,pre:1,section:1,header:1,footer:1,nav:1,article:1,aside:1,figure:1,dialog:1,hgroup:1,time:1,meter:1,menu:1,command:1,keygen:1,output:1,progress:1,details:1,datagrid:1,datalist:1},q={a:1,blockquote:1,embed:1,hr:1,img:1,li:1,object:1,ol:1,table:1,td:1,tr:1,th:1,ul:1,dl:1,dt:1,dd:1,form:1,audio:1,video:1},y=/\s*(?:;\s*|$)/,z=/#\((.+?)\)/g,B=CKEDITOR.dom.walker.bookmark(0,1),A=CKEDITOR.dom.walker.whitespaces(1);
CKEDITOR.style=function(a,b){if(typeof a.type=="string")return new CKEDITOR.style.customHandlers[a.type](a);var c=a.attributes;if(c&&c.style){a.styles=CKEDITOR.tools.extend({},a.styles,CKEDITOR.tools.parseCssText(c.style));delete c.style}if(b){a=CKEDITOR.tools.clone(a);t(a.attributes,b);t(a.styles,b)}c=this.element=a.element?typeof a.element=="string"?a.element.toLowerCase():a.element:"*";this.type=a.type||(v[c]?CKEDITOR.STYLE_BLOCK:q[c]?CKEDITOR.STYLE_OBJECT:CKEDITOR.STYLE_INLINE);if(typeof this.element==
"object")this.type=CKEDITOR.STYLE_OBJECT;this._={definition:a}};CKEDITOR.style.prototype={apply:function(a){if(a instanceof CKEDITOR.dom.document)return x.call(this,a.getSelection());if(this.checkApplicable(a.elementPath(),a)){var b=this._.enterMode;if(!b)this._.enterMode=a.activeEnterMode;x.call(this,a.getSelection(),0,a);this._.enterMode=b}},remove:function(a){if(a instanceof CKEDITOR.dom.document)return x.call(this,a.getSelection(),1);if(this.checkApplicable(a.elementPath(),a)){var b=this._.enterMode;
if(!b)this._.enterMode=a.activeEnterMode;x.call(this,a.getSelection(),1,a);this._.enterMode=b}},applyToRange:function(a){this.applyToRange=this.type==CKEDITOR.STYLE_INLINE?e:this.type==CKEDITOR.STYLE_BLOCK?i:this.type==CKEDITOR.STYLE_OBJECT?f:null;return this.applyToRange(a)},removeFromRange:function(a){this.removeFromRange=this.type==CKEDITOR.STYLE_INLINE?b:this.type==CKEDITOR.STYLE_BLOCK?d:this.type==CKEDITOR.STYLE_OBJECT?k:null;return this.removeFromRange(a)},applyToObject:function(a){s(a,this)},
checkActive:function(a,b){switch(this.type){case CKEDITOR.STYLE_BLOCK:return this.checkElementRemovable(a.block||a.blockLimit,true,b);case CKEDITOR.STYLE_OBJECT:case CKEDITOR.STYLE_INLINE:for(var c=a.elements,d=0,g;d<c.length;d++){g=c[d];if(!(this.type==CKEDITOR.STYLE_INLINE&&(g==a.block||g==a.blockLimit))){if(this.type==CKEDITOR.STYLE_OBJECT){var f=g.getName();if(!(typeof this.element=="string"?f==this.element:f in this.element))continue}if(this.checkElementRemovable(g,true,b))return true}}}return false},
checkApplicable:function(a,b,c){b&&b instanceof CKEDITOR.filter&&(c=b);if(c&&!c.check(this))return false;switch(this.type){case CKEDITOR.STYLE_OBJECT:return!!a.contains(this.element);case CKEDITOR.STYLE_BLOCK:return!!a.blockLimit.getDtd()[this.element]}return true},checkElementMatch:function(a,b){var c=this._.definition;if(!a||!c.ignoreReadonly&&a.isReadOnly())return false;var d=a.getName();if(typeof this.element=="string"?d==this.element:d in this.element){if(!b&&!a.hasAttributes())return true;if(d=
c._AC)c=d;else{var d={},g=0,f=c.attributes;if(f)for(var e in f){g++;d[e]=f[e]}if(e=CKEDITOR.style.getStyleText(c)){d.style||g++;d.style=e}d._length=g;c=c._AC=d}if(c._length){for(var h in c)if(h!="_length"){g=a.getAttribute(h)||"";if(h=="style")a:{d=c[h];typeof d=="string"&&(d=CKEDITOR.tools.parseCssText(d));typeof g=="string"&&(g=CKEDITOR.tools.parseCssText(g,true));e=void 0;for(e in d)if(!(e in g&&(g[e]==d[e]||d[e]=="inherit"||g[e]=="inherit"))){d=false;break a}d=true}else d=c[h]==g;if(d){if(!b)return true}else if(b)return false}if(b)return true}else return true}return false},
checkElementRemovable:function(a,b,c){if(this.checkElementMatch(a,b,c))return true;if(b=w(this)[a.getName()]){var d;if(!(b=b.attributes))return true;for(c=0;c<b.length;c++){d=b[c][0];if(d=a.getAttribute(d)){var g=b[c][1];if(g===null)return true;if(typeof g=="string"){if(d==g)return true}else if(g.test(d))return true}}}return false},buildPreview:function(a){var b=this._.definition,c=[],d=b.element;d=="bdo"&&(d="span");var c=["<",d],g=b.attributes;if(g)for(var f in g)c.push(" ",f,'="',g[f],'"');(g=
CKEDITOR.style.getStyleText(b))&&c.push(' style="',g,'"');c.push(">",a||b.name,"</",d,">");return c.join("")},getDefinition:function(){return this._.definition}};CKEDITOR.style.getStyleText=function(a){var b=a._ST;if(b)return b;var b=a.styles,c=a.attributes&&a.attributes.style||"",d="";c.length&&(c=c.replace(y,";"));for(var g in b){var f=b[g],e=(g+":"+f).replace(y,";");f=="inherit"?d=d+e:c=c+e}c.length&&(c=CKEDITOR.tools.normalizeCssText(c,true));return a._ST=c+d};CKEDITOR.style.customHandlers={};
CKEDITOR.style.addCustomHandler=function(a){var b=function(a){this._={definition:a};this.setup&&this.setup(a)};b.prototype=CKEDITOR.tools.extend(CKEDITOR.tools.prototypedCopy(CKEDITOR.style.prototype),{assignedTo:CKEDITOR.STYLE_OBJECT},a,true);return this.customHandlers[a.type]=b};var D=CKEDITOR.POSITION_PRECEDING|CKEDITOR.POSITION_IDENTICAL|CKEDITOR.POSITION_IS_CONTAINED,C=CKEDITOR.POSITION_FOLLOWING|CKEDITOR.POSITION_IDENTICAL|CKEDITOR.POSITION_IS_CONTAINED}(),CKEDITOR.styleCommand=function(a,e){this.requiredContent=
this.allowedContent=this.style=a;CKEDITOR.tools.extend(this,e,true)},CKEDITOR.styleCommand.prototype.exec=function(a){a.focus();this.state==CKEDITOR.TRISTATE_OFF?a.applyStyle(this.style):this.state==CKEDITOR.TRISTATE_ON&&a.removeStyle(this.style)},CKEDITOR.stylesSet=new CKEDITOR.resourceManager("","stylesSet"),CKEDITOR.addStylesSet=CKEDITOR.tools.bind(CKEDITOR.stylesSet.add,CKEDITOR.stylesSet),CKEDITOR.loadStylesSet=function(a,e,b){CKEDITOR.stylesSet.addExternal(a,e,"");CKEDITOR.stylesSet.load(a,
b)},CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{attachStyleStateChange:function(a,e){var b=this._.styleStateChangeCallbacks;if(!b){b=this._.styleStateChangeCallbacks=[];this.on("selectionChange",function(a){for(var f=0;f<b.length;f++){var e=b[f],i=e.style.checkActive(a.data.path,this)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF;e.fn.call(this,i)}})}b.push({style:a,fn:e})},applyStyle:function(a){a.apply(this)},removeStyle:function(a){a.remove(this)},getStylesSet:function(a){if(this._.stylesDefinitions)a(this._.stylesDefinitions);
else{var e=this,b=e.config.stylesCombo_stylesSet||e.config.stylesSet;if(b===false)a(null);else if(b instanceof Array){e._.stylesDefinitions=b;a(b)}else{b||(b="default");var b=b.split(":"),c=b[0];CKEDITOR.stylesSet.addExternal(c,b[1]?b.slice(1).join(":"):CKEDITOR.getUrl("styles.js"),"");CKEDITOR.stylesSet.load(c,function(b){e._.stylesDefinitions=b[c];a(e._.stylesDefinitions)})}}}}),CKEDITOR.dom.comment=function(a,e){typeof a=="string"&&(a=(e?e.$:document).createComment(a));CKEDITOR.dom.domObject.call(this,
a)},CKEDITOR.dom.comment.prototype=new CKEDITOR.dom.node,CKEDITOR.tools.extend(CKEDITOR.dom.comment.prototype,{type:CKEDITOR.NODE_COMMENT,getOuterHtml:function(){return"<\!--"+this.$.nodeValue+"--\>"}}),"use strict",function(){var a={},e={},b;for(b in CKEDITOR.dtd.$blockLimit)b in CKEDITOR.dtd.$list||(a[b]=1);for(b in CKEDITOR.dtd.$block)b in CKEDITOR.dtd.$blockLimit||b in CKEDITOR.dtd.$empty||(e[b]=1);CKEDITOR.dom.elementPath=function(b,f){var k=null,i=null,d=[],j=b,h,f=f||b.getDocument().getBody();
do if(j.type==CKEDITOR.NODE_ELEMENT){d.push(j);if(!this.lastElement){this.lastElement=j;if(j.is(CKEDITOR.dtd.$object)||j.getAttribute("contenteditable")=="false")continue}if(j.equals(f))break;if(!i){h=j.getName();j.getAttribute("contenteditable")=="true"?i=j:!k&&e[h]&&(k=j);if(a[h]){var g;if(g=!k){if(h=h=="div"){a:{h=j.getChildren();g=0;for(var m=h.count();g<m;g++){var p=h.getItem(g);if(p.type==CKEDITOR.NODE_ELEMENT&&CKEDITOR.dtd.$block[p.getName()]){h=true;break a}}h=false}h=!h}g=h}g?k=j:i=j}}}while(j=
j.getParent());i||(i=f);this.block=k;this.blockLimit=i;this.root=f;this.elements=d}}(),CKEDITOR.dom.elementPath.prototype={compare:function(a){var e=this.elements,a=a&&a.elements;if(!a||e.length!=a.length)return false;for(var b=0;b<e.length;b++)if(!e[b].equals(a[b]))return false;return true},contains:function(a,e,b){var c;typeof a=="string"&&(c=function(b){return b.getName()==a});a instanceof CKEDITOR.dom.element?c=function(b){return b.equals(a)}:CKEDITOR.tools.isArray(a)?c=function(b){return CKEDITOR.tools.indexOf(a,
b.getName())>-1}:typeof a=="function"?c=a:typeof a=="object"&&(c=function(b){return b.getName()in a});var f=this.elements,k=f.length;e&&k--;if(b){f=Array.prototype.slice.call(f,0);f.reverse()}for(e=0;e<k;e++)if(c(f[e]))return f[e];return null},isContextFor:function(a){var e;if(a in CKEDITOR.dtd.$block){e=this.contains(CKEDITOR.dtd.$intermediate)||this.root.equals(this.block)&&this.block||this.blockLimit;return!!e.getDtd()[a]}return true},direction:function(){return(this.block||this.blockLimit||this.root).getDirection(1)}},
CKEDITOR.dom.text=function(a,e){typeof a=="string"&&(a=(e?e.$:document).createTextNode(a));this.$=a},CKEDITOR.dom.text.prototype=new CKEDITOR.dom.node,CKEDITOR.tools.extend(CKEDITOR.dom.text.prototype,{type:CKEDITOR.NODE_TEXT,getLength:function(){return this.$.nodeValue.length},getText:function(){return this.$.nodeValue},setText:function(a){this.$.nodeValue=a},split:function(a){var e=this.$.parentNode,b=e.childNodes.length,c=this.getLength(),f=this.getDocument(),k=new CKEDITOR.dom.text(this.$.splitText(a),
f);if(e.childNodes.length==b)if(a>=c){k=f.createText("");k.insertAfter(this)}else{a=f.createText("");a.insertAfter(k);a.remove()}return k},substring:function(a,e){return typeof e!="number"?this.$.nodeValue.substr(a):this.$.nodeValue.substring(a,e)}}),function(){function a(a,c,f){var e=a.serializable,i=c[f?"endContainer":"startContainer"],d=f?"endOffset":"startOffset",j=e?c.document.getById(a.startNode):a.startNode,a=e?c.document.getById(a.endNode):a.endNode;if(i.equals(j.getPrevious())){c.startOffset=
c.startOffset-i.getLength()-a.getPrevious().getLength();i=a.getNext()}else if(i.equals(a.getPrevious())){c.startOffset=c.startOffset-i.getLength();i=a.getNext()}i.equals(j.getParent())&&c[d]++;i.equals(a.getParent())&&c[d]++;c[f?"endContainer":"startContainer"]=i;return c}CKEDITOR.dom.rangeList=function(a){if(a instanceof CKEDITOR.dom.rangeList)return a;a?a instanceof CKEDITOR.dom.range&&(a=[a]):a=[];return CKEDITOR.tools.extend(a,e)};var e={createIterator:function(){var a=this,c=CKEDITOR.dom.walker.bookmark(),
f=[],e;return{getNextRange:function(i){e=e===void 0?0:e+1;var d=a[e];if(d&&a.length>1){if(!e)for(var j=a.length-1;j>=0;j--)f.unshift(a[j].createBookmark(true));if(i)for(var h=0;a[e+h+1];){for(var g=d.document,i=0,j=g.getById(f[h].endNode),g=g.getById(f[h+1].startNode);;){j=j.getNextSourceNode(false);if(g.equals(j))i=1;else if(c(j)||j.type==CKEDITOR.NODE_ELEMENT&&j.isBlockBoundary())continue;break}if(!i)break;h++}for(d.moveToBookmark(f.shift());h--;){j=a[++e];j.moveToBookmark(f.shift());d.setEnd(j.endContainer,
j.endOffset)}}return d}}},createBookmarks:function(b){for(var c=[],f,e=0;e<this.length;e++){c.push(f=this[e].createBookmark(b,true));for(var i=e+1;i<this.length;i++){this[i]=a(f,this[i]);this[i]=a(f,this[i],true)}}return c},createBookmarks2:function(a){for(var c=[],f=0;f<this.length;f++)c.push(this[f].createBookmark2(a));return c},moveToBookmarks:function(a){for(var c=0;c<this.length;c++)this[c].moveToBookmark(a[c])}}}(),function(){function a(){return CKEDITOR.getUrl(CKEDITOR.skinName.split(",")[1]||
"skins/"+CKEDITOR.skinName.split(",")[0]+"/")}function e(b){var c=CKEDITOR.skin["ua_"+b],d=CKEDITOR.env;if(c)for(var c=c.split(",").sort(function(a,b){return a>b?-1:1}),f=0,e;f<c.length;f++){e=c[f];if(d.ie&&(e.replace(/^ie/,"")==d.version||d.quirks&&e=="iequirks"))e="ie";if(d[e]){b=b+("_"+c[f]);break}}return CKEDITOR.getUrl(a()+b+".css")}function b(a,b){if(!k[a]){CKEDITOR.document.appendStyleSheet(e(a));k[a]=1}b&&b()}function c(a){var b=a.getById(i);if(!b){b=a.getHead().append("style");b.setAttribute("id",
i);b.setAttribute("type","text/css")}return b}function f(a,b,c){var d,f,e;if(CKEDITOR.env.webkit){b=b.split("}").slice(0,-1);for(f=0;f<b.length;f++)b[f]=b[f].split("{")}for(var j=0;j<a.length;j++)if(CKEDITOR.env.webkit)for(f=0;f<b.length;f++){e=b[f][1];for(d=0;d<c.length;d++)e=e.replace(c[d][0],c[d][1]);a[j].$.sheet.addRule(b[f][0],e)}else{e=b;for(d=0;d<c.length;d++)e=e.replace(c[d][0],c[d][1]);CKEDITOR.env.ie&&CKEDITOR.env.version<11?a[j].$.styleSheet.cssText=a[j].$.styleSheet.cssText+e:a[j].$.innerHTML=
a[j].$.innerHTML+e}}var k={};CKEDITOR.skin={path:a,loadPart:function(c,d){CKEDITOR.skin.name!=CKEDITOR.skinName.split(",")[0]?CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(a()+"skin.js"),function(){b(c,d)}):b(c,d)},getPath:function(a){return CKEDITOR.getUrl(e(a))},icons:{},addIcon:function(a,b,c,d){a=a.toLowerCase();this.icons[a]||(this.icons[a]={path:b,offset:c||0,bgsize:d||"16px"})},getIconStyle:function(a,b,c,d,f){var e;if(a){a=a.toLowerCase();b&&(e=this.icons[a+"-rtl"]);e||(e=this.icons[a])}a=c||
e&&e.path||"";d=d||e&&e.offset;f=f||e&&e.bgsize||"16px";return a&&"background-image:url("+CKEDITOR.getUrl(a)+");background-position:0 "+d+"px;background-size:"+f+";"}};CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{getUiColor:function(){return this.uiColor},setUiColor:function(a){var b=c(CKEDITOR.document);return(this.setUiColor=function(a){this.uiColor=a;var c=CKEDITOR.skin.chameleon,e="",h="";if(typeof c=="function"){e=c(this,"editor");h=c(this,"panel")}a=[[j,a]];f([b],e,a);f(d,h,a)}).call(this,
a)}});var i="cke_ui_color",d=[],j=/\$color/g;CKEDITOR.on("instanceLoaded",function(a){if(!CKEDITOR.env.ie||!CKEDITOR.env.quirks){var b=a.editor,a=function(a){a=(a.data[0]||a.data).element.getElementsByTag("iframe").getItem(0).getFrameDocument();if(!a.getById("cke_ui_color")){a=c(a);d.push(a);var e=b.getUiColor();e&&f([a],CKEDITOR.skin.chameleon(b,"panel"),[[j,e]])}};b.on("panelShow",a);b.on("menuShow",a);b.config.uiColor&&b.setUiColor(b.config.uiColor)}})}(),function(){if(CKEDITOR.env.webkit)CKEDITOR.env.hc=
false;else{var a=CKEDITOR.dom.element.createFromHtml('<div style="width:0;height:0;position:absolute;left:-10000px;border:1px solid;border-color:red blue"></div>',CKEDITOR.document);a.appendTo(CKEDITOR.document.getHead());try{var e=a.getComputedStyle("border-top-color"),b=a.getComputedStyle("border-right-color");CKEDITOR.env.hc=!!(e&&e==b)}catch(c){CKEDITOR.env.hc=false}a.remove()}if(CKEDITOR.env.hc)CKEDITOR.env.cssClass=CKEDITOR.env.cssClass+" cke_hc";CKEDITOR.document.appendStyleText(".cke{visibility:hidden;}");
CKEDITOR.status="loaded";CKEDITOR.fireOnce("loaded");if(a=CKEDITOR._.pending){delete CKEDITOR._.pending;for(e=0;e<a.length;e++){CKEDITOR.editor.prototype.constructor.apply(a[e][0],a[e][1]);CKEDITOR.add(a[e][0])}}}(),CKEDITOR.skin.name="moono",CKEDITOR.skin.ua_editor="ie,iequirks,ie7,ie8,gecko",CKEDITOR.skin.ua_dialog="ie,iequirks,ie7,ie8",CKEDITOR.skin.chameleon=function(){var a=function(){return function(a,b){for(var e=a.match(/[^#]./g),i=0;i<3;i++){var d=e,j=i,h;h=parseInt(e[i],16);h=("0"+(b<0?
0|h*(1+b):0|h+(255-h)*b).toString(16)).slice(-2);d[j]=h}return"#"+e.join("")}}(),e=function(){var a=new CKEDITOR.template("background:#{to};background-image:linear-gradient(to bottom,{from},{to});filter:progid:DXImageTransform.Microsoft.gradient(gradientType=0,startColorstr='{from}',endColorstr='{to}');");return function(b,e){return a.output({from:b,to:e})}}(),b={editor:new CKEDITOR.template("{id}.cke_chrome [border-color:{defaultBorder};] {id} .cke_top [ {defaultGradient}border-bottom-color:{defaultBorder};] {id} .cke_bottom [{defaultGradient}border-top-color:{defaultBorder};] {id} .cke_resizer [border-right-color:{ckeResizer}] {id} .cke_dialog_title [{defaultGradient}border-bottom-color:{defaultBorder};] {id} .cke_dialog_footer [{defaultGradient}outline-color:{defaultBorder};border-top-color:{defaultBorder};] {id} .cke_dialog_tab [{lightGradient}border-color:{defaultBorder};] {id} .cke_dialog_tab:hover [{mediumGradient}] {id} .cke_dialog_contents [border-top-color:{defaultBorder};] {id} .cke_dialog_tab_selected, {id} .cke_dialog_tab_selected:hover [background:{dialogTabSelected};border-bottom-color:{dialogTabSelectedBorder};] {id} .cke_dialog_body [background:{dialogBody};border-color:{defaultBorder};] {id} .cke_toolgroup [{lightGradient}border-color:{defaultBorder};] {id} a.cke_button_off:hover, {id} a.cke_button_off:focus, {id} a.cke_button_off:active [{mediumGradient}] {id} .cke_button_on [{ckeButtonOn}] {id} .cke_toolbar_separator [background-color: {ckeToolbarSeparator};] {id} .cke_combo_button [border-color:{defaultBorder};{lightGradient}] {id} a.cke_combo_button:hover, {id} a.cke_combo_button:focus, {id} .cke_combo_on a.cke_combo_button [border-color:{defaultBorder};{mediumGradient}] {id} .cke_path_item [color:{elementsPathColor};] {id} a.cke_path_item:hover, {id} a.cke_path_item:focus, {id} a.cke_path_item:active [background-color:{elementsPathBg};] {id}.cke_panel [border-color:{defaultBorder};] "),
panel:new CKEDITOR.template(".cke_panel_grouptitle [{lightGradient}border-color:{defaultBorder};] .cke_menubutton_icon [background-color:{menubuttonIcon};] .cke_menubutton:hover .cke_menubutton_icon, .cke_menubutton:focus .cke_menubutton_icon, .cke_menubutton:active .cke_menubutton_icon [background-color:{menubuttonIconHover};] .cke_menuseparator [background-color:{menubuttonIcon};] a:hover.cke_colorbox, a:focus.cke_colorbox, a:active.cke_colorbox [border-color:{defaultBorder};] a:hover.cke_colorauto, a:hover.cke_colormore, a:focus.cke_colorauto, a:focus.cke_colormore, a:active.cke_colorauto, a:active.cke_colormore [background-color:{ckeColorauto};border-color:{defaultBorder};] ")};
return function(c,f){var k=c.uiColor,k={id:"."+c.id,defaultBorder:a(k,-0.1),defaultGradient:e(a(k,0.9),k),lightGradient:e(a(k,1),a(k,0.7)),mediumGradient:e(a(k,0.8),a(k,0.5)),ckeButtonOn:e(a(k,0.6),a(k,0.7)),ckeResizer:a(k,-0.4),ckeToolbarSeparator:a(k,0.5),ckeColorauto:a(k,0.8),dialogBody:a(k,0.7),dialogTabSelected:e("#FFFFFF","#FFFFFF"),dialogTabSelectedBorder:"#FFF",elementsPathColor:a(k,-0.6),elementsPathBg:k,menubuttonIcon:a(k,0.5),menubuttonIconHover:a(k,0.3)};return b[f].output(k).replace(/\[/g,
"{").replace(/\]/g,"}")}}(),CKEDITOR.plugins.add("dialogui",{onLoad:function(){var a=function(a){this._||(this._={});this._["default"]=this._.initValue=a["default"]||"";this._.required=a.required||false;for(var b=[this._],c=1;c<arguments.length;c++)b.push(arguments[c]);b.push(true);CKEDITOR.tools.extend.apply(CKEDITOR.tools,b);return this._},e={build:function(a,b,c){return new CKEDITOR.ui.dialog.textInput(a,b,c)}},b={build:function(a,b,c){return new CKEDITOR.ui.dialog[b.type](a,b,c)}},c={isChanged:function(){return this.getValue()!=
this.getInitValue()},reset:function(a){this.setValue(this.getInitValue(),a)},setInitValue:function(){this._.initValue=this.getValue()},resetInitValue:function(){this._.initValue=this._["default"]},getInitValue:function(){return this._.initValue}},f=CKEDITOR.tools.extend({},CKEDITOR.ui.dialog.uiElement.prototype.eventProcessors,{onChange:function(a,b){if(!this._.domOnChangeRegistered){a.on("load",function(){this.getInputElement().on("change",function(){a.parts.dialog.isVisible()&&this.fire("change",
{value:this.getValue()})},this)},this);this._.domOnChangeRegistered=true}this.on("change",b)}},true),k=/^on([A-Z]\w+)/,i=function(a){for(var b in a)(k.test(b)||b=="title"||b=="type")&&delete a[b];return a},d=function(a){a=a.data.getKeystroke();a==CKEDITOR.SHIFT+CKEDITOR.ALT+36?this.setDirectionMarker("ltr"):a==CKEDITOR.SHIFT+CKEDITOR.ALT+35&&this.setDirectionMarker("rtl")};CKEDITOR.tools.extend(CKEDITOR.ui.dialog,{labeledElement:function(b,c,d,f){if(!(arguments.length<4)){var e=a.call(this,c);e.labelId=
CKEDITOR.tools.getNextId()+"_label";this._.children=[];var i={role:c.role||"presentation"};if(c.includeLabel)i["aria-labelledby"]=e.labelId;CKEDITOR.ui.dialog.uiElement.call(this,b,c,d,"div",null,i,function(){var a=[],d=c.required?" cke_required":"";if(c.labelLayout!="horizontal")a.push('<label class="cke_dialog_ui_labeled_label'+d+'" ',' id="'+e.labelId+'"',e.inputId?' for="'+e.inputId+'"':"",(c.labelStyle?' style="'+c.labelStyle+'"':"")+">",c.label,"</label>",'<div class="cke_dialog_ui_labeled_content"',
c.controlStyle?' style="'+c.controlStyle+'"':"",' role="presentation">',f.call(this,b,c),"</div>");else{d={type:"hbox",widths:c.widths,padding:0,children:[{type:"html",html:'<label class="cke_dialog_ui_labeled_label'+d+'" id="'+e.labelId+'" for="'+e.inputId+'"'+(c.labelStyle?' style="'+c.labelStyle+'"':"")+">"+CKEDITOR.tools.htmlEncode(c.label)+"</label>"},{type:"html",html:'<span class="cke_dialog_ui_labeled_content"'+(c.controlStyle?' style="'+c.controlStyle+'"':"")+">"+f.call(this,b,c)+"</span>"}]};
CKEDITOR.dialog._.uiElementBuilders.hbox.build(b,d,a)}return a.join("")})}},textInput:function(b,c,g){if(!(arguments.length<3)){a.call(this,c);var f=this._.inputId=CKEDITOR.tools.getNextId()+"_textInput",e={"class":"cke_dialog_ui_input_"+c.type,id:f,type:c.type};if(c.validate)this.validate=c.validate;if(c.maxLength)e.maxlength=c.maxLength;if(c.size)e.size=c.size;if(c.inputStyle)e.style=c.inputStyle;var i=this,k=false;b.on("load",function(){i.getInputElement().on("keydown",function(a){a.data.getKeystroke()==
13&&(k=true)});i.getInputElement().on("keyup",function(a){if(a.data.getKeystroke()==13&&k){b.getButton("ok")&&setTimeout(function(){b.getButton("ok").click()},0);k=false}i.bidi&&d.call(i,a)},null,null,1E3)});CKEDITOR.ui.dialog.labeledElement.call(this,b,c,g,function(){var a=['<div class="cke_dialog_ui_input_',c.type,'" role="presentation"'];c.width&&a.push('style="width:'+c.width+'" ');a.push("><input ");e["aria-labelledby"]=this._.labelId;this._.required&&(e["aria-required"]=this._.required);for(var b in e)a.push(b+
'="'+e[b]+'" ');a.push(" /></div>");return a.join("")})}},textarea:function(b,c,g){if(!(arguments.length<3)){a.call(this,c);var f=this,e=this._.inputId=CKEDITOR.tools.getNextId()+"_textarea",i={};if(c.validate)this.validate=c.validate;i.rows=c.rows||5;i.cols=c.cols||20;i["class"]="cke_dialog_ui_input_textarea "+(c["class"]||"");if(typeof c.inputStyle!="undefined")i.style=c.inputStyle;if(c.dir)i.dir=c.dir;if(f.bidi)b.on("load",function(){f.getInputElement().on("keyup",d)},f);CKEDITOR.ui.dialog.labeledElement.call(this,
b,c,g,function(){i["aria-labelledby"]=this._.labelId;this._.required&&(i["aria-required"]=this._.required);var a=['<div class="cke_dialog_ui_input_textarea" role="presentation"><textarea id="',e,'" '],b;for(b in i)a.push(b+'="'+CKEDITOR.tools.htmlEncode(i[b])+'" ');a.push(">",CKEDITOR.tools.htmlEncode(f._["default"]),"</textarea></div>");return a.join("")})}},checkbox:function(b,c,d){if(!(arguments.length<3)){var f=a.call(this,c,{"default":!!c["default"]});if(c.validate)this.validate=c.validate;CKEDITOR.ui.dialog.uiElement.call(this,
b,c,d,"span",null,null,function(){var a=CKEDITOR.tools.extend({},c,{id:c.id?c.id+"_checkbox":CKEDITOR.tools.getNextId()+"_checkbox"},true),d=[],g=CKEDITOR.tools.getNextId()+"_label",e={"class":"cke_dialog_ui_checkbox_input",type:"checkbox","aria-labelledby":g};i(a);if(c["default"])e.checked="checked";if(typeof a.inputStyle!="undefined")a.style=a.inputStyle;f.checkbox=new CKEDITOR.ui.dialog.uiElement(b,a,d,"input",null,e);d.push(' <label id="',g,'" for="',e.id,'"'+(c.labelStyle?' style="'+c.labelStyle+
'"':"")+">",CKEDITOR.tools.htmlEncode(c.label),"</label>");return d.join("")})}},radio:function(b,c,d){if(!(arguments.length<3)){a.call(this,c);if(!this._["default"])this._["default"]=this._.initValue=c.items[0][1];if(c.validate)this.validate=c.validate;var f=[],e=this;c.role="radiogroup";c.includeLabel=true;CKEDITOR.ui.dialog.labeledElement.call(this,b,c,d,function(){for(var a=[],d=[],g=(c.id?c.id:CKEDITOR.tools.getNextId())+"_radio",k=0;k<c.items.length;k++){var s=c.items[k],t=s[2]!==void 0?s[2]:
s[0],w=s[1]!==void 0?s[1]:s[0],u=CKEDITOR.tools.getNextId()+"_radio_input",x=u+"_label",u=CKEDITOR.tools.extend({},c,{id:u,title:null,type:null},true),t=CKEDITOR.tools.extend({},u,{title:t},true),v={type:"radio","class":"cke_dialog_ui_radio_input",name:g,value:w,"aria-labelledby":x},q=[];if(e._["default"]==w)v.checked="checked";i(u);i(t);if(typeof u.inputStyle!="undefined")u.style=u.inputStyle;u.keyboardFocusable=true;f.push(new CKEDITOR.ui.dialog.uiElement(b,u,q,"input",null,v));q.push(" ");new CKEDITOR.ui.dialog.uiElement(b,
t,q,"label",null,{id:x,"for":v.id},s[0]);a.push(q.join(""))}new CKEDITOR.ui.dialog.hbox(b,f,a,d);return d.join("")});this._.children=f}},button:function(b,c,d){if(arguments.length){typeof c=="function"&&(c=c(b.getParentEditor()));a.call(this,c,{disabled:c.disabled||false});CKEDITOR.event.implementOn(this);var f=this;b.on("load",function(){var a=this.getElement();(function(){a.on("click",function(a){f.click();a.data.preventDefault()});a.on("keydown",function(a){if(a.data.getKeystroke()in{32:1}){f.click();
a.data.preventDefault()}})})();a.unselectable()},this);var e=CKEDITOR.tools.extend({},c);delete e.style;var i=CKEDITOR.tools.getNextId()+"_label";CKEDITOR.ui.dialog.uiElement.call(this,b,e,d,"a",null,{style:c.style,href:"javascript:void(0)",title:c.label,hidefocus:"true","class":c["class"],role:"button","aria-labelledby":i},'<span id="'+i+'" class="cke_dialog_ui_button">'+CKEDITOR.tools.htmlEncode(c.label)+"</span>")}},select:function(b,c,d){if(!(arguments.length<3)){var f=a.call(this,c);if(c.validate)this.validate=
c.validate;f.inputId=CKEDITOR.tools.getNextId()+"_select";CKEDITOR.ui.dialog.labeledElement.call(this,b,c,d,function(){var a=CKEDITOR.tools.extend({},c,{id:c.id?c.id+"_select":CKEDITOR.tools.getNextId()+"_select"},true),d=[],g=[],e={id:f.inputId,"class":"cke_dialog_ui_input_select","aria-labelledby":this._.labelId};d.push('<div class="cke_dialog_ui_input_',c.type,'" role="presentation"');c.width&&d.push('style="width:'+c.width+'" ');d.push(">");if(c.size!==void 0)e.size=c.size;if(c.multiple!==void 0)e.multiple=
c.multiple;i(a);for(var k=0,s;k<c.items.length&&(s=c.items[k]);k++)g.push('<option value="',CKEDITOR.tools.htmlEncode(s[1]!==void 0?s[1]:s[0]).replace(/"/g,"&quot;"),'" /> ',CKEDITOR.tools.htmlEncode(s[0]));if(typeof a.inputStyle!="undefined")a.style=a.inputStyle;f.select=new CKEDITOR.ui.dialog.uiElement(b,a,d,"select",null,e,g.join(""));d.push("</div>");return d.join("")})}},file:function(b,c,d){if(!(arguments.length<3)){c["default"]===void 0&&(c["default"]="");var f=CKEDITOR.tools.extend(a.call(this,
c),{definition:c,buttons:[]});if(c.validate)this.validate=c.validate;b.on("load",function(){CKEDITOR.document.getById(f.frameId).getParent().addClass("cke_dialog_ui_input_file")});CKEDITOR.ui.dialog.labeledElement.call(this,b,c,d,function(){f.frameId=CKEDITOR.tools.getNextId()+"_fileInput";var a=['<iframe frameborder="0" allowtransparency="0" class="cke_dialog_ui_input_file" role="presentation" id="',f.frameId,'" title="',c.label,'" src="javascript:void('];a.push(CKEDITOR.env.ie?"(function(){"+encodeURIComponent("document.open();("+
CKEDITOR.tools.fixDomain+")();document.close();")+"})()":"0");a.push(')"></iframe>');return a.join("")})}},fileButton:function(b,c,d){var f=this;if(!(arguments.length<3)){a.call(this,c);if(c.validate)this.validate=c.validate;var e=CKEDITOR.tools.extend({},c),i=e.onClick;e.className=(e.className?e.className+" ":"")+"cke_dialog_ui_button";e.onClick=function(a){var d=c["for"];if(!i||i.call(this,a)!==false){b.getContentElement(d[0],d[1]).submit();this.disable()}};b.on("load",function(){b.getContentElement(c["for"][0],
c["for"][1])._.buttons.push(f)});CKEDITOR.ui.dialog.button.call(this,b,e,d)}},html:function(){var a=/^\s*<[\w:]+\s+([^>]*)?>/,b=/^(\s*<[\w:]+(?:\s+[^>]*)?)((?:.|\r|\n)+)$/,c=/\/$/;return function(d,f,e){if(!(arguments.length<3)){var i=[],k=f.html;k.charAt(0)!="<"&&(k="<span>"+k+"</span>");var l=f.focus;if(l){var s=this.focus;this.focus=function(){(typeof l=="function"?l:s).call(this);this.fire("focus")};if(f.isFocusable)this.isFocusable=this.isFocusable;this.keyboardFocusable=true}CKEDITOR.ui.dialog.uiElement.call(this,
d,f,i,"span",null,null,"");i=i.join("").match(a);k=k.match(b)||["","",""];if(c.test(k[1])){k[1]=k[1].slice(0,-1);k[2]="/"+k[2]}e.push([k[1]," ",i[1]||"",k[2]].join(""))}}}(),fieldset:function(a,b,c,d,f){var e=f.label;this._={children:b};CKEDITOR.ui.dialog.uiElement.call(this,a,f,d,"fieldset",null,null,function(){var a=[];e&&a.push("<legend"+(f.labelStyle?' style="'+f.labelStyle+'"':"")+">"+e+"</legend>");for(var b=0;b<c.length;b++)a.push(c[b]);return a.join("")})}},true);CKEDITOR.ui.dialog.html.prototype=
new CKEDITOR.ui.dialog.uiElement;CKEDITOR.ui.dialog.labeledElement.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{setLabel:function(a){var b=CKEDITOR.document.getById(this._.labelId);b.getChildCount()<1?(new CKEDITOR.dom.text(a,CKEDITOR.document)).appendTo(b):b.getChild(0).$.nodeValue=a;return this},getLabel:function(){var a=CKEDITOR.document.getById(this._.labelId);return!a||a.getChildCount()<1?"":a.getChild(0).getText()},eventProcessors:f},true);CKEDITOR.ui.dialog.button.prototype=
CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{click:function(){return!this._.disabled?this.fire("click",{dialog:this._.dialog}):false},enable:function(){this._.disabled=false;var a=this.getElement();a&&a.removeClass("cke_disabled")},disable:function(){this._.disabled=true;this.getElement().addClass("cke_disabled")},isVisible:function(){return this.getElement().getFirst().isVisible()},isEnabled:function(){return!this._.disabled},eventProcessors:CKEDITOR.tools.extend({},CKEDITOR.ui.dialog.uiElement.prototype.eventProcessors,
{onClick:function(a,b){this.on("click",function(){b.apply(this,arguments)})}},true),accessKeyUp:function(){this.click()},accessKeyDown:function(){this.focus()},keyboardFocusable:true},true);CKEDITOR.ui.dialog.textInput.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,{getInputElement:function(){return CKEDITOR.document.getById(this._.inputId)},focus:function(){var a=this.selectParentTab();setTimeout(function(){var b=a.getInputElement();b&&b.$.focus()},0)},select:function(){var a=
this.selectParentTab();setTimeout(function(){var b=a.getInputElement();if(b){b.$.focus();b.$.select()}},0)},accessKeyUp:function(){this.select()},setValue:function(a){if(this.bidi){var b=a&&a.charAt(0);(b=b=="‪"?"ltr":b=="‫"?"rtl":null)&&(a=a.slice(1));this.setDirectionMarker(b)}a||(a="");return CKEDITOR.ui.dialog.uiElement.prototype.setValue.apply(this,arguments)},getValue:function(){var a=CKEDITOR.ui.dialog.uiElement.prototype.getValue.call(this);if(this.bidi&&a){var b=this.getDirectionMarker();
b&&(a=(b=="ltr"?"‪":"‫")+a)}return a},setDirectionMarker:function(a){var b=this.getInputElement();a?b.setAttributes({dir:a,"data-cke-dir-marker":a}):this.getDirectionMarker()&&b.removeAttributes(["dir","data-cke-dir-marker"])},getDirectionMarker:function(){return this.getInputElement().data("cke-dir-marker")},keyboardFocusable:true},c,true);CKEDITOR.ui.dialog.textarea.prototype=new CKEDITOR.ui.dialog.textInput;CKEDITOR.ui.dialog.select.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,
{getInputElement:function(){return this._.select.getElement()},add:function(a,b,c){var d=new CKEDITOR.dom.element("option",this.getDialog().getParentEditor().document),f=this.getInputElement().$;d.$.text=a;d.$.value=b===void 0||b===null?a:b;c===void 0||c===null?CKEDITOR.env.ie?f.add(d.$):f.add(d.$,null):f.add(d.$,c);return this},remove:function(a){this.getInputElement().$.remove(a);return this},clear:function(){for(var a=this.getInputElement().$;a.length>0;)a.remove(0);return this},keyboardFocusable:true},
c,true);CKEDITOR.ui.dialog.checkbox.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{getInputElement:function(){return this._.checkbox.getElement()},setValue:function(a,b){this.getInputElement().$.checked=a;!b&&this.fire("change",{value:a})},getValue:function(){return this.getInputElement().$.checked},accessKeyUp:function(){this.setValue(!this.getValue())},eventProcessors:{onChange:function(a,b){if(!CKEDITOR.env.ie||CKEDITOR.env.version>8)return f.onChange.apply(this,arguments);a.on("load",
function(){var a=this._.checkbox.getElement();a.on("propertychange",function(b){b=b.data.$;b.propertyName=="checked"&&this.fire("change",{value:a.$.checked})},this)},this);this.on("change",b);return null}},keyboardFocusable:true},c,true);CKEDITOR.ui.dialog.radio.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,{setValue:function(a,b){for(var c=this._.children,d,f=0;f<c.length&&(d=c[f]);f++)d.getElement().$.checked=d.getValue()==a;!b&&this.fire("change",{value:a})},getValue:function(){for(var a=
this._.children,b=0;b<a.length;b++)if(a[b].getElement().$.checked)return a[b].getValue();return null},accessKeyUp:function(){var a=this._.children,b;for(b=0;b<a.length;b++)if(a[b].getElement().$.checked){a[b].getElement().focus();return}a[0].getElement().focus()},eventProcessors:{onChange:function(a,b){if(CKEDITOR.env.ie){a.on("load",function(){for(var a=this._.children,b=this,c=0;c<a.length;c++)a[c].getElement().on("propertychange",function(a){a=a.data.$;a.propertyName=="checked"&&this.$.checked&&
b.fire("change",{value:this.getAttribute("value")})})},this);this.on("change",b)}else return f.onChange.apply(this,arguments);return null}}},c,true);CKEDITOR.ui.dialog.file.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.labeledElement,c,{getInputElement:function(){var a=CKEDITOR.document.getById(this._.frameId).getFrameDocument();return a.$.forms.length>0?new CKEDITOR.dom.element(a.$.forms[0].elements[0]):this.getElement()},submit:function(){this.getInputElement().getParent().$.submit();return this},
getAction:function(){return this.getInputElement().getParent().$.action},registerEvents:function(a){var b=/^on([A-Z]\w+)/,c,d=function(a,b,c,d){a.on("formLoaded",function(){a.getInputElement().on(c,d,a)})},f;for(f in a)if(c=f.match(b))this.eventProcessors[f]?this.eventProcessors[f].call(this,this._.dialog,a[f]):d(this,this._.dialog,c[1].toLowerCase(),a[f]);return this},reset:function(){function a(){c.$.open();var j="";d.size&&(j=d.size-(CKEDITOR.env.ie?7:0));var t=b.frameId+"_input";c.$.write(['<html dir="'+
k+'" lang="'+l+'"><head><title></title></head><body style="margin: 0; overflow: hidden; background: transparent;">','<form enctype="multipart/form-data" method="POST" dir="'+k+'" lang="'+l+'" action="',CKEDITOR.tools.htmlEncode(d.action),'"><label id="',b.labelId,'" for="',t,'" style="display:none">',CKEDITOR.tools.htmlEncode(d.label),'</label><input style="width:100%" id="',t,'" aria-labelledby="',b.labelId,'" type="file" name="',CKEDITOR.tools.htmlEncode(d.id||"cke_upload"),'" size="',CKEDITOR.tools.htmlEncode(j>
0?j:""),'" /></form></body></html><script>',CKEDITOR.env.ie?"("+CKEDITOR.tools.fixDomain+")();":"","window.parent.CKEDITOR.tools.callFunction("+e+");","window.onbeforeunload = function() {window.parent.CKEDITOR.tools.callFunction("+i+")}","<\/script>"].join(""));c.$.close();for(j=0;j<f.length;j++)f[j].enable()}var b=this._,c=CKEDITOR.document.getById(b.frameId).getFrameDocument(),d=b.definition,f=b.buttons,e=this.formLoadedNumber,i=this.formUnloadNumber,k=b.dialog._.editor.lang.dir,l=b.dialog._.editor.langCode;
if(!e){e=this.formLoadedNumber=CKEDITOR.tools.addFunction(function(){this.fire("formLoaded")},this);i=this.formUnloadNumber=CKEDITOR.tools.addFunction(function(){this.getInputElement().clearCustomData()},this);this.getDialog()._.editor.on("destroy",function(){CKEDITOR.tools.removeFunction(e);CKEDITOR.tools.removeFunction(i)})}CKEDITOR.env.gecko?setTimeout(a,500):a()},getValue:function(){return this.getInputElement().$.value||""},setInitValue:function(){this._.initValue=""},eventProcessors:{onChange:function(a,
b){if(!this._.domOnChangeRegistered){this.on("formLoaded",function(){this.getInputElement().on("change",function(){this.fire("change",{value:this.getValue()})},this)},this);this._.domOnChangeRegistered=true}this.on("change",b)}},keyboardFocusable:true},true);CKEDITOR.ui.dialog.fileButton.prototype=new CKEDITOR.ui.dialog.button;CKEDITOR.ui.dialog.fieldset.prototype=CKEDITOR.tools.clone(CKEDITOR.ui.dialog.hbox.prototype);CKEDITOR.dialog.addUIElement("text",e);CKEDITOR.dialog.addUIElement("password",
e);CKEDITOR.dialog.addUIElement("textarea",b);CKEDITOR.dialog.addUIElement("checkbox",b);CKEDITOR.dialog.addUIElement("radio",b);CKEDITOR.dialog.addUIElement("button",b);CKEDITOR.dialog.addUIElement("select",b);CKEDITOR.dialog.addUIElement("file",b);CKEDITOR.dialog.addUIElement("fileButton",b);CKEDITOR.dialog.addUIElement("html",b);CKEDITOR.dialog.addUIElement("fieldset",{build:function(a,b,c){for(var d=b.children,f,e=[],i=[],k=0;k<d.length&&(f=d[k]);k++){var l=[];e.push(l);i.push(CKEDITOR.dialog._.uiElementBuilders[f.type].build(a,
f,l))}return new CKEDITOR.ui.dialog[b.type](a,i,e,c,b)}})}}),CKEDITOR.DIALOG_RESIZE_NONE=0,CKEDITOR.DIALOG_RESIZE_WIDTH=1,CKEDITOR.DIALOG_RESIZE_HEIGHT=2,CKEDITOR.DIALOG_RESIZE_BOTH=3,CKEDITOR.DIALOG_STATE_IDLE=1,CKEDITOR.DIALOG_STATE_BUSY=2,function(){function a(){for(var a=this._.tabIdList.length,b=CKEDITOR.tools.indexOf(this._.tabIdList,this._.currentTabId)+a,c=b-1;c>b-a;c--)if(this._.tabs[this._.tabIdList[c%a]][0].$.offsetHeight)return this._.tabIdList[c%a];return null}function e(){for(var a=
this._.tabIdList.length,b=CKEDITOR.tools.indexOf(this._.tabIdList,this._.currentTabId),c=b+1;c<b+a;c++)if(this._.tabs[this._.tabIdList[c%a]][0].$.offsetHeight)return this._.tabIdList[c%a];return null}function b(a,b){for(var c=a.$.getElementsByTagName("input"),d=0,f=c.length;d<f;d++){var g=new CKEDITOR.dom.element(c[d]);if(g.getAttribute("type").toLowerCase()=="text")if(b){g.setAttribute("value",g.getCustomData("fake_value")||"");g.removeCustomData("fake_value")}else{g.setCustomData("fake_value",g.getAttribute("value"));
g.setAttribute("value","")}}}function c(a,b){var c=this.getInputElement();c&&(a?c.removeAttribute("aria-invalid"):c.setAttribute("aria-invalid",true));a||(this.select?this.select():this.focus());b&&alert(b);this.fire("validated",{valid:a,msg:b})}function f(){var a=this.getInputElement();a&&a.removeAttribute("aria-invalid")}function k(a){var b=CKEDITOR.dom.element.createFromHtml(CKEDITOR.addTemplate("dialog",n).output({id:CKEDITOR.tools.getNextNumber(),editorId:a.id,langDir:a.lang.dir,langCode:a.langCode,
editorDialogClass:"cke_editor_"+a.name.replace(/\./g,"\\.")+"_dialog",closeTitle:a.lang.common.close,hidpi:CKEDITOR.env.hidpi?"cke_hidpi":""})),c=b.getChild([0,0,0,0,0]),d=c.getChild(0),g=c.getChild(1);a.plugins.clipboard&&CKEDITOR.plugins.clipboard.preventDefaultDropOnElement(c);if(CKEDITOR.env.ie&&!CKEDITOR.env.quirks&&!CKEDITOR.env.edge){a="javascript:void(function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.close();")+"}())";CKEDITOR.dom.element.createFromHtml('<iframe frameBorder="0" class="cke_iframe_shim" src="'+
a+'" tabIndex="-1"></iframe>').appendTo(c.getParent())}d.unselectable();g.unselectable();return{element:b,parts:{dialog:b.getChild(0),title:d,close:g,tabs:c.getChild(2),contents:c.getChild([3,0,0,0]),footer:c.getChild([3,0,1,0])}}}function i(a,b,c){this.element=b;this.focusIndex=c;this.tabIndex=0;this.isFocusable=function(){return!b.getAttribute("disabled")&&b.isVisible()};this.focus=function(){a._.currentFocusIndex=this.focusIndex;this.element.focus()};b.on("keydown",function(a){a.data.getKeystroke()in
{32:1,13:1}&&this.fire("click")});b.on("focus",function(){this.fire("mouseover")});b.on("blur",function(){this.fire("mouseout")})}function d(a){function b(){a.layout()}var c=CKEDITOR.document.getWindow();c.on("resize",b);a.on("hide",function(){c.removeListener("resize",b)})}function j(a,b){this._={dialog:a};CKEDITOR.tools.extend(this,b)}function h(a){function b(c){var h=a.getSize(),k=CKEDITOR.document.getWindow().getViewPaneSize(),j=c.data.$.screenX,m=c.data.$.screenY,l=j-d.x,s=m-d.y;d={x:j,y:m};
g.x=g.x+l;g.y=g.y+s;a.move(g.x+i[3]<e?-i[3]:g.x-i[1]>k.width-h.width-e?k.width-h.width+(f.lang.dir=="rtl"?0:i[1]):g.x,g.y+i[0]<e?-i[0]:g.y-i[2]>k.height-h.height-e?k.height-h.height+i[2]:g.y,1);c.data.preventDefault()}function c(){CKEDITOR.document.removeListener("mousemove",b);CKEDITOR.document.removeListener("mouseup",c);if(CKEDITOR.env.ie6Compat){var a=q.getChild(0).getFrameDocument();a.removeListener("mousemove",b);a.removeListener("mouseup",c)}}var d=null,g=null,f=a.getParentEditor(),e=f.config.dialog_magnetDistance,
i=CKEDITOR.skin.margins||[0,0,0,0];typeof e=="undefined"&&(e=20);a.parts.title.on("mousedown",function(f){d={x:f.data.$.screenX,y:f.data.$.screenY};CKEDITOR.document.on("mousemove",b);CKEDITOR.document.on("mouseup",c);g=a.getPosition();if(CKEDITOR.env.ie6Compat){var e=q.getChild(0).getFrameDocument();e.on("mousemove",b);e.on("mouseup",c)}f.data.preventDefault()},a)}function g(a){var b,c;function d(g){var l=i.lang.dir=="rtl",s=m.width,t=m.height,o=s+(g.data.$.screenX-b)*(l?-1:1)*(a._.moved?1:2),r=
t+(g.data.$.screenY-c)*(a._.moved?1:2),n=a._.element.getFirst(),n=l&&n.getComputedStyle("right"),w=a.getPosition();w.y+r>j.height&&(r=j.height-w.y);if((l?n:w.x)+o>j.width)o=j.width-(l?n:w.x);if(e==CKEDITOR.DIALOG_RESIZE_WIDTH||e==CKEDITOR.DIALOG_RESIZE_BOTH)s=Math.max(f.minWidth||0,o-h);if(e==CKEDITOR.DIALOG_RESIZE_HEIGHT||e==CKEDITOR.DIALOG_RESIZE_BOTH)t=Math.max(f.minHeight||0,r-k);a.resize(s,t);a._.moved||a.layout();g.data.preventDefault()}function g(){CKEDITOR.document.removeListener("mouseup",
g);CKEDITOR.document.removeListener("mousemove",d);if(l){l.remove();l=null}if(CKEDITOR.env.ie6Compat){var a=q.getChild(0).getFrameDocument();a.removeListener("mouseup",g);a.removeListener("mousemove",d)}}var f=a.definition,e=f.resizable;if(e!=CKEDITOR.DIALOG_RESIZE_NONE){var i=a.getParentEditor(),h,k,j,m,l,s=CKEDITOR.tools.addFunction(function(f){m=a.getSize();var e=a.parts.contents;if(e.$.getElementsByTagName("iframe").length){l=CKEDITOR.dom.element.createFromHtml('<div class="cke_dialog_resize_cover" style="height: 100%; position: absolute; width: 100%;"></div>');
e.append(l)}k=m.height-a.parts.contents.getSize("height",!(CKEDITOR.env.gecko||CKEDITOR.env.ie&&CKEDITOR.env.quirks));h=m.width-a.parts.contents.getSize("width",1);b=f.screenX;c=f.screenY;j=CKEDITOR.document.getWindow().getViewPaneSize();CKEDITOR.document.on("mousemove",d);CKEDITOR.document.on("mouseup",g);if(CKEDITOR.env.ie6Compat){e=q.getChild(0).getFrameDocument();e.on("mousemove",d);e.on("mouseup",g)}f.preventDefault&&f.preventDefault()});a.on("load",function(){var b="";e==CKEDITOR.DIALOG_RESIZE_WIDTH?
b=" cke_resizer_horizontal":e==CKEDITOR.DIALOG_RESIZE_HEIGHT&&(b=" cke_resizer_vertical");b=CKEDITOR.dom.element.createFromHtml('<div class="cke_resizer'+b+" cke_resizer_"+i.lang.dir+'" title="'+CKEDITOR.tools.htmlEncode(i.lang.common.resize)+'" onmousedown="CKEDITOR.tools.callFunction('+s+', event )">'+(i.lang.dir=="ltr"?"◢":"◣")+"</div>");a.parts.footer.append(b,1)});i.on("destroy",function(){CKEDITOR.tools.removeFunction(s)})}}function m(a){a.data.preventDefault(1)}function p(a){var b=CKEDITOR.document.getWindow(),
c=a.config,d=c.dialog_backgroundCoverColor||"white",g=c.dialog_backgroundCoverOpacity,f=c.baseFloatZIndex,c=CKEDITOR.tools.genKey(d,g,f),e=v[c];if(e)e.show();else{f=['<div tabIndex="-1" style="position: ',CKEDITOR.env.ie6Compat?"absolute":"fixed","; z-index: ",f,"; top: 0px; left: 0px; ",!CKEDITOR.env.ie6Compat?"background-color: "+d:"",'" class="cke_dialog_background_cover">'];if(CKEDITOR.env.ie6Compat){d="<html><body style=\\'background-color:"+d+";\\'></body></html>";f.push('<iframe hidefocus="true" frameborder="0" id="cke_dialog_background_iframe" src="javascript:');
f.push("void((function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.write( '"+d+"' );document.close();")+"})())");f.push('" style="position:absolute;left:0;top:0;width:100%;height: 100%;filter: progid:DXImageTransform.Microsoft.Alpha(opacity=0)"></iframe>')}f.push("</div>");e=CKEDITOR.dom.element.createFromHtml(f.join(""));e.setOpacity(g!==void 0?g:0.5);e.on("keydown",m);e.on("keypress",m);e.on("keyup",m);e.appendTo(CKEDITOR.document.getBody());v[c]=e}a.focusManager.add(e);
q=e;var a=function(){var a=b.getViewPaneSize();e.setStyles({width:a.width+"px",height:a.height+"px"})},i=function(){var a=b.getScrollPosition(),c=CKEDITOR.dialog._.currentTop;e.setStyles({left:a.x+"px",top:a.y+"px"});if(c){do{a=c.getPosition();c.move(a.x,a.y)}while(c=c._.parentDialog)}};x=a;b.on("resize",a);a();(!CKEDITOR.env.mac||!CKEDITOR.env.webkit)&&e.focus();if(CKEDITOR.env.ie6Compat){var h=function(){i();arguments.callee.prevScrollHandler.apply(this,arguments)};b.$.setTimeout(function(){h.prevScrollHandler=
window.onscroll||function(){};window.onscroll=h},0);i()}}function r(a){if(q){a.focusManager.remove(q);a=CKEDITOR.document.getWindow();q.hide();a.removeListener("resize",x);CKEDITOR.env.ie6Compat&&a.$.setTimeout(function(){window.onscroll=window.onscroll&&window.onscroll.prevScrollHandler||null},0);x=null}}var o=CKEDITOR.tools.cssLength,n='<div class="cke_reset_all {editorId} {editorDialogClass} {hidpi}" dir="{langDir}" lang="{langCode}" role="dialog" aria-labelledby="cke_dialog_title_{id}"><table class="cke_dialog '+
CKEDITOR.env.cssClass+' cke_{langDir}" style="position:absolute" role="presentation"><tr><td role="presentation"><div class="cke_dialog_body" role="presentation"><div id="cke_dialog_title_{id}" class="cke_dialog_title" role="presentation"></div><a id="cke_dialog_close_button_{id}" class="cke_dialog_close_button" href="javascript:void(0)" title="{closeTitle}" role="button"><span class="cke_label">X</span></a><div id="cke_dialog_tabs_{id}" class="cke_dialog_tabs" role="tablist"></div><table class="cke_dialog_contents" role="presentation"><tr><td id="cke_dialog_contents_{id}" class="cke_dialog_contents_body" role="presentation"></td></tr><tr><td id="cke_dialog_footer_{id}" class="cke_dialog_footer" role="presentation"></td></tr></table></div></td></tr></table></div>';
CKEDITOR.dialog=function(b,d){function i(){var a=q._.focusList;a.sort(function(a,b){return a.tabIndex!=b.tabIndex?b.tabIndex-a.tabIndex:a.focusIndex-b.focusIndex});for(var b=a.length,c=0;c<b;c++)a[c].focusIndex=c}function j(a){var b=q._.focusList,a=a||0;if(!(b.length<1)){var c=q._.currentFocusIndex;q._.tabBarMode&&a<0&&(c=0);try{b[c].getInputElement().$.blur()}catch(d){}var g=c,f=q._.pageCount>1;do{g=g+a;if(f&&!q._.tabBarMode&&(g==b.length||g==-1)){q._.tabBarMode=true;q._.tabs[q._.currentTabId][0].focus();
q._.currentFocusIndex=-1;return}g=(g+b.length)%b.length;if(g==c)break}while(a&&!b[g].isFocusable());b[g].focus();b[g].type=="text"&&b[g].select()}}function m(c){if(q==CKEDITOR.dialog._.currentTop){var d=c.data.getKeystroke(),g=b.lang.dir=="rtl",f=[37,38,39,40];p=x=0;if(d==9||d==CKEDITOR.SHIFT+9){j(d==CKEDITOR.SHIFT+9?-1:1);p=1}else if(d==CKEDITOR.ALT+121&&!q._.tabBarMode&&q.getPageCount()>1){q._.tabBarMode=true;q._.tabs[q._.currentTabId][0].focus();q._.currentFocusIndex=-1;p=1}else if(CKEDITOR.tools.indexOf(f,
d)!=-1&&q._.tabBarMode){d=CKEDITOR.tools.indexOf([g?39:37,38],d)!=-1?a.call(q):e.call(q);q.selectPage(d);q._.tabs[d][0].focus();p=1}else if((d==13||d==32)&&q._.tabBarMode){this.selectPage(this._.currentTabId);this._.tabBarMode=false;this._.currentFocusIndex=-1;j(1);p=1}else if(d==13){d=c.data.getTarget();if(!d.is("a","button","select","textarea")&&(!d.is("input")||d.$.type!="button")){(d=this.getButton("ok"))&&CKEDITOR.tools.setTimeout(d.click,0,d);p=1}x=1}else if(d==27){(d=this.getButton("cancel"))?
CKEDITOR.tools.setTimeout(d.click,0,d):this.fire("cancel",{hide:true}).hide!==false&&this.hide();x=1}else return;s(c)}}function s(a){p?a.data.preventDefault(1):x&&a.data.stopPropagation()}var t=CKEDITOR.dialog._.dialogDefinitions[d],o=CKEDITOR.tools.clone(l),r=b.config.dialog_buttonsOrder||"OS",n=b.lang.dir,w={},p,x;(r=="OS"&&CKEDITOR.env.mac||r=="rtl"&&n=="ltr"||r=="ltr"&&n=="rtl")&&o.buttons.reverse();t=CKEDITOR.tools.extend(t(b),o);t=CKEDITOR.tools.clone(t);t=new u(this,t);o=k(b);this._={editor:b,
element:o.element,name:d,contentSize:{width:0,height:0},size:{width:0,height:0},contents:{},buttons:{},accessKeyMap:{},tabs:{},tabIdList:[],currentTabId:null,currentTabIndex:null,pageCount:0,lastTab:null,tabBarMode:false,focusList:[],currentFocusIndex:0,hasFocus:false};this.parts=o.parts;CKEDITOR.tools.setTimeout(function(){b.fire("ariaWidget",this.parts.contents)},0,this);o={position:CKEDITOR.env.ie6Compat?"absolute":"fixed",top:0,visibility:"hidden"};o[n=="rtl"?"right":"left"]=0;this.parts.dialog.setStyles(o);
CKEDITOR.event.call(this);this.definition=t=CKEDITOR.fire("dialogDefinition",{name:d,definition:t},b).definition;if(!("removeDialogTabs"in b._)&&b.config.removeDialogTabs){o=b.config.removeDialogTabs.split(";");for(n=0;n<o.length;n++){r=o[n].split(":");if(r.length==2){var v=r[0];w[v]||(w[v]=[]);w[v].push(r[1])}}b._.removeDialogTabs=w}if(b._.removeDialogTabs&&(w=b._.removeDialogTabs[d]))for(n=0;n<w.length;n++)t.removeContents(w[n]);if(t.onLoad)this.on("load",t.onLoad);if(t.onShow)this.on("show",t.onShow);
if(t.onHide)this.on("hide",t.onHide);if(t.onOk)this.on("ok",function(a){b.fire("saveSnapshot");setTimeout(function(){b.fire("saveSnapshot")},0);if(t.onOk.call(this,a)===false)a.data.hide=false});this.state=CKEDITOR.DIALOG_STATE_IDLE;if(t.onCancel)this.on("cancel",function(a){if(t.onCancel.call(this,a)===false)a.data.hide=false});var q=this,y=function(a){var b=q._.contents,c=false,d;for(d in b)for(var g in b[d])if(c=a.call(this,b[d][g]))return};this.on("ok",function(a){y(function(b){if(b.validate){var d=
b.validate(this),g=typeof d=="string"||d===false;if(g){a.data.hide=false;a.stop()}c.call(b,!g,typeof d=="string"?d:void 0);return g}})},this,null,0);this.on("cancel",function(a){y(function(c){if(c.isChanged()){if(!b.config.dialog_noConfirmCancel&&!confirm(b.lang.common.confirmCancel))a.data.hide=false;return true}})},this,null,0);this.parts.close.on("click",function(a){this.fire("cancel",{hide:true}).hide!==false&&this.hide();a.data.preventDefault()},this);this.changeFocus=j;var z=this._.element;
b.focusManager.add(z,1);this.on("show",function(){z.on("keydown",m,this);if(CKEDITOR.env.gecko)z.on("keypress",s,this)});this.on("hide",function(){z.removeListener("keydown",m);CKEDITOR.env.gecko&&z.removeListener("keypress",s);y(function(a){f.apply(a)})});this.on("iframeAdded",function(a){(new CKEDITOR.dom.document(a.data.iframe.$.contentWindow.document)).on("keydown",m,this,null,0)});this.on("show",function(){i();var a=q._.pageCount>1;if(b.config.dialog_startupFocusTab&&a){q._.tabBarMode=true;q._.tabs[q._.currentTabId][0].focus();
q._.currentFocusIndex=-1}else if(!this._.hasFocus){this._.currentFocusIndex=a?-1:this._.focusList.length-1;if(t.onFocus)(a=t.onFocus.call(this))&&a.focus();else j(1)}},this,null,4294967295);if(CKEDITOR.env.ie6Compat)this.on("load",function(){var a=this.getElement(),b=a.getFirst();b.remove();b.appendTo(a)},this);h(this);g(this);(new CKEDITOR.dom.text(t.title,CKEDITOR.document)).appendTo(this.parts.title);for(n=0;n<t.contents.length;n++)(w=t.contents[n])&&this.addPage(w);this.parts.tabs.on("click",
function(a){var b=a.data.getTarget();if(b.hasClass("cke_dialog_tab")){b=b.$.id;this.selectPage(b.substring(4,b.lastIndexOf("_")));if(this._.tabBarMode){this._.tabBarMode=false;this._.currentFocusIndex=-1;j(1)}a.data.preventDefault()}},this);n=[];w=CKEDITOR.dialog._.uiElementBuilders.hbox.build(this,{type:"hbox",className:"cke_dialog_footer_buttons",widths:[],children:t.buttons},n).getChild();this.parts.footer.setHtml(n.join(""));for(n=0;n<w.length;n++)this._.buttons[w[n].id]=w[n]};CKEDITOR.dialog.prototype=
{destroy:function(){this.hide();this._.element.remove()},resize:function(){return function(a,b){if(!this._.contentSize||!(this._.contentSize.width==a&&this._.contentSize.height==b)){CKEDITOR.dialog.fire("resize",{dialog:this,width:a,height:b},this._.editor);this.fire("resize",{width:a,height:b},this._.editor);this.parts.contents.setStyles({width:a+"px",height:b+"px"});if(this._.editor.lang.dir=="rtl"&&this._.position)this._.position.x=CKEDITOR.document.getWindow().getViewPaneSize().width-this._.contentSize.width-
parseInt(this._.element.getFirst().getStyle("right"),10);this._.contentSize={width:a,height:b}}}}(),getSize:function(){var a=this._.element.getFirst();return{width:a.$.offsetWidth||0,height:a.$.offsetHeight||0}},move:function(a,b,c){var d=this._.element.getFirst(),g=this._.editor.lang.dir=="rtl",f=d.getComputedStyle("position")=="fixed";CKEDITOR.env.ie&&d.setStyle("zoom","100%");if(!f||!this._.position||!(this._.position.x==a&&this._.position.y==b)){this._.position={x:a,y:b};if(!f){f=CKEDITOR.document.getWindow().getScrollPosition();
a=a+f.x;b=b+f.y}if(g){f=this.getSize();a=CKEDITOR.document.getWindow().getViewPaneSize().width-f.width-a}b={top:(b>0?b:0)+"px"};b[g?"right":"left"]=(a>0?a:0)+"px";d.setStyles(b);c&&(this._.moved=1)}},getPosition:function(){return CKEDITOR.tools.extend({},this._.position)},show:function(){var a=this._.element,b=this.definition;!a.getParent()||!a.getParent().equals(CKEDITOR.document.getBody())?a.appendTo(CKEDITOR.document.getBody()):a.setStyle("display","block");this.resize(this._.contentSize&&this._.contentSize.width||
b.width||b.minWidth,this._.contentSize&&this._.contentSize.height||b.height||b.minHeight);this.reset();this.selectPage(this.definition.contents[0].id);if(CKEDITOR.dialog._.currentZIndex===null)CKEDITOR.dialog._.currentZIndex=this._.editor.config.baseFloatZIndex;this._.element.getFirst().setStyle("z-index",CKEDITOR.dialog._.currentZIndex=CKEDITOR.dialog._.currentZIndex+10);if(CKEDITOR.dialog._.currentTop===null){CKEDITOR.dialog._.currentTop=this;this._.parentDialog=null;p(this._.editor)}else{this._.parentDialog=
CKEDITOR.dialog._.currentTop;this._.parentDialog.getElement().getFirst().$.style.zIndex-=Math.floor(this._.editor.config.baseFloatZIndex/2);CKEDITOR.dialog._.currentTop=this}a.on("keydown",z);a.on("keyup",B);this._.hasFocus=false;for(var c in b.contents)if(b.contents[c]){var a=b.contents[c],g=this._.tabs[a.id],f=a.requiredContent,e=0;if(g){for(var i in this._.contents[a.id]){var h=this._.contents[a.id][i];if(!(h.type=="hbox"||h.type=="vbox"||!h.getInputElement()))if(h.requiredContent&&!this._.editor.activeFilter.check(h.requiredContent))h.disable();
else{h.enable();e++}}!e||f&&!this._.editor.activeFilter.check(f)?g[0].addClass("cke_dialog_tab_disabled"):g[0].removeClass("cke_dialog_tab_disabled")}}CKEDITOR.tools.setTimeout(function(){this.layout();d(this);this.parts.dialog.setStyle("visibility","");this.fireOnce("load",{});CKEDITOR.ui.fire("ready",this);this.fire("show",{});this._.editor.fire("dialogShow",this);this._.parentDialog||this._.editor.focusManager.lock();this.foreach(function(a){a.setInitValue&&a.setInitValue()})},100,this)},layout:function(){var a=
this.parts.dialog,b=this.getSize(),c=CKEDITOR.document.getWindow().getViewPaneSize(),d=(c.width-b.width)/2,g=(c.height-b.height)/2;CKEDITOR.env.ie6Compat||(b.height+(g>0?g:0)>c.height||b.width+(d>0?d:0)>c.width?a.setStyle("position","absolute"):a.setStyle("position","fixed"));this.move(this._.moved?this._.position.x:d,this._.moved?this._.position.y:g)},foreach:function(a){for(var b in this._.contents)for(var c in this._.contents[b])a.call(this,this._.contents[b][c]);return this},reset:function(){var a=
function(a){a.reset&&a.reset(1)};return function(){this.foreach(a);return this}}(),setupContent:function(){var a=arguments;this.foreach(function(b){b.setup&&b.setup.apply(b,a)})},commitContent:function(){var a=arguments;this.foreach(function(b){CKEDITOR.env.ie&&this._.currentFocusIndex==b.focusIndex&&b.getInputElement().$.blur();b.commit&&b.commit.apply(b,a)})},hide:function(){if(this.parts.dialog.isVisible()){this.fire("hide",{});this._.editor.fire("dialogHide",this);this.selectPage(this._.tabIdList[0]);
var a=this._.element;a.setStyle("display","none");this.parts.dialog.setStyle("visibility","hidden");for(D(this);CKEDITOR.dialog._.currentTop!=this;)CKEDITOR.dialog._.currentTop.hide();if(this._.parentDialog){var b=this._.parentDialog.getElement().getFirst();b.setStyle("z-index",parseInt(b.$.style.zIndex,10)+Math.floor(this._.editor.config.baseFloatZIndex/2))}else r(this._.editor);if(CKEDITOR.dialog._.currentTop=this._.parentDialog)CKEDITOR.dialog._.currentZIndex=CKEDITOR.dialog._.currentZIndex-10;
else{CKEDITOR.dialog._.currentZIndex=null;a.removeListener("keydown",z);a.removeListener("keyup",B);var c=this._.editor;c.focus();setTimeout(function(){c.focusManager.unlock();CKEDITOR.env.iOS&&c.window.focus()},0)}delete this._.parentDialog;this.foreach(function(a){a.resetInitValue&&a.resetInitValue()});this.setState(CKEDITOR.DIALOG_STATE_IDLE)}},addPage:function(a){if(!a.requiredContent||this._.editor.filter.check(a.requiredContent)){for(var b=[],c=a.label?' title="'+CKEDITOR.tools.htmlEncode(a.label)+
'"':"",d=CKEDITOR.dialog._.uiElementBuilders.vbox.build(this,{type:"vbox",className:"cke_dialog_page_contents",children:a.elements,expand:!!a.expand,padding:a.padding,style:a.style||"width: 100%;"},b),g=this._.contents[a.id]={},f=d.getChild(),e=0;d=f.shift();){!d.notAllowed&&(d.type!="hbox"&&d.type!="vbox")&&e++;g[d.id]=d;typeof d.getChild=="function"&&f.push.apply(f,d.getChild())}if(!e)a.hidden=true;b=CKEDITOR.dom.element.createFromHtml(b.join(""));b.setAttribute("role","tabpanel");d=CKEDITOR.env;
g="cke_"+a.id+"_"+CKEDITOR.tools.getNextNumber();c=CKEDITOR.dom.element.createFromHtml(['<a class="cke_dialog_tab"',this._.pageCount>0?" cke_last":"cke_first",c,a.hidden?' style="display:none"':"",' id="',g,'"',d.gecko&&!d.hc?"":' href="javascript:void(0)"',' tabIndex="-1" hidefocus="true" role="tab">',a.label,"</a>"].join(""));b.setAttribute("aria-labelledby",g);this._.tabs[a.id]=[c,b];this._.tabIdList.push(a.id);!a.hidden&&this._.pageCount++;this._.lastTab=c;this.updateStyle();b.setAttribute("name",
a.id);b.appendTo(this.parts.contents);c.unselectable();this.parts.tabs.append(c);if(a.accessKey){A(this,this,"CTRL+"+a.accessKey,G,C);this._.accessKeyMap["CTRL+"+a.accessKey]=a.id}}},selectPage:function(a){if(this._.currentTabId!=a&&!this._.tabs[a][0].hasClass("cke_dialog_tab_disabled")&&this.fire("selectPage",{page:a,currentPage:this._.currentTabId})!==false){for(var c in this._.tabs){var d=this._.tabs[c][0],g=this._.tabs[c][1];if(c!=a){d.removeClass("cke_dialog_tab_selected");g.hide()}g.setAttribute("aria-hidden",
c!=a)}var f=this._.tabs[a];f[0].addClass("cke_dialog_tab_selected");if(CKEDITOR.env.ie6Compat||CKEDITOR.env.ie7Compat){b(f[1]);f[1].show();setTimeout(function(){b(f[1],1)},0)}else f[1].show();this._.currentTabId=a;this._.currentTabIndex=CKEDITOR.tools.indexOf(this._.tabIdList,a)}},updateStyle:function(){this.parts.dialog[(this._.pageCount===1?"add":"remove")+"Class"]("cke_single_page")},hidePage:function(b){var c=this._.tabs[b]&&this._.tabs[b][0];if(c&&this._.pageCount!=1&&c.isVisible()){b==this._.currentTabId&&
this.selectPage(a.call(this));c.hide();this._.pageCount--;this.updateStyle()}},showPage:function(a){if(a=this._.tabs[a]&&this._.tabs[a][0]){a.show();this._.pageCount++;this.updateStyle()}},getElement:function(){return this._.element},getName:function(){return this._.name},getContentElement:function(a,b){var c=this._.contents[a];return c&&c[b]},getValueOf:function(a,b){return this.getContentElement(a,b).getValue()},setValueOf:function(a,b,c){return this.getContentElement(a,b).setValue(c)},getButton:function(a){return this._.buttons[a]},
click:function(a){return this._.buttons[a].click()},disableButton:function(a){return this._.buttons[a].disable()},enableButton:function(a){return this._.buttons[a].enable()},getPageCount:function(){return this._.pageCount},getParentEditor:function(){return this._.editor},getSelectedElement:function(){return this.getParentEditor().getSelection().getSelectedElement()},addFocusable:function(a,b){if(typeof b=="undefined"){b=this._.focusList.length;this._.focusList.push(new i(this,a,b))}else{this._.focusList.splice(b,
0,new i(this,a,b));for(var c=b+1;c<this._.focusList.length;c++)this._.focusList[c].focusIndex++}},setState:function(a){if(this.state!=a){this.state=a;if(a==CKEDITOR.DIALOG_STATE_BUSY){if(!this.parts.spinner){var b=this.getParentEditor().lang.dir,c={attributes:{"class":"cke_dialog_spinner"},styles:{"float":b=="rtl"?"right":"left"}};c.styles["margin-"+(b=="rtl"?"left":"right")]="8px";this.parts.spinner=CKEDITOR.document.createElement("div",c);this.parts.spinner.setHtml("&#8987;");this.parts.spinner.appendTo(this.parts.title,
1)}this.parts.spinner.show();this.getButton("ok").disable()}else if(a==CKEDITOR.DIALOG_STATE_IDLE){this.parts.spinner&&this.parts.spinner.hide();this.getButton("ok").enable()}this.fire("state",a)}}};CKEDITOR.tools.extend(CKEDITOR.dialog,{add:function(a,b){if(!this._.dialogDefinitions[a]||typeof b=="function")this._.dialogDefinitions[a]=b},exists:function(a){return!!this._.dialogDefinitions[a]},getCurrent:function(){return CKEDITOR.dialog._.currentTop},isTabEnabled:function(a,b,c){a=a.config.removeDialogTabs;
return!(a&&a.match(RegExp("(?:^|;)"+b+":"+c+"(?:$|;)","i")))},okButton:function(){var a=function(a,b){b=b||{};return CKEDITOR.tools.extend({id:"ok",type:"button",label:a.lang.common.ok,"class":"cke_dialog_ui_button_ok",onClick:function(a){a=a.data.dialog;a.fire("ok",{hide:true}).hide!==false&&a.hide()}},b,true)};a.type="button";a.override=function(b){return CKEDITOR.tools.extend(function(c){return a(c,b)},{type:"button"},true)};return a}(),cancelButton:function(){var a=function(a,b){b=b||{};return CKEDITOR.tools.extend({id:"cancel",
type:"button",label:a.lang.common.cancel,"class":"cke_dialog_ui_button_cancel",onClick:function(a){a=a.data.dialog;a.fire("cancel",{hide:true}).hide!==false&&a.hide()}},b,true)};a.type="button";a.override=function(b){return CKEDITOR.tools.extend(function(c){return a(c,b)},{type:"button"},true)};return a}(),addUIElement:function(a,b){this._.uiElementBuilders[a]=b}});CKEDITOR.dialog._={uiElementBuilders:{},dialogDefinitions:{},currentTop:null,currentZIndex:null};CKEDITOR.event.implementOn(CKEDITOR.dialog);
CKEDITOR.event.implementOn(CKEDITOR.dialog.prototype);var l={resizable:CKEDITOR.DIALOG_RESIZE_BOTH,minWidth:600,minHeight:400,buttons:[CKEDITOR.dialog.okButton,CKEDITOR.dialog.cancelButton]},s=function(a,b,c){for(var d=0,g;g=a[d];d++){if(g.id==b)return g;if(c&&g[c])if(g=s(g[c],b,c))return g}return null},t=function(a,b,c,d,g){if(c){for(var f=0,e;e=a[f];f++){if(e.id==c){a.splice(f,0,b);return b}if(d&&e[d])if(e=t(e[d],b,c,d,true))return e}if(g)return null}a.push(b);return b},w=function(a,b,c){for(var d=
0,g;g=a[d];d++){if(g.id==b)return a.splice(d,1);if(c&&g[c])if(g=w(g[c],b,c))return g}return null},u=function(a,b){this.dialog=a;for(var c=b.contents,d=0,g;g=c[d];d++)c[d]=g&&new j(a,g);CKEDITOR.tools.extend(this,b)};u.prototype={getContents:function(a){return s(this.contents,a)},getButton:function(a){return s(this.buttons,a)},addContents:function(a,b){return t(this.contents,a,b)},addButton:function(a,b){return t(this.buttons,a,b)},removeContents:function(a){w(this.contents,a)},removeButton:function(a){w(this.buttons,
a)}};j.prototype={get:function(a){return s(this.elements,a,"children")},add:function(a,b){return t(this.elements,a,b,"children")},remove:function(a){w(this.elements,a,"children")}};var x,v={},q,y={},z=function(a){var b=a.data.$.ctrlKey||a.data.$.metaKey,c=a.data.$.altKey,d=a.data.$.shiftKey,g=String.fromCharCode(a.data.$.keyCode);if((b=y[(b?"CTRL+":"")+(c?"ALT+":"")+(d?"SHIFT+":"")+g])&&b.length){b=b[b.length-1];b.keydown&&b.keydown.call(b.uiElement,b.dialog,b.key);a.data.preventDefault()}},B=function(a){var b=
a.data.$.ctrlKey||a.data.$.metaKey,c=a.data.$.altKey,d=a.data.$.shiftKey,g=String.fromCharCode(a.data.$.keyCode);if((b=y[(b?"CTRL+":"")+(c?"ALT+":"")+(d?"SHIFT+":"")+g])&&b.length){b=b[b.length-1];if(b.keyup){b.keyup.call(b.uiElement,b.dialog,b.key);a.data.preventDefault()}}},A=function(a,b,c,d,g){(y[c]||(y[c]=[])).push({uiElement:a,dialog:b,key:c,keyup:g||a.accessKeyUp,keydown:d||a.accessKeyDown})},D=function(a){for(var b in y){for(var c=y[b],d=c.length-1;d>=0;d--)(c[d].dialog==a||c[d].uiElement==
a)&&c.splice(d,1);c.length===0&&delete y[b]}},C=function(a,b){a._.accessKeyMap[b]&&a.selectPage(a._.accessKeyMap[b])},G=function(){};(function(){CKEDITOR.ui.dialog={uiElement:function(a,b,c,d,g,f,e){if(!(arguments.length<4)){var i=(d.call?d(b):d)||"div",h=["<",i," "],k=(g&&g.call?g(b):g)||{},j=(f&&f.call?f(b):f)||{},m=(e&&e.call?e.call(this,a,b):e)||"",l=this.domId=j.id||CKEDITOR.tools.getNextId()+"_uiElement";if(b.requiredContent&&!a.getParentEditor().filter.check(b.requiredContent)){k.display="none";
this.notAllowed=true}j.id=l;var t={};b.type&&(t["cke_dialog_ui_"+b.type]=1);b.className&&(t[b.className]=1);if(b.disabled)t.cke_disabled=1;for(var s=j["class"]&&j["class"].split?j["class"].split(" "):[],l=0;l<s.length;l++)s[l]&&(t[s[l]]=1);s=[];for(l in t)s.push(l);j["class"]=s.join(" ");if(b.title)j.title=b.title;t=(b.style||"").split(";");if(b.align){s=b.align;k["margin-left"]=s=="left"?0:"auto";k["margin-right"]=s=="right"?0:"auto"}for(l in k)t.push(l+":"+k[l]);b.hidden&&t.push("display:none");
for(l=t.length-1;l>=0;l--)t[l]===""&&t.splice(l,1);if(t.length>0)j.style=(j.style?j.style+"; ":"")+t.join("; ");for(l in j)h.push(l+'="'+CKEDITOR.tools.htmlEncode(j[l])+'" ');h.push(">",m,"</",i,">");c.push(h.join(""));(this._||(this._={})).dialog=a;if(typeof b.isChanged=="boolean")this.isChanged=function(){return b.isChanged};if(typeof b.isChanged=="function")this.isChanged=b.isChanged;if(typeof b.setValue=="function")this.setValue=CKEDITOR.tools.override(this.setValue,function(a){return function(c){a.call(this,
b.setValue.call(this,c))}});if(typeof b.getValue=="function")this.getValue=CKEDITOR.tools.override(this.getValue,function(a){return function(){return b.getValue.call(this,a.call(this))}});CKEDITOR.event.implementOn(this);this.registerEvents(b);this.accessKeyUp&&(this.accessKeyDown&&b.accessKey)&&A(this,a,"CTRL+"+b.accessKey);var o=this;a.on("load",function(){var b=o.getInputElement();if(b){var c=o.type in{checkbox:1,ratio:1}&&CKEDITOR.env.ie&&CKEDITOR.env.version<8?"cke_dialog_ui_focused":"";b.on("focus",
function(){a._.tabBarMode=false;a._.hasFocus=true;o.fire("focus");c&&this.addClass(c)});b.on("blur",function(){o.fire("blur");c&&this.removeClass(c)})}});CKEDITOR.tools.extend(this,b);if(this.keyboardFocusable){this.tabIndex=b.tabIndex||0;this.focusIndex=a._.focusList.push(this)-1;this.on("focus",function(){a._.currentFocusIndex=o.focusIndex})}}},hbox:function(a,b,c,d,g){if(!(arguments.length<4)){this._||(this._={});var f=this._.children=b,e=g&&g.widths||null,i=g&&g.height||null,h,k={role:"presentation"};
g&&g.align&&(k.align=g.align);CKEDITOR.ui.dialog.uiElement.call(this,a,g||{type:"hbox"},d,"table",{},k,function(){var a=['<tbody><tr class="cke_dialog_ui_hbox">'];for(h=0;h<c.length;h++){var b="cke_dialog_ui_hbox_child",d=[];h===0&&(b="cke_dialog_ui_hbox_first");h==c.length-1&&(b="cke_dialog_ui_hbox_last");a.push('<td class="',b,'" role="presentation" ');e?e[h]&&d.push("width:"+o(e[h])):d.push("width:"+Math.floor(100/c.length)+"%");i&&d.push("height:"+o(i));g&&g.padding!==void 0&&d.push("padding:"+
o(g.padding));CKEDITOR.env.ie&&(CKEDITOR.env.quirks&&f[h].align)&&d.push("text-align:"+f[h].align);d.length>0&&a.push('style="'+d.join("; ")+'" ');a.push(">",c[h],"</td>")}a.push("</tr></tbody>");return a.join("")})}},vbox:function(a,b,c,d,g){if(!(arguments.length<3)){this._||(this._={});var f=this._.children=b,e=g&&g.width||null,i=g&&g.heights||null;CKEDITOR.ui.dialog.uiElement.call(this,a,g||{type:"vbox"},d,"div",null,{role:"presentation"},function(){var b=['<table role="presentation" cellspacing="0" border="0" '];
b.push('style="');g&&g.expand&&b.push("height:100%;");b.push("width:"+o(e||"100%"),";");CKEDITOR.env.webkit&&b.push("float:none;");b.push('"');b.push('align="',CKEDITOR.tools.htmlEncode(g&&g.align||(a.getParentEditor().lang.dir=="ltr"?"left":"right")),'" ');b.push("><tbody>");for(var d=0;d<c.length;d++){var h=[];b.push('<tr><td role="presentation" ');e&&h.push("width:"+o(e||"100%"));i?h.push("height:"+o(i[d])):g&&g.expand&&h.push("height:"+Math.floor(100/c.length)+"%");g&&g.padding!==void 0&&h.push("padding:"+
o(g.padding));CKEDITOR.env.ie&&(CKEDITOR.env.quirks&&f[d].align)&&h.push("text-align:"+f[d].align);h.length>0&&b.push('style="',h.join("; "),'" ');b.push(' class="cke_dialog_ui_vbox_child">',c[d],"</td></tr>")}b.push("</tbody></table>");return b.join("")})}}}})();CKEDITOR.ui.dialog.uiElement.prototype={getElement:function(){return CKEDITOR.document.getById(this.domId)},getInputElement:function(){return this.getElement()},getDialog:function(){return this._.dialog},setValue:function(a,b){this.getInputElement().setValue(a);
!b&&this.fire("change",{value:a});return this},getValue:function(){return this.getInputElement().getValue()},isChanged:function(){return false},selectParentTab:function(){for(var a=this.getInputElement();(a=a.getParent())&&a.$.className.search("cke_dialog_page_contents")==-1;);if(!a)return this;a=a.getAttribute("name");this._.dialog._.currentTabId!=a&&this._.dialog.selectPage(a);return this},focus:function(){this.selectParentTab().getInputElement().focus();return this},registerEvents:function(a){var b=
/^on([A-Z]\w+)/,c,d=function(a,b,c,d){b.on("load",function(){a.getInputElement().on(c,d,a)})},g;for(g in a)if(c=g.match(b))this.eventProcessors[g]?this.eventProcessors[g].call(this,this._.dialog,a[g]):d(this,this._.dialog,c[1].toLowerCase(),a[g]);return this},eventProcessors:{onLoad:function(a,b){a.on("load",b,this)},onShow:function(a,b){a.on("show",b,this)},onHide:function(a,b){a.on("hide",b,this)}},accessKeyDown:function(){this.focus()},accessKeyUp:function(){},disable:function(){var a=this.getElement();
this.getInputElement().setAttribute("disabled","true");a.addClass("cke_disabled")},enable:function(){var a=this.getElement();this.getInputElement().removeAttribute("disabled");a.removeClass("cke_disabled")},isEnabled:function(){return!this.getElement().hasClass("cke_disabled")},isVisible:function(){return this.getInputElement().isVisible()},isFocusable:function(){return!this.isEnabled()||!this.isVisible()?false:true}};CKEDITOR.ui.dialog.hbox.prototype=CKEDITOR.tools.extend(new CKEDITOR.ui.dialog.uiElement,
{getChild:function(a){if(arguments.length<1)return this._.children.concat();a.splice||(a=[a]);return a.length<2?this._.children[a[0]]:this._.children[a[0]]&&this._.children[a[0]].getChild?this._.children[a[0]].getChild(a.slice(1,a.length)):null}},true);CKEDITOR.ui.dialog.vbox.prototype=new CKEDITOR.ui.dialog.hbox;(function(){var a={build:function(a,b,c){for(var d=b.children,g,f=[],e=[],i=0;i<d.length&&(g=d[i]);i++){var h=[];f.push(h);e.push(CKEDITOR.dialog._.uiElementBuilders[g.type].build(a,g,h))}return new CKEDITOR.ui.dialog[b.type](a,
e,f,c,b)}};CKEDITOR.dialog.addUIElement("hbox",a);CKEDITOR.dialog.addUIElement("vbox",a)})();CKEDITOR.dialogCommand=function(a,b){this.dialogName=a;CKEDITOR.tools.extend(this,b,true)};CKEDITOR.dialogCommand.prototype={exec:function(a){a.openDialog(this.dialogName)},canUndo:false,editorFocus:1};(function(){var a=/^([a]|[^a])+$/,b=/^\d*$/,c=/^\d*(?:\.\d+)?$/,d=/^(((\d*(\.\d+))|(\d*))(px|\%)?)?$/,g=/^(((\d*(\.\d+))|(\d*))(px|em|ex|in|cm|mm|pt|pc|\%)?)?$/i,f=/^(\s*[\w-]+\s*:\s*[^:;]+(?:;|$))*$/;CKEDITOR.VALIDATE_OR=
1;CKEDITOR.VALIDATE_AND=2;CKEDITOR.dialog.validate={functions:function(){var a=arguments;return function(){var b=this&&this.getValue?this.getValue():a[0],c,d=CKEDITOR.VALIDATE_AND,g=[],f;for(f=0;f<a.length;f++)if(typeof a[f]=="function")g.push(a[f]);else break;if(f<a.length&&typeof a[f]=="string"){c=a[f];f++}f<a.length&&typeof a[f]=="number"&&(d=a[f]);var e=d==CKEDITOR.VALIDATE_AND?true:false;for(f=0;f<g.length;f++)e=d==CKEDITOR.VALIDATE_AND?e&&g[f](b):e||g[f](b);return!e?c:true}},regex:function(a,
b){return function(c){c=this&&this.getValue?this.getValue():c;return!a.test(c)?b:true}},notEmpty:function(b){return this.regex(a,b)},integer:function(a){return this.regex(b,a)},number:function(a){return this.regex(c,a)},cssLength:function(a){return this.functions(function(a){return g.test(CKEDITOR.tools.trim(a))},a)},htmlLength:function(a){return this.functions(function(a){return d.test(CKEDITOR.tools.trim(a))},a)},inlineStyle:function(a){return this.functions(function(a){return f.test(CKEDITOR.tools.trim(a))},
a)},equals:function(a,b){return this.functions(function(b){return b==a},b)},notEqual:function(a,b){return this.functions(function(b){return b!=a},b)}};CKEDITOR.on("instanceDestroyed",function(a){if(CKEDITOR.tools.isEmpty(CKEDITOR.instances)){for(var b;b=CKEDITOR.dialog._.currentTop;)b.hide();for(var c in v)v[c].remove();v={}}var a=a.editor._.storedDialogs,d;for(d in a)a[d].destroy()})})();CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{openDialog:function(a,b){var c=null,d=CKEDITOR.dialog._.dialogDefinitions[a];
CKEDITOR.dialog._.currentTop===null&&p(this);if(typeof d=="function"){c=this._.storedDialogs||(this._.storedDialogs={});c=c[a]||(c[a]=new CKEDITOR.dialog(this,a));b&&b.call(c,c);c.show()}else{if(d=="failed"){r(this);throw Error('[CKEDITOR.dialog.openDialog] Dialog "'+a+'" failed when loading definition.');}typeof d=="string"&&CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(d),function(){typeof CKEDITOR.dialog._.dialogDefinitions[a]!="function"&&(CKEDITOR.dialog._.dialogDefinitions[a]="failed");this.openDialog(a,
b)},this,0,1)}CKEDITOR.skin.loadPart("dialog");return c}})}(),CKEDITOR.plugins.add("dialog",{requires:"dialogui",init:function(a){a.on("doubleclick",function(e){e.data.dialog&&a.openDialog(e.data.dialog)},null,null,999)}}),function(){CKEDITOR.plugins.add("a11yhelp",{requires:"dialog",availableLangs:{af:1,ar:1,bg:1,ca:1,cs:1,cy:1,da:1,de:1,el:1,en:1,"en-gb":1,eo:1,es:1,et:1,fa:1,fi:1,fo:1,fr:1,"fr-ca":1,gl:1,gu:1,he:1,hi:1,hr:1,hu:1,id:1,it:1,ja:1,km:1,ko:1,ku:1,lt:1,lv:1,mk:1,mn:1,nb:1,nl:1,no:1,
pl:1,pt:1,"pt-br":1,ro:1,ru:1,si:1,sk:1,sl:1,sq:1,sr:1,"sr-latn":1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,zh:1,"zh-cn":1},init:function(a){var e=this;a.addCommand("a11yHelp",{exec:function(){var b=a.langCode,b=e.availableLangs[b]?b:e.availableLangs[b.replace(/-.*/,"")]?b.replace(/-.*/,""):"en";CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(e.path+"dialogs/lang/"+b+".js"),function(){a.lang.a11yhelp=e.langEntries[b];a.openDialog("a11yHelp")})},modes:{wysiwyg:1,source:1},readOnly:1,canUndo:false});a.setKeystroke(CKEDITOR.ALT+
48,"a11yHelp");CKEDITOR.dialog.add("a11yHelp",this.path+"dialogs/a11yhelp.js");a.on("ariaEditorHelpLabel",function(b){b.data.label=a.lang.common.editorHelp})}})}(),CKEDITOR.plugins.add("about",{requires:"dialog",init:function(a){var e=a.addCommand("about",new CKEDITOR.dialogCommand("about"));e.modes={wysiwyg:1,source:1};e.canUndo=false;e.readOnly=1;a.ui.addButton&&a.ui.addButton("About",{label:a.lang.about.title,command:"about",toolbar:"about"});CKEDITOR.dialog.add("about",this.path+"dialogs/about.js")}}),
CKEDITOR.plugins.add("basicstyles",{init:function(a){var e=0,b=function(b,d,f,h){if(h){var h=new CKEDITOR.style(h),g=c[f];g.unshift(h);a.attachStyleStateChange(h,function(b){!a.readOnly&&a.getCommand(f).setState(b)});a.addCommand(f,new CKEDITOR.styleCommand(h,{contentForms:g}));a.ui.addButton&&a.ui.addButton(b,{label:d,command:f,toolbar:"basicstyles,"+(e=e+10)})}},c={bold:["strong","b",["span",function(a){a=a.styles["font-weight"];return a=="bold"||+a>=700}]],italic:["em","i",["span",function(a){return a.styles["font-style"]==
"italic"}]],underline:["u",["span",function(a){return a.styles["text-decoration"]=="underline"}]],strike:["s","strike",["span",function(a){return a.styles["text-decoration"]=="line-through"}]],subscript:["sub"],superscript:["sup"]},f=a.config,k=a.lang.basicstyles;b("Bold",k.bold,"bold",f.coreStyles_bold);b("Italic",k.italic,"italic",f.coreStyles_italic);b("Underline",k.underline,"underline",f.coreStyles_underline);b("Strike",k.strike,"strike",f.coreStyles_strike);b("Subscript",k.subscript,"subscript",
f.coreStyles_subscript);b("Superscript",k.superscript,"superscript",f.coreStyles_superscript);a.setKeystroke([[CKEDITOR.CTRL+66,"bold"],[CKEDITOR.CTRL+73,"italic"],[CKEDITOR.CTRL+85,"underline"]])}}),CKEDITOR.config.coreStyles_bold={element:"strong",overrides:"b"},CKEDITOR.config.coreStyles_italic={element:"em",overrides:"i"},CKEDITOR.config.coreStyles_underline={element:"u"},CKEDITOR.config.coreStyles_strike={element:"s",overrides:"strike"},CKEDITOR.config.coreStyles_subscript={element:"sub"},CKEDITOR.config.coreStyles_superscript=
{element:"sup"},function(){function a(a,b,c,d){if(!a.isReadOnly()&&!a.equals(c.editable())){CKEDITOR.dom.element.setMarker(d,a,"bidi_processed",1);for(var d=a,f=c.editable();(d=d.getParent())&&!d.equals(f);)if(d.getCustomData("bidi_processed")){a.removeStyle("direction");a.removeAttribute("dir");return}d="useComputedState"in c.config?c.config.useComputedState:1;if((d?a.getComputedStyle("direction"):a.getStyle("direction")||a.hasAttribute("dir"))!=b){a.removeStyle("direction");if(d){a.removeAttribute("dir");
b!=a.getComputedStyle("direction")&&a.setAttribute("dir",b)}else a.setAttribute("dir",b);c.forceNextSelectionCheck()}}}function e(a,b,c){var d=a.getCommonAncestor(false,true),a=a.clone();a.enlarge(c==CKEDITOR.ENTER_BR?CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS:CKEDITOR.ENLARGE_BLOCK_CONTENTS);if(a.checkBoundaryOfElement(d,CKEDITOR.START)&&a.checkBoundaryOfElement(d,CKEDITOR.END)){for(var f;d&&d.type==CKEDITOR.NODE_ELEMENT&&(f=d.getParent())&&f.getChildCount()==1&&!(d.getName()in b);)d=f;return d.type==CKEDITOR.NODE_ELEMENT&&
d.getName()in b&&d}}function b(b){return{context:"p",allowedContent:{"h1 h2 h3 h4 h5 h6 table ul ol blockquote div tr p div li td":{propertiesOnly:true,attributes:"dir"}},requiredContent:"p[dir]",refresh:function(a,b){var c=a.config.useComputedState,d,c=c===void 0||c;if(!c){d=b.lastElement;for(var g=a.editable();d&&!(d.getName()in i||d.equals(g));){var f=d.getParent();if(!f)break;d=f}}d=d||b.block||b.blockLimit;if(d.equals(a.editable()))(g=a.getSelection().getRanges()[0].getEnclosedNode())&&g.type==
CKEDITOR.NODE_ELEMENT&&(d=g);if(d){c=c?d.getComputedStyle("direction"):d.getStyle("direction")||d.getAttribute("dir");a.getCommand("bidirtl").setState(c=="rtl"?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF);a.getCommand("bidiltr").setState(c=="ltr"?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)}c=(b.block||b.blockLimit||a.editable()).getDirection(1);if(c!=(a._.selDir||a.lang.dir)){a._.selDir=c;a.fire("contentDirChanged",c)}},exec:function(c){var d=c.getSelection(),i=c.config.enterMode,h=d.getRanges();if(h&&
h.length){for(var j={},l=d.createBookmarks(),h=h.createIterator(),s,t=0;s=h.getNextRange(1);){var w=s.getEnclosedNode();if(!w||w&&!(w.type==CKEDITOR.NODE_ELEMENT&&w.getName()in k))w=e(s,f,i);w&&a(w,b,c,j);var u=new CKEDITOR.dom.walker(s),x=l[t].startNode,v=l[t++].endNode;u.evaluator=function(a){var b=i==CKEDITOR.ENTER_P?"p":"div",c;if(c=a?a.type==CKEDITOR.NODE_ELEMENT:false)if(c=a.getName()in f){if(b=a.is(b))b=((b=a.getParent())?b.type==CKEDITOR.NODE_ELEMENT:false)&&a.getParent().is("blockquote");
c=!b&&a.getPosition(x)&CKEDITOR.POSITION_FOLLOWING&&(a.getPosition(v)&CKEDITOR.POSITION_PRECEDING+CKEDITOR.POSITION_CONTAINS)==CKEDITOR.POSITION_PRECEDING}return!!c};for(;w=u.next();)a(w,b,c,j);s=s.createIterator();for(s.enlargeBr=i!=CKEDITOR.ENTER_BR;w=s.getNextParagraph(i==CKEDITOR.ENTER_P?"p":"div");)a(w,b,c,j)}CKEDITOR.dom.element.clearAllMarkers(j);c.forceNextSelectionCheck();d.selectBookmarks(l);c.focus()}}}}function c(a){var b=a==d.setAttribute,c=a==d.removeAttribute,f=/\bdirection\s*:\s*(.*?)\s*(:?$|;)/;
return function(d,e){if(!this.isReadOnly()){var i;if(i=d==(b||c?"dir":"direction")||d=="style"&&(c||f.test(e))){a:{i=this;for(var h=i.getDocument().getBody().getParent();i;){if(i.equals(h)){i=false;break a}i=i.getParent()}i=true}i=!i}if(i){i=this.getDirection(1);h=a.apply(this,arguments);if(i!=this.getDirection(1)){this.getDocument().fire("dirChanged",this);return h}}}return a.apply(this,arguments)}}var f={table:1,ul:1,ol:1,blockquote:1,div:1},k={},i={};CKEDITOR.tools.extend(k,f,{tr:1,p:1,div:1,li:1});
CKEDITOR.tools.extend(i,k,{td:1});CKEDITOR.plugins.add("bidi",{init:function(a){function c(b,d,f,e,i){a.addCommand(f,new CKEDITOR.command(a,e));a.ui.addButton&&a.ui.addButton(b,{label:d,command:f,toolbar:"bidi,"+i})}if(!a.blockless){var d=a.lang.bidi;c("BidiLtr",d.ltr,"bidiltr",b("ltr"),10);c("BidiRtl",d.rtl,"bidirtl",b("rtl"),20);a.on("contentDom",function(){a.document.on("dirChanged",function(b){a.fire("dirChanged",{node:b.data,dir:b.data.getDirection(1)})})});a.on("contentDirChanged",function(b){var b=
(a.lang.dir!=b.data?"add":"remove")+"Class",c=a.ui.space(a.config.toolbarLocation);if(c)c[b]("cke_mixed_dir_content")})}}});for(var d=CKEDITOR.dom.element.prototype,j=["setStyle","removeStyle","setAttribute","removeAttribute"],h=0;h<j.length;h++)d[j[h]]=CKEDITOR.tools.override(d[j[h]],c)}(),function(){var a={exec:function(a){var b=a.getCommand("blockquote").state,c=a.getSelection(),f=c&&c.getRanges()[0];if(f){var k=c.createBookmarks();if(CKEDITOR.env.ie){var i=k[0].startNode,d=k[0].endNode,j;if(i&&
i.getParent().getName()=="blockquote")for(j=i;j=j.getNext();)if(j.type==CKEDITOR.NODE_ELEMENT&&j.isBlockBoundary()){i.move(j,true);break}if(d&&d.getParent().getName()=="blockquote")for(j=d;j=j.getPrevious();)if(j.type==CKEDITOR.NODE_ELEMENT&&j.isBlockBoundary()){d.move(j);break}}var h=f.createIterator();h.enlargeBr=a.config.enterMode!=CKEDITOR.ENTER_BR;if(b==CKEDITOR.TRISTATE_OFF){for(i=[];b=h.getNextParagraph();)i.push(b);if(i.length<1){b=a.document.createElement(a.config.enterMode==CKEDITOR.ENTER_P?
"p":"div");d=k.shift();f.insertNode(b);b.append(new CKEDITOR.dom.text("﻿",a.document));f.moveToBookmark(d);f.selectNodeContents(b);f.collapse(true);d=f.createBookmark();i.push(b);k.unshift(d)}j=i[0].getParent();f=[];for(d=0;d<i.length;d++){b=i[d];j=j.getCommonAncestor(b.getParent())}for(b={table:1,tbody:1,tr:1,ol:1,ul:1};b[j.getName()];)j=j.getParent();for(d=null;i.length>0;){for(b=i.shift();!b.getParent().equals(j);)b=b.getParent();b.equals(d)||f.push(b);d=b}for(;f.length>0;){b=f.shift();if(b.getName()==
"blockquote"){for(d=new CKEDITOR.dom.documentFragment(a.document);b.getFirst();){d.append(b.getFirst().remove());i.push(d.getLast())}d.replace(b)}else i.push(b)}f=a.document.createElement("blockquote");for(f.insertBefore(i[0]);i.length>0;){b=i.shift();f.append(b)}}else if(b==CKEDITOR.TRISTATE_ON){d=[];for(j={};b=h.getNextParagraph();){for(i=f=null;b.getParent();){if(b.getParent().getName()=="blockquote"){f=b.getParent();i=b;break}b=b.getParent()}if(f&&i&&!i.getCustomData("blockquote_moveout")){d.push(i);
CKEDITOR.dom.element.setMarker(j,i,"blockquote_moveout",true)}}CKEDITOR.dom.element.clearAllMarkers(j);b=[];i=[];for(j={};d.length>0;){h=d.shift();f=h.getParent();if(h.getPrevious())if(h.getNext()){h.breakParent(h.getParent());i.push(h.getNext())}else h.remove().insertAfter(f);else h.remove().insertBefore(f);if(!f.getCustomData("blockquote_processed")){i.push(f);CKEDITOR.dom.element.setMarker(j,f,"blockquote_processed",true)}b.push(h)}CKEDITOR.dom.element.clearAllMarkers(j);for(d=i.length-1;d>=0;d--){f=
i[d];a:{j=f;for(var h=0,g=j.getChildCount(),m=void 0;h<g&&(m=j.getChild(h));h++)if(m.type==CKEDITOR.NODE_ELEMENT&&m.isBlockBoundary()){j=false;break a}j=true}j&&f.remove()}if(a.config.enterMode==CKEDITOR.ENTER_BR)for(f=true;b.length;){h=b.shift();if(h.getName()=="div"){d=new CKEDITOR.dom.documentFragment(a.document);f&&(h.getPrevious()&&!(h.getPrevious().type==CKEDITOR.NODE_ELEMENT&&h.getPrevious().isBlockBoundary()))&&d.append(a.document.createElement("br"));for(f=h.getNext()&&!(h.getNext().type==
CKEDITOR.NODE_ELEMENT&&h.getNext().isBlockBoundary());h.getFirst();)h.getFirst().remove().appendTo(d);f&&d.append(a.document.createElement("br"));d.replace(h);f=false}}}c.selectBookmarks(k);a.focus()}},refresh:function(a,b){this.setState(a.elementPath(b.block||b.blockLimit).contains("blockquote",1)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)},context:"blockquote",allowedContent:"blockquote",requiredContent:"blockquote"};CKEDITOR.plugins.add("blockquote",{init:function(e){if(!e.blockless){e.addCommand("blockquote",
a);e.ui.addButton&&e.ui.addButton("Blockquote",{label:e.lang.blockquote.toolbar,command:"blockquote",toolbar:"blocks,10"})}}})}(),"use strict",function(){function a(a,b,c){if(!b.type)b.type="auto";if(c&&a.fire("beforePaste",b)===false||!b.dataValue&&b.dataTransfer.isEmpty())return false;if(!b.dataValue)b.dataValue="";if(CKEDITOR.env.gecko&&b.method=="drop"&&a.toolbox)a.once("afterPaste",function(){a.toolbox.focus()});return a.fire("paste",b)}function e(b){function c(){var a=b.editable();if(CKEDITOR.plugins.clipboard.isCustomCopyCutSupported){var d=
function(a){y.initPasteDataTransfer(a,b);a.data.preventDefault()};a.on("copy",d);a.on("cut",d);a.on("cut",function(){b.extractSelectedHtml()},null,null,999)}a.on(y.mainPasteEvent,function(a){y.mainPasteEvent=="beforepaste"&&z||x(a)});if(y.mainPasteEvent=="beforepaste"){a.on("paste",function(a){if(!B){e();a.data.preventDefault();x(a);h("paste")||b.openDialog("paste")}});a.on("contextmenu",i,null,null,0);a.on("beforepaste",function(a){a.data&&(!a.data.$.ctrlKey&&!a.data.$.shiftKey)&&i()},null,null,
0)}a.on("beforecut",function(){!z&&k(b)});var f;a.attachListener(CKEDITOR.env.ie?a:b.document.getDocumentElement(),"mouseup",function(){f=setTimeout(function(){v()},0)});b.on("destroy",function(){clearTimeout(f)});a.on("keyup",v)}function d(a){return{type:a,canUndo:a=="cut",startDisabled:true,exec:function(){this.type=="cut"&&k();var a;var c=this.type;if(CKEDITOR.env.ie)a=h(c);else try{a=b.document.$.execCommand(c,false,null)}catch(d){a=false}a||b.showNotification(b.lang.clipboard[this.type+"Error"]);
return a}}}function f(){return{canUndo:false,async:true,exec:function(b,c){var d=function(c,d){c&&a(b,c,!!d);b.fire("afterCommandExec",{name:"paste",command:f,returnValue:!!c})},f=this;typeof c=="string"?d({dataValue:c,method:"paste",dataTransfer:y.initPasteDataTransfer()},1):b.getClipboardData(d)}}}function e(){B=1;setTimeout(function(){B=0},100)}function i(){z=1;setTimeout(function(){z=0},10)}function h(a){var c=b.document,d=c.getBody(),f=false,e=function(){f=true};d.on(a,e);CKEDITOR.env.version>
7?c.$.execCommand(a):c.$.selection.createRange().execCommand(a);d.removeListener(a,e);return f}function k(){if(CKEDITOR.env.ie&&!CKEDITOR.env.quirks){var a=b.getSelection(),c,d,f;if(a.getType()==CKEDITOR.SELECTION_ELEMENT&&(c=a.getSelectedElement())){d=a.getRanges()[0];f=b.document.createText("");f.insertBefore(c);d.setStartBefore(f);d.setEndAfter(c);a.selectRanges([d]);setTimeout(function(){if(c.getParent()){f.remove();a.selectElement(c)}},0)}}}function j(a,c){var d=b.document,f=b.editable(),e=function(a){a.cancel()},
i;if(!d.getById("cke_pastebin")){var h=b.getSelection(),k=h.createBookmarks();CKEDITOR.env.ie&&h.root.fire("selectionchange");var l=new CKEDITOR.dom.element((CKEDITOR.env.webkit||f.is("body"))&&!CKEDITOR.env.ie?"body":"div",d);l.setAttributes({id:"cke_pastebin","data-cke-temp":"1"});var m=0,d=d.getWindow();if(CKEDITOR.env.webkit){f.append(l);l.addClass("cke_editable");if(!f.is("body")){m=f.getComputedStyle("position")!="static"?f:CKEDITOR.dom.element.get(f.$.offsetParent);m=m.getDocumentPosition().y}}else f.getAscendant(CKEDITOR.env.ie?
"body":"html",1).append(l);l.setStyles({position:"absolute",top:d.getScrollPosition().y-m+10+"px",width:"1px",height:Math.max(1,d.getViewPaneSize().height-20)+"px",overflow:"hidden",margin:0,padding:0});CKEDITOR.env.safari&&l.setStyles(CKEDITOR.tools.cssVendorPrefix("user-select","text"));if(m=l.getParent().isReadOnly()){l.setOpacity(0);l.setAttribute("contenteditable",true)}else l.setStyle(b.config.contentsLangDirection=="ltr"?"left":"right","-1000px");b.on("selectionChange",e,null,null,0);if(CKEDITOR.env.webkit||
CKEDITOR.env.gecko)i=f.once("blur",e,null,null,-100);m&&l.focus();m=new CKEDITOR.dom.range(l);m.selectNodeContents(l);var t=m.select();CKEDITOR.env.ie&&(i=f.once("blur",function(){b.lockSelection(t)}));var s=CKEDITOR.document.getWindow().getScrollPosition().y;setTimeout(function(){if(CKEDITOR.env.webkit)CKEDITOR.document.getBody().$.scrollTop=s;i&&i.removeListener();CKEDITOR.env.ie&&f.focus();h.selectBookmarks(k);l.remove();var a;if(CKEDITOR.env.webkit&&(a=l.getFirst())&&a.is&&a.hasClass("Apple-style-span"))l=
a;b.removeListener("selectionChange",e);c(l.getHtml())},0)}}function w(){if(y.mainPasteEvent=="paste"){b.fire("beforePaste",{type:"auto",method:"paste"});return false}b.focus();e();var a=b.focusManager;a.lock();if(b.editable().fire(y.mainPasteEvent)&&!h("paste")){a.unlock();return false}a.unlock();return true}function u(a){if(b.mode=="wysiwyg")switch(a.data.keyCode){case CKEDITOR.CTRL+86:case CKEDITOR.SHIFT+45:a=b.editable();e();y.mainPasteEvent=="paste"&&a.fire("beforepaste");break;case CKEDITOR.CTRL+
88:case CKEDITOR.SHIFT+46:b.fire("saveSnapshot");setTimeout(function(){b.fire("saveSnapshot")},50)}}function x(c){var d={type:"auto",method:"paste",dataTransfer:y.initPasteDataTransfer(c)};d.dataTransfer.cacheData();var f=b.fire("beforePaste",d)!==false;if(f&&y.canClipboardApiBeTrusted(d.dataTransfer,b)){c.data.preventDefault();setTimeout(function(){a(b,d)},0)}else j(c,function(c){d.dataValue=c.replace(/<span[^>]+data-cke-bookmark[^<]*?<\/span>/ig,"");f&&a(b,d)})}function v(){if(b.mode=="wysiwyg"){var a=
q("paste");b.getCommand("cut").setState(q("cut"));b.getCommand("copy").setState(q("copy"));b.getCommand("paste").setState(a);b.fire("pasteState",a)}}function q(a){if(A&&a in{paste:1,cut:1})return CKEDITOR.TRISTATE_DISABLED;if(a=="paste")return CKEDITOR.TRISTATE_OFF;var a=b.getSelection(),c=a.getRanges();return a.getType()==CKEDITOR.SELECTION_NONE||c.length==1&&c[0].collapsed?CKEDITOR.TRISTATE_DISABLED:CKEDITOR.TRISTATE_OFF}var y=CKEDITOR.plugins.clipboard,z=0,B=0,A=0;(function(){b.on("key",u);b.on("contentDom",
c);b.on("selectionChange",function(a){A=a.data.selection.getRanges()[0].checkReadOnly();v()});b.contextMenu&&b.contextMenu.addListener(function(a,b){A=b.getRanges()[0].checkReadOnly();return{cut:q("cut"),copy:q("copy"),paste:q("paste")}})})();(function(){function a(c,d,f,e,i){var h=b.lang.clipboard[d];b.addCommand(d,f);b.ui.addButton&&b.ui.addButton(c,{label:h,command:d,toolbar:"clipboard,"+e});b.addMenuItems&&b.addMenuItem(d,{label:h,command:d,group:"clipboard",order:i})}a("Cut","cut",d("cut"),10,
1);a("Copy","copy",d("copy"),20,4);a("Paste","paste",f(),30,8)})();b.getClipboardData=function(a,c){function d(a){a.removeListener();a.cancel();c(a.data)}function f(a){a.removeListener();a.cancel();k=true;c({type:h,dataValue:a.data,method:"paste"})}function e(){this.customTitle=a&&a.title}var i=false,h="auto",k=false;if(!c){c=a;a=null}b.on("paste",d,null,null,0);b.on("beforePaste",function(a){a.removeListener();i=true;h=a.data.type},null,null,1E3);if(w()===false){b.removeListener("paste",d);if(i&&
b.fire("pasteDialog",e)){b.on("pasteDialogCommit",f);b.on("dialogHide",function(a){a.removeListener();a.data.removeListener("pasteDialogCommit",f);setTimeout(function(){k||c(null)},10)})}else c(null)}}}function b(a){if(CKEDITOR.env.webkit){if(!a.match(/^[^<]*$/g)&&!a.match(/^(<div><br( ?\/)?><\/div>|<div>[^<]*<\/div>)*$/gi))return"html"}else if(CKEDITOR.env.ie){if(!a.match(/^([^<]|<br( ?\/)?>)*$/gi)&&!a.match(/^(<p>([^<]|<br( ?\/)?>)*<\/p>|(\r\n))*$/gi))return"html"}else if(CKEDITOR.env.gecko){if(!a.match(/^([^<]|<br( ?\/)?>)*$/gi))return"html"}else return"html";
return"htmlifiedtext"}function c(a,b){function c(a){return CKEDITOR.tools.repeat("</p><p>",~~(a/2))+(a%2==1?"<br>":"")}b=b.replace(/\s+/g," ").replace(/> +</g,"><").replace(/<br ?\/>/gi,"<br>");b=b.replace(/<\/?[A-Z]+>/g,function(a){return a.toLowerCase()});if(b.match(/^[^<]$/))return b;if(CKEDITOR.env.webkit&&b.indexOf("<div>")>-1){b=b.replace(/^(<div>(<br>|)<\/div>)(?!$|(<div>(<br>|)<\/div>))/g,"<br>").replace(/^(<div>(<br>|)<\/div>){2}(?!$)/g,"<div></div>");b.match(/<div>(<br>|)<\/div>/)&&(b="<p>"+
b.replace(/(<div>(<br>|)<\/div>)+/g,function(a){return c(a.split("</div><div>").length+1)})+"</p>");b=b.replace(/<\/div><div>/g,"<br>");b=b.replace(/<\/?div>/g,"")}if(CKEDITOR.env.gecko&&a.enterMode!=CKEDITOR.ENTER_BR){CKEDITOR.env.gecko&&(b=b.replace(/^<br><br>$/,"<br>"));b.indexOf("<br><br>")>-1&&(b="<p>"+b.replace(/(<br>){2,}/g,function(a){return c(a.length/4)})+"</p>")}return i(a,b)}function f(){function a(){var b={},c;for(c in CKEDITOR.dtd)c.charAt(0)!="$"&&(c!="div"&&c!="span")&&(b[c]=1);return b}
var b,c;return{get:function(d){if(d=="plain-text")return b||(b=new CKEDITOR.filter("br"));if(d=="semantic-content"){if(!(d=c)){d=new CKEDITOR.filter;d.allow({$1:{elements:a(),attributes:true,styles:false,classes:false}});d=c=d}return d}return d?new CKEDITOR.filter(d):null}}}function k(a,b,c){var b=CKEDITOR.htmlParser.fragment.fromHtml(b),d=new CKEDITOR.htmlParser.basicWriter;c.applyTo(b,true,false,a.activeEnterMode);b.writeHtml(d);return d.getHtml()}function i(a,b){a.enterMode==CKEDITOR.ENTER_BR?
b=b.replace(/(<\/p><p>)+/g,function(a){return CKEDITOR.tools.repeat("<br>",a.length/7*2)}).replace(/<\/?p>/g,""):a.enterMode==CKEDITOR.ENTER_DIV&&(b=b.replace(/<(\/)?p>/g,"<$1div>"));return b}function d(a){a.data.preventDefault();a.data.$.dataTransfer.dropEffect="none"}function j(b){var c=CKEDITOR.plugins.clipboard;b.on("contentDom",function(){function d(c,f,e){f.select();a(b,{dataTransfer:e,method:"drop"},1);e.sourceEditor.fire("saveSnapshot");e.sourceEditor.editable().extractHtmlFromRange(c);e.sourceEditor.getSelection().selectRanges([c]);
e.sourceEditor.fire("saveSnapshot")}function f(d,e){d.select();a(b,{dataTransfer:e,method:"drop"},1);c.resetDragDataTransfer()}function e(a,c,d){var f={$:a.data.$,target:a.data.getTarget()};if(c)f.dragRange=c;if(d)f.dropRange=d;b.fire(a.name,f)===false&&a.data.preventDefault()}function i(a){a.type!=CKEDITOR.NODE_ELEMENT&&(a=a.getParent());return a.getChildCount()}var h=b.editable(),k=CKEDITOR.plugins.clipboard.getDropTarget(b),j=b.ui.space("top"),w=b.ui.space("bottom");c.preventDefaultDropOnElement(j);
c.preventDefaultDropOnElement(w);h.attachListener(k,"dragstart",e);h.attachListener(b,"dragstart",c.resetDragDataTransfer,c,null,1);h.attachListener(b,"dragstart",function(a){c.initDragDataTransfer(a,b);a=c.dragRange=b.getSelection().getRanges()[0];if(CKEDITOR.env.ie&&CKEDITOR.env.version<10){c.dragStartContainerChildCount=a?i(a.startContainer):null;c.dragEndContainerChildCount=a?i(a.endContainer):null}},null,null,2);h.attachListener(k,"dragend",e);h.attachListener(b,"dragend",c.initDragDataTransfer,
c,null,1);h.attachListener(b,"dragend",c.resetDragDataTransfer,c,null,100);h.attachListener(k,"dragover",function(a){var b=a.data.getTarget();b&&b.is&&b.is("html")?a.data.preventDefault():CKEDITOR.env.ie&&(CKEDITOR.plugins.clipboard.isFileApiSupported&&a.data.$.dataTransfer.types.contains("Files"))&&a.data.preventDefault()});h.attachListener(k,"drop",function(a){a.data.preventDefault();var d=a.data.getTarget();if(!d.isReadOnly()||d.type==CKEDITOR.NODE_ELEMENT&&d.is("html")){var d=c.getRangeAtDropPosition(a,
b),f=c.dragRange;d&&e(a,f,d)}});h.attachListener(b,"drop",c.initDragDataTransfer,c,null,1);h.attachListener(b,"drop",function(a){if(a=a.data){var e=a.dropRange,i=a.dragRange,h=a.dataTransfer;h.getTransferType(b)==CKEDITOR.DATA_TRANSFER_INTERNAL?setTimeout(function(){c.internalDrop(i,e,h,b)},0):h.getTransferType(b)==CKEDITOR.DATA_TRANSFER_CROSS_EDITORS?d(i,e,h):f(e,h)}},null,null,9999)})}CKEDITOR.plugins.add("clipboard",{requires:"dialog",init:function(a){var d,i=f();a.config.forcePasteAsPlainText?
d="plain-text":a.config.pasteFilter?d=a.config.pasteFilter:CKEDITOR.env.webkit&&!("pasteFilter"in a.config)&&(d="semantic-content");a.pasteFilter=i.get(d);e(a);j(a);CKEDITOR.dialog.add("paste",CKEDITOR.getUrl(this.path+"dialogs/paste.js"));a.on("paste",function(b){if(!b.data.dataTransfer)b.data.dataTransfer=new CKEDITOR.plugins.clipboard.dataTransfer;if(!b.data.dataValue){var c=b.data.dataTransfer,d=c.getData("text/html");if(d){b.data.dataValue=d;b.data.type="html"}else if(d=c.getData("text/plain")){b.data.dataValue=
a.editable().transformPlainTextToHtml(d);b.data.type="text"}}},null,null,1);a.on("paste",function(a){var b=a.data.dataValue,c=CKEDITOR.dtd.$block;if(b.indexOf("Apple-")>-1){b=b.replace(/<span class="Apple-converted-space">&nbsp;<\/span>/gi," ");a.data.type!="html"&&(b=b.replace(/<span class="Apple-tab-span"[^>]*>([^<]*)<\/span>/gi,function(a,b){return b.replace(/\t/g,"&nbsp;&nbsp; &nbsp;")}));if(b.indexOf('<br class="Apple-interchange-newline">')>-1){a.data.startsWithEOL=1;a.data.preSniffing="html";
b=b.replace(/<br class="Apple-interchange-newline">/,"")}b=b.replace(/(<[^>]+) class="Apple-[^"]*"/gi,"$1")}if(b.match(/^<[^<]+cke_(editable|contents)/i)){var d,f,e=new CKEDITOR.dom.element("div");for(e.setHtml(b);e.getChildCount()==1&&(d=e.getFirst())&&d.type==CKEDITOR.NODE_ELEMENT&&(d.hasClass("cke_editable")||d.hasClass("cke_contents"));)e=f=d;f&&(b=f.getHtml().replace(/<br>$/i,""))}CKEDITOR.env.ie?b=b.replace(/^&nbsp;(?: |\r\n)?<(\w+)/g,function(b,d){if(d.toLowerCase()in c){a.data.preSniffing=
"html";return"<"+d}return b}):CKEDITOR.env.webkit?b=b.replace(/<\/(\w+)><div><br><\/div>$/,function(b,d){if(d in c){a.data.endsWithEOL=1;return"</"+d+">"}return b}):CKEDITOR.env.gecko&&(b=b.replace(/(\s)<br>$/,"$1"));a.data.dataValue=b},null,null,3);a.on("paste",function(d){var d=d.data,f=d.type,e=d.dataValue,h,j=a.config.clipboard_defaultContentType||"html",t=d.dataTransfer.getTransferType(a);h=f=="html"||d.preSniffing=="html"?"html":b(e);h=="htmlifiedtext"&&(e=c(a.config,e));f=="text"&&h=="html"?
e=k(a,e,i.get("plain-text")):t==CKEDITOR.DATA_TRANSFER_EXTERNAL&&(a.pasteFilter&&!d.dontFilter)&&(e=k(a,e,a.pasteFilter));d.startsWithEOL&&(e='<br data-cke-eol="1">'+e);d.endsWithEOL&&(e=e+'<br data-cke-eol="1">');f=="auto"&&(f=h=="html"||j=="html"?"html":"text");d.type=f;d.dataValue=e;delete d.preSniffing;delete d.startsWithEOL;delete d.endsWithEOL},null,null,6);a.on("paste",function(b){b=b.data;if(b.dataValue){a.insertHtml(b.dataValue,b.type,b.range);setTimeout(function(){a.fire("afterPaste")},
0)}},null,null,1E3);a.on("pasteDialog",function(b){setTimeout(function(){a.openDialog("paste",b.data)},0)})}});CKEDITOR.plugins.clipboard={isCustomCopyCutSupported:!CKEDITOR.env.ie&&!CKEDITOR.env.iOS,isCustomDataTypesSupported:!CKEDITOR.env.ie,isFileApiSupported:!CKEDITOR.env.ie||CKEDITOR.env.version>9,mainPasteEvent:CKEDITOR.env.ie&&!CKEDITOR.env.edge?"beforepaste":"paste",canClipboardApiBeTrusted:function(a,b){return a.getTransferType(b)!=CKEDITOR.DATA_TRANSFER_EXTERNAL||CKEDITOR.env.chrome&&!a.isEmpty()||
CKEDITOR.env.gecko&&(a.getData("text/html")||a.getFilesCount())?true:false},getDropTarget:function(a){var b=a.editable();return CKEDITOR.env.ie&&CKEDITOR.env.version<9||b.isInline()?b:a.document},fixSplitNodesAfterDrop:function(a,b,c,d){function f(a,c,d){var e=a;e.type==CKEDITOR.NODE_TEXT&&(e=a.getParent());if(e.equals(c)&&d!=c.getChildCount()){a=b;c=a.startContainer.getChild(a.startOffset-1);d=a.startContainer.getChild(a.startOffset);if(c&&c.type==CKEDITOR.NODE_TEXT&&d&&d.type==CKEDITOR.NODE_TEXT){e=
c.getLength();c.setText(c.getText()+d.getText());d.remove();a.setStart(c,e);a.collapse(true)}return true}}var e=b.startContainer;!(typeof d!="number"||typeof c!="number")&&(e.type==CKEDITOR.NODE_ELEMENT&&!f(a.startContainer,e,c))&&f(a.endContainer,e,d)},isDropRangeAffectedByDragRange:function(a,b){var c=b.startContainer,d=b.endOffset;return a.endContainer.equals(c)&&a.endOffset<=d||a.startContainer.getParent().equals(c)&&a.startContainer.getIndex()<d||a.endContainer.getParent().equals(c)&&a.endContainer.getIndex()<
d?true:false},internalDrop:function(b,c,d,f){var e=CKEDITOR.plugins.clipboard,i=f.editable(),h,k;f.fire("saveSnapshot");f.fire("lockSnapshot",{dontUpdate:1});CKEDITOR.env.ie&&CKEDITOR.env.version<10&&this.fixSplitNodesAfterDrop(b,c,e.dragStartContainerChildCount,e.dragEndContainerChildCount);(k=this.isDropRangeAffectedByDragRange(b,c))||(h=b.createBookmark(false));e=c.clone().createBookmark(false);k&&(h=b.createBookmark(false));b=h.startNode;k=h.endNode;var j=e.startNode;if(k&&b.getPosition(j)==CKEDITOR.POSITION_PRECEDING&&
k.getPosition(j)==CKEDITOR.POSITION_FOLLOWING){f.getSelection().selectRanges([c]);b.remove();k.remove();j.remove()}else{b=f.createRange();b.moveToBookmark(h);i.extractHtmlFromRange(b,1);c=f.createRange();c.moveToBookmark(e);a(f,{dataTransfer:d,method:"drop",range:c},1)}f.fire("unlockSnapshot")},getRangeAtDropPosition:function(a,b){var c=a.data.$,d=c.clientX,f=c.clientY,e=b.getSelection(true).getRanges()[0],i=b.createRange();if(a.data.testRange)return a.data.testRange;if(document.caretRangeFromPoint){c=
b.document.$.caretRangeFromPoint(d,f);i.setStart(CKEDITOR.dom.node(c.startContainer),c.startOffset);i.collapse(true)}else if(c.rangeParent){i.setStart(CKEDITOR.dom.node(c.rangeParent),c.rangeOffset);i.collapse(true)}else{if(CKEDITOR.env.ie&&CKEDITOR.env.version>8&&e&&b.editable().hasFocus)return e;if(document.body.createTextRange){b.focus();c=b.document.getBody().$.createTextRange();try{for(var h=false,k=0;k<20&&!h;k++){if(!h)try{c.moveToPoint(d,f-k);h=true}catch(j){}if(!h)try{c.moveToPoint(d,f+k);
h=true}catch(u){}}if(h){var x="cke-temp-"+(new Date).getTime();c.pasteHTML('<span id="'+x+'">​</span>');var v=b.document.getById(x);i.moveToPosition(v,CKEDITOR.POSITION_BEFORE_START);v.remove()}else{var q=b.document.$.elementFromPoint(d,f),y=new CKEDITOR.dom.element(q),z;if(!y.equals(b.editable())&&y.getName()!="html"){z=y.getClientRect();d<z.left?i.setStartAt(y,CKEDITOR.POSITION_AFTER_START):i.setStartAt(y,CKEDITOR.POSITION_BEFORE_END);i.collapse(true)}else return e&&e.startContainer&&!e.startContainer.equals(b.editable())?
e:null}}catch(B){return null}}else return null}return i},initDragDataTransfer:function(a,b){var c=a.data.$?a.data.$.dataTransfer:null,d=new this.dataTransfer(c,b);c?this.dragData&&d.id==this.dragData.id?d=this.dragData:this.dragData=d:this.dragData?d=this.dragData:this.dragData=d;a.data.dataTransfer=d},resetDragDataTransfer:function(){this.dragData=null},initPasteDataTransfer:function(a,b){if(this.isCustomCopyCutSupported&&a&&a.data&&a.data.$){var c=new this.dataTransfer(a.data.$.clipboardData,b);
if(this.copyCutData&&c.id==this.copyCutData.id){c=this.copyCutData;c.$=a.data.$.clipboardData}else this.copyCutData=c;return c}return new this.dataTransfer(null,b)},preventDefaultDropOnElement:function(a){a&&a.on("dragover",d)}};var h=CKEDITOR.plugins.clipboard.isCustomDataTypesSupported?"cke/id":"Text";CKEDITOR.plugins.clipboard.dataTransfer=function(a,b){if(a)this.$=a;this._={metaRegExp:/^<meta.*?>/,bodyRegExp:/<body(?:[\s\S]*?)>([\s\S]*)<\/body>/,fragmentRegExp:/<\!--(?:Start|End)Fragment--\>/g,
data:{},files:[],normalizeType:function(a){a=a.toLowerCase();return a=="text"||a=="text/plain"?"Text":a=="url"?"URL":a}};this.id=this.getData(h);if(!this.id)this.id=h=="Text"?"":"cke-"+CKEDITOR.tools.getUniqueId();if(h!="Text")try{this.$.setData(h,this.id)}catch(c){}if(b){this.sourceEditor=b;this.setData("text/html",b.getSelectedHtml(1));h!="Text"&&!this.getData("text/plain")&&this.setData("text/plain",b.getSelection().getSelectedText())}};CKEDITOR.DATA_TRANSFER_INTERNAL=1;CKEDITOR.DATA_TRANSFER_CROSS_EDITORS=
2;CKEDITOR.DATA_TRANSFER_EXTERNAL=3;CKEDITOR.plugins.clipboard.dataTransfer.prototype={getData:function(a){var a=this._.normalizeType(a),b=this._.data[a];if(b===void 0||b===null||b==="")try{b=this.$.getData(a)}catch(c){}if(b===void 0||b===null||b==="")b="";if(a=="text/html"){b=b.replace(this._.metaRegExp,"");if((a=this._.bodyRegExp.exec(b))&&a.length){b=a[1];b=b.replace(this._.fragmentRegExp,"")}}else a=="Text"&&(CKEDITOR.env.gecko&&this.getFilesCount()&&b.substring(0,7)=="file://")&&(b="");return b},
setData:function(a,b){a=this._.normalizeType(a);this._.data[a]=b;if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported||!(a!="URL"&&a!="Text")){if(h=="Text"&&a=="Text")this.id=b;try{this.$.setData(a,b)}catch(c){}}},getTransferType:function(a){return this.sourceEditor?this.sourceEditor==a?CKEDITOR.DATA_TRANSFER_INTERNAL:CKEDITOR.DATA_TRANSFER_CROSS_EDITORS:CKEDITOR.DATA_TRANSFER_EXTERNAL},cacheData:function(){function a(c){var c=b._.normalizeType(c),d=b.getData(c);d&&(b._.data[c]=d)}if(this.$){var b=
this,c,d;if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported){if(this.$.types)for(c=0;c<this.$.types.length;c++)a(this.$.types[c])}else{a("Text");a("URL")}d=this._getImageFromClipboard();if(this.$&&this.$.files||d){this._.files=[];for(c=0;c<this.$.files.length;c++)this._.files.push(this.$.files[c]);this._.files.length===0&&d&&this._.files.push(d)}}},getFilesCount:function(){return this._.files.length?this._.files.length:this.$&&this.$.files&&this.$.files.length?this.$.files.length:this._getImageFromClipboard()?
1:0},getFile:function(a){return this._.files.length?this._.files[a]:this.$&&this.$.files&&this.$.files.length?this.$.files[a]:a===0?this._getImageFromClipboard():void 0},isEmpty:function(){var a={},b;if(this.getFilesCount())return false;for(b in this._.data)a[b]=1;if(this.$)if(CKEDITOR.plugins.clipboard.isCustomDataTypesSupported){if(this.$.types)for(var c=0;c<this.$.types.length;c++)a[this.$.types[c]]=1}else{a.Text=1;a.URL=1}h!="Text"&&(a[h]=0);for(b in a)if(a[b]&&this.getData(b)!=="")return false;
return true},_getImageFromClipboard:function(){var a;if(this.$&&this.$.items&&this.$.items[0])try{if((a=this.$.items[0].getAsFile())&&a.type)return a}catch(b){}}}}(),function(){var a='<a id="{id}" class="cke_button cke_button__{name} cke_button_{state} {cls}"'+(CKEDITOR.env.gecko&&!CKEDITOR.env.hc?"":" href=\"javascript:void('{titleJs}')\"")+' title="{title}" tabindex="-1" hidefocus="true" role="button" aria-labelledby="{id}_label" aria-haspopup="{hasArrow}" aria-disabled="{ariaDisabled}"';CKEDITOR.env.gecko&&
CKEDITOR.env.mac&&(a=a+' onkeypress="return false;"');CKEDITOR.env.gecko&&(a=a+' onblur="this.style.cssText = this.style.cssText;"');var a=a+(' onkeydown="return CKEDITOR.tools.callFunction({keydownFn},event);" onfocus="return CKEDITOR.tools.callFunction({focusFn},event);" '+(CKEDITOR.env.ie?'onclick="return false;" onmouseup':"onclick")+'="CKEDITOR.tools.callFunction({clickFn},this);return false;"><span class="cke_button_icon cke_button__{iconName}_icon" style="{style}"'),a=a+'>&nbsp;</span><span id="{id}_label" class="cke_button_label cke_button__{name}_label" aria-hidden="false">{label}</span>{arrowHtml}</a>',
e=CKEDITOR.addTemplate("buttonArrow",'<span class="cke_button_arrow">'+(CKEDITOR.env.hc?"&#9660;":"")+"</span>"),b=CKEDITOR.addTemplate("button",a);CKEDITOR.plugins.add("button",{beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_BUTTON,CKEDITOR.ui.button.handler)}});CKEDITOR.UI_BUTTON="button";CKEDITOR.ui.button=function(a){CKEDITOR.tools.extend(this,a,{title:a.label,click:a.click||function(b){b.execCommand(a.command)}});this._={}};CKEDITOR.ui.button.handler={create:function(a){return new CKEDITOR.ui.button(a)}};
CKEDITOR.ui.button.prototype={render:function(a,f){function k(){var b=a.mode;if(b){b=this.modes[b]?n[b]!==void 0?n[b]:CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED;b=a.readOnly&&!this.readOnly?CKEDITOR.TRISTATE_DISABLED:b;this.setState(b);this.refresh&&this.refresh()}}var i=CKEDITOR.env,d=this._.id=CKEDITOR.tools.getNextId(),j="",h=this.command,g;this._.editor=a;var m={id:d,button:this,editor:a,focus:function(){CKEDITOR.document.getById(d).focus()},execute:function(){this.button.click(a)},attach:function(a){this.button.attach(a)}},
p=CKEDITOR.tools.addFunction(function(a){if(m.onkey){a=new CKEDITOR.dom.event(a);return m.onkey(m,a.getKeystroke())!==false}}),r=CKEDITOR.tools.addFunction(function(a){var b;m.onfocus&&(b=m.onfocus(m,new CKEDITOR.dom.event(a))!==false);return b}),o=0;m.clickFn=g=CKEDITOR.tools.addFunction(function(){if(o){a.unlockSelection(1);o=0}m.execute();i.iOS&&a.focus()});if(this.modes){var n={};a.on("beforeModeUnload",function(){if(a.mode&&this._.state!=CKEDITOR.TRISTATE_DISABLED)n[a.mode]=this._.state},this);
a.on("activeFilterChange",k,this);a.on("mode",k,this);!this.readOnly&&a.on("readOnly",k,this)}else if(h)if(h=a.getCommand(h)){h.on("state",function(){this.setState(h.state)},this);j=j+(h.state==CKEDITOR.TRISTATE_ON?"on":h.state==CKEDITOR.TRISTATE_DISABLED?"disabled":"off")}if(this.directional)a.on("contentDirChanged",function(b){var d=CKEDITOR.document.getById(this._.id),f=d.getFirst(),b=b.data;b!=a.lang.dir?d.addClass("cke_"+b):d.removeClass("cke_ltr").removeClass("cke_rtl");f.setAttribute("style",
CKEDITOR.skin.getIconStyle(s,b=="rtl",this.icon,this.iconOffset))},this);h||(j=j+"off");var l=this.name||this.command,s=l;if(this.icon&&!/\./.test(this.icon)){s=this.icon;this.icon=null}j={id:d,name:l,iconName:s,label:this.label,cls:this.className||"",state:j,ariaDisabled:j=="disabled"?"true":"false",title:this.title,titleJs:i.gecko&&!i.hc?"":(this.title||"").replace("'",""),hasArrow:this.hasArrow?"true":"false",keydownFn:p,focusFn:r,clickFn:g,style:CKEDITOR.skin.getIconStyle(s,a.lang.dir=="rtl",
this.icon,this.iconOffset),arrowHtml:this.hasArrow?e.output():""};b.output(j,f);if(this.onRender)this.onRender();return m},setState:function(a){if(this._.state==a)return false;this._.state=a;var b=CKEDITOR.document.getById(this._.id);if(b){b.setState(a,"cke_button");a==CKEDITOR.TRISTATE_DISABLED?b.setAttribute("aria-disabled",true):b.removeAttribute("aria-disabled");if(this.hasArrow){a=a==CKEDITOR.TRISTATE_ON?this._.editor.lang.button.selectedLabel.replace(/%1/g,this.label):this.label;CKEDITOR.document.getById(this._.id+
"_label").setText(a)}else a==CKEDITOR.TRISTATE_ON?b.setAttribute("aria-pressed",true):b.removeAttribute("aria-pressed");return true}return false},getState:function(){return this._.state},toFeature:function(a){if(this._.feature)return this._.feature;var b=this;!this.allowedContent&&(!this.requiredContent&&this.command)&&(b=a.getCommand(this.command)||b);return this._.feature=b}};CKEDITOR.ui.prototype.addButton=function(a,b){this.add(a,CKEDITOR.UI_BUTTON,b)}}(),CKEDITOR.plugins.add("panelbutton",{requires:"button",
onLoad:function(){function a(a){var b=this._;if(b.state!=CKEDITOR.TRISTATE_DISABLED){this.createPanel(a);b.on?b.panel.hide():b.panel.showBlock(this._.id,this.document.getById(this._.id),4)}}CKEDITOR.ui.panelButton=CKEDITOR.tools.createClass({base:CKEDITOR.ui.button,$:function(e){var b=e.panel||{};delete e.panel;this.base(e);this.document=b.parent&&b.parent.getDocument()||CKEDITOR.document;b.block={attributes:b.attributes};this.hasArrow=b.toolbarRelated=true;this.click=a;this._={panelDefinition:b}},
statics:{handler:{create:function(a){return new CKEDITOR.ui.panelButton(a)}}},proto:{createPanel:function(a){var b=this._;if(!b.panel){var c=this._.panelDefinition,f=this._.panelDefinition.block,k=c.parent||CKEDITOR.document.getBody(),i=this._.panel=new CKEDITOR.ui.floatPanel(a,k,c),c=i.addBlock(b.id,f),d=this;i.onShow=function(){d.className&&this.element.addClass(d.className+"_panel");d.setState(CKEDITOR.TRISTATE_ON);b.on=1;d.editorFocus&&a.focus();if(d.onOpen)d.onOpen()};i.onHide=function(c){d.className&&
this.element.getFirst().removeClass(d.className+"_panel");d.setState(d.modes&&d.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);b.on=0;if(!c&&d.onClose)d.onClose()};i.onEscape=function(){i.hide(1);d.document.getById(b.id).focus()};if(this.onBlock)this.onBlock(i,c);c.onHide=function(){b.on=0;d.setState(CKEDITOR.TRISTATE_OFF)}}}}})},beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_PANELBUTTON,CKEDITOR.ui.panelButton.handler)}}),CKEDITOR.UI_PANELBUTTON="panelbutton",function(){CKEDITOR.plugins.add("panel",
{beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_PANEL,CKEDITOR.ui.panel.handler)}});CKEDITOR.UI_PANEL="panel";CKEDITOR.ui.panel=function(a,b){b&&CKEDITOR.tools.extend(this,b);CKEDITOR.tools.extend(this,{className:"",css:[]});this.id=CKEDITOR.tools.getNextId();this.document=a;this.isFramed=this.forceIFrame||this.css.length;this._={blocks:{}}};CKEDITOR.ui.panel.handler={create:function(a){return new CKEDITOR.ui.panel(a)}};var a=CKEDITOR.addTemplate("panel",'<div lang="{langCode}" id="{id}" dir={dir} class="cke cke_reset_all {editorId} cke_panel cke_panel {cls} cke_{dir}" style="z-index:{z-index}" role="presentation">{frame}</div>'),
e=CKEDITOR.addTemplate("panel-frame",'<iframe id="{id}" class="cke_panel_frame" role="presentation" frameborder="0" src="{src}"></iframe>'),b=CKEDITOR.addTemplate("panel-frame-inner",'<!DOCTYPE html><html class="cke_panel_container {env}" dir="{dir}" lang="{langCode}"><head>{css}</head><body class="cke_{dir}" style="margin:0;padding:0" onload="{onload}"></body></html>');CKEDITOR.ui.panel.prototype={render:function(c,f){this.getHolderElement=function(){var a=this._.holder;if(!a){if(this.isFramed){var a=
this.document.getById(this.id+"_frame"),c=a.getParent(),a=a.getFrameDocument();CKEDITOR.env.iOS&&c.setStyles({overflow:"scroll","-webkit-overflow-scrolling":"touch"});c=CKEDITOR.tools.addFunction(CKEDITOR.tools.bind(function(){this.isLoaded=true;if(this.onLoad)this.onLoad()},this));a.write(b.output(CKEDITOR.tools.extend({css:CKEDITOR.tools.buildStyleHtml(this.css),onload:"window.parent.CKEDITOR.tools.callFunction("+c+");"},k)));a.getWindow().$.CKEDITOR=CKEDITOR;a.on("keydown",function(a){var b=a.data.getKeystroke(),
c=this.document.getById(this.id).getAttribute("dir");this._.onKeyDown&&this._.onKeyDown(b)===false?a.data.preventDefault():(b==27||b==(c=="rtl"?39:37))&&this.onEscape&&this.onEscape(b)===false&&a.data.preventDefault()},this);a=a.getBody();a.unselectable();CKEDITOR.env.air&&CKEDITOR.tools.callFunction(c)}else a=this.document.getById(this.id);this._.holder=a}return a};var k={editorId:c.id,id:this.id,langCode:c.langCode,dir:c.lang.dir,cls:this.className,frame:"",env:CKEDITOR.env.cssClass,"z-index":c.config.baseFloatZIndex+
1};if(this.isFramed){var i=CKEDITOR.env.air?"javascript:void(0)":CKEDITOR.env.ie?"javascript:void(function(){"+encodeURIComponent("document.open();("+CKEDITOR.tools.fixDomain+")();document.close();")+"}())":"";k.frame=e.output({id:this.id+"_frame",src:i})}i=a.output(k);f&&f.push(i);return i},addBlock:function(a,b){b=this._.blocks[a]=b instanceof CKEDITOR.ui.panel.block?b:new CKEDITOR.ui.panel.block(this.getHolderElement(),b);this._.currentBlock||this.showBlock(a);return b},getBlock:function(a){return this._.blocks[a]},
showBlock:function(a){var a=this._.blocks[a],b=this._.currentBlock,e=!this.forceIFrame||CKEDITOR.env.ie?this._.holder:this.document.getById(this.id+"_frame");b&&b.hide();this._.currentBlock=a;CKEDITOR.fire("ariaWidget",e);a._.focusIndex=-1;this._.onKeyDown=a.onKeyDown&&CKEDITOR.tools.bind(a.onKeyDown,a);a.show();return a},destroy:function(){this.element&&this.element.remove()}};CKEDITOR.ui.panel.block=CKEDITOR.tools.createClass({$:function(a,b){this.element=a.append(a.getDocument().createElement("div",
{attributes:{tabindex:-1,"class":"cke_panel_block"},styles:{display:"none"}}));b&&CKEDITOR.tools.extend(this,b);this.element.setAttributes({role:this.attributes.role||"presentation","aria-label":this.attributes["aria-label"],title:this.attributes.title||this.attributes["aria-label"]});this.keys={};this._.focusIndex=-1;this.element.disableContextMenu()},_:{markItem:function(a){if(a!=-1){a=this.element.getElementsByTag("a").getItem(this._.focusIndex=a);CKEDITOR.env.webkit&&a.getDocument().getWindow().focus();
a.focus();this.onMark&&this.onMark(a)}}},proto:{show:function(){this.element.setStyle("display","")},hide:function(){(!this.onHide||this.onHide.call(this)!==true)&&this.element.setStyle("display","none")},onKeyDown:function(a,b){var e=this.keys[a];switch(e){case "next":for(var i=this._.focusIndex,e=this.element.getElementsByTag("a"),d;d=e.getItem(++i);)if(d.getAttribute("_cke_focus")&&d.$.offsetWidth){this._.focusIndex=i;d.focus();break}if(!d&&!b){this._.focusIndex=-1;return this.onKeyDown(a,1)}return false;
case "prev":i=this._.focusIndex;for(e=this.element.getElementsByTag("a");i>0&&(d=e.getItem(--i));){if(d.getAttribute("_cke_focus")&&d.$.offsetWidth){this._.focusIndex=i;d.focus();break}d=null}if(!d&&!b){this._.focusIndex=e.count();return this.onKeyDown(a,1)}return false;case "click":case "mouseup":i=this._.focusIndex;(d=i>=0&&this.element.getElementsByTag("a").getItem(i))&&(d.$[e]?d.$[e]():d.$["on"+e]());return false}return true}}})}(),CKEDITOR.plugins.add("floatpanel",{requires:"panel"}),function(){function a(a,
c,f,k,i){var i=CKEDITOR.tools.genKey(c.getUniqueId(),f.getUniqueId(),a.lang.dir,a.uiColor||"",k.css||"",i||""),d=e[i];if(!d){d=e[i]=new CKEDITOR.ui.panel(c,k);d.element=f.append(CKEDITOR.dom.element.createFromHtml(d.render(a),c));d.element.setStyles({display:"none",position:"absolute"})}return d}var e={};CKEDITOR.ui.floatPanel=CKEDITOR.tools.createClass({$:function(b,c,f,e){function i(){g.hide()}f.forceIFrame=1;f.toolbarRelated&&b.elementMode==CKEDITOR.ELEMENT_MODE_INLINE&&(c=CKEDITOR.document.getById("cke_"+
b.name));var d=c.getDocument(),e=a(b,d,c,f,e||0),j=e.element,h=j.getFirst(),g=this;j.disableContextMenu();this.element=j;this._={editor:b,panel:e,parentElement:c,definition:f,document:d,iframe:h,children:[],dir:b.lang.dir};b.on("mode",i);b.on("resize",i);if(!CKEDITOR.env.iOS)d.getWindow().on("resize",i)},proto:{addBlock:function(a,c){return this._.panel.addBlock(a,c)},addListBlock:function(a,c){return this._.panel.addListBlock(a,c)},getBlock:function(a){return this._.panel.getBlock(a)},showBlock:function(a,
c,f,e,i,d){var j=this._.panel,h=j.showBlock(a);this.allowBlur(false);a=this._.editor.editable();this._.returnFocus=a.hasFocus?a:new CKEDITOR.dom.element(CKEDITOR.document.$.activeElement);this._.hideTimeout=0;var g=this.element,a=this._.iframe,a=CKEDITOR.env.ie&&!CKEDITOR.env.edge?a:new CKEDITOR.dom.window(a.$.contentWindow),m=g.getDocument(),p=this._.parentElement.getPositionedAncestor(),r=c.getDocumentPosition(m),m=p?p.getDocumentPosition(m):{x:0,y:0},o=this._.dir=="rtl",n=r.x+(e||0)-m.x,l=r.y+
(i||0)-m.y;if(o&&(f==1||f==4))n=n+c.$.offsetWidth;else if(!o&&(f==2||f==3))n=n+(c.$.offsetWidth-1);if(f==3||f==4)l=l+(c.$.offsetHeight-1);this._.panel._.offsetParentId=c.getId();g.setStyles({top:l+"px",left:0,display:""});g.setOpacity(0);g.getFirst().removeStyle("width");this._.editor.focusManager.add(a);if(!this._.blurSet){CKEDITOR.event.useCapture=true;a.on("blur",function(a){function b(){delete this._.returnFocus;this.hide()}if(this.allowBlur()&&a.data.getPhase()==CKEDITOR.EVENT_PHASE_AT_TARGET&&
this.visible&&!this._.activeChild)if(CKEDITOR.env.iOS){if(!this._.hideTimeout)this._.hideTimeout=CKEDITOR.tools.setTimeout(b,0,this)}else b.call(this)},this);a.on("focus",function(){this._.focused=true;this.hideChild();this.allowBlur(true)},this);if(CKEDITOR.env.iOS){a.on("touchstart",function(){clearTimeout(this._.hideTimeout)},this);a.on("touchend",function(){this._.hideTimeout=0;this.focus()},this)}CKEDITOR.event.useCapture=false;this._.blurSet=1}j.onEscape=CKEDITOR.tools.bind(function(a){if(this.onEscape&&
this.onEscape(a)===false)return false},this);CKEDITOR.tools.setTimeout(function(){var a=CKEDITOR.tools.bind(function(){g.removeStyle("width");if(h.autoSize){var a=h.element.getDocument(),a=(CKEDITOR.env.webkit?h.element:a.getBody()).$.scrollWidth;CKEDITOR.env.ie&&(CKEDITOR.env.quirks&&a>0)&&(a=a+((g.$.offsetWidth||0)-(g.$.clientWidth||0)+3));g.setStyle("width",a+10+"px");a=h.element.$.scrollHeight;CKEDITOR.env.ie&&(CKEDITOR.env.quirks&&a>0)&&(a=a+((g.$.offsetHeight||0)-(g.$.clientHeight||0)+3));g.setStyle("height",
a+"px");j._.currentBlock.element.setStyle("display","none").removeStyle("display")}else g.removeStyle("height");o&&(n=n-g.$.offsetWidth);g.setStyle("left",n+"px");var b=j.element.getWindow(),a=g.$.getBoundingClientRect(),b=b.getViewPaneSize(),c=a.width||a.right-a.left,f=a.height||a.bottom-a.top,e=o?a.right:b.width-a.left,i=o?b.width-a.right:a.left;o?e<c&&(n=i>c?n+c:b.width>c?n-a.left:n-a.right+b.width):e<c&&(n=i>c?n-c:b.width>c?n-a.right+b.width:n-a.left);c=a.top;b.height-a.top<f&&(l=c>f?l-f:b.height>
f?l-a.bottom+b.height:l-a.top);if(CKEDITOR.env.ie){b=a=new CKEDITOR.dom.element(g.$.offsetParent);b.getName()=="html"&&(b=b.getDocument().getBody());b.getComputedStyle("direction")=="rtl"&&(n=CKEDITOR.env.ie8Compat?n-g.getDocument().getDocumentElement().$.scrollLeft*2:n-(a.$.scrollWidth-a.$.clientWidth))}var a=g.getFirst(),k;(k=a.getCustomData("activePanel"))&&k.onHide&&k.onHide.call(this,1);a.setCustomData("activePanel",this);g.setStyles({top:l+"px",left:n+"px"});g.setOpacity(1);d&&d()},this);j.isLoaded?
a():j.onLoad=a;CKEDITOR.tools.setTimeout(function(){var a=CKEDITOR.env.webkit&&CKEDITOR.document.getWindow().getScrollPosition().y;this.focus();h.element.focus();if(CKEDITOR.env.webkit)CKEDITOR.document.getBody().$.scrollTop=a;this.allowBlur(true);this._.editor.fire("panelShow",this)},0,this)},CKEDITOR.env.air?200:0,this);this.visible=1;this.onShow&&this.onShow.call(this)},focus:function(){if(CKEDITOR.env.webkit){var a=CKEDITOR.document.getActive();a&&!a.equals(this._.iframe)&&a.$.blur()}(this._.lastFocused||
this._.iframe.getFrameDocument().getWindow()).focus()},blur:function(){var a=this._.iframe.getFrameDocument().getActive();a&&a.is("a")&&(this._.lastFocused=a)},hide:function(a){if(this.visible&&(!this.onHide||this.onHide.call(this)!==true)){this.hideChild();CKEDITOR.env.gecko&&this._.iframe.getFrameDocument().$.activeElement.blur();this.element.setStyle("display","none");this.visible=0;this.element.getFirst().removeCustomData("activePanel");if(a=a&&this._.returnFocus){CKEDITOR.env.webkit&&a.type&&
a.getWindow().$.focus();a.focus()}delete this._.lastFocused;this._.editor.fire("panelHide",this)}},allowBlur:function(a){var c=this._.panel;if(a!==void 0)c.allowBlur=a;return c.allowBlur},showAsChild:function(a,c,f,e,i,d){if(!(this._.activeChild==a&&a._.panel._.offsetParentId==f.getId())){this.hideChild();a.onHide=CKEDITOR.tools.bind(function(){CKEDITOR.tools.setTimeout(function(){this._.focused||this.hide()},0,this)},this);this._.activeChild=a;this._.focused=false;a.showBlock(c,f,e,i,d);this.blur();
(CKEDITOR.env.ie7Compat||CKEDITOR.env.ie6Compat)&&setTimeout(function(){a.element.getChild(0).$.style.cssText+=""},100)}},hideChild:function(a){var c=this._.activeChild;if(c){delete c.onHide;delete this._.activeChild;c.hide();a&&this.focus()}}}});CKEDITOR.on("instanceDestroyed",function(){var a=CKEDITOR.tools.isEmpty(CKEDITOR.instances),c;for(c in e){var f=e[c];a?f.destroy():f.element.hide()}a&&(e={})})}(),CKEDITOR.plugins.add("colorbutton",{requires:"panelbutton,floatpanel",init:function(a){function e(c,
d,e,h){var g=new CKEDITOR.style(f["colorButton_"+d+"Style"]),m=CKEDITOR.tools.getNextId()+"_colorBox";a.ui.add(c,CKEDITOR.UI_PANELBUTTON,{label:e,title:e,modes:{wysiwyg:1},editorFocus:0,toolbar:"colors,"+h,allowedContent:g,requiredContent:g,panel:{css:CKEDITOR.skin.getPath("editor"),attributes:{role:"listbox","aria-label":k.panelTitle}},onBlock:function(c,f){f.autoSize=true;f.element.addClass("cke_colorblock");f.element.setHtml(b(c,d,m));f.element.getDocument().getBody().setStyle("overflow","hidden");
CKEDITOR.ui.fire("ready",this);var e=f.keys,g=a.lang.dir=="rtl";e[g?37:39]="next";e[40]="next";e[9]="next";e[g?39:37]="prev";e[38]="prev";e[CKEDITOR.SHIFT+9]="prev";e[32]="click"},refresh:function(){a.activeFilter.check(g)||this.setState(CKEDITOR.TRISTATE_DISABLED)},onOpen:function(){var b=a.getSelection(),b=b&&b.getStartElement(),b=a.elementPath(b),c;if(b){b=b.block||b.blockLimit||a.document.getBody();do c=b&&b.getComputedStyle(d=="back"?"background-color":"color")||"transparent";while(d=="back"&&
c=="transparent"&&b&&(b=b.getParent()));if(!c||c=="transparent")c="#ffffff";this._.panel._.iframe.getFrameDocument().getById(m).setStyle("background-color",c);return c}}})}function b(b,d,e){var h=[],g=f.colorButton_colors.split(","),m=a.plugins.colordialog&&f.colorButton_enableMore!==false,p=g.length+(m?2:1),r=CKEDITOR.tools.addFunction(function(d,e){function g(a){this.removeListener("ok",g);this.removeListener("cancel",g);a.name=="ok"&&h(this.getContentElement("picker","selectedColor").getValue(),
e)}var h=arguments.callee;if(d=="?")a.openDialog("colordialog",function(){this.on("ok",g);this.on("cancel",g)});else{a.focus();b.hide();a.fire("saveSnapshot");a.removeStyle(new CKEDITOR.style(f["colorButton_"+e+"Style"],{color:"inherit"}));if(d){var k=f["colorButton_"+e+"Style"];k.childRule=e=="back"?function(a){return c(a)}:function(a){return!(a.is("a")||a.getElementsByTag("a").count())||c(a)};a.applyStyle(new CKEDITOR.style(k,{color:d}))}a.fire("saveSnapshot")}});h.push('<a class="cke_colorauto" _cke_focus=1 hidefocus=true title="',
k.auto,'" onclick="CKEDITOR.tools.callFunction(',r,",null,'",d,"');return false;\" href=\"javascript:void('",k.auto,'\')" role="option" aria-posinset="1" aria-setsize="',p,'"><table role="presentation" cellspacing=0 cellpadding=0 width="100%"><tr><td><span class="cke_colorbox" id="',e,'"></span></td><td colspan=7 align=center>',k.auto,'</td></tr></table></a><table role="presentation" cellspacing=0 cellpadding=0 width="100%">');for(e=0;e<g.length;e++){e%8===0&&h.push("</tr><tr>");var o=g[e].split("/"),
n=o[0],l=o[1]||n;o[1]||(n="#"+n.replace(/^(.)(.)(.)$/,"$1$1$2$2$3$3"));o=a.lang.colorbutton.colors[l]||l;h.push('<td><a class="cke_colorbox" _cke_focus=1 hidefocus=true title="',o,'" onclick="CKEDITOR.tools.callFunction(',r,",'",n,"','",d,"'); return false;\" href=\"javascript:void('",o,'\')" role="option" aria-posinset="',e+2,'" aria-setsize="',p,'"><span class="cke_colorbox" style="background-color:#',l,'"></span></a></td>')}m&&h.push('</tr><tr><td colspan=8 align=center><a class="cke_colormore" _cke_focus=1 hidefocus=true title="',
k.more,'" onclick="CKEDITOR.tools.callFunction(',r,",'?','",d,"');return false;\" href=\"javascript:void('",k.more,"')\"",' role="option" aria-posinset="',p,'" aria-setsize="',p,'">',k.more,"</a></td>");h.push("</tr></table>");return h.join("")}function c(a){return a.getAttribute("contentEditable")=="false"||a.getAttribute("data-nostyle")}var f=a.config,k=a.lang.colorbutton;if(!CKEDITOR.env.hc){e("TextColor","fore",k.textColorTitle,10);e("BGColor","back",k.bgColorTitle,20)}}}),CKEDITOR.config.colorButton_colors=
"000,800000,8B4513,2F4F4F,008080,000080,4B0082,696969,B22222,A52A2A,DAA520,006400,40E0D0,0000CD,800080,808080,F00,FF8C00,FFD700,008000,0FF,00F,EE82EE,A9A9A9,FFA07A,FFA500,FFFF00,00FF00,AFEEEE,ADD8E6,DDA0DD,D3D3D3,FFF0F5,FAEBD7,FFFFE0,F0FFF0,F0FFFF,F0F8FF,E6E6FA,FFF",CKEDITOR.config.colorButton_foreStyle={element:"span",styles:{color:"#(color)"},overrides:[{element:"font",attributes:{color:null}}]},CKEDITOR.config.colorButton_backStyle={element:"span",styles:{"background-color":"#(color)"}},CKEDITOR.plugins.colordialog=
{requires:"dialog",init:function(a){var e=new CKEDITOR.dialogCommand("colordialog");e.editorFocus=false;a.addCommand("colordialog",e);CKEDITOR.dialog.add("colordialog",this.path+"dialogs/colordialog.js");a.getColorFromDialog=function(b,c){var f=function(a){this.removeListener("ok",f);this.removeListener("cancel",f);a=a.name=="ok"?this.getValueOf("picker","selectedColor"):null;b.call(c,a)},e=function(a){a.on("ok",f);a.on("cancel",f)};a.execCommand("colordialog");if(a._.storedDialogs&&a._.storedDialogs.colordialog)e(a._.storedDialogs.colordialog);
else CKEDITOR.on("dialogDefinition",function(a){if(a.data.name=="colordialog"){var b=a.data.definition;a.removeListener();b.onLoad=CKEDITOR.tools.override(b.onLoad,function(a){return function(){e(this);b.onLoad=a;typeof a=="function"&&a.call(this)}})}})}}},CKEDITOR.plugins.add("colordialog",CKEDITOR.plugins.colordialog),CKEDITOR.plugins.add("menu",{requires:"floatpanel",beforeInit:function(a){for(var e=a.config.menu_groups.split(","),b=a._.menuGroups={},c=a._.menuItems={},f=0;f<e.length;f++)b[e[f]]=
f+1;a.addMenuGroup=function(a,c){b[a]=c||100};a.addMenuItem=function(a,f){b[f.group]&&(c[a]=new CKEDITOR.menuItem(this,a,f))};a.addMenuItems=function(a){for(var b in a)this.addMenuItem(b,a[b])};a.getMenuItem=function(a){return c[a]};a.removeMenuItem=function(a){delete c[a]}}}),function(){function a(a){a.sort(function(a,b){return a.group<b.group?-1:a.group>b.group?1:a.order<b.order?-1:a.order>b.order?1:0})}var e='<span class="cke_menuitem"><a id="{id}" class="cke_menubutton cke_menubutton__{name} cke_menubutton_{state} {cls}" href="{href}" title="{title}" tabindex="-1"_cke_focus=1 hidefocus="true" role="{role}" aria-haspopup="{hasPopup}" aria-disabled="{disabled}" {ariaChecked}';
CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(e=e+' onkeypress="return false;"');CKEDITOR.env.gecko&&(e=e+' onblur="this.style.cssText = this.style.cssText;"');var e=e+(' onmouseover="CKEDITOR.tools.callFunction({hoverFn},{index});" onmouseout="CKEDITOR.tools.callFunction({moveOutFn},{index});" '+(CKEDITOR.env.ie?'onclick="return false;" onmouseup':"onclick")+'="CKEDITOR.tools.callFunction({clickFn},{index}); return false;">'),b=CKEDITOR.addTemplate("menuItem",e+'<span class="cke_menubutton_inner"><span class="cke_menubutton_icon"><span class="cke_button_icon cke_button__{iconName}_icon" style="{iconStyle}"></span></span><span class="cke_menubutton_label">{label}</span>{arrowHtml}</span></a></span>'),
c=CKEDITOR.addTemplate("menuArrow",'<span class="cke_menuarrow"><span>{label}</span></span>');CKEDITOR.menu=CKEDITOR.tools.createClass({$:function(a,b){b=this._.definition=b||{};this.id=CKEDITOR.tools.getNextId();this.editor=a;this.items=[];this._.listeners=[];this._.level=b.level||1;var c=CKEDITOR.tools.extend({},b.panel,{css:[CKEDITOR.skin.getPath("editor")],level:this._.level-1,block:{}}),d=c.block.attributes=c.attributes||{};!d.role&&(d.role="menu");this._.panelDefinition=c},_:{onShow:function(){var a=
this.editor.getSelection(),b=a&&a.getStartElement(),c=this.editor.elementPath(),d=this._.listeners;this.removeAll();for(var e=0;e<d.length;e++){var h=d[e](b,a,c);if(h)for(var g in h){var m=this.editor.getMenuItem(g);if(m&&(!m.command||this.editor.getCommand(m.command).state)){m.state=h[g];this.add(m)}}}},onClick:function(a){this.hide();if(a.onClick)a.onClick();else a.command&&this.editor.execCommand(a.command)},onEscape:function(a){var b=this.parent;b?b._.panel.hideChild(1):a==27&&this.hide(1);return false},
onHide:function(){this.onHide&&this.onHide()},showSubMenu:function(a){var b=this._.subMenu,c=this.items[a];if(c=c.getItems&&c.getItems()){if(b)b.removeAll();else{b=this._.subMenu=new CKEDITOR.menu(this.editor,CKEDITOR.tools.extend({},this._.definition,{level:this._.level+1},true));b.parent=this;b._.onClick=CKEDITOR.tools.bind(this._.onClick,this)}for(var d in c){var e=this.editor.getMenuItem(d);if(e){e.state=c[d];b.add(e)}}var h=this._.panel.getBlock(this.id).element.getDocument().getById(this.id+
(""+a));setTimeout(function(){b.show(h,2)},0)}else this._.panel.hideChild(1)}},proto:{add:function(a){if(!a.order)a.order=this.items.length;this.items.push(a)},removeAll:function(){this.items=[]},show:function(b,c,e,d){if(!this.parent){this._.onShow();if(!this.items.length)return}var c=c||(this.editor.lang.dir=="rtl"?2:1),j=this.items,h=this.editor,g=this._.panel,m=this._.element;if(!g){g=this._.panel=new CKEDITOR.ui.floatPanel(this.editor,CKEDITOR.document.getBody(),this._.panelDefinition,this._.level);
g.onEscape=CKEDITOR.tools.bind(function(a){if(this._.onEscape(a)===false)return false},this);g.onShow=function(){g._.panel.getHolderElement().getParent().addClass("cke").addClass("cke_reset_all")};g.onHide=CKEDITOR.tools.bind(function(){this._.onHide&&this._.onHide()},this);m=g.addBlock(this.id,this._.panelDefinition.block);m.autoSize=true;var p=m.keys;p[40]="next";p[9]="next";p[38]="prev";p[CKEDITOR.SHIFT+9]="prev";p[h.lang.dir=="rtl"?37:39]=CKEDITOR.env.ie?"mouseup":"click";p[32]=CKEDITOR.env.ie?
"mouseup":"click";CKEDITOR.env.ie&&(p[13]="mouseup");m=this._.element=m.element;p=m.getDocument();p.getBody().setStyle("overflow","hidden");p.getElementsByTag("html").getItem(0).setStyle("overflow","hidden");this._.itemOverFn=CKEDITOR.tools.addFunction(function(a){clearTimeout(this._.showSubTimeout);this._.showSubTimeout=CKEDITOR.tools.setTimeout(this._.showSubMenu,h.config.menu_subMenuDelay||400,this,[a])},this);this._.itemOutFn=CKEDITOR.tools.addFunction(function(){clearTimeout(this._.showSubTimeout)},
this);this._.itemClickFn=CKEDITOR.tools.addFunction(function(a){var b=this.items[a];if(b.state==CKEDITOR.TRISTATE_DISABLED)this.hide(1);else if(b.getItems)this._.showSubMenu(a);else this._.onClick(b)},this)}a(j);for(var p=h.elementPath(),p=['<div class="cke_menu'+(p&&p.direction()!=h.lang.dir?" cke_mixed_dir_content":"")+'" role="presentation">'],r=j.length,o=r&&j[0].group,n=0;n<r;n++){var l=j[n];if(o!=l.group){p.push('<div class="cke_menuseparator" role="separator"></div>');o=l.group}l.render(this,
n,p)}p.push("</div>");m.setHtml(p.join(""));CKEDITOR.ui.fire("ready",this);this.parent?this.parent._.panel.showAsChild(g,this.id,b,c,e,d):g.showBlock(this.id,b,c,e,d);h.fire("menuShow",[g])},addListener:function(a){this._.listeners.push(a)},hide:function(a){this._.onHide&&this._.onHide();this._.panel&&this._.panel.hide(a)}}});CKEDITOR.menuItem=CKEDITOR.tools.createClass({$:function(a,b,c){CKEDITOR.tools.extend(this,c,{order:0,className:"cke_menubutton__"+b});this.group=a._.menuGroups[this.group];
this.editor=a;this.name=b},proto:{render:function(a,e,i){var d=a.id+(""+e),j=typeof this.state=="undefined"?CKEDITOR.TRISTATE_OFF:this.state,h="",g=j==CKEDITOR.TRISTATE_ON?"on":j==CKEDITOR.TRISTATE_DISABLED?"disabled":"off";this.role in{menuitemcheckbox:1,menuitemradio:1}&&(h=' aria-checked="'+(j==CKEDITOR.TRISTATE_ON?"true":"false")+'"');var m=this.getItems,p="&#"+(this.editor.lang.dir=="rtl"?"9668":"9658")+";",r=this.name;if(this.icon&&!/\./.test(this.icon))r=this.icon;a={id:d,name:this.name,iconName:r,
label:this.label,cls:this.className||"",state:g,hasPopup:m?"true":"false",disabled:j==CKEDITOR.TRISTATE_DISABLED,title:this.label,href:"javascript:void('"+(this.label||"").replace("'")+"')",hoverFn:a._.itemOverFn,moveOutFn:a._.itemOutFn,clickFn:a._.itemClickFn,index:e,iconStyle:CKEDITOR.skin.getIconStyle(r,this.editor.lang.dir=="rtl",r==this.icon?null:this.icon,this.iconOffset),arrowHtml:m?c.output({label:p}):"",role:this.role?this.role:"menuitem",ariaChecked:h};b.output(a,i)}}})}(),CKEDITOR.config.menu_groups=
"clipboard,form,tablecell,tablecellproperties,tablerow,tablecolumn,table,anchor,link,image,flash,checkbox,radio,textfield,hiddenfield,imagebutton,button,select,textarea,div",CKEDITOR.plugins.add("contextmenu",{requires:"menu",onLoad:function(){CKEDITOR.plugins.contextMenu=CKEDITOR.tools.createClass({base:CKEDITOR.menu,$:function(a){this.base.call(this,a,{panel:{className:"cke_menu_panel",attributes:{"aria-label":a.lang.contextmenu.options}}})},proto:{addTarget:function(a,e){a.on("contextmenu",function(a){var a=
a.data,c=CKEDITOR.env.webkit?b:CKEDITOR.env.mac?a.$.metaKey:a.$.ctrlKey;if(!e||!c){a.preventDefault();if(CKEDITOR.env.mac&&CKEDITOR.env.webkit){var c=this.editor,i=(new CKEDITOR.dom.elementPath(a.getTarget(),c.editable())).contains(function(a){return a.hasAttribute("contenteditable")},true);i&&i.getAttribute("contenteditable")=="false"&&c.getSelection().fake(i)}var i=a.getTarget().getDocument(),d=a.getTarget().getDocument().getDocumentElement(),c=!i.equals(CKEDITOR.document),i=i.getWindow().getScrollPosition(),
j=c?a.$.clientX:a.$.pageX||i.x+a.$.clientX,h=c?a.$.clientY:a.$.pageY||i.y+a.$.clientY;CKEDITOR.tools.setTimeout(function(){this.open(d,null,j,h)},CKEDITOR.env.ie?200:0,this)}},this);if(CKEDITOR.env.webkit){var b,c=function(){b=0};a.on("keydown",function(a){b=CKEDITOR.env.mac?a.data.$.metaKey:a.data.$.ctrlKey});a.on("keyup",c);a.on("contextmenu",c)}},open:function(a,e,b,c){this.editor.focus();a=a||CKEDITOR.document.getDocumentElement();this.editor.selectionChange(1);this.show(a,e,b,c)}}})},beforeInit:function(a){var e=
a.contextMenu=new CKEDITOR.plugins.contextMenu(a);a.on("contentDom",function(){e.addTarget(a.editable(),a.config.browserContextMenuOnCtrl!==false)});a.addCommand("contextMenu",{exec:function(){a.contextMenu.open(a.document.getBody())}});a.setKeystroke(CKEDITOR.SHIFT+121,"contextMenu");a.setKeystroke(CKEDITOR.CTRL+CKEDITOR.SHIFT+121,"contextMenu")}}),function(){function a(a){var b=this.att,a=a&&a.hasAttribute(b)&&a.getAttribute(b)||"";a!==void 0&&this.setValue(a)}function e(){for(var a,b=0;b<arguments.length;b++)if(arguments[b]instanceof
CKEDITOR.dom.element){a=arguments[b];break}if(a){var b=this.att,e=this.getValue();e?a.setAttribute(b,e):a.removeAttribute(b,e)}}var b={id:1,dir:1,classes:1,styles:1};CKEDITOR.plugins.add("dialogadvtab",{requires:"dialog",allowedContent:function(a){a||(a=b);var e=[];a.id&&e.push("id");a.dir&&e.push("dir");var k="";e.length&&(k=k+("["+e.join(",")+"]"));a.classes&&(k=k+"(*)");a.styles&&(k=k+"{*}");return k},createAdvancedTab:function(c,f,k){f||(f=b);var i=c.lang.common,d={id:"advanced",label:i.advancedTab,
title:i.advancedTab,elements:[{type:"vbox",padding:1,children:[]}]},j=[];if(f.id||f.dir){f.id&&j.push({id:"advId",att:"id",type:"text",requiredContent:k?k+"[id]":null,label:i.id,setup:a,commit:e});f.dir&&j.push({id:"advLangDir",att:"dir",type:"select",requiredContent:k?k+"[dir]":null,label:i.langDir,"default":"",style:"width:100%",items:[[i.notSet,""],[i.langDirLTR,"ltr"],[i.langDirRTL,"rtl"]],setup:a,commit:e});d.elements[0].children.push({type:"hbox",widths:["50%","50%"],children:[].concat(j)})}if(f.styles||
f.classes){j=[];f.styles&&j.push({id:"advStyles",att:"style",type:"text",requiredContent:k?k+"{cke-xyz}":null,label:i.styles,"default":"",validate:CKEDITOR.dialog.validate.inlineStyle(i.invalidInlineStyle),onChange:function(){},getStyle:function(a,b){var c=this.getValue().match(RegExp("(?:^|;)\\s*"+a+"\\s*:\\s*([^;]*)","i"));return c?c[1]:b},updateStyle:function(a,b){var d=this.getValue(),e=c.document.createElement("span");e.setAttribute("style",d);e.setStyle(a,b);d=CKEDITOR.tools.normalizeCssText(e.getAttribute("style"));
this.setValue(d,1)},setup:a,commit:e});f.classes&&j.push({type:"hbox",widths:["45%","55%"],children:[{id:"advCSSClasses",att:"class",type:"text",requiredContent:k?k+"(cke-xyz)":null,label:i.cssClasses,"default":"",setup:a,commit:e}]});d.elements[0].children.push({type:"hbox",widths:["50%","50%"],children:[].concat(j)})}return d}})}(),function(){CKEDITOR.plugins.add("div",{requires:"dialog",init:function(a){if(!a.blockless){var e=a.lang.div,b="div(*)";CKEDITOR.dialog.isTabEnabled(a,"editdiv","advanced")&&
(b=b+";div[dir,id,lang,title]{*}");a.addCommand("creatediv",new CKEDITOR.dialogCommand("creatediv",{allowedContent:b,requiredContent:"div",contextSensitive:true,refresh:function(a,b){this.setState("div"in(a.config.div_wrapTable?b.root:b.blockLimit).getDtd()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}}));a.addCommand("editdiv",new CKEDITOR.dialogCommand("editdiv",{requiredContent:"div"}));a.addCommand("removediv",{requiredContent:"div",exec:function(a){function b(d){if((d=CKEDITOR.plugins.div.getSurroundDiv(a,
d))&&!d.data("cke-div-added")){h.push(d);d.data("cke-div-added")}}for(var e=a.getSelection(),i=e&&e.getRanges(),d,j=e.createBookmarks(),h=[],g=0;g<i.length;g++){d=i[g];if(d.collapsed)b(e.getStartElement());else{d=new CKEDITOR.dom.walker(d);d.evaluator=b;d.lastForward()}}for(g=0;g<h.length;g++)h[g].remove(true);e.selectBookmarks(j)}});a.ui.addButton&&a.ui.addButton("CreateDiv",{label:e.toolbar,command:"creatediv",toolbar:"blocks,50"});if(a.addMenuItems){a.addMenuItems({editdiv:{label:e.edit,command:"editdiv",
group:"div",order:1},removediv:{label:e.remove,command:"removediv",group:"div",order:5}});a.contextMenu&&a.contextMenu.addListener(function(b){return!b||b.isReadOnly()?null:CKEDITOR.plugins.div.getSurroundDiv(a)?{editdiv:CKEDITOR.TRISTATE_OFF,removediv:CKEDITOR.TRISTATE_OFF}:null})}CKEDITOR.dialog.add("creatediv",this.path+"dialogs/div.js");CKEDITOR.dialog.add("editdiv",this.path+"dialogs/div.js")}}});CKEDITOR.plugins.div={getSurroundDiv:function(a,e){var b=a.elementPath(e);return a.elementPath(b.blockLimit).contains(function(a){return a.is("div")&&
!a.isReadOnly()},1)}}}(),function(){var a;function e(c,e){function d(a){a=m.list[a];if(a.equals(c.editable())||a.getAttribute("contenteditable")=="true"){var b=c.createRange();b.selectNodeContents(a);b.select()}else c.getSelection().selectElement(a);c.focus()}function j(){g&&g.setHtml(b);delete m.list}var h=c.ui.spaceId("path"),g,m=c._.elementsPath,p=m.idBase;e.html=e.html+('<span id="'+h+'_label" class="cke_voice_label">'+c.lang.elementspath.eleLabel+'</span><span id="'+h+'" class="cke_path" role="group" aria-labelledby="'+
h+'_label">'+b+"</span>");c.on("uiReady",function(){var a=c.ui.space("path");a&&c.focusManager.add(a,1)});m.onClick=d;var r=CKEDITOR.tools.addFunction(d),o=CKEDITOR.tools.addFunction(function(a,b){var e=m.idBase,f,b=new CKEDITOR.dom.event(b);f=c.lang.dir=="rtl";switch(b.getKeystroke()){case f?39:37:case 9:(f=CKEDITOR.document.getById(e+(a+1)))||(f=CKEDITOR.document.getById(e+"0"));f.focus();return false;case f?37:39:case CKEDITOR.SHIFT+9:(f=CKEDITOR.document.getById(e+(a-1)))||(f=CKEDITOR.document.getById(e+
(m.list.length-1)));f.focus();return false;case 27:c.focus();return false;case 13:case 32:d(a);return false}return true});c.on("selectionChange",function(){for(var a=[],d=m.list=[],e=[],i=m.filters,j=true,u=c.elementPath().elements,x,v=u.length;v--;){var q=u[v],y=0;x=q.data("cke-display-name")?q.data("cke-display-name"):q.data("cke-real-element-type")?q.data("cke-real-element-type"):q.getName();j=q.hasAttribute("contenteditable")?q.getAttribute("contenteditable")=="true":j;!j&&!q.hasAttribute("contenteditable")&&
(y=1);for(var z=0;z<i.length;z++){var B=i[z](q,x);if(B===false){y=1;break}x=B||x}if(!y){d.unshift(q);e.unshift(x)}}d=d.length;for(i=0;i<d;i++){x=e[i];j=c.lang.elementspath.eleTitle.replace(/%1/,x);x=f.output({id:p+i,label:j,text:x,jsTitle:"javascript:void('"+x+"')",index:i,keyDownFn:o,clickFn:r});a.unshift(x)}g||(g=CKEDITOR.document.getById(h));e=g;e.setHtml(a.join("")+b);c.fire("elementsPathUpdate",{space:e})});c.on("readOnly",j);c.on("contentDomUnload",j);c.addCommand("elementsPathFocus",a);c.setKeystroke(CKEDITOR.ALT+
122,"elementsPathFocus")}a={editorFocus:false,readOnly:1,exec:function(a){(a=CKEDITOR.document.getById(a._.elementsPath.idBase+"0"))&&a.focus(CKEDITOR.env.ie||CKEDITOR.env.air)}};var b='<span class="cke_path_empty">&nbsp;</span>',c="";CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(c=c+' onkeypress="return false;"');CKEDITOR.env.gecko&&(c=c+' onblur="this.style.cssText = this.style.cssText;"');var f=CKEDITOR.addTemplate("pathItem",'<a id="{id}" href="{jsTitle}" tabindex="-1" class="cke_path_item" title="{label}"'+
c+' hidefocus="true"  onkeydown="return CKEDITOR.tools.callFunction({keyDownFn},{index}, event );" onclick="CKEDITOR.tools.callFunction({clickFn},{index}); return false;" role="button" aria-label="{label}">{text}</a>');CKEDITOR.plugins.add("elementspath",{init:function(a){a._.elementsPath={idBase:"cke_elementspath_"+CKEDITOR.tools.getNextNumber()+"_",filters:[]};a.on("uiSpace",function(b){b.data.space=="bottom"&&e(a,b.data)})}})}(),function(){function a(a,b,c){c=a.config.forceEnterMode||c;if(a.mode==
"wysiwyg"){if(!b)b=a.activeEnterMode;if(!a.elementPath().isContextFor("p")){b=CKEDITOR.ENTER_BR;c=1}a.fire("saveSnapshot");b==CKEDITOR.ENTER_BR?i(a,b,null,c):d(a,b,null,c);a.fire("saveSnapshot")}}function e(a){for(var a=a.getSelection().getRanges(true),b=a.length-1;b>0;b--)a[b].deleteContents();return a[0]}function b(a){var b=a.startContainer.getAscendant(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.getAttribute("contenteditable")=="true"},true);if(a.root.equals(b))return a;b=new CKEDITOR.dom.range(b);
b.moveToRange(a);return b}CKEDITOR.plugins.add("enterkey",{init:function(b){b.addCommand("enter",{modes:{wysiwyg:1},editorFocus:false,exec:function(b){a(b)}});b.addCommand("shiftEnter",{modes:{wysiwyg:1},editorFocus:false,exec:function(b){a(b,b.activeShiftEnterMode,1)}});b.setKeystroke([[13,"enter"],[CKEDITOR.SHIFT+13,"shiftEnter"]])}});var c=CKEDITOR.dom.walker.whitespaces(),f=CKEDITOR.dom.walker.bookmark();CKEDITOR.plugins.enterkey={enterBlock:function(a,d,k,p){if(k=k||e(a)){var k=b(k),r=k.document,
o=k.checkStartOfBlock(),n=k.checkEndOfBlock(),l=a.elementPath(k.startContainer),s=l.block,t=d==CKEDITOR.ENTER_DIV?"div":"p",w;if(o&&n){if(s&&(s.is("li")||s.getParent().is("li"))){s.is("li")||(s=s.getParent());k=s.getParent();w=k.getParent();var p=!s.hasPrevious(),u=!s.hasNext(),t=a.getSelection(),x=t.createBookmarks(),o=s.getDirection(1),n=s.getAttribute("class"),v=s.getAttribute("style"),q=w.getDirection(1)!=o,a=a.enterMode!=CKEDITOR.ENTER_BR||q||v||n;if(w.is("li"))if(p||u){p&&u&&k.remove();s[u?
"insertAfter":"insertBefore"](w)}else s.breakParent(w);else{if(a){if(l.block.is("li")){w=r.createElement(d==CKEDITOR.ENTER_P?"p":"div");q&&w.setAttribute("dir",o);v&&w.setAttribute("style",v);n&&w.setAttribute("class",n);s.moveChildren(w)}else w=l.block;if(p||u)w[p?"insertBefore":"insertAfter"](k);else{s.breakParent(k);w.insertAfter(k)}}else{s.appendBogus(true);if(p||u)for(;r=s[p?"getFirst":"getLast"]();)r[p?"insertBefore":"insertAfter"](k);else for(s.breakParent(k);r=s.getLast();)r.insertAfter(k)}s.remove()}t.selectBookmarks(x);
return}if(s&&s.getParent().is("blockquote")){s.breakParent(s.getParent());s.getPrevious().getFirst(CKEDITOR.dom.walker.invisible(1))||s.getPrevious().remove();s.getNext().getFirst(CKEDITOR.dom.walker.invisible(1))||s.getNext().remove();k.moveToElementEditStart(s);k.select();return}}else if(s&&s.is("pre")&&!n){i(a,d,k,p);return}if(o=k.splitBlock(t)){d=o.previousBlock;s=o.nextBlock;l=o.wasStartOfBlock;a=o.wasEndOfBlock;if(s){x=s.getParent();if(x.is("li")){s.breakParent(x);s.move(s.getNext(),1)}}else if(d&&
(x=d.getParent())&&x.is("li")){d.breakParent(x);x=d.getNext();k.moveToElementEditStart(x);d.move(d.getPrevious())}if(!l&&!a){if(s.is("li")){w=k.clone();w.selectNodeContents(s);w=new CKEDITOR.dom.walker(w);w.evaluator=function(a){return!(f(a)||c(a)||a.type==CKEDITOR.NODE_ELEMENT&&a.getName()in CKEDITOR.dtd.$inline&&!(a.getName()in CKEDITOR.dtd.$empty))};(x=w.next())&&(x.type==CKEDITOR.NODE_ELEMENT&&x.is("ul","ol"))&&(CKEDITOR.env.needsBrFiller?r.createElement("br"):r.createText(" ")).insertBefore(x)}s&&
k.moveToElementEditStart(s)}else{if(d){if(d.is("li")||!j.test(d.getName())&&!d.is("pre"))w=d.clone()}else s&&(w=s.clone());if(w)p&&!w.is("li")&&w.renameNode(t);else if(x&&x.is("li"))w=x;else{w=r.createElement(t);d&&(u=d.getDirection())&&w.setAttribute("dir",u)}if(r=o.elementPath){p=0;for(t=r.elements.length;p<t;p++){x=r.elements[p];if(x.equals(r.block)||x.equals(r.blockLimit))break;if(CKEDITOR.dtd.$removeEmpty[x.getName()]){x=x.clone();w.moveChildren(x);w.append(x)}}}w.appendBogus();w.getParent()||
k.insertNode(w);w.is("li")&&w.removeAttribute("value");if(CKEDITOR.env.ie&&l&&(!a||!d.getChildCount())){k.moveToElementEditStart(a?d:w);k.select()}k.moveToElementEditStart(l&&!a?s:w)}k.select();k.scrollIntoView()}}},enterBr:function(a,b,c,f){if(c=c||e(a)){var i=c.document,k=c.checkEndOfBlock(),n=new CKEDITOR.dom.elementPath(a.getSelection().getStartElement()),l=n.block,s=l&&n.block.getName();if(!f&&s=="li")d(a,b,c,f);else{if(!f&&k&&j.test(s))if(k=l.getDirection()){i=i.createElement("div");i.setAttribute("dir",
k);i.insertAfter(l);c.setStart(i,0)}else{i.createElement("br").insertAfter(l);CKEDITOR.env.gecko&&i.createText("").insertAfter(l);c.setStartAt(l.getNext(),CKEDITOR.env.ie?CKEDITOR.POSITION_BEFORE_START:CKEDITOR.POSITION_AFTER_START)}else{a=s=="pre"&&CKEDITOR.env.ie&&CKEDITOR.env.version<8?i.createText("\r"):i.createElement("br");c.deleteContents();c.insertNode(a);if(CKEDITOR.env.needsBrFiller){i.createText("﻿").insertAfter(a);k&&(l||n.blockLimit).appendBogus();a.getNext().$.nodeValue="";c.setStartAt(a.getNext(),
CKEDITOR.POSITION_AFTER_START)}else c.setStartAt(a,CKEDITOR.POSITION_AFTER_END)}c.collapse(true);c.select();c.scrollIntoView()}}}};var k=CKEDITOR.plugins.enterkey,i=k.enterBr,d=k.enterBlock,j=/^h[1-6]$/}(),function(){function a(a,b){var c={},f=[],k={nbsp:" ",shy:"­",gt:">",lt:"<",amp:"&",apos:"'",quot:'"'},a=a.replace(/\b(nbsp|shy|gt|lt|amp|apos|quot)(?:,|$)/g,function(a,d){var e=b?"&"+d+";":k[d];c[e]=b?k[d]:"&"+d+";";f.push(e);return""});if(!b&&a){var a=a.split(","),i=document.createElement("div"),
d;i.innerHTML="&"+a.join(";&")+";";d=i.innerHTML;i=null;for(i=0;i<d.length;i++){var j=d.charAt(i);c[j]="&"+a[i]+";";f.push(j)}}c.regex=f.join(b?"|":"");return c}CKEDITOR.plugins.add("entities",{afterInit:function(e){function b(a){return j[a]}function c(a){return f.entities_processNumerical=="force"||!i[a]?"&#"+a.charCodeAt(0)+";":i[a]}var f=e.config;if(e=(e=e.dataProcessor)&&e.htmlFilter){var k=[];f.basicEntities!==false&&k.push("nbsp,gt,lt,amp");if(f.entities){k.length&&k.push("quot,iexcl,cent,pound,curren,yen,brvbar,sect,uml,copy,ordf,laquo,not,shy,reg,macr,deg,plusmn,sup2,sup3,acute,micro,para,middot,cedil,sup1,ordm,raquo,frac14,frac12,frac34,iquest,times,divide,fnof,bull,hellip,prime,Prime,oline,frasl,weierp,image,real,trade,alefsym,larr,uarr,rarr,darr,harr,crarr,lArr,uArr,rArr,dArr,hArr,forall,part,exist,empty,nabla,isin,notin,ni,prod,sum,minus,lowast,radic,prop,infin,ang,and,or,cap,cup,int,there4,sim,cong,asymp,ne,equiv,le,ge,sub,sup,nsub,sube,supe,oplus,otimes,perp,sdot,lceil,rceil,lfloor,rfloor,lang,rang,loz,spades,clubs,hearts,diams,circ,tilde,ensp,emsp,thinsp,zwnj,zwj,lrm,rlm,ndash,mdash,lsquo,rsquo,sbquo,ldquo,rdquo,bdquo,dagger,Dagger,permil,lsaquo,rsaquo,euro");
f.entities_latin&&k.push("Agrave,Aacute,Acirc,Atilde,Auml,Aring,AElig,Ccedil,Egrave,Eacute,Ecirc,Euml,Igrave,Iacute,Icirc,Iuml,ETH,Ntilde,Ograve,Oacute,Ocirc,Otilde,Ouml,Oslash,Ugrave,Uacute,Ucirc,Uuml,Yacute,THORN,szlig,agrave,aacute,acirc,atilde,auml,aring,aelig,ccedil,egrave,eacute,ecirc,euml,igrave,iacute,icirc,iuml,eth,ntilde,ograve,oacute,ocirc,otilde,ouml,oslash,ugrave,uacute,ucirc,uuml,yacute,thorn,yuml,OElig,oelig,Scaron,scaron,Yuml");f.entities_greek&&k.push("Alpha,Beta,Gamma,Delta,Epsilon,Zeta,Eta,Theta,Iota,Kappa,Lambda,Mu,Nu,Xi,Omicron,Pi,Rho,Sigma,Tau,Upsilon,Phi,Chi,Psi,Omega,alpha,beta,gamma,delta,epsilon,zeta,eta,theta,iota,kappa,lambda,mu,nu,xi,omicron,pi,rho,sigmaf,sigma,tau,upsilon,phi,chi,psi,omega,thetasym,upsih,piv");
f.entities_additional&&k.push(f.entities_additional)}var i=a(k.join(",")),d=i.regex?"["+i.regex+"]":"a^";delete i.regex;f.entities&&f.entities_processNumerical&&(d="[^ -~]|"+d);var d=RegExp(d,"g"),j=a("nbsp,gt,lt,amp,shy",true),h=RegExp(j.regex,"g");e.addRules({text:function(a){return a.replace(h,b).replace(d,c)}},{applyToAll:true,excludeNestedEditable:true})}}})}(),CKEDITOR.config.basicEntities=!0,CKEDITOR.config.entities=!0,CKEDITOR.config.entities_latin=!0,CKEDITOR.config.entities_greek=!0,CKEDITOR.config.entities_additional=
"#39",CKEDITOR.plugins.add("popup"),CKEDITOR.tools.extend(CKEDITOR.editor.prototype,{popup:function(a,e,b,c){e=e||"80%";b=b||"70%";typeof e=="string"&&(e.length>1&&e.substr(e.length-1,1)=="%")&&(e=parseInt(window.screen.width*parseInt(e,10)/100,10));typeof b=="string"&&(b.length>1&&b.substr(b.length-1,1)=="%")&&(b=parseInt(window.screen.height*parseInt(b,10)/100,10));e<640&&(e=640);b<420&&(b=420);var f=parseInt((window.screen.height-b)/2,10),k=parseInt((window.screen.width-e)/2,10),c=(c||"location=no,menubar=no,toolbar=no,dependent=yes,minimizable=no,modal=yes,alwaysRaised=yes,resizable=yes,scrollbars=yes")+
",width="+e+",height="+b+",top="+f+",left="+k,i=window.open("",null,c,true);if(!i)return false;try{if(navigator.userAgent.toLowerCase().indexOf(" chrome/")==-1){i.moveTo(k,f);i.resizeTo(e,b)}i.focus();i.location.href=a}catch(d){window.open(a,null,c,true)}return true}}),function(){function a(a,b){var c=[];if(b)for(var d in b)c.push(d+"="+encodeURIComponent(b[d]));else return a;return a+(a.indexOf("?")!=-1?"&":"?")+c.join("&")}function e(a){a=a+"";return a.charAt(0).toUpperCase()+a.substr(1)}function b(){var b=
this.getDialog(),c=b.getParentEditor();c._.filebrowserSe=this;var d=c.config["filebrowser"+e(b.getName())+"WindowWidth"]||c.config.filebrowserWindowWidth||"80%",b=c.config["filebrowser"+e(b.getName())+"WindowHeight"]||c.config.filebrowserWindowHeight||"70%",f=this.filebrowser.params||{};f.CKEditor=c.name;f.CKEditorFuncNum=c._.filebrowserFn;if(!f.langCode)f.langCode=c.langCode;f=a(this.filebrowser.url,f);c.popup(f,d,b,c.config.filebrowserWindowFeatures||c.config.fileBrowserWindowFeatures)}function c(){var a=
this.getDialog();a.getParentEditor()._.filebrowserSe=this;return!a.getContentElement(this["for"][0],this["for"][1]).getInputElement().$.value||!a.getContentElement(this["for"][0],this["for"][1]).getAction()?false:true}function f(b,c,d){var e=d.params||{};e.CKEditor=b.name;e.CKEditorFuncNum=b._.filebrowserFn;if(!e.langCode)e.langCode=b.langCode;c.action=a(d.url,e);c.filebrowser=d}function k(a,d,g,i){if(i&&i.length)for(var p,r=i.length;r--;){p=i[r];(p.type=="hbox"||p.type=="vbox"||p.type=="fieldset")&&
k(a,d,g,p.children);if(p.filebrowser){if(typeof p.filebrowser=="string")p.filebrowser={action:p.type=="fileButton"?"QuickUpload":"Browse",target:p.filebrowser};if(p.filebrowser.action=="Browse"){var o=p.filebrowser.url;if(o===void 0){o=a.config["filebrowser"+e(d)+"BrowseUrl"];if(o===void 0)o=a.config.filebrowserBrowseUrl}if(o){p.onClick=b;p.filebrowser.url=o;p.hidden=false}}else if(p.filebrowser.action=="QuickUpload"&&p["for"]){o=p.filebrowser.url;if(o===void 0){o=a.config["filebrowser"+e(d)+"UploadUrl"];
if(o===void 0)o=a.config.filebrowserUploadUrl}if(o){var n=p.onClick;p.onClick=function(a){var b=a.sender;return n&&n.call(b,a)===false?false:c.call(b,a)};p.filebrowser.url=o;p.hidden=false;f(a,g.getContents(p["for"][0]).get(p["for"][1]),p.filebrowser)}}}}}function i(a,b,c){if(c.indexOf(";")!==-1){for(var c=c.split(";"),d=0;d<c.length;d++)if(i(a,b,c[d]))return true;return false}return(a=a.getContents(b).get(c).filebrowser)&&a.url}function d(a,b){var c=this._.filebrowserSe.getDialog(),d=this._.filebrowserSe["for"],
e=this._.filebrowserSe.filebrowser.onSelect;d&&c.getContentElement(d[0],d[1]).reset();if(!(typeof b=="function"&&b.call(this._.filebrowserSe)===false)&&!(e&&e.call(this._.filebrowserSe,a,b)===false)){typeof b=="string"&&b&&alert(b);if(a){d=this._.filebrowserSe;c=d.getDialog();if(d=d.filebrowser.target||null){d=d.split(":");if(e=c.getContentElement(d[0],d[1])){e.setValue(a);c.selectPage(d[0])}}}}}CKEDITOR.plugins.add("filebrowser",{requires:"popup",init:function(a){a._.filebrowserFn=CKEDITOR.tools.addFunction(d,
a);a.on("destroy",function(){CKEDITOR.tools.removeFunction(this._.filebrowserFn)})}});CKEDITOR.on("dialogDefinition",function(a){if(a.editor.plugins.filebrowser)for(var b=a.data.definition,c,d=0;d<b.contents.length;++d)if(c=b.contents[d]){k(a.editor,a.data.name,b,c.elements);if(c.hidden&&c.filebrowser)c.hidden=!i(b,c.id,c.filebrowser)}})}(),CKEDITOR.plugins.add("find",{requires:"dialog",init:function(a){var e=a.addCommand("find",new CKEDITOR.dialogCommand("find"));e.canUndo=false;e.readOnly=1;a.addCommand("replace",
new CKEDITOR.dialogCommand("replace")).canUndo=false;if(a.ui.addButton){a.ui.addButton("Find",{label:a.lang.find.find,command:"find",toolbar:"find,10"});a.ui.addButton("Replace",{label:a.lang.find.replace,command:"replace",toolbar:"find,20"})}CKEDITOR.dialog.add("find",this.path+"dialogs/find.js");CKEDITOR.dialog.add("replace",this.path+"dialogs/find.js")}}),CKEDITOR.config.find_highlight={element:"span",styles:{"background-color":"#004",color:"#fff"}},function(){function a(a,b){var d=c.exec(a),e=
c.exec(b);if(d){if(!d[2]&&e[2]=="px")return e[1];if(d[2]=="px"&&!e[2])return e[1]+"px"}return b}var e=CKEDITOR.htmlParser.cssStyle,b=CKEDITOR.tools.cssLength,c=/^((?:\d*(?:\.\d+))|(?:\d+))(.*)?$/i,f={elements:{$:function(b){var c=b.attributes;if((c=(c=(c=c&&c["data-cke-realelement"])&&new CKEDITOR.htmlParser.fragment.fromHtml(decodeURIComponent(c)))&&c.children[0])&&b.attributes["data-cke-resizable"]){var d=(new e(b)).rules,b=c.attributes,f=d.width,d=d.height;f&&(b.width=a(b.width,f));d&&(b.height=
a(b.height,d))}return c}}};CKEDITOR.plugins.add("fakeobjects",{init:function(a){a.filter.allow("img[!data-cke-realelement,src,alt,title](*){*}","fakeobjects")},afterInit:function(a){(a=(a=a.dataProcessor)&&a.htmlFilter)&&a.addRules(f,{applyToAll:true})}});CKEDITOR.editor.prototype.createFakeElement=function(a,c,d,f){var h=this.lang.fakeobjects,h=h[d]||h.unknown,c={"class":c,"data-cke-realelement":encodeURIComponent(a.getOuterHtml()),"data-cke-real-node-type":a.type,alt:h,title:h,align:a.getAttribute("align")||
""};if(!CKEDITOR.env.hc)c.src=CKEDITOR.tools.transparentImageData;d&&(c["data-cke-real-element-type"]=d);if(f){c["data-cke-resizable"]=f;d=new e;f=a.getAttribute("width");a=a.getAttribute("height");f&&(d.rules.width=b(f));a&&(d.rules.height=b(a));d.populate(c)}return this.document.createElement("img",{attributes:c})};CKEDITOR.editor.prototype.createFakeParserElement=function(a,c,d,f){var h=this.lang.fakeobjects,h=h[d]||h.unknown,g;g=new CKEDITOR.htmlParser.basicWriter;a.writeHtml(g);g=g.getHtml();
c={"class":c,"data-cke-realelement":encodeURIComponent(g),"data-cke-real-node-type":a.type,alt:h,title:h,align:a.attributes.align||""};if(!CKEDITOR.env.hc)c.src=CKEDITOR.tools.transparentImageData;d&&(c["data-cke-real-element-type"]=d);if(f){c["data-cke-resizable"]=f;f=a.attributes;a=new e;d=f.width;f=f.height;d!==void 0&&(a.rules.width=b(d));f!==void 0&&(a.rules.height=b(f));a.populate(c)}return new CKEDITOR.htmlParser.element("img",c)};CKEDITOR.editor.prototype.restoreRealElement=function(b){if(b.data("cke-real-node-type")!=
CKEDITOR.NODE_ELEMENT)return null;var c=CKEDITOR.dom.element.createFromHtml(decodeURIComponent(b.data("cke-realelement")),this.document);if(b.data("cke-resizable")){var d=b.getStyle("width"),b=b.getStyle("height");d&&c.setAttribute("width",a(c.getAttribute("width"),d));b&&c.setAttribute("height",a(c.getAttribute("height"),b))}return c}}(),function(){function a(a){a=a.attributes;return a.type=="application/x-shockwave-flash"||b.test(a.src||"")}function e(a,b){return a.createFakeParserElement(b,"cke_flash",
"flash",true)}var b=/\.swf(?:$|\?)/i;CKEDITOR.plugins.add("flash",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss("img.cke_flash{background-image: url("+CKEDITOR.getUrl(this.path+"images/placeholder.png")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 80px;height: 80px;}")},init:function(a){var b="object[classid,codebase,height,hspace,vspace,width];param[name,value];embed[height,hspace,pluginspage,src,type,vspace,width]";CKEDITOR.dialog.isTabEnabled(a,
"flash","properties")&&(b=b+";object[align]; embed[allowscriptaccess,quality,scale,wmode]");CKEDITOR.dialog.isTabEnabled(a,"flash","advanced")&&(b=b+";object[id]{*}; embed[bgcolor]{*}(*)");a.addCommand("flash",new CKEDITOR.dialogCommand("flash",{allowedContent:b,requiredContent:"embed"}));a.ui.addButton&&a.ui.addButton("Flash",{label:a.lang.common.flash,command:"flash",toolbar:"insert,20"});CKEDITOR.dialog.add("flash",this.path+"dialogs/flash.js");a.addMenuItems&&a.addMenuItems({flash:{label:a.lang.flash.properties,
command:"flash",group:"flash"}});a.on("doubleclick",function(a){var b=a.data.element;if(b.is("img")&&b.data("cke-real-element-type")=="flash")a.data.dialog="flash"});a.contextMenu&&a.contextMenu.addListener(function(a){if(a&&a.is("img")&&!a.isReadOnly()&&a.data("cke-real-element-type")=="flash")return{flash:CKEDITOR.TRISTATE_OFF}})},afterInit:function(b){var f=b.dataProcessor;(f=f&&f.dataFilter)&&f.addRules({elements:{"cke:object":function(f){var i=f.attributes;if((!i.classid||!(""+i.classid).toLowerCase())&&
!a(f)){for(i=0;i<f.children.length;i++)if(f.children[i].name=="cke:embed"){if(!a(f.children[i]))break;return e(b,f)}return null}return e(b,f)},"cke:embed":function(f){return!a(f)?null:e(b,f)}}},5)}})}(),CKEDITOR.tools.extend(CKEDITOR.config,{flashEmbedTagOnly:!1,flashAddEmbedTag:!0,flashConvertOnEdit:!1}),function(){function a(a){var f=a.config,k=a.fire("uiSpace",{space:"top",html:""}).html,i=function(){function d(a,c,e){j.setStyle(c,b(e));j.setStyle("position",a)}function g(a){var b=k.getDocumentPosition();
switch(a){case "top":d("absolute","top",b.y-t-x);break;case "pin":d("fixed","top",q);break;case "bottom":d("absolute","top",b.y+(l.height||l.bottom-l.top)+x)}h=a}var h,k,n,l,s,t,w,u=f.floatSpaceDockedOffsetX||0,x=f.floatSpaceDockedOffsetY||0,v=f.floatSpacePinnedOffsetX||0,q=f.floatSpacePinnedOffsetY||0;return function(d){if(k=a.editable()){var m=d&&d.name=="focus";m&&j.show();a.fire("floatingSpaceLayout",{show:m});j.removeStyle("left");j.removeStyle("right");n=j.getClientRect();l=k.getClientRect();
s=e.getViewPaneSize();t=n.height;w="pageXOffset"in e.$?e.$.pageXOffset:CKEDITOR.document.$.documentElement.scrollLeft;if(h){t+x<=l.top?g("top"):t+x>s.height-l.bottom?g("pin"):g("bottom");d=s.width/2;d=f.floatSpacePreferRight?"right":l.left>0&&l.right<s.width&&l.width>n.width?f.contentsLangDirection=="rtl"?"right":"left":d-l.left>l.right-d?"left":"right";if(n.width>s.width){d="left";m=0}else{m=d=="left"?l.left>0?l.left:0:l.right<s.width?s.width-l.right:0;if(m+n.width>s.width){d=d=="left"?"right":"left";
m=0}}j.setStyle(d,b((h=="pin"?v:u)+m+(h=="pin"?0:d=="left"?w:-w)))}else{h="pin";g("pin");i(d)}}}}();if(k){var d=new CKEDITOR.template('<div id="cke_{name}" class="cke {id} cke_reset_all cke_chrome cke_editor_{name} cke_float cke_{langDir} '+CKEDITOR.env.cssClass+'" dir="{langDir}" title="'+(CKEDITOR.env.gecko?" ":"")+'" lang="{langCode}" role="application" style="{style}"'+(a.title?' aria-labelledby="cke_{name}_arialbl"':" ")+">"+(a.title?'<span id="cke_{name}_arialbl" class="cke_voice_label">{voiceLabel}</span>':
" ")+'<div class="cke_inner"><div id="{topId}" class="cke_top" role="presentation">{content}</div></div></div>'),j=CKEDITOR.document.getBody().append(CKEDITOR.dom.element.createFromHtml(d.output({content:k,id:a.id,langDir:a.lang.dir,langCode:a.langCode,name:a.name,style:"display:none;z-index:"+(f.baseFloatZIndex-1),topId:a.ui.spaceId("top"),voiceLabel:a.title}))),h=CKEDITOR.tools.eventsBuffer(500,i),g=CKEDITOR.tools.eventsBuffer(100,i);j.unselectable();j.on("mousedown",function(a){a=a.data;a.getTarget().hasAscendant("a",
1)||a.preventDefault()});a.on("focus",function(b){i(b);a.on("change",h.input);e.on("scroll",g.input);e.on("resize",g.input)});a.on("blur",function(){j.hide();a.removeListener("change",h.input);e.removeListener("scroll",g.input);e.removeListener("resize",g.input)});a.on("destroy",function(){e.removeListener("scroll",g.input);e.removeListener("resize",g.input);j.clearCustomData();j.remove()});a.focusManager.hasFocus&&j.show();a.focusManager.add(j,1)}}var e=CKEDITOR.document.getWindow(),b=CKEDITOR.tools.cssLength;
CKEDITOR.plugins.add("floatingspace",{init:function(b){b.on("loaded",function(){a(this)},null,null,20)}})}(),CKEDITOR.plugins.add("listblock",{requires:"panel",onLoad:function(){var a=CKEDITOR.addTemplate("panel-list",'<ul role="presentation" class="cke_panel_list">{items}</ul>'),e=CKEDITOR.addTemplate("panel-list-item",'<li id="{id}" class="cke_panel_listItem" role=presentation><a id="{id}_option" _cke_focus=1 hidefocus=true title="{title}" href="javascript:void(\'{val}\')"  {onclick}="CKEDITOR.tools.callFunction({clickFn},\'{val}\'); return false;" role="option">{text}</a></li>'),
b=CKEDITOR.addTemplate("panel-list-group",'<h1 id="{id}" class="cke_panel_grouptitle" role="presentation" >{label}</h1>'),c=/\'/g;CKEDITOR.ui.panel.prototype.addListBlock=function(a,b){return this.addBlock(a,new CKEDITOR.ui.listBlock(this.getHolderElement(),b))};CKEDITOR.ui.listBlock=CKEDITOR.tools.createClass({base:CKEDITOR.ui.panel.block,$:function(a,b){var b=b||{},c=b.attributes||(b.attributes={});(this.multiSelect=!!b.multiSelect)&&(c["aria-multiselectable"]=true);!c.role&&(c.role="listbox");
this.base.apply(this,arguments);this.element.setAttribute("role",c.role);c=this.keys;c[40]="next";c[9]="next";c[38]="prev";c[CKEDITOR.SHIFT+9]="prev";c[32]=CKEDITOR.env.ie?"mouseup":"click";CKEDITOR.env.ie&&(c[13]="mouseup");this._.pendingHtml=[];this._.pendingList=[];this._.items={};this._.groups={}},_:{close:function(){if(this._.started){var b=a.output({items:this._.pendingList.join("")});this._.pendingList=[];this._.pendingHtml.push(b);delete this._.started}},getClick:function(){if(!this._.click)this._.click=
CKEDITOR.tools.addFunction(function(a){var b=this.toggle(a);if(this.onClick)this.onClick(a,b)},this);return this._.click}},proto:{add:function(a,b,i){var d=CKEDITOR.tools.getNextId();if(!this._.started){this._.started=1;this._.size=this._.size||0}this._.items[a]=d;var j;j=CKEDITOR.tools.htmlEncodeAttr(a).replace(c,"\\'");a={id:d,val:j,onclick:CKEDITOR.env.ie?'onclick="return false;" onmouseup':"onclick",clickFn:this._.getClick(),title:CKEDITOR.tools.htmlEncodeAttr(i||a),text:b||a};this._.pendingList.push(e.output(a))},
startGroup:function(a){this._.close();var c=CKEDITOR.tools.getNextId();this._.groups[a]=c;this._.pendingHtml.push(b.output({id:c,label:a}))},commit:function(){this._.close();this.element.appendHtml(this._.pendingHtml.join(""));delete this._.size;this._.pendingHtml=[]},toggle:function(a){var b=this.isMarked(a);b?this.unmark(a):this.mark(a);return!b},hideGroup:function(a){var b=(a=this.element.getDocument().getById(this._.groups[a]))&&a.getNext();if(a){a.setStyle("display","none");b&&b.getName()=="ul"&&
b.setStyle("display","none")}},hideItem:function(a){this.element.getDocument().getById(this._.items[a]).setStyle("display","none")},showAll:function(){var a=this._.items,b=this._.groups,c=this.element.getDocument(),d;for(d in a)c.getById(a[d]).setStyle("display","");for(var e in b){a=c.getById(b[e]);d=a.getNext();a.setStyle("display","");d&&d.getName()=="ul"&&d.setStyle("display","")}},mark:function(a){this.multiSelect||this.unmarkAll();var a=this._.items[a],b=this.element.getDocument().getById(a);
b.addClass("cke_selected");this.element.getDocument().getById(a+"_option").setAttribute("aria-selected",true);this.onMark&&this.onMark(b)},unmark:function(a){var b=this.element.getDocument(),a=this._.items[a],c=b.getById(a);c.removeClass("cke_selected");b.getById(a+"_option").removeAttribute("aria-selected");this.onUnmark&&this.onUnmark(c)},unmarkAll:function(){var a=this._.items,b=this.element.getDocument(),c;for(c in a){var d=a[c];b.getById(d).removeClass("cke_selected");b.getById(d+"_option").removeAttribute("aria-selected")}this.onUnmark&&
this.onUnmark()},isMarked:function(a){return this.element.getDocument().getById(this._.items[a]).hasClass("cke_selected")},focus:function(a){this._.focusIndex=-1;var b=this.element.getElementsByTag("a"),c,d=-1;if(a)for(c=this.element.getDocument().getById(this._.items[a]).getFirst();a=b.getItem(++d);){if(a.equals(c)){this._.focusIndex=d;break}}else this.element.focus();c&&setTimeout(function(){c.focus()},0)}}})}}),CKEDITOR.plugins.add("richcombo",{requires:"floatpanel,listblock,button",beforeInit:function(a){a.ui.addHandler(CKEDITOR.UI_RICHCOMBO,
CKEDITOR.ui.richCombo.handler)}}),function(){var a='<span id="{id}" class="cke_combo cke_combo__{name} {cls}" role="presentation"><span id="{id}_label" class="cke_combo_label">{label}</span><a class="cke_combo_button" title="{title}" tabindex="-1"'+(CKEDITOR.env.gecko&&!CKEDITOR.env.hc?"":" href=\"javascript:void('{titleJs}')\"")+' hidefocus="true" role="button" aria-labelledby="{id}_label" aria-haspopup="true"';CKEDITOR.env.gecko&&CKEDITOR.env.mac&&(a=a+' onkeypress="return false;"');CKEDITOR.env.gecko&&
(a=a+' onblur="this.style.cssText = this.style.cssText;"');var a=a+(' onkeydown="return CKEDITOR.tools.callFunction({keydownFn},event,this);" onfocus="return CKEDITOR.tools.callFunction({focusFn},event);" '+(CKEDITOR.env.ie?'onclick="return false;" onmouseup':"onclick")+'="CKEDITOR.tools.callFunction({clickFn},this);return false;"><span id="{id}_text" class="cke_combo_text cke_combo_inlinelabel">{label}</span><span class="cke_combo_open"><span class="cke_combo_arrow">'+(CKEDITOR.env.hc?"&#9660;":
CKEDITOR.env.air?"&nbsp;":"")+"</span></span></a></span>"),e=CKEDITOR.addTemplate("combo",a);CKEDITOR.UI_RICHCOMBO="richcombo";CKEDITOR.ui.richCombo=CKEDITOR.tools.createClass({$:function(a){CKEDITOR.tools.extend(this,a,{canGroup:false,title:a.label,modes:{wysiwyg:1},editorFocus:1});a=this.panel||{};delete this.panel;this.id=CKEDITOR.tools.getNextNumber();this.document=a.parent&&a.parent.getDocument()||CKEDITOR.document;a.className="cke_combopanel";a.block={multiSelect:a.multiSelect,attributes:a.attributes};
a.toolbarRelated=true;this._={panelDefinition:a,items:{}}},proto:{renderHtml:function(a){var c=[];this.render(a,c);return c.join("")},render:function(a,c){function f(){if(this.getState()!=CKEDITOR.TRISTATE_ON){var c=this.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED;if(a.readOnly&&!this.readOnly)c=CKEDITOR.TRISTATE_DISABLED;this.setState(c);this.setValue("");c!=CKEDITOR.TRISTATE_DISABLED&&this.refresh&&this.refresh()}}var k=CKEDITOR.env,i="cke_"+this.id,d=CKEDITOR.tools.addFunction(function(c){if(p){a.unlockSelection(1);
p=0}h.execute(c)},this),j=this,h={id:i,combo:this,focus:function(){CKEDITOR.document.getById(i).getChild(1).focus()},execute:function(c){var d=j._;if(d.state!=CKEDITOR.TRISTATE_DISABLED){j.createPanel(a);if(d.on)d.panel.hide();else{j.commit();var e=j.getValue();e?d.list.mark(e):d.list.unmarkAll();d.panel.showBlock(j.id,new CKEDITOR.dom.element(c),4)}}},clickFn:d};a.on("activeFilterChange",f,this);a.on("mode",f,this);a.on("selectionChange",f,this);!this.readOnly&&a.on("readOnly",f,this);var g=CKEDITOR.tools.addFunction(function(c,
e){var c=new CKEDITOR.dom.event(c),f=c.getKeystroke();if(f==40)a.once("panelShow",function(a){a.data._.panel._.currentBlock.onKeyDown(40)});switch(f){case 13:case 32:case 40:CKEDITOR.tools.callFunction(d,e);break;default:h.onkey(h,f)}c.preventDefault()}),m=CKEDITOR.tools.addFunction(function(){h.onfocus&&h.onfocus()}),p=0;h.keyDownFn=g;k={id:i,name:this.name||this.command,label:this.label,title:this.title,cls:this.className||"",titleJs:k.gecko&&!k.hc?"":(this.title||"").replace("'",""),keydownFn:g,
focusFn:m,clickFn:d};e.output(k,c);if(this.onRender)this.onRender();return h},createPanel:function(a){if(!this._.panel){var c=this._.panelDefinition,e=this._.panelDefinition.block,k=c.parent||CKEDITOR.document.getBody(),i="cke_combopanel__"+this.name,d=new CKEDITOR.ui.floatPanel(a,k,c),j=d.addListBlock(this.id,e),h=this;d.onShow=function(){this.element.addClass(i);h.setState(CKEDITOR.TRISTATE_ON);h._.on=1;h.editorFocus&&!a.focusManager.hasFocus&&a.focus();if(h.onOpen)h.onOpen();a.once("panelShow",
function(){j.focus(!j.multiSelect&&h.getValue())})};d.onHide=function(c){this.element.removeClass(i);h.setState(h.modes&&h.modes[a.mode]?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);h._.on=0;if(!c&&h.onClose)h.onClose()};d.onEscape=function(){d.hide(1)};j.onClick=function(a,b){h.onClick&&h.onClick.call(h,a,b);d.hide()};this._.panel=d;this._.list=j;d.getBlock(this.id).onHide=function(){h._.on=0;h.setState(CKEDITOR.TRISTATE_OFF)};this.init&&this.init()}},setValue:function(a,c){this._.value=a;var e=
this.document.getById("cke_"+this.id+"_text");if(e){if(!a&&!c){c=this.label;e.addClass("cke_combo_inlinelabel")}else e.removeClass("cke_combo_inlinelabel");e.setText(typeof c!="undefined"?c:a)}},getValue:function(){return this._.value||""},unmarkAll:function(){this._.list.unmarkAll()},mark:function(a){this._.list.mark(a)},hideItem:function(a){this._.list.hideItem(a)},hideGroup:function(a){this._.list.hideGroup(a)},showAll:function(){this._.list.showAll()},add:function(a,c,e){this._.items[a]=e||a;
this._.list.add(a,c,e)},startGroup:function(a){this._.list.startGroup(a)},commit:function(){if(!this._.committed){this._.list.commit();this._.committed=1;CKEDITOR.ui.fire("ready",this)}this._.committed=1},setState:function(a){if(this._.state!=a){var c=this.document.getById("cke_"+this.id);c.setState(a,"cke_combo");a==CKEDITOR.TRISTATE_DISABLED?c.setAttribute("aria-disabled",true):c.removeAttribute("aria-disabled");this._.state=a}},getState:function(){return this._.state},enable:function(){this._.state==
CKEDITOR.TRISTATE_DISABLED&&this.setState(this._.lastState)},disable:function(){if(this._.state!=CKEDITOR.TRISTATE_DISABLED){this._.lastState=this._.state;this.setState(CKEDITOR.TRISTATE_DISABLED)}}},statics:{handler:{create:function(a){return new CKEDITOR.ui.richCombo(a)}}}});CKEDITOR.ui.prototype.addRichCombo=function(a,c){this.add(a,CKEDITOR.UI_RICHCOMBO,c)}}(),function(){function a(a,c,f,k,i,d,j,h){for(var g=a.config,m=new CKEDITOR.style(j),p=i.split(";"),i=[],r={},o=0;o<p.length;o++){var n=p[o];
if(n){var n=n.split("/"),l={},s=p[o]=n[0];l[f]=i[o]=n[1]||s;r[s]=new CKEDITOR.style(j,l);r[s]._.definition.name=s}else p.splice(o--,1)}a.ui.addRichCombo(c,{label:k.label,title:k.panelTitle,toolbar:"styles,"+h,allowedContent:m,requiredContent:m,panel:{css:[CKEDITOR.skin.getPath("editor")].concat(g.contentsCss),multiSelect:false,attributes:{"aria-label":k.panelTitle}},init:function(){this.startGroup(k.panelTitle);for(var a=0;a<p.length;a++){var b=p[a];this.add(b,r[b].buildPreview(),b)}},onClick:function(c){a.focus();
a.fire("saveSnapshot");var d=this.getValue(),f=r[c];if(d&&c!=d){var g=r[d],i=a.getSelection().getRanges()[0];if(i.collapsed){var h=a.elementPath(),j=h.contains(function(a){return g.checkElementRemovable(a)});if(j){var k=i.checkBoundaryOfElement(j,CKEDITOR.START),l=i.checkBoundaryOfElement(j,CKEDITOR.END);if(k&&l){for(k=i.createBookmark();h=j.getFirst();)h.insertBefore(j);j.remove();i.moveToBookmark(k)}else if(k)i.moveToPosition(j,CKEDITOR.POSITION_BEFORE_START);else if(l)i.moveToPosition(j,CKEDITOR.POSITION_AFTER_END);
else{i.splitElement(j);i.moveToPosition(j,CKEDITOR.POSITION_AFTER_END);e(i,h.elements.slice(),j)}a.getSelection().selectRanges([i])}}else a.removeStyle(g)}a[d==c?"removeStyle":"applyStyle"](f);a.fire("saveSnapshot")},onRender:function(){a.on("selectionChange",function(c){for(var e=this.getValue(),c=c.data.path.elements,f=0,g;f<c.length;f++){g=c[f];for(var i in r)if(r[i].checkElementMatch(g,true,a)){i!=e&&this.setValue(i);return}}this.setValue("",d)},this)},refresh:function(){a.activeFilter.check(m)||
this.setState(CKEDITOR.TRISTATE_DISABLED)}})}function e(a,c,f){var k=c.pop();if(k){if(f)return e(a,c,k.equals(f)?null:f);f=k.clone();a.insertNode(f);a.moveToPosition(f,CKEDITOR.POSITION_AFTER_START);e(a,c)}}CKEDITOR.plugins.add("font",{requires:"richcombo",init:function(b){var c=b.config;a(b,"Font","family",b.lang.font,c.font_names,c.font_defaultLabel,c.font_style,30);a(b,"FontSize","size",b.lang.font.fontSize,c.fontSize_sizes,c.fontSize_defaultLabel,c.fontSize_style,40)}})}(),CKEDITOR.config.font_names=
"Arial/Arial, Helvetica, sans-serif;Comic Sans MS/Comic Sans MS, cursive;Courier New/Courier New, Courier, monospace;Georgia/Georgia, serif;Lucida Sans Unicode/Lucida Sans Unicode, Lucida Grande, sans-serif;Tahoma/Tahoma, Geneva, sans-serif;Times New Roman/Times New Roman, Times, serif;Trebuchet MS/Trebuchet MS, Helvetica, sans-serif;Verdana/Verdana, Geneva, sans-serif",CKEDITOR.config.font_defaultLabel="",CKEDITOR.config.font_style={element:"span",styles:{"font-family":"#(family)"},overrides:[{element:"font",
attributes:{face:null}}]},CKEDITOR.config.fontSize_sizes="8/8px;9/9px;10/10px;11/11px;12/12px;14/14px;16/16px;18/18px;20/20px;22/22px;24/24px;26/26px;28/28px;36/36px;48/48px;72/72px",CKEDITOR.config.fontSize_defaultLabel="",CKEDITOR.config.fontSize_style={element:"span",styles:{"font-size":"#(size)"},overrides:[{element:"font",attributes:{size:null}}]},CKEDITOR.plugins.add("format",{requires:"richcombo",init:function(a){if(!a.blockless){for(var e=a.config,b=a.lang.format,c=e.format_tags.split(";"),
f={},k=0,i=[],d=0;d<c.length;d++){var j=c[d],h=new CKEDITOR.style(e["format_"+j]);if(!a.filter.customConfig||a.filter.check(h)){k++;f[j]=h;f[j]._.enterMode=a.config.enterMode;i.push(h)}}k!==0&&a.ui.addRichCombo("Format",{label:b.label,title:b.panelTitle,toolbar:"styles,20",allowedContent:i,panel:{css:[CKEDITOR.skin.getPath("editor")].concat(e.contentsCss),multiSelect:false,attributes:{"aria-label":b.panelTitle}},init:function(){this.startGroup(b.panelTitle);for(var a in f){var c=b["tag_"+a];this.add(a,
f[a].buildPreview(c),c)}},onClick:function(b){a.focus();a.fire("saveSnapshot");var b=f[b],c=a.elementPath();a[b.checkActive(c,a)?"removeStyle":"applyStyle"](b);setTimeout(function(){a.fire("saveSnapshot")},0)},onRender:function(){a.on("selectionChange",function(b){var c=this.getValue(),b=b.data.path;this.refresh();for(var d in f)if(f[d].checkActive(b,a)){d!=c&&this.setValue(d,a.lang.format["tag_"+d]);return}this.setValue("")},this)},onOpen:function(){this.showAll();for(var b in f)a.activeFilter.check(f[b])||
this.hideItem(b)},refresh:function(){var b=a.elementPath();if(b){if(b.isContextFor("p"))for(var c in f)if(a.activeFilter.check(f[c]))return;this.setState(CKEDITOR.TRISTATE_DISABLED)}}})}}}),CKEDITOR.config.format_tags="p;h1;h2;h3;h4;h5;h6;pre;address;div",CKEDITOR.config.format_p={element:"p"},CKEDITOR.config.format_div={element:"div"},CKEDITOR.config.format_pre={element:"pre"},CKEDITOR.config.format_address={element:"address"},CKEDITOR.config.format_h1={element:"h1"},CKEDITOR.config.format_h2={element:"h2"},
CKEDITOR.config.format_h3={element:"h3"},CKEDITOR.config.format_h4={element:"h4"},CKEDITOR.config.format_h5={element:"h5"},CKEDITOR.config.format_h6={element:"h6"},CKEDITOR.plugins.add("forms",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss(".cke_editable form{border: 1px dotted #FF0000;padding: 2px;}\n");CKEDITOR.addCss("img.cke_hidden{background-image: url("+CKEDITOR.getUrl(this.path+"images/hiddenfield.gif")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 16px !important;height: 16px !important;}")},
init:function(a){var e=a.lang,b=0,c={email:1,password:1,search:1,tel:1,text:1,url:1},f={checkbox:"input[type,name,checked,required]",radio:"input[type,name,checked,required]",textfield:"input[type,name,value,size,maxlength,required]",textarea:"textarea[cols,rows,name,required]",select:"select[name,size,multiple,required]; option[value,selected]",button:"input[type,name,value]",form:"form[action,name,id,enctype,target,method]",hiddenfield:"input[type,name,value]",imagebutton:"input[type,alt,src]{width,height,border,border-width,border-style,margin,float}"},
k={checkbox:"input",radio:"input",textfield:"input",textarea:"textarea",select:"select",button:"input",form:"form",hiddenfield:"input",imagebutton:"input"},i=function(c,d,i){var j={allowedContent:f[d],requiredContent:k[d]};d=="form"&&(j.context="form");a.addCommand(d,new CKEDITOR.dialogCommand(d,j));a.ui.addButton&&a.ui.addButton(c,{label:e.common[c.charAt(0).toLowerCase()+c.slice(1)],command:d,toolbar:"forms,"+(b=b+10)});CKEDITOR.dialog.add(d,i)},d=this.path+"dialogs/";!a.blockless&&i("Form","form",
d+"form.js");i("Checkbox","checkbox",d+"checkbox.js");i("Radio","radio",d+"radio.js");i("TextField","textfield",d+"textfield.js");i("Textarea","textarea",d+"textarea.js");i("Select","select",d+"select.js");i("Button","button",d+"button.js");var j=a.plugins.image;j&&!a.plugins.image2&&i("ImageButton","imagebutton",CKEDITOR.plugins.getPath("image")+"dialogs/image.js");i("HiddenField","hiddenfield",d+"hiddenfield.js");if(a.addMenuItems){i={checkbox:{label:e.forms.checkboxAndRadio.checkboxTitle,command:"checkbox",
group:"checkbox"},radio:{label:e.forms.checkboxAndRadio.radioTitle,command:"radio",group:"radio"},textfield:{label:e.forms.textfield.title,command:"textfield",group:"textfield"},hiddenfield:{label:e.forms.hidden.title,command:"hiddenfield",group:"hiddenfield"},button:{label:e.forms.button.title,command:"button",group:"button"},select:{label:e.forms.select.title,command:"select",group:"select"},textarea:{label:e.forms.textarea.title,command:"textarea",group:"textarea"}};if(j)i.imagebutton={label:e.image.titleButton,
command:"imagebutton",group:"imagebutton"};!a.blockless&&(i.form={label:e.forms.form.menu,command:"form",group:"form"});a.addMenuItems(i)}if(a.contextMenu){!a.blockless&&a.contextMenu.addListener(function(a,b,c){if((a=c.contains("form",1))&&!a.isReadOnly())return{form:CKEDITOR.TRISTATE_OFF}});a.contextMenu.addListener(function(a){if(a&&!a.isReadOnly()){var b=a.getName();if(b=="select")return{select:CKEDITOR.TRISTATE_OFF};if(b=="textarea")return{textarea:CKEDITOR.TRISTATE_OFF};if(b=="input"){var d=
a.getAttribute("type")||"text";switch(d){case "button":case "submit":case "reset":return{button:CKEDITOR.TRISTATE_OFF};case "checkbox":return{checkbox:CKEDITOR.TRISTATE_OFF};case "radio":return{radio:CKEDITOR.TRISTATE_OFF};case "image":return j?{imagebutton:CKEDITOR.TRISTATE_OFF}:null}if(c[d])return{textfield:CKEDITOR.TRISTATE_OFF}}if(b=="img"&&a.data("cke-real-element-type")=="hiddenfield")return{hiddenfield:CKEDITOR.TRISTATE_OFF}}})}a.on("doubleclick",function(b){var d=b.data.element;if(!a.blockless&&
d.is("form"))b.data.dialog="form";else if(d.is("select"))b.data.dialog="select";else if(d.is("textarea"))b.data.dialog="textarea";else if(d.is("img")&&d.data("cke-real-element-type")=="hiddenfield")b.data.dialog="hiddenfield";else if(d.is("input")){d=d.getAttribute("type")||"text";switch(d){case "button":case "submit":case "reset":b.data.dialog="button";break;case "checkbox":b.data.dialog="checkbox";break;case "radio":b.data.dialog="radio";break;case "image":b.data.dialog="imagebutton"}if(c[d])b.data.dialog=
"textfield"}})},afterInit:function(a){var e=a.dataProcessor,b=e&&e.htmlFilter,e=e&&e.dataFilter;CKEDITOR.env.ie&&b&&b.addRules({elements:{input:function(a){var a=a.attributes,b=a.type;if(!b)a.type="text";(b=="checkbox"||b=="radio")&&a.value=="on"&&delete a.value}}},{applyToAll:true});e&&e.addRules({elements:{input:function(b){if(b.attributes.type=="hidden")return a.createFakeParserElement(b,"cke_hidden","hiddenfield")}}},{applyToAll:true})}}),function(){var a={canUndo:false,exec:function(a){var b=
a.document.createElement("hr");a.insertElement(b)},allowedContent:"hr",requiredContent:"hr"};CKEDITOR.plugins.add("horizontalrule",{init:function(e){if(!e.blockless){e.addCommand("horizontalrule",a);e.ui.addButton&&e.ui.addButton("HorizontalRule",{label:e.lang.horizontalrule.toolbar,command:"horizontalrule",toolbar:"insert,40"})}}})}(),CKEDITOR.plugins.add("htmlwriter",{init:function(a){var e=new CKEDITOR.htmlWriter;e.forceSimpleAmpersand=a.config.forceSimpleAmpersand;e.indentationChars=a.config.dataIndentationChars||
"\t";a.dataProcessor.writer=e}}),CKEDITOR.htmlWriter=CKEDITOR.tools.createClass({base:CKEDITOR.htmlParser.basicWriter,$:function(){this.base();this.indentationChars="\t";this.selfClosingEnd=" />";this.lineBreakChars="\n";this.sortAttributes=1;this._.indent=0;this._.indentation="";this._.inPre=0;this._.rules={};var a=CKEDITOR.dtd,e;for(e in CKEDITOR.tools.extend({},a.$nonBodyContent,a.$block,a.$listItem,a.$tableContent))this.setRules(e,{indent:!a[e]["#"],breakBeforeOpen:1,breakBeforeClose:!a[e]["#"],
breakAfterClose:1,needsSpace:e in a.$block&&!(e in{li:1,dt:1,dd:1})});this.setRules("br",{breakAfterOpen:1});this.setRules("title",{indent:0,breakAfterOpen:0});this.setRules("style",{indent:0,breakBeforeClose:1});this.setRules("pre",{breakAfterOpen:1,indent:0})},proto:{openTag:function(a){var e=this._.rules[a];this._.afterCloser&&(e&&e.needsSpace&&this._.needsSpace)&&this._.output.push("\n");if(this._.indent)this.indentation();else if(e&&e.breakBeforeOpen){this.lineBreak();this.indentation()}this._.output.push("<",
a);this._.afterCloser=0},openTagClose:function(a,e){var b=this._.rules[a];if(e){this._.output.push(this.selfClosingEnd);if(b&&b.breakAfterClose)this._.needsSpace=b.needsSpace}else{this._.output.push(">");if(b&&b.indent)this._.indentation=this._.indentation+this.indentationChars}b&&b.breakAfterOpen&&this.lineBreak();a=="pre"&&(this._.inPre=1)},attribute:function(a,e){if(typeof e=="string"){this.forceSimpleAmpersand&&(e=e.replace(/&amp;/g,"&"));e=CKEDITOR.tools.htmlEncodeAttr(e)}this._.output.push(" ",
a,'="',e,'"')},closeTag:function(a){var e=this._.rules[a];if(e&&e.indent)this._.indentation=this._.indentation.substr(this.indentationChars.length);if(this._.indent)this.indentation();else if(e&&e.breakBeforeClose){this.lineBreak();this.indentation()}this._.output.push("</",a,">");a=="pre"&&(this._.inPre=0);if(e&&e.breakAfterClose){this.lineBreak();this._.needsSpace=e.needsSpace}this._.afterCloser=1},text:function(a){if(this._.indent){this.indentation();!this._.inPre&&(a=CKEDITOR.tools.ltrim(a))}this._.output.push(a)},
comment:function(a){this._.indent&&this.indentation();this._.output.push("<\!--",a,"--\>")},lineBreak:function(){!this._.inPre&&this._.output.length>0&&this._.output.push(this.lineBreakChars);this._.indent=1},indentation:function(){!this._.inPre&&this._.indentation&&this._.output.push(this._.indentation);this._.indent=0},reset:function(){this._.output=[];this._.indent=0;this._.indentation="";this._.afterCloser=0;this._.inPre=0},setRules:function(a,e){var b=this._.rules[a];b?CKEDITOR.tools.extend(b,
e,true):this._.rules[a]=e}}}),function(){CKEDITOR.plugins.add("iframe",{requires:"dialog,fakeobjects",onLoad:function(){CKEDITOR.addCss("img.cke_iframe{background-image: url("+CKEDITOR.getUrl(this.path+"images/placeholder.png")+");background-position: center center;background-repeat: no-repeat;border: 1px solid #a9a9a9;width: 80px;height: 80px;}")},init:function(a){var e=a.lang.iframe,b="iframe[align,longdesc,frameborder,height,name,scrolling,src,title,width]";a.plugins.dialogadvtab&&(b=b+(";iframe"+
a.plugins.dialogadvtab.allowedContent({id:1,classes:1,styles:1})));CKEDITOR.dialog.add("iframe",this.path+"dialogs/iframe.js");a.addCommand("iframe",new CKEDITOR.dialogCommand("iframe",{allowedContent:b,requiredContent:"iframe"}));a.ui.addButton&&a.ui.addButton("Iframe",{label:e.toolbar,command:"iframe",toolbar:"insert,80"});a.on("doubleclick",function(a){var b=a.data.element;if(b.is("img")&&b.data("cke-real-element-type")=="iframe")a.data.dialog="iframe"});a.addMenuItems&&a.addMenuItems({iframe:{label:e.title,
command:"iframe",group:"image"}});a.contextMenu&&a.contextMenu.addListener(function(a){if(a&&a.is("img")&&a.data("cke-real-element-type")=="iframe")return{iframe:CKEDITOR.TRISTATE_OFF}})},afterInit:function(a){var e=a.dataProcessor;(e=e&&e.dataFilter)&&e.addRules({elements:{iframe:function(b){return a.createFakeParserElement(b,"cke_iframe","iframe",true)}}})}})}(),function(){function a(a,c){c||(c=a.getSelection().getSelectedElement());if(c&&c.is("img")&&!c.data("cke-realelement")&&!c.isReadOnly())return c}
function e(a){var c=a.getStyle("float");if(c=="inherit"||c=="none")c=0;c||(c=a.getAttribute("align"));return c}CKEDITOR.plugins.add("image",{requires:"dialog",init:function(b){if(!b.plugins.image2){CKEDITOR.dialog.add("image",this.path+"dialogs/image.js");var c="img[alt,!src]{border-style,border-width,float,height,margin,margin-bottom,margin-left,margin-right,margin-top,width}";CKEDITOR.dialog.isTabEnabled(b,"image","advanced")&&(c="img[alt,dir,id,lang,longdesc,!src,title]{*}(*)");b.addCommand("image",
new CKEDITOR.dialogCommand("image",{allowedContent:c,requiredContent:"img[alt,src]",contentTransformations:[["img{width}: sizeToStyle","img[width]: sizeToAttribute"],["img{float}: alignmentToStyle","img[align]: alignmentToAttribute"]]}));b.ui.addButton&&b.ui.addButton("Image",{label:b.lang.common.image,command:"image",toolbar:"insert,10"});b.on("doubleclick",function(a){var b=a.data.element;if(b.is("img")&&!b.data("cke-realelement")&&!b.isReadOnly())a.data.dialog="image"});b.addMenuItems&&b.addMenuItems({image:{label:b.lang.image.menu,
command:"image",group:"image"}});b.contextMenu&&b.contextMenu.addListener(function(c){if(a(b,c))return{image:CKEDITOR.TRISTATE_OFF}})}},afterInit:function(b){function c(c){var k=b.getCommand("justify"+c);if(k){if(c=="left"||c=="right")k.on("exec",function(i){var d=a(b),j;if(d){j=e(d);if(j==c){d.removeStyle("float");c==e(d)&&d.removeAttribute("align")}else d.setStyle("float",c);i.cancel()}});k.on("refresh",function(i){var d=a(b);if(d){d=e(d);this.setState(d==c?CKEDITOR.TRISTATE_ON:c=="right"||c=="left"?
CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);i.cancel()}})}}if(!b.plugins.image2){c("left");c("right");c("center");c("block")}}})}(),CKEDITOR.config.image_removeLinkByEmptyURL=!0,function(){function a(a,f){var k,i;f.on("refresh",function(a){var c=[e],f;for(f in a.data.states)c.push(a.data.states[f]);this.setState(CKEDITOR.tools.search(c,b)?b:e)},f,null,100);f.on("exec",function(b){k=a.getSelection();i=k.createBookmarks(1);if(!b.data)b.data={};b.data.done=false},f,null,0);f.on("exec",function(){a.forceNextSelectionCheck();
k.selectBookmarks(i)},f,null,100)}var e=CKEDITOR.TRISTATE_DISABLED,b=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indent",{init:function(b){var e=CKEDITOR.plugins.indent.genericDefinition;a(b,b.addCommand("indent",new e(true)));a(b,b.addCommand("outdent",new e));if(b.ui.addButton){b.ui.addButton("Indent",{label:b.lang.indent.indent,command:"indent",directional:true,toolbar:"indent,20"});b.ui.addButton("Outdent",{label:b.lang.indent.outdent,command:"outdent",directional:true,toolbar:"indent,10"})}b.on("dirChanged",
function(a){var e=b.createRange(),d=a.data.node;e.setStartBefore(d);e.setEndAfter(d);for(var f=new CKEDITOR.dom.walker(e),h;h=f.next();)if(h.type==CKEDITOR.NODE_ELEMENT)if(!h.equals(d)&&h.getDirection()){e.setStartAfter(h);f=new CKEDITOR.dom.walker(e)}else{var g=b.config.indentClasses;if(g)for(var m=a.data.dir=="ltr"?["_rtl",""]:["","_rtl"],p=0;p<g.length;p++)if(h.hasClass(g[p]+m[0])){h.removeClass(g[p]+m[0]);h.addClass(g[p]+m[1])}g=h.getStyle("margin-right");m=h.getStyle("margin-left");g?h.setStyle("margin-left",
g):h.removeStyle("margin-left");m?h.setStyle("margin-right",m):h.removeStyle("margin-right")}})}});CKEDITOR.plugins.indent={genericDefinition:function(a){this.isIndent=!!a;this.startDisabled=!this.isIndent},specificDefinition:function(a,b,e){this.name=b;this.editor=a;this.jobs={};this.enterBr=a.config.enterMode==CKEDITOR.ENTER_BR;this.isIndent=!!e;this.relatedGlobal=e?"indent":"outdent";this.indentKey=e?9:CKEDITOR.SHIFT+9;this.database={}},registerCommands:function(a,b){a.on("pluginsLoaded",function(){for(var a in b)(function(a,
b){var c=a.getCommand(b.relatedGlobal),e;for(e in b.jobs){c.on("exec",function(c){if(!c.data.done){a.fire("lockSnapshot");if(b.execJob(a,e))c.data.done=true;a.fire("unlockSnapshot");CKEDITOR.dom.element.clearAllMarkers(b.database)}},this,null,e);c.on("refresh",function(c){if(!c.data.states)c.data.states={};c.data.states[b.name+"@"+e]=b.refreshJob(a,e,c.data.path)},this,null,e)}a.addFeature(b)})(this,b[a])})}};CKEDITOR.plugins.indent.genericDefinition.prototype={context:"p",exec:function(){}};CKEDITOR.plugins.indent.specificDefinition.prototype=
{execJob:function(a,b){var k=this.jobs[b];if(k.state!=e)return k.exec.call(this,a)},refreshJob:function(a,b,k){b=this.jobs[b];b.state=a.activeFilter.checkFeature(this)?b.refresh.call(this,a,k):e;return b.state},getContext:function(a){return a.contains(this.context)}}}(),function(){function a(a){function c(e){for(var j=r.startContainer,k=r.endContainer;j&&!j.getParent().equals(e);)j=j.getParent();for(;k&&!k.getParent().equals(e);)k=k.getParent();if(!j||!k)return false;for(var o=j,j=[],n=false;!n;){o.equals(k)&&
(n=true);j.push(o);o=o.getNext()}if(j.length<1)return false;o=e.getParents(true);for(k=0;k<o.length;k++)if(o[k].getName&&i[o[k].getName()]){e=o[k];break}for(var o=f.isIndent?1:-1,k=j[0],j=j[j.length-1],n=CKEDITOR.plugins.list.listToArray(e,g),x=n[j.getCustomData("listarray_index")].indent,k=k.getCustomData("listarray_index");k<=j.getCustomData("listarray_index");k++){n[k].indent=n[k].indent+o;if(o>0){var p=n[k].parent;n[k].parent=new CKEDITOR.dom.element(p.getName(),p.getDocument())}}for(k=j.getCustomData("listarray_index")+
1;k<n.length&&n[k].indent>x;k++)n[k].indent=n[k].indent+o;j=CKEDITOR.plugins.list.arrayToList(n,g,null,a.config.enterMode,e.getDirection());if(!f.isIndent){var q;if((q=e.getParent())&&q.is("li"))for(var o=j.listNode.getChildren(),y=[],z,k=o.count()-1;k>=0;k--)(z=o.getItem(k))&&(z.is&&z.is("li"))&&y.push(z)}j&&j.listNode.replace(e);if(y&&y.length)for(k=0;k<y.length;k++){for(z=e=y[k];(z=z.getNext())&&z.is&&z.getName()in i;){CKEDITOR.env.needsNbspFiller&&!e.getFirst(b)&&e.append(r.document.createText(" "));
e.append(z)}e.insertAfter(q)}j&&a.fire("contentDomInvalidated");return true}for(var f=this,g=this.database,i=this.context,k=a.getSelection(),k=(k&&k.getRanges()).createIterator(),r;r=k.getNextRange();){for(var o=r.getCommonAncestor();o&&!(o.type==CKEDITOR.NODE_ELEMENT&&i[o.getName()]);){if(a.editable().equals(o)){o=false;break}o=o.getParent()}o||(o=r.startPath().contains(i))&&r.setEndAt(o,CKEDITOR.POSITION_BEFORE_END);if(!o){var n=r.getEnclosedNode();if(n&&n.type==CKEDITOR.NODE_ELEMENT&&n.getName()in
i){r.setStartAt(n,CKEDITOR.POSITION_AFTER_START);r.setEndAt(n,CKEDITOR.POSITION_BEFORE_END);o=n}}if(o&&r.startContainer.type==CKEDITOR.NODE_ELEMENT&&r.startContainer.getName()in i){n=new CKEDITOR.dom.walker(r);n.evaluator=e;r.startContainer=n.next()}if(o&&r.endContainer.type==CKEDITOR.NODE_ELEMENT&&r.endContainer.getName()in i){n=new CKEDITOR.dom.walker(r);n.evaluator=e;r.endContainer=n.previous()}if(o)return c(o)}return 0}function e(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.is("li")}function b(a){return c(a)&&
f(a)}var c=CKEDITOR.dom.walker.whitespaces(true),f=CKEDITOR.dom.walker.bookmark(false,true),k=CKEDITOR.TRISTATE_DISABLED,i=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indentlist",{requires:"indent",init:function(b){function c(b){e.specificDefinition.apply(this,arguments);this.requiredContent=["ul","ol"];b.on("key",function(a){if(b.mode=="wysiwyg"&&a.data.keyCode==this.indentKey){var c=this.getContext(b.elementPath());if(c&&(!this.isIndent||!CKEDITOR.plugins.indentList.firstItemInPath(this.context,
b.elementPath(),c))){b.execCommand(this.relatedGlobal);a.cancel()}}},this);this.jobs[this.isIndent?10:30]={refresh:this.isIndent?function(a,b){var c=this.getContext(b),d=CKEDITOR.plugins.indentList.firstItemInPath(this.context,b,c);return!c||!this.isIndent||d?k:i}:function(a,b){return!this.getContext(b)||this.isIndent?k:i},exec:CKEDITOR.tools.bind(a,this)}}var e=CKEDITOR.plugins.indent;e.registerCommands(b,{indentlist:new c(b,"indentlist",true),outdentlist:new c(b,"outdentlist")});CKEDITOR.tools.extend(c.prototype,
e.specificDefinition.prototype,{context:{ol:1,ul:1}})}});CKEDITOR.plugins.indentList={};CKEDITOR.plugins.indentList.firstItemInPath=function(a,b,c){var f=b.contains(e);c||(c=b.contains(a));return c&&f&&f.equals(c.getFirst(e))}}(),function(){function a(a,b,c){if(!a.getCustomData("indent_processed")){var f=this.editor,g=this.isIndent;if(b){f=a.$.className.match(this.classNameRegex);c=0;if(f){f=f[1];c=CKEDITOR.tools.indexOf(b,f)+1}if((c=c+(g?1:-1))<0)return;c=Math.min(c,b.length);c=Math.max(c,0);a.$.className=
CKEDITOR.tools.ltrim(a.$.className.replace(this.classNameRegex,""));c>0&&a.addClass(b[c-1])}else{var b=e(a,c),c=parseInt(a.getStyle(b),10),k=f.config.indentOffset||40;isNaN(c)&&(c=0);c=c+(g?1:-1)*k;if(c<0)return;c=Math.max(c,0);c=Math.ceil(c/k)*k;a.setStyle(b,c?c+(f.config.indentUnit||"px"):"");a.getAttribute("style")===""&&a.removeAttribute("style")}CKEDITOR.dom.element.setMarker(this.database,a,"indent_processed",1)}}function e(a,b){return(b||a.getComputedStyle("direction"))=="ltr"?"margin-left":
"margin-right"}var b=CKEDITOR.dtd.$listItem,c=CKEDITOR.dtd.$list,f=CKEDITOR.TRISTATE_DISABLED,k=CKEDITOR.TRISTATE_OFF;CKEDITOR.plugins.add("indentblock",{requires:"indent",init:function(i){function d(){j.specificDefinition.apply(this,arguments);this.allowedContent={"div h1 h2 h3 h4 h5 h6 ol p pre ul":{propertiesOnly:true,styles:!h?"margin-left,margin-right":null,classes:h||null}};if(this.enterBr)this.allowedContent.div=true;this.requiredContent=(this.enterBr?"div":"p")+(h?"("+h.join(",")+")":"{margin-left}");
this.jobs={20:{refresh:function(a,c){var d=c.block||c.blockLimit;if(!d.is(b))var i=d.getAscendant(b),d=i&&c.contains(i)||d;d.is(b)&&(d=d.getParent());if(!this.enterBr&&!this.getContext(c))return f;if(h){var i=h,d=d.$.className.match(this.classNameRegex),j=this.isIndent,i=d?j?d[1]!=i.slice(-1):true:j;return i?k:f}return this.isIndent?k:d?CKEDITOR[(parseInt(d.getStyle(e(d)),10)||0)<=0?"TRISTATE_DISABLED":"TRISTATE_OFF"]:f},exec:function(b){var d=b.getSelection(),d=d&&d.getRanges()[0],e;if(e=b.elementPath().contains(c))a.call(this,
e,h);else{d=d.createIterator();b=b.config.enterMode;d.enforceRealBlocks=true;for(d.enlargeBr=b!=CKEDITOR.ENTER_BR;e=d.getNextParagraph(b==CKEDITOR.ENTER_P?"p":"div");)e.isReadOnly()||a.call(this,e,h)}return true}}}}var j=CKEDITOR.plugins.indent,h=i.config.indentClasses;j.registerCommands(i,{indentblock:new d(i,"indentblock",true),outdentblock:new d(i,"outdentblock")});CKEDITOR.tools.extend(d.prototype,j.specificDefinition.prototype,{context:{div:1,dl:1,h1:1,h2:1,h3:1,h4:1,h5:1,h6:1,ul:1,ol:1,p:1,
pre:1,table:1},classNameRegex:h?RegExp("(?:^|\\s+)("+h.join("|")+")(?=$|\\s)"):null})}})}(),function(){function a(a,b){var b=b===void 0||b,e;if(b)e=a.getComputedStyle("text-align");else{for(;!a.hasAttribute||!a.hasAttribute("align")&&!a.getStyle("text-align");){e=a.getParent();if(!e)break;a=e}e=a.getStyle("text-align")||a.getAttribute("align")||""}e&&(e=e.replace(/(?:-(?:moz|webkit)-)?(?:start|auto)/i,""));!e&&b&&(e=a.getComputedStyle("direction")=="rtl"?"right":"left");return e}function e(a,b,e){this.editor=
a;this.name=b;this.value=e;this.context="p";var b=a.config.justifyClasses,i=a.config.enterMode==CKEDITOR.ENTER_P?"p":"div";if(b){switch(e){case "left":this.cssClassName=b[0];break;case "center":this.cssClassName=b[1];break;case "right":this.cssClassName=b[2];break;case "justify":this.cssClassName=b[3]}this.cssClassRegex=RegExp("(?:^|\\s+)(?:"+b.join("|")+")(?=$|\\s)");this.requiredContent=i+"("+this.cssClassName+")"}else this.requiredContent=i+"{text-align}";this.allowedContent={"caption div h1 h2 h3 h4 h5 h6 p pre td th li":{propertiesOnly:true,
styles:this.cssClassName?null:"text-align",classes:this.cssClassName||null}};if(a.config.enterMode==CKEDITOR.ENTER_BR)this.allowedContent.div=true}function b(a){var b=a.editor,e=b.createRange();e.setStartBefore(a.data.node);e.setEndAfter(a.data.node);for(var i=new CKEDITOR.dom.walker(e),d;d=i.next();)if(d.type==CKEDITOR.NODE_ELEMENT)if(!d.equals(a.data.node)&&d.getDirection()){e.setStartAfter(d);i=new CKEDITOR.dom.walker(e)}else{var j=b.config.justifyClasses;if(j)if(d.hasClass(j[0])){d.removeClass(j[0]);
d.addClass(j[2])}else if(d.hasClass(j[2])){d.removeClass(j[2]);d.addClass(j[0])}j=d.getStyle("text-align");j=="left"?d.setStyle("text-align","right"):j=="right"&&d.setStyle("text-align","left")}}e.prototype={exec:function(b){var e=b.getSelection(),k=b.config.enterMode;if(e){for(var i=e.createBookmarks(),d=e.getRanges(),j=this.cssClassName,h,g,m=b.config.useComputedState,m=m===void 0||m,p=d.length-1;p>=0;p--){h=d[p].createIterator();for(h.enlargeBr=k!=CKEDITOR.ENTER_BR;g=h.getNextParagraph(k==CKEDITOR.ENTER_P?
"p":"div");)if(!g.isReadOnly()){g.removeAttribute("align");g.removeStyle("text-align");var r=j&&(g.$.className=CKEDITOR.tools.ltrim(g.$.className.replace(this.cssClassRegex,""))),o=this.state==CKEDITOR.TRISTATE_OFF&&(!m||a(g,true)!=this.value);j?o?g.addClass(j):r||g.removeAttribute("class"):o&&g.setStyle("text-align",this.value)}}b.focus();b.forceNextSelectionCheck();e.selectBookmarks(i)}},refresh:function(b,e){var k=e.block||e.blockLimit;this.setState(k.getName()!="body"&&a(k,this.editor.config.useComputedState)==
this.value?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)}};CKEDITOR.plugins.add("justify",{init:function(a){if(!a.blockless){var f=new e(a,"justifyleft","left"),k=new e(a,"justifycenter","center"),i=new e(a,"justifyright","right"),d=new e(a,"justifyblock","justify");a.addCommand("justifyleft",f);a.addCommand("justifycenter",k);a.addCommand("justifyright",i);a.addCommand("justifyblock",d);if(a.ui.addButton){a.ui.addButton("JustifyLeft",{label:a.lang.justify.left,command:"justifyleft",toolbar:"align,10"});
a.ui.addButton("JustifyCenter",{label:a.lang.justify.center,command:"justifycenter",toolbar:"align,20"});a.ui.addButton("JustifyRight",{label:a.lang.justify.right,command:"justifyright",toolbar:"align,30"});a.ui.addButton("JustifyBlock",{label:a.lang.justify.block,command:"justifyblock",toolbar:"align,40"})}a.on("dirChanged",b)}}})}(),"use strict",function(){function a(a){return a.replace(/'/g,"\\$&")}function e(a){for(var b,c=a.length,d=[],e=0;e<c;e++){b=a.charCodeAt(e);d.push(b)}return"String.fromCharCode("+
d.join(",")+")"}function b(b,c){var d=b.plugins.link,e=d.compiledProtectionFunction.params,f,g;g=[d.compiledProtectionFunction.name,"("];for(var i=0;i<e.length;i++){d=e[i].toLowerCase();f=c[d];i>0&&g.push(",");g.push("'",f?a(encodeURIComponent(c[d])):"","'")}g.push(")");return g.join("")}function c(a){var a=a.config.emailProtection||"",b;if(a&&a!="encode"){b={};a.replace(/^([^(]+)\(([^)]+)\)$/,function(a,c,d){b.name=c;b.params=[];d.replace(/[^,\s]+/g,function(a){b.params.push(a)})})}return b}CKEDITOR.plugins.add("link",
{requires:"dialog,fakeobjects",onLoad:function(){function a(b){return c.replace(/%1/g,b=="rtl"?"right":"left").replace(/%2/g,"cke_contents_"+b)}var b="background:url("+CKEDITOR.getUrl(this.path+"images"+(CKEDITOR.env.hidpi?"/hidpi":"")+"/anchor.png")+") no-repeat %1 center;border:1px dotted #00f;background-size:16px;",c=".%2 a.cke_anchor,.%2 a.cke_anchor_empty,.cke_editable.%2 a[name],.cke_editable.%2 a[data-cke-saved-name]{"+b+"padding-%1:18px;cursor:auto;}.%2 img.cke_anchor{"+b+"width:16px;min-height:15px;height:1.15em;vertical-align:text-bottom;}";
CKEDITOR.addCss(a("ltr")+a("rtl"))},init:function(a){var b="a[!href]";CKEDITOR.dialog.isTabEnabled(a,"link","advanced")&&(b=b.replace("]",",accesskey,charset,dir,id,lang,name,rel,tabindex,title,type]{*}(*)"));CKEDITOR.dialog.isTabEnabled(a,"link","target")&&(b=b.replace("]",",target,onclick]"));a.addCommand("link",new CKEDITOR.dialogCommand("link",{allowedContent:b,requiredContent:"a[href]"}));a.addCommand("anchor",new CKEDITOR.dialogCommand("anchor",{allowedContent:"a[!name,id]",requiredContent:"a[name]"}));
a.addCommand("unlink",new CKEDITOR.unlinkCommand);a.addCommand("removeAnchor",new CKEDITOR.removeAnchorCommand);a.setKeystroke(CKEDITOR.CTRL+76,"link");if(a.ui.addButton){a.ui.addButton("Link",{label:a.lang.link.toolbar,command:"link",toolbar:"links,10"});a.ui.addButton("Unlink",{label:a.lang.link.unlink,command:"unlink",toolbar:"links,20"});a.ui.addButton("Anchor",{label:a.lang.link.anchor.toolbar,command:"anchor",toolbar:"links,30"})}CKEDITOR.dialog.add("link",this.path+"dialogs/link.js");CKEDITOR.dialog.add("anchor",
this.path+"dialogs/anchor.js");a.on("doubleclick",function(b){var c=CKEDITOR.plugins.link.getSelectedLink(a)||b.data.element;if(!c.isReadOnly())if(c.is("a")){b.data.dialog=c.getAttribute("name")&&(!c.getAttribute("href")||!c.getChildCount())?"anchor":"link";b.data.link=c}else if(CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,c))b.data.dialog="anchor"},null,null,0);a.on("doubleclick",function(b){b.data.dialog in{link:1,anchor:1}&&b.data.link&&a.getSelection().selectElement(b.data.link)},null,null,20);
a.addMenuItems&&a.addMenuItems({anchor:{label:a.lang.link.anchor.menu,command:"anchor",group:"anchor",order:1},removeAnchor:{label:a.lang.link.anchor.remove,command:"removeAnchor",group:"anchor",order:5},link:{label:a.lang.link.menu,command:"link",group:"link",order:1},unlink:{label:a.lang.link.unlink,command:"unlink",group:"link",order:5}});a.contextMenu&&a.contextMenu.addListener(function(b){if(!b||b.isReadOnly())return null;b=CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,b);if(!b&&!(b=CKEDITOR.plugins.link.getSelectedLink(a)))return null;
var c={};b.getAttribute("href")&&b.getChildCount()&&(c={link:CKEDITOR.TRISTATE_OFF,unlink:CKEDITOR.TRISTATE_OFF});if(b&&b.hasAttribute("name"))c.anchor=c.removeAnchor=CKEDITOR.TRISTATE_OFF;return c});this.compiledProtectionFunction=c(a)},afterInit:function(a){a.dataProcessor.dataFilter.addRules({elements:{a:function(b){return!b.attributes.name?null:!b.children.length?a.createFakeParserElement(b,"cke_anchor","anchor"):null}}});var b=a._.elementsPath&&a._.elementsPath.filters;b&&b.push(function(b,c){if(c==
"a"&&(CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,b)||b.getAttribute("name")&&(!b.getAttribute("href")||!b.getChildCount())))return"anchor"})}});var f=/^javascript:/,k=/^mailto:([^?]+)(?:\?(.+))?$/,i=/subject=([^;?:@&=$,\/]*)/,d=/body=([^;?:@&=$,\/]*)/,j=/^#(.*)$/,h=/^((?:http|https|ftp|news):\/\/)?(.*)$/,g=/^(_(?:self|top|parent|blank))$/,m=/^javascript:void\(location\.href='mailto:'\+String\.fromCharCode\(([^)]+)\)(?:\+'(.*)')?\)$/,p=/^javascript:([^(]+)\(([^)]+)\)$/,r=/\s*window.open\(\s*this\.href\s*,\s*(?:'([^']*)'|null)\s*,\s*'([^']*)'\s*\)\s*;\s*return\s*false;*\s*/,
o=/(?:^|,)([^=]+)=(\d+|yes|no)/gi,n={id:"advId",dir:"advLangDir",accessKey:"advAccessKey",name:"advName",lang:"advLangCode",tabindex:"advTabIndex",title:"advTitle",type:"advContentType","class":"advCSSClasses",charset:"advCharset",style:"advStyles",rel:"advRel"};CKEDITOR.plugins.link={getSelectedLink:function(a){var b=a.getSelection(),c=b.getSelectedElement();if(c&&c.is("a"))return c;if(b=b.getRanges()[0]){b.shrink(CKEDITOR.SHRINK_TEXT);return a.elementPath(b.getCommonAncestor()).contains("a",1)}return null},
getEditorAnchors:function(a){for(var b=a.editable(),c=b.isInline()&&!a.plugins.divarea?a.document:b,b=c.getElementsByTag("a"),c=c.getElementsByTag("img"),d=[],e=0,f;f=b.getItem(e++);)if(f.data("cke-saved-name")||f.hasAttribute("name"))d.push({name:f.data("cke-saved-name")||f.getAttribute("name"),id:f.getAttribute("id")});for(e=0;f=c.getItem(e++);)(f=this.tryRestoreFakeAnchor(a,f))&&d.push({name:f.getAttribute("name"),id:f.getAttribute("id")});return d},fakeAnchor:true,tryRestoreFakeAnchor:function(a,
b){if(b&&b.data("cke-real-element-type")&&b.data("cke-real-element-type")=="anchor"){var c=a.restoreRealElement(b);if(c.data("cke-saved-name"))return c}},parseLinkAttributes:function(a,b){var c=b&&(b.data("cke-saved-href")||b.getAttribute("href"))||"",e=a.plugins.link.compiledProtectionFunction,u=a.config.emailProtection,x,v={};c.match(f)&&(u=="encode"?c=c.replace(m,function(a,b,c){return"mailto:"+String.fromCharCode.apply(String,b.split(","))+(c&&c.replace(/\\'/g,"'"))}):u&&c.replace(p,function(a,
b,c){if(b==e.name){v.type="email";for(var a=v.email={},b=/(^')|('$)/g,c=c.match(/[^,\s]+/g),d=c.length,f,g,i=0;i<d;i++){f=decodeURIComponent;g=c[i].replace(b,"").replace(/\\'/g,"'");g=f(g);f=e.params[i].toLowerCase();a[f]=g}a.address=[a.name,a.domain].join("@")}}));if(!v.type)if(u=c.match(j)){v.type="anchor";v.anchor={};v.anchor.name=v.anchor.id=u[1]}else if(u=c.match(k)){x=c.match(i);c=c.match(d);v.type="email";var q=v.email={};q.address=u[1];x&&(q.subject=decodeURIComponent(x[1]));c&&(q.body=decodeURIComponent(c[1]))}else if(c&&
(x=c.match(h))){v.type="url";v.url={};v.url.protocol=x[1];v.url.url=x[2]}if(b){if(c=b.getAttribute("target"))v.target={type:c.match(g)?c:"frame",name:c};else if(c=(c=b.data("cke-pa-onclick")||b.getAttribute("onclick"))&&c.match(r))for(v.target={type:"popup",name:c[1]};u=o.exec(c[2]);)(u[2]=="yes"||u[2]=="1")&&!(u[1]in{height:1,width:1,top:1,left:1})?v.target[u[1]]=true:isFinite(u[2])&&(v.target[u[1]]=u[2]);var c={},y;for(y in n)(u=b.getAttribute(y))&&(c[n[y]]=u);if(y=b.data("cke-saved-name")||c.advName)c.advName=
y;if(!CKEDITOR.tools.isEmpty(c))v.advanced=c}return v},getLinkAttributes:function(c,d){var f=c.config.emailProtection||"",g={};switch(d.type){case "url":var f=d.url&&d.url.protocol!==void 0?d.url.protocol:"http://",i=d.url&&CKEDITOR.tools.trim(d.url.url)||"";g["data-cke-saved-href"]=i.indexOf("/")===0?i:f+i;break;case "anchor":f=d.anchor&&d.anchor.id;g["data-cke-saved-href"]="#"+(d.anchor&&d.anchor.name||f||"");break;case "email":var h=d.email,i=h.address;switch(f){case "":case "encode":var j=encodeURIComponent(h.subject||
""),k=encodeURIComponent(h.body||""),h=[];j&&h.push("subject="+j);k&&h.push("body="+k);h=h.length?"?"+h.join("&"):"";if(f=="encode"){f=["javascript:void(location.href='mailto:'+",e(i)];h&&f.push("+'",a(h),"'");f.push(")")}else f=["mailto:",i,h];break;default:f=i.split("@",2);h.name=f[0];h.domain=f[1];f=["javascript:",b(c,h)]}g["data-cke-saved-href"]=f.join("")}if(d.target)if(d.target.type=="popup"){for(var f=["window.open(this.href, '",d.target.name||"","', '"],o=["resizable","status","location",
"toolbar","menubar","fullscreen","scrollbars","dependent"],i=o.length,j=function(a){d.target[a]&&o.push(a+"="+d.target[a])},h=0;h<i;h++)o[h]=o[h]+(d.target[o[h]]?"=yes":"=no");j("width");j("left");j("height");j("top");f.push(o.join(","),"'); return false;");g["data-cke-pa-onclick"]=f.join("")}else if(d.target.type!="notSet"&&d.target.name)g.target=d.target.name;if(d.advanced){for(var m in n)(f=d.advanced[n[m]])&&(g[m]=f);if(g.name)g["data-cke-saved-name"]=g.name}if(g["data-cke-saved-href"])g.href=
g["data-cke-saved-href"];m={target:1,onclick:1,"data-cke-pa-onclick":1,"data-cke-saved-name":1};d.advanced&&CKEDITOR.tools.extend(m,n);for(var r in g)delete m[r];return{set:g,removed:CKEDITOR.tools.objectKeys(m)}}};CKEDITOR.unlinkCommand=function(){};CKEDITOR.unlinkCommand.prototype={exec:function(a){var b=new CKEDITOR.style({element:"a",type:CKEDITOR.STYLE_INLINE,alwaysRemoveElement:1});a.removeStyle(b)},refresh:function(a,b){var c=b.lastElement&&b.lastElement.getAscendant("a",true);c&&c.getName()==
"a"&&c.getAttribute("href")&&c.getChildCount()?this.setState(CKEDITOR.TRISTATE_OFF):this.setState(CKEDITOR.TRISTATE_DISABLED)},contextSensitive:1,startDisabled:1,requiredContent:"a[href]"};CKEDITOR.removeAnchorCommand=function(){};CKEDITOR.removeAnchorCommand.prototype={exec:function(a){var b=a.getSelection(),c=b.createBookmarks(),d;if(b&&(d=b.getSelectedElement())&&(!d.getChildCount()?CKEDITOR.plugins.link.tryRestoreFakeAnchor(a,d):d.is("a")))d.remove(1);else if(d=CKEDITOR.plugins.link.getSelectedLink(a))if(d.hasAttribute("href")){d.removeAttributes({name:1,
"data-cke-saved-name":1});d.removeClass("cke_anchor")}else d.remove(1);b.selectBookmarks(c)},requiredContent:"a[name]"};CKEDITOR.tools.extend(CKEDITOR.config,{linkShowAdvancedTab:true,linkShowTargetTab:true})}(),function(){function a(a,b,c){function d(c){if((j=h[c?"getFirst":"getLast"]())&&(!j.is||!j.isBlockBoundary())&&(k=b.root[c?"getPrevious":"getNext"](CKEDITOR.dom.walker.invisible(true)))&&(!k.is||!k.isBlockBoundary({br:1})))a.document.createElement("br")[c?"insertBefore":"insertAfter"](j)}for(var e=
CKEDITOR.plugins.list.listToArray(b.root,c),f=[],g=0;g<b.contents.length;g++){var i=b.contents[g];if((i=i.getAscendant("li",true))&&!i.getCustomData("list_item_processed")){f.push(i);CKEDITOR.dom.element.setMarker(c,i,"list_item_processed",true)}}i=null;for(g=0;g<f.length;g++){i=f[g].getCustomData("listarray_index");e[i].indent=-1}for(g=i+1;g<e.length;g++)if(e[g].indent>e[g-1].indent+1){f=e[g-1].indent+1-e[g].indent;for(i=e[g].indent;e[g]&&e[g].indent>=i;){e[g].indent=e[g].indent+f;g++}g--}var h=
CKEDITOR.plugins.list.arrayToList(e,c,null,a.config.enterMode,b.root.getAttribute("dir")).listNode,j,k;d(true);d();h.replace(b.root);a.fire("contentDomInvalidated")}function e(a,b){this.name=a;this.context=this.type=b;this.allowedContent=b+" li";this.requiredContent=b}function b(a,b,c,d){for(var e,f;e=a[d?"getLast":"getFirst"](r);){(f=e.getDirection(1))!==b.getDirection(1)&&e.setAttribute("dir",f);e.remove();c?e[d?"insertBefore":"insertAfter"](c):b.append(e,d)}}function c(a){function c(d){var e=a[d?
"getPrevious":"getNext"](g);if(e&&e.type==CKEDITOR.NODE_ELEMENT&&e.is(a.getName())){b(a,e,null,!d);a.remove();a=e}}c();c(1)}function f(a){return a.type==CKEDITOR.NODE_ELEMENT&&(a.getName()in CKEDITOR.dtd.$block||a.getName()in CKEDITOR.dtd.$listItem)&&CKEDITOR.dtd[a.getName()]["#"]}function k(a,d,e){a.fire("saveSnapshot");e.enlarge(CKEDITOR.ENLARGE_LIST_ITEM_CONTENTS);var f=e.extractContents();d.trim(false,true);var h=d.createBookmark(),j=new CKEDITOR.dom.elementPath(d.startContainer),k=j.block,j=
j.lastElement.getAscendant("li",1)||k,r=new CKEDITOR.dom.elementPath(e.startContainer),p=r.contains(CKEDITOR.dtd.$listItem),r=r.contains(CKEDITOR.dtd.$list);if(k)(k=k.getBogus())&&k.remove();else if(r)(k=r.getPrevious(g))&&m(k)&&k.remove();(k=f.getLast())&&(k.type==CKEDITOR.NODE_ELEMENT&&k.is("br"))&&k.remove();(k=d.startContainer.getChild(d.startOffset))?f.insertBefore(k):d.startContainer.append(f);if(p)if(f=i(p))if(j.contains(p)){b(f,p.getParent(),p);f.remove()}else j.append(f);for(;e.checkStartOfBlock()&&
e.checkEndOfBlock();){r=e.startPath();f=r.block;if(!f)break;if(f.is("li")){j=f.getParent();f.equals(j.getLast(g))&&f.equals(j.getFirst(g))&&(f=j)}e.moveToPosition(f,CKEDITOR.POSITION_BEFORE_START);f.remove()}e=e.clone();f=a.editable();e.setEndAt(f,CKEDITOR.POSITION_BEFORE_END);e=new CKEDITOR.dom.walker(e);e.evaluator=function(a){return g(a)&&!m(a)};(e=e.next())&&(e.type==CKEDITOR.NODE_ELEMENT&&e.getName()in CKEDITOR.dtd.$list)&&c(e);d.moveToBookmark(h);d.select();a.fire("saveSnapshot")}function i(a){return(a=
a.getLast(g))&&a.type==CKEDITOR.NODE_ELEMENT&&a.getName()in d?a:null}var d={ol:1,ul:1},j=CKEDITOR.dom.walker.whitespaces(),h=CKEDITOR.dom.walker.bookmark(),g=function(a){return!(j(a)||h(a))},m=CKEDITOR.dom.walker.bogus();CKEDITOR.plugins.list={listToArray:function(a,b,c,e,f){if(!d[a.getName()])return[];e||(e=0);c||(c=[]);for(var g=0,i=a.getChildCount();g<i;g++){var h=a.getChild(g);h.type==CKEDITOR.NODE_ELEMENT&&h.getName()in CKEDITOR.dtd.$list&&CKEDITOR.plugins.list.listToArray(h,b,c,e+1);if(h.$.nodeName.toLowerCase()==
"li"){var j={parent:a,indent:e,element:h,contents:[]};if(f)j.grandparent=f;else{j.grandparent=a.getParent();if(j.grandparent&&j.grandparent.$.nodeName.toLowerCase()=="li")j.grandparent=j.grandparent.getParent()}b&&CKEDITOR.dom.element.setMarker(b,h,"listarray_index",c.length);c.push(j);for(var k=0,m=h.getChildCount(),r;k<m;k++){r=h.getChild(k);r.type==CKEDITOR.NODE_ELEMENT&&d[r.getName()]?CKEDITOR.plugins.list.listToArray(r,b,c,e+1,j.grandparent):j.contents.push(r)}}}return c},arrayToList:function(a,
b,c,e,f){c||(c=0);if(!a||a.length<c+1)return null;for(var i,j=a[c].parent.getDocument(),k=new CKEDITOR.dom.documentFragment(j),m=null,r=c,p=Math.max(a[c].indent,0),z=null,B,A,D=e==CKEDITOR.ENTER_P?"p":"div";;){var C=a[r];i=C.grandparent;B=C.element.getDirection(1);if(C.indent==p){if(!m||a[r].parent.getName()!=m.getName()){m=a[r].parent.clone(false,1);f&&m.setAttribute("dir",f);k.append(m)}z=m.append(C.element.clone(0,1));B!=m.getDirection(1)&&z.setAttribute("dir",B);for(i=0;i<C.contents.length;i++)z.append(C.contents[i].clone(1,
1));r++}else if(C.indent==Math.max(p,0)+1){C=a[r-1].element.getDirection(1);r=CKEDITOR.plugins.list.arrayToList(a,null,r,e,C!=B?B:null);!z.getChildCount()&&(CKEDITOR.env.needsNbspFiller&&j.$.documentMode<=7)&&z.append(j.createText(" "));z.append(r.listNode);r=r.nextIndex}else if(C.indent==-1&&!c&&i){if(d[i.getName()]){z=C.element.clone(false,true);B!=i.getDirection(1)&&z.setAttribute("dir",B)}else z=new CKEDITOR.dom.documentFragment(j);var m=i.getDirection(1)!=B,G=C.element,E=G.getAttribute("class"),
H=G.getAttribute("style"),L=z.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT&&(e!=CKEDITOR.ENTER_BR||m||H||E),J,P=C.contents.length,I;for(i=0;i<P;i++){J=C.contents[i];if(h(J)&&P>1)L?I=J.clone(1,1):z.append(J.clone(1,1));else if(J.type==CKEDITOR.NODE_ELEMENT&&J.isBlockBoundary()){m&&!J.getDirection()&&J.setAttribute("dir",B);A=J;var R=G.getAttribute("style");R&&A.setAttribute("style",R.replace(/([^;])$/,"$1;")+(A.getAttribute("style")||""));E&&J.addClass(E);A=null;if(I){z.append(I);I=null}z.append(J.clone(1,
1))}else if(L){if(!A){A=j.createElement(D);z.append(A);m&&A.setAttribute("dir",B)}H&&A.setAttribute("style",H);E&&A.setAttribute("class",E);if(I){A.append(I);I=null}A.append(J.clone(1,1))}else z.append(J.clone(1,1))}if(I){(A||z).append(I);I=null}if(z.type==CKEDITOR.NODE_DOCUMENT_FRAGMENT&&r!=a.length-1){if(CKEDITOR.env.needsBrFiller)(B=z.getLast())&&(B.type==CKEDITOR.NODE_ELEMENT&&B.is("br"))&&B.remove();B=z.getLast(g);(!B||!(B.type==CKEDITOR.NODE_ELEMENT&&B.is(CKEDITOR.dtd.$block)))&&z.append(j.createElement("br"))}B=
z.$.nodeName.toLowerCase();(B=="div"||B=="p")&&z.appendBogus();k.append(z);m=null;r++}else return null;A=null;if(a.length<=r||Math.max(a[r].indent,0)<p)break}if(b)for(a=k.getFirst();a;){if(a.type==CKEDITOR.NODE_ELEMENT){CKEDITOR.dom.element.clearMarkers(b,a);if(a.getName()in CKEDITOR.dtd.$listItem){c=a;j=f=e=void 0;if(e=c.getDirection()){for(f=c.getParent();f&&!(j=f.getDirection());)f=f.getParent();e==j&&c.removeAttribute("dir")}}}a=a.getNextSourceNode()}return{listNode:k,nextIndex:r}}};var p=/^h[1-6]$/,
r=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_ELEMENT);e.prototype={exec:function(b){this.refresh(b,b.elementPath());var e=b.config,f=b.getSelection(),i=f&&f.getRanges();if(this.state==CKEDITOR.TRISTATE_OFF){var h=b.editable();if(h.getFirst(g)){var j=i.length==1&&i[0];(e=j&&j.getEnclosedNode())&&(e.is&&this.type==e.getName())&&this.setState(CKEDITOR.TRISTATE_ON)}else{e.enterMode==CKEDITOR.ENTER_BR?h.appendBogus():i[0].fixBlock(1,e.enterMode==CKEDITOR.ENTER_P?"p":"div");f.selectRanges(i)}}for(var e=
f.createBookmarks(true),h=[],k={},i=i.createIterator(),m=0;(j=i.getNextRange())&&++m;){var r=j.getBoundaryNodes(),q=r.startNode,y=r.endNode;q.type==CKEDITOR.NODE_ELEMENT&&q.getName()=="td"&&j.setStartAt(r.startNode,CKEDITOR.POSITION_AFTER_START);y.type==CKEDITOR.NODE_ELEMENT&&y.getName()=="td"&&j.setEndAt(r.endNode,CKEDITOR.POSITION_BEFORE_END);j=j.createIterator();for(j.forceBrBreak=this.state==CKEDITOR.TRISTATE_OFF;r=j.getNextParagraph();)if(!r.getCustomData("list_block")){CKEDITOR.dom.element.setMarker(k,
r,"list_block",1);for(var z=b.elementPath(r),q=z.elements,y=0,z=z.blockLimit,B,A=q.length-1;A>=0&&(B=q[A]);A--)if(d[B.getName()]&&z.contains(B)){z.removeCustomData("list_group_object_"+m);if(q=B.getCustomData("list_group_object"))q.contents.push(r);else{q={root:B,contents:[r]};h.push(q);CKEDITOR.dom.element.setMarker(k,B,"list_group_object",q)}y=1;break}if(!y){y=z;if(y.getCustomData("list_group_object_"+m))y.getCustomData("list_group_object_"+m).contents.push(r);else{q={root:y,contents:[r]};CKEDITOR.dom.element.setMarker(k,
y,"list_group_object_"+m,q);h.push(q)}}}}for(B=[];h.length>0;){q=h.shift();if(this.state==CKEDITOR.TRISTATE_OFF)if(d[q.root.getName()]){i=b;m=q;q=k;j=B;y=CKEDITOR.plugins.list.listToArray(m.root,q);z=[];for(r=0;r<m.contents.length;r++){A=m.contents[r];if((A=A.getAscendant("li",true))&&!A.getCustomData("list_item_processed")){z.push(A);CKEDITOR.dom.element.setMarker(q,A,"list_item_processed",true)}}for(var A=m.root.getDocument(),D=void 0,C=void 0,r=0;r<z.length;r++){var G=z[r].getCustomData("listarray_index"),
D=y[G].parent;if(!D.is(this.type)){C=A.createElement(this.type);D.copyAttributes(C,{start:1,type:1});C.removeStyle("list-style-type");y[G].parent=C}}q=CKEDITOR.plugins.list.arrayToList(y,q,null,i.config.enterMode);y=void 0;z=q.listNode.getChildCount();for(r=0;r<z&&(y=q.listNode.getChild(r));r++)y.getName()==this.type&&j.push(y);q.listNode.replace(m.root);i.fire("contentDomInvalidated")}else{y=b;r=q;j=B;z=r.contents;i=r.root.getDocument();m=[];if(z.length==1&&z[0].equals(r.root)){q=i.createElement("div");
z[0].moveChildren&&z[0].moveChildren(q);z[0].append(q);z[0]=q}r=r.contents[0].getParent();for(A=0;A<z.length;A++)r=r.getCommonAncestor(z[A].getParent());D=y.config.useComputedState;y=q=void 0;D=D===void 0||D;for(A=0;A<z.length;A++)for(C=z[A];G=C.getParent();){if(G.equals(r)){m.push(C);!y&&C.getDirection()&&(y=1);C=C.getDirection(D);q!==null&&(q=q&&q!=C?null:C);break}C=G}if(!(m.length<1)){z=m[m.length-1].getNext();A=i.createElement(this.type);j.push(A);for(D=j=void 0;m.length;){j=m.shift();D=i.createElement("li");
if(j.is("pre")||p.test(j.getName())||j.getAttribute("contenteditable")=="false")j.appendTo(D);else{j.copyAttributes(D);if(q&&j.getDirection()){D.removeStyle("direction");D.removeAttribute("dir")}j.moveChildren(D);j.remove()}D.appendTo(A)}q&&y&&A.setAttribute("dir",q);z?A.insertBefore(z):A.appendTo(r)}}else this.state==CKEDITOR.TRISTATE_ON&&d[q.root.getName()]&&a.call(this,b,q,k)}for(A=0;A<B.length;A++)c(B[A]);CKEDITOR.dom.element.clearAllMarkers(k);f.selectBookmarks(e);b.focus()},refresh:function(a,
b){var c=b.contains(d,1),e=b.blockLimit||b.root;c&&e.contains(c)?this.setState(c.is(this.type)?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF):this.setState(CKEDITOR.TRISTATE_OFF)}};CKEDITOR.plugins.add("list",{requires:"indentlist",init:function(a){if(!a.blockless){a.addCommand("numberedlist",new e("numberedlist","ol"));a.addCommand("bulletedlist",new e("bulletedlist","ul"));if(a.ui.addButton){a.ui.addButton("NumberedList",{label:a.lang.list.numberedlist,command:"numberedlist",directional:true,toolbar:"list,10"});
a.ui.addButton("BulletedList",{label:a.lang.list.bulletedlist,command:"bulletedlist",directional:true,toolbar:"list,20"})}a.on("key",function(b){var c=b.data.domEvent.getKey(),e;if(a.mode=="wysiwyg"&&c in{8:1,46:1}){var h=a.getSelection().getRanges()[0],j=h&&h.startPath();if(h&&h.collapsed){var r=c==8,p=a.editable(),v=new CKEDITOR.dom.walker(h.clone());v.evaluator=function(a){return g(a)&&!m(a)};v.guard=function(a,b){return!(b&&a.type==CKEDITOR.NODE_ELEMENT&&a.is("table"))};c=h.clone();if(r){var q;
if((q=j.contains(d))&&h.checkBoundaryOfElement(q,CKEDITOR.START)&&(q=q.getParent())&&q.is("li")&&(q=i(q))){e=q;q=q.getPrevious(g);c.moveToPosition(q&&m(q)?q:e,CKEDITOR.POSITION_BEFORE_START)}else{v.range.setStartAt(p,CKEDITOR.POSITION_AFTER_START);v.range.setEnd(h.startContainer,h.startOffset);if((q=v.previous())&&q.type==CKEDITOR.NODE_ELEMENT&&(q.getName()in d||q.is("li"))){if(!q.is("li")){v.range.selectNodeContents(q);v.reset();v.evaluator=f;q=v.previous()}e=q;c.moveToElementEditEnd(e);c.moveToPosition(c.endPath().block,
CKEDITOR.POSITION_BEFORE_END)}}if(e){k(a,c,h);b.cancel()}else{var y=j.contains(d);if(y&&h.checkBoundaryOfElement(y,CKEDITOR.START)){e=y.getFirst(g);if(h.checkBoundaryOfElement(e,CKEDITOR.START)){q=y.getPrevious(g);if(i(e)){if(q){h.moveToElementEditEnd(q);h.select()}}else a.execCommand("outdent");b.cancel()}}}}else if(e=j.contains("li")){v.range.setEndAt(p,CKEDITOR.POSITION_BEFORE_END);r=(p=e.getLast(g))&&f(p)?p:e;j=0;if((q=v.next())&&q.type==CKEDITOR.NODE_ELEMENT&&q.getName()in d&&q.equals(p)){j=
1;q=v.next()}else h.checkBoundaryOfElement(r,CKEDITOR.END)&&(j=2);if(j&&q){h=h.clone();h.moveToElementEditStart(q);if(j==1){c.optimize();if(!c.startContainer.equals(e)){for(e=c.startContainer;e.is(CKEDITOR.dtd.$inline);){y=e;e=e.getParent()}y&&c.moveToPosition(y,CKEDITOR.POSITION_AFTER_END)}}if(j==2){c.moveToPosition(c.endPath().block,CKEDITOR.POSITION_BEFORE_END);h.endPath().block&&h.moveToPosition(h.endPath().block,CKEDITOR.POSITION_AFTER_START)}k(a,c,h);b.cancel()}}else{v.range.setEndAt(p,CKEDITOR.POSITION_BEFORE_END);
if((q=v.next())&&q.type==CKEDITOR.NODE_ELEMENT&&q.is(d)){q=q.getFirst(g);if(j.block&&h.checkStartOfBlock()&&h.checkEndOfBlock()){j.block.remove();h.moveToElementEditStart(q);h.select()}else if(i(q)){h.moveToElementEditStart(q);h.select()}else{h=h.clone();h.moveToElementEditStart(q);k(a,c,h)}b.cancel()}}setTimeout(function(){a.selectionChange(1)})}}})}}})}(),function(){CKEDITOR.plugins.liststyle={requires:"dialog,contextmenu",init:function(a){if(!a.blockless){var e;e=new CKEDITOR.dialogCommand("numberedListStyle",
{requiredContent:"ol",allowedContent:"ol{list-style-type}[start]"});e=a.addCommand("numberedListStyle",e);a.addFeature(e);CKEDITOR.dialog.add("numberedListStyle",this.path+"dialogs/liststyle.js");e=new CKEDITOR.dialogCommand("bulletedListStyle",{requiredContent:"ul",allowedContent:"ul{list-style-type}"});e=a.addCommand("bulletedListStyle",e);a.addFeature(e);CKEDITOR.dialog.add("bulletedListStyle",this.path+"dialogs/liststyle.js");a.addMenuGroup("list",108);a.addMenuItems({numberedlist:{label:a.lang.liststyle.numberedTitle,
group:"list",command:"numberedListStyle"},bulletedlist:{label:a.lang.liststyle.bulletedTitle,group:"list",command:"bulletedListStyle"}});a.contextMenu.addListener(function(a){if(!a||a.isReadOnly())return null;for(;a;){var c=a.getName();if(c=="ol")return{numberedlist:CKEDITOR.TRISTATE_OFF};if(c=="ul")return{bulletedlist:CKEDITOR.TRISTATE_OFF};a=a.getParent()}return null})}}};CKEDITOR.plugins.add("liststyle",CKEDITOR.plugins.liststyle)}(),"use strict",function(){function a(a,b,c){return g(b)&&g(c)&&
c.equals(b.getNext(function(a){return!(Q(a)||V(a)||m(a))}))}function e(a){this.upper=a[0];this.lower=a[1];this.set.apply(this,a.slice(2))}function b(a){var b=a.element;if(b&&g(b))if((b=b.getAscendant(a.triggers,true))&&a.editable.contains(b)){var c=k(b);if(c.getAttribute("contenteditable")=="true")return b;if(c.is(a.triggers))return c}return null}function c(a,b,c){w(a,b);w(a,c);a=b.size.bottom;c=c.size.top;return a&&c?0|(a+c)/2:a||c}function f(a,b,c){return b=b[c?"getPrevious":"getNext"](function(b){return b&&
b.type==CKEDITOR.NODE_TEXT&&!Q(b)||g(b)&&!m(b)&&!h(a,b)})}function k(a,b){if(a.data("cke-editable"))return null;for(b||(a=a.getParent());a;){if(a.data("cke-editable"))break;if(a.hasAttribute("contenteditable"))return a;a=a.getParent()}return null}function i(a){var b=a.doc,c=z('<span contenteditable="false" style="'+F+"position:absolute;border-top:1px dashed "+a.boxColor+'"></span>',b),e=CKEDITOR.getUrl(this.path+"images/"+(B.hidpi?"hidpi/":"")+"icon"+(a.rtl?"-rtl":"")+".png");q(c,{attach:function(){this.wrap.getParent()||
this.wrap.appendTo(a.editable,true);return this},lineChildren:[q(z('<span title="'+a.editor.lang.magicline.title+'" contenteditable="false">&#8629;</span>',b),{base:F+"height:17px;width:17px;"+(a.rtl?"left":"right")+":17px;background:url("+e+") center no-repeat "+a.boxColor+";cursor:pointer;"+(B.hc?"font-size: 15px;line-height:14px;border:1px solid #fff;text-align:center;":"")+(B.hidpi?"background-size: 9px 10px;":""),looks:["top:-8px; border-radius: 2px;","top:-17px; border-radius: 2px 2px 0px 0px;",
"top:-1px; border-radius: 0px 0px 2px 2px;"]}),q(z(N,b),{base:M+"left:0px;border-left-color:"+a.boxColor+";",looks:["border-width:8px 0 8px 8px;top:-8px","border-width:8px 0 0 8px;top:-8px","border-width:0 0 8px 8px;top:0px"]}),q(z(N,b),{base:M+"right:0px;border-right-color:"+a.boxColor+";",looks:["border-width:8px 8px 8px 0;top:-8px","border-width:8px 8px 0 0;top:-8px","border-width:0 8px 8px 0;top:0px"]})],detach:function(){this.wrap.getParent()&&this.wrap.remove();return this},mouseNear:function(){w(a,
this);var b=a.holdDistance,c=this.size;return c&&a.mouse.y>c.top-b&&a.mouse.y<c.bottom+b&&a.mouse.x>c.left-b&&a.mouse.x<c.right+b?true:false},place:function(){var b=a.view,c=a.editable,d=a.trigger,e=d.upper,f=d.lower,g=e||f,i=g.getParent(),h={};this.trigger=d;e&&w(a,e,true);f&&w(a,f,true);w(a,i,true);a.inInlineMode&&u(a,true);if(i.equals(c)){h.left=b.scroll.x;h.right=-b.scroll.x;h.width=""}else{h.left=g.size.left-g.size.margin.left+b.scroll.x-(a.inInlineMode?b.editable.left+b.editable.border.left:
0);h.width=g.size.outerWidth+g.size.margin.left+g.size.margin.right+b.scroll.x;h.right=""}if(e&&f)h.top=e.size.margin.bottom===f.size.margin.top?0|e.size.bottom+e.size.margin.bottom/2:e.size.margin.bottom<f.size.margin.top?e.size.bottom+e.size.margin.bottom:e.size.bottom+e.size.margin.bottom-f.size.margin.top;else if(e){if(!f)h.top=e.size.bottom+e.size.margin.bottom}else h.top=f.size.top-f.size.margin.top;if(d.is(P)||h.top>b.scroll.y-15&&h.top<b.scroll.y+5){h.top=a.inInlineMode?0:b.scroll.y;this.look(P)}else if(d.is(I)||
h.top>b.pane.bottom-5&&h.top<b.pane.bottom+15){h.top=a.inInlineMode?b.editable.height+b.editable.padding.top+b.editable.padding.bottom:b.pane.bottom-1;this.look(I)}else{if(a.inInlineMode)h.top=h.top-(b.editable.top+b.editable.border.top);this.look(R)}if(a.inInlineMode){h.top--;h.top=h.top+b.editable.scroll.top;h.left=h.left+b.editable.scroll.left}for(var j in h)h[j]=CKEDITOR.tools.cssLength(h[j]);this.setStyles(h)},look:function(a){if(this.oldLook!=a){for(var b=this.lineChildren.length,c;b--;)(c=
this.lineChildren[b]).setAttribute("style",c.base+c.looks[0|a/2]);this.oldLook=a}},wrap:new y("span",a.doc)});for(b=c.lineChildren.length;b--;)c.lineChildren[b].appendTo(c);c.look(R);c.appendTo(c.wrap);c.unselectable();c.lineChildren[0].on("mouseup",function(b){c.detach();d(a,function(b){var c=a.line.trigger;b[c.is(G)?"insertBefore":"insertAfter"](c.is(G)?c.lower:c.upper)},true);a.editor.focus();!B.ie&&a.enterMode!=CKEDITOR.ENTER_BR&&a.hotNode.scrollIntoView();b.data.preventDefault(true)});c.on("mousedown",
function(a){a.data.preventDefault(true)});a.line=c}function d(a,b,c){var d=new CKEDITOR.dom.range(a.doc),e=a.editor,f;if(B.ie&&a.enterMode==CKEDITOR.ENTER_BR)f=a.doc.createText(T);else{f=(f=k(a.element,true))&&f.data("cke-enter-mode")||a.enterMode;f=new y(C[f],a.doc);f.is("br")||a.doc.createText(T).appendTo(f)}c&&e.fire("saveSnapshot");b(f);d.moveToPosition(f,CKEDITOR.POSITION_AFTER_START);e.getSelection().selectRanges([d]);a.hotNode=f;c&&e.fire("saveSnapshot")}function j(a,c){return{canUndo:true,
modes:{wysiwyg:1},exec:function(){function e(b){var f=B.ie&&B.version<9?" ":T,g=a.hotNode&&a.hotNode.getText()==f&&a.element.equals(a.hotNode)&&a.lastCmdDirection===!!c;d(a,function(d){g&&a.hotNode&&a.hotNode.remove();d[c?"insertAfter":"insertBefore"](b);d.setAttributes({"data-cke-magicline-hot":1,"data-cke-magicline-dir":!!c});a.lastCmdDirection=!!c});!B.ie&&a.enterMode!=CKEDITOR.ENTER_BR&&a.hotNode.scrollIntoView();a.line.detach()}return function(d){var d=d.getSelection().getStartElement(),i,d=
d.getAscendant(da,1);if(!o(a,d)&&d&&!d.equals(a.editable)&&!d.contains(a.editable)){if((i=k(d))&&i.getAttribute("contenteditable")=="false")d=i;a.element=d;i=f(a,d,!c);var h;if(g(i)&&i.is(a.triggers)&&i.is(S)&&(!f(a,i,!c)||(h=f(a,i,!c))&&g(h)&&h.is(a.triggers)))e(i);else{h=b(a,d);if(g(h))if(f(a,h,!c))(d=f(a,h,!c))&&(g(d)&&d.is(a.triggers))&&e(h);else e(h)}}}}()}}function h(a,b){if(!b||!(b.type==CKEDITOR.NODE_ELEMENT&&b.$))return false;var c=a.line;return c.wrap.equals(b)||c.wrap.contains(b)}function g(a){return a&&
a.type==CKEDITOR.NODE_ELEMENT&&a.$}function m(a){if(!g(a))return false;var b;if(!(b=p(a)))if(g(a)){b={left:1,right:1,center:1};b=!(!b[a.getComputedStyle("float")]&&!b[a.getAttribute("align")])}else b=false;return b}function p(a){return!!{absolute:1,fixed:1}[a.getComputedStyle("position")]}function r(a,b){return g(b)?b.is(a.triggers):null}function o(a,b){if(!b)return false;for(var c=b.getParents(1),d=c.length;d--;)for(var e=a.tabuList.length;e--;)if(c[d].hasAttribute(a.tabuList[e]))return true;return false}
function n(a,b,c){b=b[c?"getLast":"getFirst"](function(b){return a.isRelevant(b)&&!b.is(ca)});if(!b)return false;w(a,b);return c?b.size.top>a.mouse.y:b.size.bottom<a.mouse.y}function l(a){var b=a.editable,c=a.mouse,d=a.view,f=a.triggerOffset;u(a);var i=c.y>(a.inInlineMode?d.editable.top+d.editable.height/2:Math.min(d.editable.height,d.pane.height)/2),b=b[i?"getLast":"getFirst"](function(a){return!(Q(a)||V(a))});if(!b)return null;h(a,b)&&(b=a.line.wrap[i?"getPrevious":"getNext"](function(a){return!(Q(a)||
V(a))}));if(!g(b)||m(b)||!r(a,b))return null;w(a,b);if(!i&&b.size.top>=0&&c.y>0&&c.y<b.size.top+f){a=a.inInlineMode||d.scroll.y===0?P:R;return new e([null,b,G,L,a])}if(i&&b.size.bottom<=d.pane.height&&c.y>b.size.bottom-f&&c.y<d.pane.height){a=a.inInlineMode||b.size.bottom>d.pane.height-f&&b.size.bottom<d.pane.height?I:R;return new e([b,null,E,L,a])}return null}function s(a){var c=a.mouse,d=a.view,i=a.triggerOffset,h=b(a);if(!h)return null;w(a,h);var i=Math.min(i,0|h.size.outerHeight/2),j=[],k,l;if(c.y>
h.size.top-1&&c.y<h.size.top+i)l=false;else if(c.y>h.size.bottom-i&&c.y<h.size.bottom+1)l=true;else return null;if(m(h)||n(a,h,l)||h.getParent().is(X))return null;var o=f(a,h,!l);if(o){if(o&&o.type==CKEDITOR.NODE_TEXT)return null;if(g(o)){if(m(o)||!r(a,o)||o.getParent().is(X))return null;j=[o,h][l?"reverse":"concat"]().concat([H,L])}}else{if(h.equals(a.editable[l?"getLast":"getFirst"](a.isRelevant))){u(a);l&&c.y>h.size.bottom-i&&c.y<d.pane.height&&h.size.bottom>d.pane.height-i&&h.size.bottom<d.pane.height?
k=I:c.y>0&&c.y<h.size.top+i&&(k=P)}else k=R;j=[null,h][l?"reverse":"concat"]().concat([l?E:G,L,k,h.equals(a.editable[l?"getLast":"getFirst"](a.isRelevant))?l?I:P:R])}return 0 in j?new e(j):null}function t(a,b,c,d){for(var e=b.getDocumentPosition(),f={},g={},i={},h={},j=O.length;j--;){f[O[j]]=parseInt(b.getComputedStyle.call(b,"border-"+O[j]+"-width"),10)||0;i[O[j]]=parseInt(b.getComputedStyle.call(b,"padding-"+O[j]),10)||0;g[O[j]]=parseInt(b.getComputedStyle.call(b,"margin-"+O[j]),10)||0}(!c||d)&&
x(a,d);h.top=e.y-(c?0:a.view.scroll.y);h.left=e.x-(c?0:a.view.scroll.x);h.outerWidth=b.$.offsetWidth;h.outerHeight=b.$.offsetHeight;h.height=h.outerHeight-(i.top+i.bottom+f.top+f.bottom);h.width=h.outerWidth-(i.left+i.right+f.left+f.right);h.bottom=h.top+h.outerHeight;h.right=h.left+h.outerWidth;if(a.inInlineMode)h.scroll={top:b.$.scrollTop,left:b.$.scrollLeft};return q({border:f,padding:i,margin:g,ignoreScroll:c},h,true)}function w(a,b,c){if(!g(b))return b.size=null;if(b.size){if(b.size.ignoreScroll==
c&&b.size.date>new Date-K)return null}else b.size={};return q(b.size,t(a,b,c),{date:+new Date},true)}function u(a,b){a.view.editable=t(a,a.editable,b,true)}function x(a,b){if(!a.view)a.view={};var c=a.view;if(b||!(c&&c.date>new Date-K)){var d=a.win,c=d.getScrollPosition(),d=d.getViewPaneSize();q(a.view,{scroll:{x:c.x,y:c.y,width:a.doc.$.documentElement.scrollWidth-d.width,height:a.doc.$.documentElement.scrollHeight-d.height},pane:{width:d.width,height:d.height,bottom:d.height+c.y},date:+new Date},
true)}}function v(a,b,c,d){for(var f=d,g=d,i=0,h=false,j=false,k=a.view.pane.height,l=a.mouse;l.y+i<k&&l.y-i>0;){h||(h=b(f,d));j||(j=b(g,d));!h&&l.y-i>0&&(f=c(a,{x:l.x,y:l.y-i}));!j&&l.y+i<k&&(g=c(a,{x:l.x,y:l.y+i}));if(h&&j)break;i=i+2}return new e([f,g,null,null])}CKEDITOR.plugins.add("magicline",{init:function(a){var c=a.config,k=c.magicline_triggerOffset||30,n={editor:a,enterMode:c.enterMode,triggerOffset:k,holdDistance:0|k*(c.magicline_holdDistance||0.5),boxColor:c.magicline_color||"#ff0000",
rtl:c.contentsLangDirection=="rtl",tabuList:["data-cke-hidden-sel"].concat(c.magicline_tabuList||[]),triggers:c.magicline_everywhere?da:{table:1,hr:1,div:1,ul:1,ol:1,dl:1,form:1,blockquote:1}},r,w,v;n.isRelevant=function(a){return g(a)&&!h(n,a)&&!m(a)};a.on("contentDom",function(){var g=a.editable(),k=a.document,m=a.window;q(n,{editable:g,inInlineMode:g.isInline(),doc:k,win:m,hotNode:null},true);n.boundary=n.inInlineMode?n.editable:n.doc.getDocumentElement();if(!g.is(D.$inline)){n.inInlineMode&&!p(g)&&
g.setStyles({position:"relative",top:null,left:null});i.call(this,n);x(n);g.attachListener(a,"beforeUndoImage",function(){n.line.detach()});g.attachListener(a,"beforeGetData",function(){if(n.line.wrap.getParent()){n.line.detach();a.once("getData",function(){n.line.attach()},null,null,1E3)}},null,null,0);g.attachListener(n.inInlineMode?k:k.getWindow().getFrame(),"mouseout",function(b){if(a.mode=="wysiwyg")if(n.inInlineMode){var c=b.data.$.clientX,b=b.data.$.clientY;x(n);u(n,true);var d=n.view.editable,
e=n.view.scroll;if(!(c>d.left-e.x&&c<d.right-e.x)||!(b>d.top-e.y&&b<d.bottom-e.y)){clearTimeout(v);v=null;n.line.detach()}}else{clearTimeout(v);v=null;n.line.detach()}});g.attachListener(g,"keyup",function(){n.hiddenMode=0});g.attachListener(g,"keydown",function(b){if(a.mode=="wysiwyg")switch(b.data.getKeystroke()){case 2228240:case 16:n.hiddenMode=1;n.line.detach()}});g.attachListener(n.inInlineMode?g:k,"mousemove",function(b){w=true;if(!(a.mode!="wysiwyg"||a.readOnly||v)){var c={x:b.data.$.clientX,
y:b.data.$.clientY};v=setTimeout(function(){n.mouse=c;v=n.trigger=null;x(n);if(w&&!n.hiddenMode&&a.focusManager.hasFocus&&!n.line.mouseNear()&&(n.element=U(n,true))){if((n.trigger=l(n)||s(n)||Z(n))&&!o(n,n.trigger.upper||n.trigger.lower))n.line.attach().place();else{n.trigger=null;n.line.detach()}w=false}},30)}});g.attachListener(m,"scroll",function(){if(a.mode=="wysiwyg"){n.line.detach();if(B.webkit){n.hiddenMode=1;clearTimeout(r);r=setTimeout(function(){if(!n.mouseDown)n.hiddenMode=0},50)}}});g.attachListener(A?
k:m,"mousedown",function(){if(a.mode=="wysiwyg"){n.line.detach();n.hiddenMode=1;n.mouseDown=1}});g.attachListener(A?k:m,"mouseup",function(){n.hiddenMode=0;n.mouseDown=0});a.addCommand("accessPreviousSpace",j(n));a.addCommand("accessNextSpace",j(n,true));a.setKeystroke([[c.magicline_keystrokePrevious,"accessPreviousSpace"],[c.magicline_keystrokeNext,"accessNextSpace"]]);a.on("loadSnapshot",function(){var b,c,d,e;for(e in{p:1,br:1,div:1}){b=a.document.getElementsByTag(e);for(d=b.count();d--;)if((c=
b.getItem(d)).data("cke-magicline-hot")){n.hotNode=c;n.lastCmdDirection=c.data("cke-magicline-dir")==="true"?true:false;return}}});this.backdoor={accessFocusSpace:d,boxTrigger:e,isLine:h,getAscendantTrigger:b,getNonEmptyNeighbour:f,getSize:t,that:n,triggerEdge:s,triggerEditable:l,triggerExpand:Z}}},this)}});var q=CKEDITOR.tools.extend,y=CKEDITOR.dom.element,z=y.createFromHtml,B=CKEDITOR.env,A=CKEDITOR.env.ie&&CKEDITOR.env.version<9,D=CKEDITOR.dtd,C={},G=128,E=64,H=32,L=16,J=8,P=4,I=2,R=1,T=" ",X=
D.$listItem,ca=D.$tableContent,S=q({},D.$nonEditable,D.$empty),da=D.$block,K=100,F="width:0px;height:0px;padding:0px;margin:0px;display:block;z-index:9999;color:#fff;position:absolute;font-size: 0px;line-height:0px;",M=F+"border-color:transparent;display:block;border-style:solid;",N="<span>"+T+"</span>";C[CKEDITOR.ENTER_BR]="br";C[CKEDITOR.ENTER_P]="p";C[CKEDITOR.ENTER_DIV]="div";e.prototype={set:function(a,b,c){this.properties=a+b+(c||R);return this},is:function(a){return(this.properties&a)==a}};
var U=function(){function a(b,c){var d=b.$.elementFromPoint(c.x,c.y);return d&&d.nodeType?new CKEDITOR.dom.element(d):null}return function(b,c,d){if(!b.mouse)return null;var e=b.doc,f=b.line.wrap,d=d||b.mouse,g=a(e,d);if(c&&h(b,g)){f.hide();g=a(e,d);f.show()}return!g||!(g.type==CKEDITOR.NODE_ELEMENT&&g.$)||B.ie&&B.version<9&&!b.boundary.equals(g)&&!b.boundary.contains(g)?null:g}}(),Q=CKEDITOR.dom.walker.whitespaces(),V=CKEDITOR.dom.walker.nodeType(CKEDITOR.NODE_COMMENT),Z=function(){function b(e){var f=
e.element,i,h,j;if(!g(f)||f.contains(e.editable)||f.isReadOnly())return null;j=v(e,function(a,b){return!b.equals(a)},function(a,b){return U(a,true,b)},f);i=j.upper;h=j.lower;if(a(e,i,h))return j.set(H,J);if(i&&f.contains(i))for(;!i.getParent().equals(f);)i=i.getParent();else i=f.getFirst(function(a){return d(e,a)});if(h&&f.contains(h))for(;!h.getParent().equals(f);)h=h.getParent();else h=f.getLast(function(a){return d(e,a)});if(!i||!h)return null;w(e,i);w(e,h);if(!(e.mouse.y>i.size.top&&e.mouse.y<
h.size.bottom))return null;for(var f=Number.MAX_VALUE,k,l,n,o;h&&!h.equals(i);){if(!(l=i.getNext(e.isRelevant)))break;k=Math.abs(c(e,i,l)-e.mouse.y);if(k<f){f=k;n=i;o=l}i=l;w(e,i)}if(!n||!o||!(e.mouse.y>n.size.top&&e.mouse.y<o.size.bottom))return null;j.upper=n;j.lower=o;return j.set(H,J)}function d(a,b){return!(b&&b.type==CKEDITOR.NODE_TEXT||V(b)||m(b)||h(a,b)||b.type==CKEDITOR.NODE_ELEMENT&&b.$&&b.is("br"))}return function(c){var d=b(c),e;if(e=d){e=d.upper;var f=d.lower;e=!e||!f||m(f)||m(e)||f.equals(e)||
e.equals(f)||f.contains(e)||e.contains(f)?false:r(c,e)&&r(c,f)&&a(c,e,f)?true:false}return e?d:null}}(),O=["top","left","right","bottom"]}(),CKEDITOR.config.magicline_keystrokePrevious=CKEDITOR.CTRL+CKEDITOR.SHIFT+51,CKEDITOR.config.magicline_keystrokeNext=CKEDITOR.CTRL+CKEDITOR.SHIFT+52,function(){function a(a){if(!a||a.type!=CKEDITOR.NODE_ELEMENT||a.getName()!="form")return[];for(var b=[],c=["style","className"],e=0;e<c.length;e++){var f=a.$.elements.namedItem(c[e]);if(f){f=new CKEDITOR.dom.element(f);
b.push([f,f.nextSibling]);f.remove()}}return b}function e(a,b){if(a&&!(a.type!=CKEDITOR.NODE_ELEMENT||a.getName()!="form")&&b.length>0)for(var c=b.length-1;c>=0;c--){var e=b[c][0],f=b[c][1];f?e.insertBefore(f):e.appendTo(a)}}function b(b,c){var d=a(b),f={},h=b.$;if(!c){f["class"]=h.className||"";h.className=""}f.inline=h.style.cssText||"";if(!c)h.style.cssText="position: static; overflow: visible";e(d);return f}function c(b,c){var d=a(b),f=b.$;if("class"in c)f.className=c["class"];if("inline"in c)f.style.cssText=
c.inline;e(d)}function f(a){if(!a.editable().isInline()){var b=CKEDITOR.instances,c;for(c in b){var e=b[c];if(e.mode=="wysiwyg"&&!e.readOnly){e=e.document.getBody();e.setAttribute("contentEditable",false);e.setAttribute("contentEditable",true)}}if(a.editable().hasFocus){a.toolbox.focus();a.focus()}}}CKEDITOR.plugins.add("maximize",{init:function(a){function e(){var b=h.getViewPaneSize();a.resize(b.width,b.height,null,true)}if(a.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var d=a.lang,j=CKEDITOR.document,
h=j.getWindow(),g,m,p,r=CKEDITOR.TRISTATE_OFF;a.addCommand("maximize",{modes:{wysiwyg:!CKEDITOR.env.iOS,source:!CKEDITOR.env.iOS},readOnly:1,editorFocus:false,exec:function(){var o=a.container.getFirst(function(a){return a.type==CKEDITOR.NODE_ELEMENT&&a.hasClass("cke_inner")}),n=a.ui.space("contents");if(a.mode=="wysiwyg"){var l=a.getSelection();g=l&&l.getRanges();m=h.getScrollPosition()}else{var s=a.editable().$;g=!CKEDITOR.env.ie&&[s.selectionStart,s.selectionEnd];m=[s.scrollLeft,s.scrollTop]}if(this.state==
CKEDITOR.TRISTATE_OFF){h.on("resize",e);p=h.getScrollPosition();for(l=a.container;l=l.getParent();){l.setCustomData("maximize_saved_styles",b(l));l.setStyle("z-index",a.config.baseFloatZIndex-5)}n.setCustomData("maximize_saved_styles",b(n,true));o.setCustomData("maximize_saved_styles",b(o,true));n={overflow:CKEDITOR.env.webkit?"":"hidden",width:0,height:0};j.getDocumentElement().setStyles(n);!CKEDITOR.env.gecko&&j.getDocumentElement().setStyle("position","fixed");(!CKEDITOR.env.gecko||!CKEDITOR.env.quirks)&&
j.getBody().setStyles(n);CKEDITOR.env.ie?setTimeout(function(){h.$.scrollTo(0,0)},0):h.$.scrollTo(0,0);o.setStyle("position",CKEDITOR.env.gecko&&CKEDITOR.env.quirks?"fixed":"absolute");o.$.offsetLeft;o.setStyles({"z-index":a.config.baseFloatZIndex-5,left:"0px",top:"0px"});o.addClass("cke_maximized");e();n=o.getDocumentPosition();o.setStyles({left:-1*n.x+"px",top:-1*n.y+"px"});CKEDITOR.env.gecko&&f(a)}else if(this.state==CKEDITOR.TRISTATE_ON){h.removeListener("resize",e);for(var l=[n,o],t=0;t<l.length;t++){c(l[t],
l[t].getCustomData("maximize_saved_styles"));l[t].removeCustomData("maximize_saved_styles")}for(l=a.container;l=l.getParent();){c(l,l.getCustomData("maximize_saved_styles"));l.removeCustomData("maximize_saved_styles")}CKEDITOR.env.ie?setTimeout(function(){h.$.scrollTo(p.x,p.y)},0):h.$.scrollTo(p.x,p.y);o.removeClass("cke_maximized");if(CKEDITOR.env.webkit){o.setStyle("display","inline");setTimeout(function(){o.setStyle("display","block")},0)}a.fire("resize",{outerHeight:a.container.$.offsetHeight,
contentsHeight:n.$.offsetHeight,outerWidth:a.container.$.offsetWidth})}this.toggleState();if(l=this.uiItems[0]){n=this.state==CKEDITOR.TRISTATE_OFF?d.maximize.maximize:d.maximize.minimize;l=CKEDITOR.document.getById(l._.id);l.getChild(1).setHtml(n);l.setAttribute("title",n);l.setAttribute("href",'javascript:void("'+n+'");')}if(a.mode=="wysiwyg")if(g){CKEDITOR.env.gecko&&f(a);a.getSelection().selectRanges(g);(s=a.getSelection().getStartElement())&&s.scrollIntoView(true)}else h.$.scrollTo(m.x,m.y);
else{if(g){s.selectionStart=g[0];s.selectionEnd=g[1]}s.scrollLeft=m[0];s.scrollTop=m[1]}g=m=null;r=this.state;a.fire("maximize",this.state)},canUndo:false});a.ui.addButton&&a.ui.addButton("Maximize",{label:d.maximize.maximize,command:"maximize",toolbar:"tools,10"});a.on("mode",function(){var b=a.getCommand("maximize");b.setState(b.state==CKEDITOR.TRISTATE_DISABLED?CKEDITOR.TRISTATE_DISABLED:r)},null,null,100)}}})}(),CKEDITOR.plugins.add("newpage",{init:function(a){a.addCommand("newpage",{modes:{wysiwyg:1,
source:1},exec:function(a){var b=this;a.setData(a.config.newpage_html||"",function(){a.focus();setTimeout(function(){a.fire("afterCommandExec",{name:"newpage",command:b});a.selectionChange()},200)})},async:true});a.ui.addButton&&a.ui.addButton("NewPage",{label:a.lang.newpage.toolbar,command:"newpage",toolbar:"document,20"})}}),"use strict",function(){function a(a){return{"aria-label":a,"class":"cke_pagebreak",contenteditable:"false","data-cke-display-name":"pagebreak","data-cke-pagebreak":1,style:"page-break-after: always",
title:a}}CKEDITOR.plugins.add("pagebreak",{requires:"fakeobjects",onLoad:function(){var a=("background:url("+CKEDITOR.getUrl(this.path+"images/pagebreak.gif")+") no-repeat center center;clear:both;width:100%;border-top:#999 1px dotted;border-bottom:#999 1px dotted;padding:0;height:7px;cursor:default;").replace(/;/g," !important;");CKEDITOR.addCss("div.cke_pagebreak{"+a+"}")},init:function(a){if(!a.blockless){a.addCommand("pagebreak",CKEDITOR.plugins.pagebreakCmd);a.ui.addButton&&a.ui.addButton("PageBreak",
{label:a.lang.pagebreak.toolbar,command:"pagebreak",toolbar:"insert,70"});CKEDITOR.env.webkit&&a.on("contentDom",function(){a.document.on("click",function(b){b=b.data.getTarget();b.is("div")&&b.hasClass("cke_pagebreak")&&a.getSelection().selectElement(b)})})}},afterInit:function(e){function b(b){CKEDITOR.tools.extend(b.attributes,a(e.lang.pagebreak.alt),true);b.children.length=0}var c=e.dataProcessor,f=c&&c.dataFilter,c=c&&c.htmlFilter,k=/page-break-after\s*:\s*always/i,i=/display\s*:\s*none/i;c&&
c.addRules({attributes:{"class":function(a,b){var c=a.replace("cke_pagebreak","");if(c!=a){var e=CKEDITOR.htmlParser.fragment.fromHtml('<span style="display: none;">&nbsp;</span>').children[0];b.children.length=0;b.add(e);e=b.attributes;delete e["aria-label"];delete e.contenteditable;delete e.title}return c}}},{applyToAll:true,priority:5});f&&f.addRules({elements:{div:function(a){if(a.attributes["data-cke-pagebreak"])b(a);else if(k.test(a.attributes.style)){var c=a.children[0];c&&(c.name=="span"&&
i.test(c.attributes.style))&&b(a)}}}})}});CKEDITOR.plugins.pagebreakCmd={exec:function(e){var b=e.document.createElement("div",{attributes:a(e.lang.pagebreak.alt)});e.insertElement(b)},context:"div",allowedContent:{div:{styles:"!page-break-after"},span:{match:function(a){return(a=a.parent)&&a.name=="div"&&a.styles&&a.styles["page-break-after"]},styles:"display"}},requiredContent:"div{page-break-after}"}}(),function(){function a(a,c,e){var k=CKEDITOR.cleanWord;if(k)e();else{a=CKEDITOR.getUrl(a.config.pasteFromWordCleanupFile||
c+"filter/default.js");CKEDITOR.scriptLoader.load(a,e,null,true)}return!k}function e(a){a.data.type="html"}CKEDITOR.plugins.add("pastefromword",{requires:"clipboard",init:function(b){var c=0,f=this.path;b.addCommand("pastefromword",{canUndo:false,async:true,exec:function(a){var b=this;c=1;a.once("beforePaste",e);a.getClipboardData({title:a.lang.pastefromword.title},function(c){c&&a.fire("paste",{type:"html",dataValue:c.dataValue,method:"paste",dataTransfer:CKEDITOR.plugins.clipboard.initPasteDataTransfer()});
a.fire("afterCommandExec",{name:"pastefromword",command:b,returnValue:!!c})})}});b.ui.addButton&&b.ui.addButton("PasteFromWord",{label:b.lang.pastefromword.toolbar,command:"pastefromword",toolbar:"clipboard,50"});b.on("pasteState",function(a){b.getCommand("pastefromword").setState(a.data)});b.on("paste",function(e){var i=e.data,d=i.dataValue;if(d&&(c||/(class=\"?Mso|style=\"[^\"]*\bmso\-|w:WordDocument)/.test(d))){i.dontFilter=true;var j=a(b,f,function(){if(j)b.fire("paste",i);else if(!b.config.pasteFromWordPromptCleanup||
c||confirm(b.lang.pastefromword.confirmCleanup))i.dataValue=CKEDITOR.cleanWord(d,b);c=0});j&&e.cancel()}},null,null,3)}})}(),function(){var a={canUndo:false,async:true,exec:function(e){e.getClipboardData({title:e.lang.pastetext.title},function(b){b&&e.fire("paste",{type:"text",dataValue:b.dataValue,method:"paste",dataTransfer:CKEDITOR.plugins.clipboard.initPasteDataTransfer()});e.fire("afterCommandExec",{name:"pastetext",command:a,returnValue:!!b})})}};CKEDITOR.plugins.add("pastetext",{requires:"clipboard",
init:function(e){e.addCommand("pastetext",a);e.ui.addButton&&e.ui.addButton("PasteText",{label:e.lang.pastetext.button,command:"pastetext",toolbar:"clipboard,40"});if(e.config.forcePasteAsPlainText)e.on("beforePaste",function(a){if(a.data.type!="html")a.data.type="text"});e.on("pasteState",function(a){e.getCommand("pastetext").setState(a.data)})}})}(),function(){var a,e={modes:{wysiwyg:1,source:1},canUndo:false,readOnly:1,exec:function(b){var c,e=b.config,k=e.baseHref?'<base href="'+e.baseHref+'"/>':
"";if(e.fullPage)c=b.getData().replace(/<head>/,"$&"+k).replace(/[^>]*(?=<\/title>)/,"$& &mdash; "+b.lang.preview.preview);else{var e="<body ",i=b.document&&b.document.getBody();if(i){i.getAttribute("id")&&(e=e+('id="'+i.getAttribute("id")+'" '));i.getAttribute("class")&&(e=e+('class="'+i.getAttribute("class")+'" '))}c=b.config.docType+'<html dir="'+b.config.contentsLangDirection+'"><head>'+k+"<title>"+b.lang.preview.preview+"</title>"+CKEDITOR.tools.buildStyleHtml(b.config.contentsCss)+"</head>"+
(e+">")+b.getData()+"</body></html>"}k=640;e=420;i=80;try{var d=window.screen,k=Math.round(d.width*0.8),e=Math.round(d.height*0.7),i=Math.round(d.width*0.1)}catch(j){}if(b.fire("contentPreview",b={dataValue:c})===false)return false;var d="",h;if(CKEDITOR.env.ie){window._cke_htmlToLoad=b.dataValue;h="javascript:void( (function(){document.open();"+("("+CKEDITOR.tools.fixDomain+")();").replace(/\/\/.*?\n/g,"").replace(/parent\./g,"window.opener.")+"document.write( window.opener._cke_htmlToLoad );document.close();window.opener._cke_htmlToLoad = null;})() )";
d=""}if(CKEDITOR.env.gecko){window._cke_htmlToLoad=b.dataValue;d=CKEDITOR.getUrl(a+"preview.html")}d=window.open(d,null,"toolbar=yes,location=no,status=yes,menubar=yes,scrollbars=yes,resizable=yes,width="+k+",height="+e+",left="+i);if(CKEDITOR.env.ie&&d)d.location=h;if(!CKEDITOR.env.ie&&!CKEDITOR.env.gecko){h=d.document;h.open();h.write(b.dataValue);h.close()}return true}};CKEDITOR.plugins.add("preview",{init:function(b){if(b.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){a=this.path;b.addCommand("preview",
e);b.ui.addButton&&b.ui.addButton("Preview",{label:b.lang.preview.preview,command:"preview",toolbar:"document,40"})}}})}(),CKEDITOR.plugins.add("print",{init:function(a){if(a.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){a.addCommand("print",CKEDITOR.plugins.print);a.ui.addButton&&a.ui.addButton("Print",{label:a.lang.print.toolbar,command:"print",toolbar:"document,50"})}}}),CKEDITOR.plugins.print={exec:function(a){CKEDITOR.env.gecko?a.window.$.print():a.document.$.execCommand("Print")},canUndo:!1,readOnly:1,
modes:{wysiwyg:1}},CKEDITOR.plugins.add("removeformat",{init:function(a){a.addCommand("removeFormat",CKEDITOR.plugins.removeformat.commands.removeformat);a.ui.addButton&&a.ui.addButton("RemoveFormat",{label:a.lang.removeformat.toolbar,command:"removeFormat",toolbar:"cleanup,10"})}}),CKEDITOR.plugins.removeformat={commands:{removeformat:{exec:function(a){for(var e=a._.removeFormatRegex||(a._.removeFormatRegex=RegExp("^(?:"+a.config.removeFormatTags.replace(/,/g,"|")+")$","i")),b=a._.removeAttributes||
(a._.removeAttributes=a.config.removeFormatAttributes.split(",")),c=CKEDITOR.plugins.removeformat.filter,f=a.getSelection().getRanges(),k=f.createIterator(),i=function(a){return a.type==CKEDITOR.NODE_ELEMENT},d;d=k.getNextRange();){d.collapsed||d.enlarge(CKEDITOR.ENLARGE_ELEMENT);var j=d.createBookmark(),h=j.startNode,g=j.endNode,m=function(b){for(var d=a.elementPath(b),f=d.elements,g=1,i;i=f[g];g++){if(i.equals(d.block)||i.equals(d.blockLimit))break;e.test(i.getName())&&c(a,i)&&b.breakParent(i)}};
m(h);if(g){m(g);for(h=h.getNextSourceNode(true,CKEDITOR.NODE_ELEMENT);h;){if(h.equals(g))break;if(h.isReadOnly()){if(h.getPosition(g)&CKEDITOR.POSITION_CONTAINS)break;h=h.getNext(i)}else{m=h.getNextSourceNode(false,CKEDITOR.NODE_ELEMENT);if(!(h.getName()=="img"&&h.data("cke-realelement"))&&c(a,h))if(e.test(h.getName()))h.remove(1);else{h.removeAttributes(b);a.fire("removeFormatCleanup",h)}h=m}}}d.moveToBookmark(j)}a.forceNextSelectionCheck();a.getSelection().selectRanges(f)}}},filter:function(a,e){for(var b=
a._.removeFormatFilters||[],c=0;c<b.length;c++)if(b[c](e)===false)return false;return true}},CKEDITOR.editor.prototype.addRemoveFormatFilter=function(a){if(!this._.removeFormatFilters)this._.removeFormatFilters=[];this._.removeFormatFilters.push(a)},CKEDITOR.config.removeFormatTags="b,big,cite,code,del,dfn,em,font,i,ins,kbd,q,s,samp,small,span,strike,strong,sub,sup,tt,u,var",CKEDITOR.config.removeFormatAttributes="class,style,lang,width,height,align,hspace,valign",CKEDITOR.plugins.add("resize",{init:function(a){var e,
b,c,f;function k(g){var i=e,j=b,k=i+(g.data.$.screenX-c)*(h=="rtl"?-1:1),g=j+(g.data.$.screenY-f);m&&(i=Math.max(d.resize_minWidth,Math.min(k,d.resize_maxWidth)));p&&(j=Math.max(d.resize_minHeight,Math.min(g,d.resize_maxHeight)));a.resize(m?i:null,j)}function i(){CKEDITOR.document.removeListener("mousemove",k);CKEDITOR.document.removeListener("mouseup",i);if(a.document){a.document.removeListener("mousemove",k);a.document.removeListener("mouseup",i)}}var d=a.config,j=a.ui.spaceId("resizer"),h=a.element?
a.element.getDirection(1):"ltr";!d.resize_dir&&(d.resize_dir="vertical");d.resize_maxWidth===void 0&&(d.resize_maxWidth=3E3);d.resize_maxHeight===void 0&&(d.resize_maxHeight=3E3);d.resize_minWidth===void 0&&(d.resize_minWidth=750);d.resize_minHeight===void 0&&(d.resize_minHeight=250);if(d.resize_enabled!==false){var g=null,m=(d.resize_dir=="both"||d.resize_dir=="horizontal")&&d.resize_minWidth!=d.resize_maxWidth,p=(d.resize_dir=="both"||d.resize_dir=="vertical")&&d.resize_minHeight!=d.resize_maxHeight,
r=CKEDITOR.tools.addFunction(function(h){g||(g=a.getResizable());e=g.$.offsetWidth||0;b=g.$.offsetHeight||0;c=h.screenX;f=h.screenY;d.resize_minWidth>e&&(d.resize_minWidth=e);d.resize_minHeight>b&&(d.resize_minHeight=b);CKEDITOR.document.on("mousemove",k);CKEDITOR.document.on("mouseup",i);if(a.document){a.document.on("mousemove",k);a.document.on("mouseup",i)}h.preventDefault&&h.preventDefault()});a.on("destroy",function(){CKEDITOR.tools.removeFunction(r)});a.on("uiSpace",function(b){if(b.data.space==
"bottom"){var c="";m&&!p&&(c=" cke_resizer_horizontal");!m&&p&&(c=" cke_resizer_vertical");var d='<span id="'+j+'" class="cke_resizer'+c+" cke_resizer_"+h+'" title="'+CKEDITOR.tools.htmlEncode(a.lang.common.resize)+'" onmousedown="CKEDITOR.tools.callFunction('+r+', event)">'+(h=="ltr"?"◢":"◣")+"</span>";h=="ltr"&&c=="ltr"?b.data.html=b.data.html+d:b.data.html=d+b.data.html}},a,null,100);a.on("maximize",function(b){a.ui.space("resizer")[b.data==CKEDITOR.TRISTATE_ON?"hide":"show"]()})}}}),function(){var a=
{readOnly:1,exec:function(a){if(a.fire("save"))if(a=a.element.$.form)try{a.submit()}catch(b){a.submit.click&&a.submit.click()}}};CKEDITOR.plugins.add("save",{init:function(e){if(e.elementMode==CKEDITOR.ELEMENT_MODE_REPLACE){e.addCommand("save",a).modes={wysiwyg:!!e.element.$.form};e.ui.addButton&&e.ui.addButton("Save",{label:e.lang.save.toolbar,command:"save",toolbar:"document,10"})}}})}(),function(){CKEDITOR.plugins.add("selectall",{init:function(a){a.addCommand("selectAll",{modes:{wysiwyg:1,source:1},
exec:function(a){var b=a.editable();if(b.is("textarea")){a=b.$;if(CKEDITOR.env.ie)a.createTextRange().execCommand("SelectAll");else{a.selectionStart=0;a.selectionEnd=a.value.length}a.focus()}else{if(b.is("body"))a.document.$.execCommand("SelectAll",false,null);else{var c=a.createRange();c.selectNodeContents(b);c.select()}a.forceNextSelectionCheck();a.selectionChange()}},canUndo:false});a.ui.addButton&&a.ui.addButton("SelectAll",{label:a.lang.selectall.toolbar,command:"selectAll",toolbar:"selection,10"})}})}(),
function(){var a={readOnly:1,preserveState:true,editorFocus:false,exec:function(a){this.toggleState();this.refresh(a)},refresh:function(a){if(a.document){var b=this.state==CKEDITOR.TRISTATE_ON&&(a.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE||a.focusManager.hasFocus)?"attachClass":"removeClass";a.editable()[b]("cke_show_blocks")}}};CKEDITOR.plugins.add("showblocks",{onLoad:function(){var a=["p","div","pre","address","blockquote","h1","h2","h3","h4","h5","h6"],b,c,f,k,i=CKEDITOR.getUrl(this.path),d=!(CKEDITOR.env.ie&&
CKEDITOR.env.version<9),j=d?":not([contenteditable=false]):not(.cke_show_blocks_off)":"",h,g;for(b=c=f=k="";h=a.pop();){g=a.length?",":"";b=b+(".cke_show_blocks "+h+j+g);f=f+(".cke_show_blocks.cke_contents_ltr "+h+j+g);k=k+(".cke_show_blocks.cke_contents_rtl "+h+j+g);c=c+(".cke_show_blocks "+h+j+"{background-image:url("+CKEDITOR.getUrl(i+"images/block_"+h+".png")+")}")}CKEDITOR.addCss((b+"{background-repeat:no-repeat;border:1px dotted gray;padding-top:8px}").concat(c,f+"{background-position:top left;padding-left:8px}",
k+"{background-position:top right;padding-right:8px}"));d||CKEDITOR.addCss(".cke_show_blocks [contenteditable=false],.cke_show_blocks .cke_show_blocks_off{border:none;padding-top:0;background-image:none}.cke_show_blocks.cke_contents_rtl [contenteditable=false],.cke_show_blocks.cke_contents_rtl .cke_show_blocks_off{padding-right:0}.cke_show_blocks.cke_contents_ltr [contenteditable=false],.cke_show_blocks.cke_contents_ltr .cke_show_blocks_off{padding-left:0}")},init:function(e){function b(){c.refresh(e)}
if(!e.blockless){var c=e.addCommand("showblocks",a);c.canUndo=false;e.config.startupOutlineBlocks&&c.setState(CKEDITOR.TRISTATE_ON);e.ui.addButton&&e.ui.addButton("ShowBlocks",{label:e.lang.showblocks.toolbar,command:"showblocks",toolbar:"tools,20"});e.on("mode",function(){c.state!=CKEDITOR.TRISTATE_DISABLED&&c.refresh(e)});if(e.elementMode==CKEDITOR.ELEMENT_MODE_INLINE){e.on("focus",b);e.on("blur",b)}e.on("contentDom",function(){c.state!=CKEDITOR.TRISTATE_DISABLED&&c.refresh(e)})}}})}(),function(){var a=
{preserveState:true,editorFocus:false,readOnly:1,exec:function(a){this.toggleState();this.refresh(a)},refresh:function(a){if(a.document){var b=this.state==CKEDITOR.TRISTATE_ON?"attachClass":"removeClass";a.editable()[b]("cke_show_borders")}}};CKEDITOR.plugins.add("showborders",{modes:{wysiwyg:1},onLoad:function(){var a;a=(CKEDITOR.env.ie6Compat?[".%1 table.%2,",".%1 table.%2 td, .%1 table.%2 th","{","border : #d3d3d3 1px dotted","}"]:[".%1 table.%2,",".%1 table.%2 > tr > td, .%1 table.%2 > tr > th,",
".%1 table.%2 > tbody > tr > td, .%1 table.%2 > tbody > tr > th,",".%1 table.%2 > thead > tr > td, .%1 table.%2 > thead > tr > th,",".%1 table.%2 > tfoot > tr > td, .%1 table.%2 > tfoot > tr > th","{","border : #d3d3d3 1px dotted","}"]).join("").replace(/%2/g,"cke_show_border").replace(/%1/g,"cke_show_borders ");CKEDITOR.addCss(a)},init:function(e){var b=e.addCommand("showborders",a);b.canUndo=false;e.config.startupShowBorders!==false&&b.setState(CKEDITOR.TRISTATE_ON);e.on("mode",function(){b.state!=
CKEDITOR.TRISTATE_DISABLED&&b.refresh(e)},null,null,100);e.on("contentDom",function(){b.state!=CKEDITOR.TRISTATE_DISABLED&&b.refresh(e)});e.on("removeFormatCleanup",function(a){a=a.data;e.getCommand("showborders").state==CKEDITOR.TRISTATE_ON&&(a.is("table")&&(!a.hasAttribute("border")||parseInt(a.getAttribute("border"),10)<=0))&&a.addClass("cke_show_border")})},afterInit:function(a){var b=a.dataProcessor,a=b&&b.dataFilter,b=b&&b.htmlFilter;a&&a.addRules({elements:{table:function(a){var a=a.attributes,
b=a["class"],e=parseInt(a.border,10);if((!e||e<=0)&&(!b||b.indexOf("cke_show_border")==-1))a["class"]=(b||"")+" cke_show_border"}}});b&&b.addRules({elements:{table:function(a){var a=a.attributes,b=a["class"];b&&(a["class"]=b.replace("cke_show_border","").replace(/\s{2}/," ").replace(/^\s+|\s+$/,""))}}})}});CKEDITOR.on("dialogDefinition",function(a){var b=a.data.name;if(b=="table"||b=="tableProperties"){a=a.data.definition;b=a.getContents("info").get("txtBorder");b.commit=CKEDITOR.tools.override(b.commit,
function(a){return function(b,e){a.apply(this,arguments);var i=parseInt(this.getValue(),10);e[!i||i<=0?"addClass":"removeClass"]("cke_show_border")}});if(a=(a=a.getContents("advanced"))&&a.get("advCSSClasses")){a.setup=CKEDITOR.tools.override(a.setup,function(a){return function(){a.apply(this,arguments);this.setValue(this.getValue().replace(/cke_show_border/,""))}});a.commit=CKEDITOR.tools.override(a.commit,function(a){return function(b,e){a.apply(this,arguments);parseInt(e.getAttribute("border"),
10)||e.addClass("cke_show_border")}})}}})}(),CKEDITOR.plugins.add("smiley",{requires:"dialog",init:function(a){a.config.smiley_path=a.config.smiley_path||this.path+"images/";a.addCommand("smiley",new CKEDITOR.dialogCommand("smiley",{allowedContent:"img[alt,height,!src,title,width]",requiredContent:"img"}));a.ui.addButton&&a.ui.addButton("Smiley",{label:a.lang.smiley.toolbar,command:"smiley",toolbar:"insert,50"});CKEDITOR.dialog.add("smiley",this.path+"dialogs/smiley.js")}}),CKEDITOR.config.smiley_images=
"regular_smile.png sad_smile.png wink_smile.png teeth_smile.png confused_smile.png tongue_smile.png embarrassed_smile.png omg_smile.png whatchutalkingabout_smile.png angry_smile.png angel_smile.png shades_smile.png devil_smile.png cry_smile.png lightbulb.png thumbs_down.png thumbs_up.png heart.png broken_heart.png kiss.png envelope.png".split(" "),CKEDITOR.config.smiley_descriptions="smiley;sad;wink;laugh;frown;cheeky;blush;surprise;indecision;angry;angel;cool;devil;crying;enlightened;no;yes;heart;broken heart;kiss;mail".split(";"),
function(){CKEDITOR.plugins.add("sourcearea",{init:function(e){function b(){var a=f&&this.equals(CKEDITOR.document.getActive());this.hide();this.setStyle("height",this.getParent().$.clientHeight+"px");this.setStyle("width",this.getParent().$.clientWidth+"px");this.show();a&&this.focus()}if(e.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var c=CKEDITOR.plugins.sourcearea;e.addMode("source",function(c){var f=e.ui.space("contents").getDocument().createElement("textarea");f.setStyles(CKEDITOR.tools.extend({width:CKEDITOR.env.ie7Compat?
"99%":"100%",height:"100%",resize:"none",outline:"none","text-align":"left"},CKEDITOR.tools.cssVendorPrefix("tab-size",e.config.sourceAreaTabSize||4)));f.setAttribute("dir","ltr");f.addClass("cke_source").addClass("cke_reset").addClass("cke_enable_context_menu");e.ui.space("contents").append(f);f=e.editable(new a(e,f));f.setData(e.getData(1));if(CKEDITOR.env.ie){f.attachListener(e,"resize",b,f);f.attachListener(CKEDITOR.document.getWindow(),"resize",b,f);CKEDITOR.tools.setTimeout(b,0,f)}e.fire("ariaWidget",
this);c()});e.addCommand("source",c.commands.source);e.ui.addButton&&e.ui.addButton("Source",{label:e.lang.sourcearea.toolbar,command:"source",toolbar:"mode,10"});e.on("mode",function(){e.getCommand("source").setState(e.mode=="source"?CKEDITOR.TRISTATE_ON:CKEDITOR.TRISTATE_OFF)});var f=CKEDITOR.env.ie&&CKEDITOR.env.version==9}}});var a=CKEDITOR.tools.createClass({base:CKEDITOR.editable,proto:{setData:function(a){this.setValue(a);this.status="ready";this.editor.fire("dataReady")},getData:function(){return this.getValue()},
insertHtml:function(){},insertElement:function(){},insertText:function(){},setReadOnly:function(a){this[(a?"set":"remove")+"Attribute"]("readOnly","readonly")},detach:function(){a.baseProto.detach.call(this);this.clearCustomData();this.remove()}}})}(),CKEDITOR.plugins.sourcearea={commands:{source:{modes:{wysiwyg:1,source:1},editorFocus:!1,readOnly:1,exec:function(a){a.mode=="wysiwyg"&&a.fire("saveSnapshot");a.getCommand("source").setState(CKEDITOR.TRISTATE_DISABLED);a.setMode(a.mode=="source"?"wysiwyg":
"source")},canUndo:!1}}},CKEDITOR.plugins.add("specialchar",{availableLangs:{af:1,ar:1,bg:1,ca:1,cs:1,cy:1,da:1,de:1,el:1,en:1,"en-gb":1,eo:1,es:1,et:1,fa:1,fi:1,fr:1,"fr-ca":1,gl:1,he:1,hr:1,hu:1,id:1,it:1,ja:1,km:1,ko:1,ku:1,lt:1,lv:1,nb:1,nl:1,no:1,pl:1,pt:1,"pt-br":1,ru:1,si:1,sk:1,sl:1,sq:1,sv:1,th:1,tr:1,tt:1,ug:1,uk:1,vi:1,zh:1,"zh-cn":1},requires:"dialog",init:function(a){var e=this;CKEDITOR.dialog.add("specialchar",this.path+"dialogs/specialchar.js");a.addCommand("specialchar",{exec:function(){var b=
a.langCode,b=e.availableLangs[b]?b:e.availableLangs[b.replace(/-.*/,"")]?b.replace(/-.*/,""):"en";CKEDITOR.scriptLoader.load(CKEDITOR.getUrl(e.path+"dialogs/lang/"+b+".js"),function(){CKEDITOR.tools.extend(a.lang.specialchar,e.langEntries[b]);a.openDialog("specialchar")})},modes:{wysiwyg:1},canUndo:false});a.ui.addButton&&a.ui.addButton("SpecialChar",{label:a.lang.specialchar.toolbar,command:"specialchar",toolbar:"insert,50"})}}),CKEDITOR.config.specialChars="! &quot; # $ % &amp; ' ( ) * + - . / 0 1 2 3 4 5 6 7 8 9 : ; &lt; = &gt; ? @ A B C D E F G H I J K L M N O P Q R S T U V W X Y Z [ ] ^ _ ` a b c d e f g h i j k l m n o p q r s t u v w x y z { | } ~ &euro; &lsquo; &rsquo; &ldquo; &rdquo; &ndash; &mdash; &iexcl; &cent; &pound; &curren; &yen; &brvbar; &sect; &uml; &copy; &ordf; &laquo; &not; &reg; &macr; &deg; &sup2; &sup3; &acute; &micro; &para; &middot; &cedil; &sup1; &ordm; &raquo; &frac14; &frac12; &frac34; &iquest; &Agrave; &Aacute; &Acirc; &Atilde; &Auml; &Aring; &AElig; &Ccedil; &Egrave; &Eacute; &Ecirc; &Euml; &Igrave; &Iacute; &Icirc; &Iuml; &ETH; &Ntilde; &Ograve; &Oacute; &Ocirc; &Otilde; &Ouml; &times; &Oslash; &Ugrave; &Uacute; &Ucirc; &Uuml; &Yacute; &THORN; &szlig; &agrave; &aacute; &acirc; &atilde; &auml; &aring; &aelig; &ccedil; &egrave; &eacute; &ecirc; &euml; &igrave; &iacute; &icirc; &iuml; &eth; &ntilde; &ograve; &oacute; &ocirc; &otilde; &ouml; &divide; &oslash; &ugrave; &uacute; &ucirc; &uuml; &yacute; &thorn; &yuml; &OElig; &oelig; &#372; &#374 &#373 &#375; &sbquo; &#8219; &bdquo; &hellip; &trade; &#9658; &bull; &rarr; &rArr; &hArr; &diams; &asymp;".split(" "),
function(){CKEDITOR.plugins.add("stylescombo",{requires:"richcombo",init:function(a){var e=a.config,b=a.lang.stylescombo,c={},f=[],k=[];a.on("stylesSet",function(b){if(b=b.data.styles){for(var d,j,h,g=0,m=b.length;g<m;g++){d=b[g];if(!(a.blockless&&d.element in CKEDITOR.dtd.$block)){j=d.name;d=new CKEDITOR.style(d);if(!a.filter.customConfig||a.filter.check(d)){d._name=j;d._.enterMode=e.enterMode;d._.type=h=d.assignedTo||d.type;d._.weight=g+(h==CKEDITOR.STYLE_OBJECT?1:h==CKEDITOR.STYLE_BLOCK?2:3)*1E3;
c[j]=d;f.push(d);k.push(d)}}}f.sort(function(a,b){return a._.weight-b._.weight})}});a.ui.addRichCombo("Styles",{label:b.label,title:b.panelTitle,toolbar:"styles,10",allowedContent:k,panel:{css:[CKEDITOR.skin.getPath("editor")].concat(e.contentsCss),multiSelect:true,attributes:{"aria-label":b.panelTitle}},init:function(){var a,c,e,h,g,k;g=0;for(k=f.length;g<k;g++){a=f[g];c=a._name;h=a._.type;if(h!=e){this.startGroup(b["panelTitle"+h]);e=h}this.add(c,a.type==CKEDITOR.STYLE_OBJECT?c:a.buildPreview(),
c)}this.commit()},onClick:function(b){a.focus();a.fire("saveSnapshot");var b=c[b],d=a.elementPath();a[b.checkActive(d,a)?"removeStyle":"applyStyle"](b);a.fire("saveSnapshot")},onRender:function(){a.on("selectionChange",function(b){for(var d=this.getValue(),b=b.data.path.elements,e=0,f=b.length,g;e<f;e++){g=b[e];for(var k in c)if(c[k].checkElementRemovable(g,true,a)){k!=d&&this.setValue(k);return}}this.setValue("")},this)},onOpen:function(){var e=a.getSelection().getSelectedElement(),e=a.elementPath(e),
d=[0,0,0,0];this.showAll();this.unmarkAll();for(var f in c){var h=c[f],g=h._.type;h.checkApplicable(e,a,a.activeFilter)?d[g]++:this.hideItem(f);h.checkActive(e,a)&&this.mark(f)}d[CKEDITOR.STYLE_BLOCK]||this.hideGroup(b["panelTitle"+CKEDITOR.STYLE_BLOCK]);d[CKEDITOR.STYLE_INLINE]||this.hideGroup(b["panelTitle"+CKEDITOR.STYLE_INLINE]);d[CKEDITOR.STYLE_OBJECT]||this.hideGroup(b["panelTitle"+CKEDITOR.STYLE_OBJECT])},refresh:function(){var b=a.elementPath();if(b){for(var d in c)if(c[d].checkApplicable(b,
a,a.activeFilter))return;this.setState(CKEDITOR.TRISTATE_DISABLED)}},reset:function(){c={};f=[]}})}})}(),function(){function a(a){return{editorFocus:false,canUndo:false,modes:{wysiwyg:1},exec:function(b){if(b.editable().hasFocus){var c=b.getSelection(),d;if(d=(new CKEDITOR.dom.elementPath(c.getCommonAncestor(),c.root)).contains({td:1,th:1},1)){var c=b.createRange(),e=CKEDITOR.tools.tryThese(function(){var b=d.getParent().$.cells[d.$.cellIndex+(a?-1:1)];b.parentNode.parentNode;return b},function(){var b=
d.getParent(),b=b.getAscendant("table").$.rows[b.$.rowIndex+(a?-1:1)];return b.cells[a?b.cells.length-1:0]});if(!e&&!a){for(var h=d.getAscendant("table").$,e=d.getParent().$.cells,h=new CKEDITOR.dom.element(h.insertRow(-1),b.document),g=0,m=e.length;g<m;g++)h.append((new CKEDITOR.dom.element(e[g],b.document)).clone(false,false)).appendBogus();c.moveToElementEditStart(h)}else if(e){e=new CKEDITOR.dom.element(e);c.moveToElementEditStart(e);(!c.checkStartOfBlock()||!c.checkEndOfBlock())&&c.selectNodeContents(e)}else return true;
c.select(true);return true}}return false}}}var e={editorFocus:false,modes:{wysiwyg:1,source:1}},b={exec:function(a){a.container.focusNext(true,a.tabIndex)}},c={exec:function(a){a.container.focusPrevious(true,a.tabIndex)}};CKEDITOR.plugins.add("tab",{init:function(f){for(var k=f.config.enableTabKeyTools!==false,i=f.config.tabSpaces||0,d="";i--;)d=d+" ";if(d)f.on("key",function(a){if(a.data.keyCode==9){f.insertText(d);a.cancel()}});if(k)f.on("key",function(a){(a.data.keyCode==9&&f.execCommand("selectNextCell")||
a.data.keyCode==CKEDITOR.SHIFT+9&&f.execCommand("selectPreviousCell"))&&a.cancel()});f.addCommand("blur",CKEDITOR.tools.extend(b,e));f.addCommand("blurBack",CKEDITOR.tools.extend(c,e));f.addCommand("selectNextCell",a());f.addCommand("selectPreviousCell",a(true))}})}(),CKEDITOR.dom.element.prototype.focusNext=function(a,e){var b=e===void 0?this.getTabIndex():e,c,f,k,i,d,j;if(b<=0)for(d=this.getNextSourceNode(a,CKEDITOR.NODE_ELEMENT);d;){if(d.isVisible()&&d.getTabIndex()===0){k=d;break}d=d.getNextSourceNode(false,
CKEDITOR.NODE_ELEMENT)}else for(d=this.getDocument().getBody().getFirst();d=d.getNextSourceNode(false,CKEDITOR.NODE_ELEMENT);){if(!c)if(!f&&d.equals(this)){f=true;if(a){if(!(d=d.getNextSourceNode(true,CKEDITOR.NODE_ELEMENT)))break;c=1}}else f&&!this.contains(d)&&(c=1);if(d.isVisible()&&!((j=d.getTabIndex())<0)){if(c&&j==b){k=d;break}if(j>b&&(!k||!i||j<i)){k=d;i=j}else if(!k&&j===0){k=d;i=j}}}k&&k.focus()},CKEDITOR.dom.element.prototype.focusPrevious=function(a,e){for(var b=e===void 0?this.getTabIndex():
e,c,f,k,i=0,d,j=this.getDocument().getBody().getLast();j=j.getPreviousSourceNode(false,CKEDITOR.NODE_ELEMENT);){if(!c)if(!f&&j.equals(this)){f=true;if(a){if(!(j=j.getPreviousSourceNode(true,CKEDITOR.NODE_ELEMENT)))break;c=1}}else f&&!this.contains(j)&&(c=1);if(j.isVisible()&&!((d=j.getTabIndex())<0))if(b<=0){if(c&&d===0){k=j;break}if(d>i){k=j;i=d}}else{if(c&&d==b){k=j;break}if(d<b&&(!k||d>i)){k=j;i=d}}}k&&k.focus()},CKEDITOR.plugins.add("table",{requires:"dialog",init:function(a){function e(a){return CKEDITOR.tools.extend(a||
{},{contextSensitive:1,refresh:function(a,b){this.setState(b.contains("table",1)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}})}if(!a.blockless){var b=a.lang.table;a.addCommand("table",new CKEDITOR.dialogCommand("table",{context:"table",allowedContent:"table{width,height}[align,border,cellpadding,cellspacing,summary];caption tbody thead tfoot;th td tr[scope];"+(a.plugins.dialogadvtab?"table"+a.plugins.dialogadvtab.allowedContent():""),requiredContent:"table",contentTransformations:[["table{width}: sizeToStyle",
"table[width]: sizeToAttribute"]]}));a.addCommand("tableProperties",new CKEDITOR.dialogCommand("tableProperties",e()));a.addCommand("tableDelete",e({exec:function(a){var b=a.elementPath().contains("table",1);if(b){var e=b.getParent(),i=a.editable();e.getChildCount()==1&&(!e.is("td","th")&&!e.equals(i))&&(b=e);a=a.createRange();a.moveToPosition(b,CKEDITOR.POSITION_BEFORE_START);b.remove();a.select()}}}));a.ui.addButton&&a.ui.addButton("Table",{label:b.toolbar,command:"table",toolbar:"insert,30"});
CKEDITOR.dialog.add("table",this.path+"dialogs/table.js");CKEDITOR.dialog.add("tableProperties",this.path+"dialogs/table.js");a.addMenuItems&&a.addMenuItems({table:{label:b.menu,command:"tableProperties",group:"table",order:5},tabledelete:{label:b.deleteTable,command:"tableDelete",group:"table",order:1}});a.on("doubleclick",function(a){if(a.data.element.is("table"))a.data.dialog="tableProperties"});a.contextMenu&&a.contextMenu.addListener(function(){return{tabledelete:CKEDITOR.TRISTATE_OFF,table:CKEDITOR.TRISTATE_OFF}})}}}),
function(){function a(a){function b(a){if(!(c.length>0)&&a.type==CKEDITOR.NODE_ELEMENT&&p.test(a.getName())&&!a.getCustomData("selected_cell")){CKEDITOR.dom.element.setMarker(d,a,"selected_cell",true);c.push(a)}}for(var a=a.getRanges(),c=[],d={},e=0;e<a.length;e++){var f=a[e];if(f.collapsed){f=f.getCommonAncestor();(f=f.getAscendant("td",true)||f.getAscendant("th",true))&&c.push(f)}else{var f=new CKEDITOR.dom.walker(f),g;for(f.guard=b;g=f.next();)if(g.type!=CKEDITOR.NODE_ELEMENT||!g.is(CKEDITOR.dtd.table))if((g=
g.getAscendant("td",true)||g.getAscendant("th",true))&&!g.getCustomData("selected_cell")){CKEDITOR.dom.element.setMarker(d,g,"selected_cell",true);c.push(g)}}}CKEDITOR.dom.element.clearAllMarkers(d);return c}function e(b,c){for(var d=a(b),e=d[0],f=e.getAscendant("table"),e=e.getDocument(),g=d[0].getParent(),h=g.$.rowIndex,d=d[d.length-1],i=d.getParent().$.rowIndex+d.$.rowSpan-1,d=new CKEDITOR.dom.element(f.$.rows[i]),h=c?h:i,g=c?g:d,d=CKEDITOR.tools.buildTableMap(f),f=d[h],h=c?d[h-1]:d[h+1],d=d[0].length,
e=e.createElement("tr"),i=0;f[i]&&i<d;i++){var j;if(f[i].rowSpan>1&&h&&f[i]==h[i]){j=f[i];j.rowSpan=j.rowSpan+1}else{j=(new CKEDITOR.dom.element(f[i])).clone();j.removeAttribute("rowSpan");j.appendBogus();e.append(j);j=j.$}i=i+(j.colSpan-1)}c?e.insertBefore(g):e.insertAfter(g)}function b(c){if(c instanceof CKEDITOR.dom.selection){for(var d=a(c),e=d[0].getAscendant("table"),f=CKEDITOR.tools.buildTableMap(e),c=d[0].getParent().$.rowIndex,d=d[d.length-1],g=d.getParent().$.rowIndex+d.$.rowSpan-1,d=[],
h=c;h<=g;h++){for(var i=f[h],j=new CKEDITOR.dom.element(e.$.rows[h]),k=0;k<i.length;k++){var m=new CKEDITOR.dom.element(i[k]),p=m.getParent().$.rowIndex;if(m.$.rowSpan==1)m.remove();else{m.$.rowSpan=m.$.rowSpan-1;if(p==h){p=f[h+1];p[k-1]?m.insertAfter(new CKEDITOR.dom.element(p[k-1])):(new CKEDITOR.dom.element(e.$.rows[h+1])).append(m,1)}}k=k+(m.$.colSpan-1)}d.push(j)}f=e.$.rows;e=new CKEDITOR.dom.element(f[g+1]||(c>0?f[c-1]:null)||e.$.parentNode);for(h=d.length;h>=0;h--)b(d[h]);return e}if(c instanceof
CKEDITOR.dom.element){e=c.getAscendant("table");e.$.rows.length==1?e.remove():c.remove()}return null}function c(a,b){for(var c=b?Infinity:0,d=0;d<a.length;d++){var e;e=a[d];for(var f=b,g=e.getParent().$.cells,h=0,i=0;i<g.length;i++){var j=g[i],h=h+(f?1:j.colSpan);if(j==e.$)break}e=h-1;if(b?e<c:e>c)c=e}return c}function f(b,d){for(var e=a(b),f=e[0].getAscendant("table"),g=c(e,1),e=c(e),g=d?g:e,h=CKEDITOR.tools.buildTableMap(f),f=[],e=[],i=h.length,j=0;j<i;j++){f.push(h[j][g]);e.push(d?h[j][g-1]:h[j][g+
1])}for(j=0;j<i;j++)if(f[j]){if(f[j].colSpan>1&&e[j]==f[j]){g=f[j];g.colSpan=g.colSpan+1}else{g=(new CKEDITOR.dom.element(f[j])).clone();g.removeAttribute("colSpan");g.appendBogus();g[d?"insertBefore":"insertAfter"].call(g,new CKEDITOR.dom.element(f[j]));g=g.$}j=j+(g.rowSpan-1)}}function k(a,b){var c=a.getStartElement();if(c=c.getAscendant("td",1)||c.getAscendant("th",1)){var d=c.clone();d.appendBogus();b?d.insertBefore(c):d.insertAfter(c)}}function i(b){if(b instanceof CKEDITOR.dom.selection){var b=
a(b),c=b[0]&&b[0].getAscendant("table"),e;a:{var f=0;e=b.length-1;for(var g={},h,j;h=b[f++];)CKEDITOR.dom.element.setMarker(g,h,"delete_cell",true);for(f=0;h=b[f++];)if((j=h.getPrevious())&&!j.getCustomData("delete_cell")||(j=h.getNext())&&!j.getCustomData("delete_cell")){CKEDITOR.dom.element.clearAllMarkers(g);e=j;break a}CKEDITOR.dom.element.clearAllMarkers(g);j=b[0].getParent();if(j=j.getPrevious())e=j.getLast();else{j=b[e].getParent();e=(j=j.getNext())?j.getChild(0):null}}for(j=b.length-1;j>=
0;j--)i(b[j]);e?d(e,true):c&&c.remove()}else if(b instanceof CKEDITOR.dom.element){c=b.getParent();c.getChildCount()==1?c.remove():b.remove()}}function d(a,b){var c=a.getDocument(),d=CKEDITOR.document;if(CKEDITOR.env.ie&&CKEDITOR.env.version==10){d.focus();c.focus()}c=new CKEDITOR.dom.range(c);if(!c["moveToElementEdit"+(b?"End":"Start")](a)){c.selectNodeContents(a);c.collapse(b?false:true)}c.select(true)}function j(a,b,c){a=a[b];if(typeof c=="undefined")return a;for(b=0;a&&b<a.length;b++){if(c.is&&
a[b]==c.$)return b;if(b==c)return new CKEDITOR.dom.element(a[b])}return c.is?-1:null}function h(b,c,d){var e=a(b),f;if((c?e.length!=1:e.length<2)||(f=b.getCommonAncestor())&&f.type==CKEDITOR.NODE_ELEMENT&&f.is("table"))return false;var g,b=e[0];f=b.getAscendant("table");var h=CKEDITOR.tools.buildTableMap(f),i=h.length,k=h[0].length,m=b.getParent().$.rowIndex,p=j(h,m,b);if(c){var y;try{var z=parseInt(b.getAttribute("rowspan"),10)||1;g=parseInt(b.getAttribute("colspan"),10)||1;y=h[c=="up"?m-z:c=="down"?
m+z:m][c=="left"?p-g:c=="right"?p+g:p]}catch(B){return false}if(!y||b.$==y)return false;e[c=="up"||c=="left"?"unshift":"push"](new CKEDITOR.dom.element(y))}for(var c=b.getDocument(),A=m,z=y=0,D=!d&&new CKEDITOR.dom.documentFragment(c),C=0,c=0;c<e.length;c++){g=e[c];var G=g.getParent(),E=g.getFirst(),H=g.$.colSpan,L=g.$.rowSpan,G=G.$.rowIndex,J=j(h,G,g),C=C+H*L,z=Math.max(z,J-p+H);y=Math.max(y,G-m+L);if(!d){H=g;(L=H.getBogus())&&L.remove();H.trim();if(g.getChildren().count()){if(G!=A&&E&&(!E.isBlockBoundary||
!E.isBlockBoundary({br:1})))(A=D.getLast(CKEDITOR.dom.walker.whitespaces(true)))&&(!A.is||!A.is("br"))&&D.append("br");g.moveChildren(D)}c?g.remove():g.setHtml("")}A=G}if(d)return y*z==C;D.moveChildren(b);b.appendBogus();z>=k?b.removeAttribute("rowSpan"):b.$.rowSpan=y;y>=i?b.removeAttribute("colSpan"):b.$.colSpan=z;d=new CKEDITOR.dom.nodeList(f.$.rows);e=d.count();for(c=e-1;c>=0;c--){f=d.getItem(c);if(!f.$.cells.length){f.remove();e++}}return b}function g(b,c){var d=a(b);if(d.length>1)return false;
if(c)return true;var d=d[0],e=d.getParent(),f=e.getAscendant("table"),g=CKEDITOR.tools.buildTableMap(f),h=e.$.rowIndex,i=j(g,h,d),k=d.$.rowSpan,m;if(k>1){m=Math.ceil(k/2);for(var k=Math.floor(k/2),e=h+m,f=new CKEDITOR.dom.element(f.$.rows[e]),g=j(g,e),p,e=d.clone(),h=0;h<g.length;h++){p=g[h];if(p.parentNode==f.$&&h>i){e.insertBefore(new CKEDITOR.dom.element(p));break}else p=null}p||f.append(e)}else{k=m=1;f=e.clone();f.insertAfter(e);f.append(e=d.clone());p=j(g,h);for(i=0;i<p.length;i++)p[i].rowSpan++}e.appendBogus();
d.$.rowSpan=m;e.$.rowSpan=k;m==1&&d.removeAttribute("rowSpan");k==1&&e.removeAttribute("rowSpan");return e}function m(b,c){var d=a(b);if(d.length>1)return false;if(c)return true;var d=d[0],e=d.getParent(),f=e.getAscendant("table"),f=CKEDITOR.tools.buildTableMap(f),g=j(f,e.$.rowIndex,d),h=d.$.colSpan;if(h>1){e=Math.ceil(h/2);h=Math.floor(h/2)}else{for(var h=e=1,i=[],k=0;k<f.length;k++){var m=f[k];i.push(m[g]);m[g].rowSpan>1&&(k=k+(m[g].rowSpan-1))}for(f=0;f<i.length;f++)i[f].colSpan++}f=d.clone();
f.insertAfter(d);f.appendBogus();d.$.colSpan=e;f.$.colSpan=h;e==1&&d.removeAttribute("colSpan");h==1&&f.removeAttribute("colSpan");return f}var p=/^(?:td|th)$/;CKEDITOR.plugins.tabletools={requires:"table,dialog,contextmenu",init:function(c){function j(a){return CKEDITOR.tools.extend(a||{},{contextSensitive:1,refresh:function(a,b){this.setState(b.contains({td:1,th:1},1)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)}})}function n(a,b){var d=c.addCommand(a,b);c.addFeature(d)}var l=c.lang.table;
n("cellProperties",new CKEDITOR.dialogCommand("cellProperties",j({allowedContent:"td th{width,height,border-color,background-color,white-space,vertical-align,text-align}[colspan,rowspan]",requiredContent:"table"})));CKEDITOR.dialog.add("cellProperties",this.path+"dialogs/tableCell.js");n("rowDelete",j({requiredContent:"table",exec:function(a){a=a.getSelection();d(b(a))}}));n("rowInsertBefore",j({requiredContent:"table",exec:function(a){a=a.getSelection();e(a,true)}}));n("rowInsertAfter",j({requiredContent:"table",
exec:function(a){a=a.getSelection();e(a)}}));n("columnDelete",j({requiredContent:"table",exec:function(b){for(var b=b.getSelection(),b=a(b),c=b[0],e=b[b.length-1],b=c.getAscendant("table"),f=CKEDITOR.tools.buildTableMap(b),g,h,i=[],j=0,k=f.length;j<k;j++)for(var m=0,l=f[j].length;m<l;m++){f[j][m]==c.$&&(g=m);f[j][m]==e.$&&(h=m)}for(j=g;j<=h;j++)for(m=0;m<f.length;m++){e=f[m];c=new CKEDITOR.dom.element(b.$.rows[m]);e=new CKEDITOR.dom.element(e[j]);if(e.$){e.$.colSpan==1?e.remove():e.$.colSpan=e.$.colSpan-
1;m=m+(e.$.rowSpan-1);c.$.cells.length||i.push(c)}}h=b.$.rows[0]&&b.$.rows[0].cells;g=new CKEDITOR.dom.element(h[g]||(g?h[g-1]:b.$.parentNode));i.length==k&&b.remove();g&&d(g,true)}}));n("columnInsertBefore",j({requiredContent:"table",exec:function(a){a=a.getSelection();f(a,true)}}));n("columnInsertAfter",j({requiredContent:"table",exec:function(a){a=a.getSelection();f(a)}}));n("cellDelete",j({requiredContent:"table",exec:function(a){a=a.getSelection();i(a)}}));n("cellMerge",j({allowedContent:"td[colspan,rowspan]",
requiredContent:"td[colspan,rowspan]",exec:function(a){d(h(a.getSelection()),true)}}));n("cellMergeRight",j({allowedContent:"td[colspan]",requiredContent:"td[colspan]",exec:function(a){d(h(a.getSelection(),"right"),true)}}));n("cellMergeDown",j({allowedContent:"td[rowspan]",requiredContent:"td[rowspan]",exec:function(a){d(h(a.getSelection(),"down"),true)}}));n("cellVerticalSplit",j({allowedContent:"td[rowspan]",requiredContent:"td[rowspan]",exec:function(a){d(m(a.getSelection()))}}));n("cellHorizontalSplit",
j({allowedContent:"td[colspan]",requiredContent:"td[colspan]",exec:function(a){d(g(a.getSelection()))}}));n("cellInsertBefore",j({requiredContent:"table",exec:function(a){a=a.getSelection();k(a,true)}}));n("cellInsertAfter",j({requiredContent:"table",exec:function(a){a=a.getSelection();k(a)}}));c.addMenuItems&&c.addMenuItems({tablecell:{label:l.cell.menu,group:"tablecell",order:1,getItems:function(){var b=c.getSelection(),d=a(b);return{tablecell_insertBefore:CKEDITOR.TRISTATE_OFF,tablecell_insertAfter:CKEDITOR.TRISTATE_OFF,
tablecell_delete:CKEDITOR.TRISTATE_OFF,tablecell_merge:h(b,null,true)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_merge_right:h(b,"right",true)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_merge_down:h(b,"down",true)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_split_vertical:m(b,true)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_split_horizontal:g(b,true)?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED,tablecell_properties:d.length>0?CKEDITOR.TRISTATE_OFF:
CKEDITOR.TRISTATE_DISABLED}}},tablecell_insertBefore:{label:l.cell.insertBefore,group:"tablecell",command:"cellInsertBefore",order:5},tablecell_insertAfter:{label:l.cell.insertAfter,group:"tablecell",command:"cellInsertAfter",order:10},tablecell_delete:{label:l.cell.deleteCell,group:"tablecell",command:"cellDelete",order:15},tablecell_merge:{label:l.cell.merge,group:"tablecell",command:"cellMerge",order:16},tablecell_merge_right:{label:l.cell.mergeRight,group:"tablecell",command:"cellMergeRight",
order:17},tablecell_merge_down:{label:l.cell.mergeDown,group:"tablecell",command:"cellMergeDown",order:18},tablecell_split_horizontal:{label:l.cell.splitHorizontal,group:"tablecell",command:"cellHorizontalSplit",order:19},tablecell_split_vertical:{label:l.cell.splitVertical,group:"tablecell",command:"cellVerticalSplit",order:20},tablecell_properties:{label:l.cell.title,group:"tablecellproperties",command:"cellProperties",order:21},tablerow:{label:l.row.menu,group:"tablerow",order:1,getItems:function(){return{tablerow_insertBefore:CKEDITOR.TRISTATE_OFF,
tablerow_insertAfter:CKEDITOR.TRISTATE_OFF,tablerow_delete:CKEDITOR.TRISTATE_OFF}}},tablerow_insertBefore:{label:l.row.insertBefore,group:"tablerow",command:"rowInsertBefore",order:5},tablerow_insertAfter:{label:l.row.insertAfter,group:"tablerow",command:"rowInsertAfter",order:10},tablerow_delete:{label:l.row.deleteRow,group:"tablerow",command:"rowDelete",order:15},tablecolumn:{label:l.column.menu,group:"tablecolumn",order:1,getItems:function(){return{tablecolumn_insertBefore:CKEDITOR.TRISTATE_OFF,
tablecolumn_insertAfter:CKEDITOR.TRISTATE_OFF,tablecolumn_delete:CKEDITOR.TRISTATE_OFF}}},tablecolumn_insertBefore:{label:l.column.insertBefore,group:"tablecolumn",command:"columnInsertBefore",order:5},tablecolumn_insertAfter:{label:l.column.insertAfter,group:"tablecolumn",command:"columnInsertAfter",order:10},tablecolumn_delete:{label:l.column.deleteColumn,group:"tablecolumn",command:"columnDelete",order:15}});c.contextMenu&&c.contextMenu.addListener(function(a,b,c){return(a=c.contains({td:1,th:1},
1))&&!a.isReadOnly()?{tablecell:CKEDITOR.TRISTATE_OFF,tablerow:CKEDITOR.TRISTATE_OFF,tablecolumn:CKEDITOR.TRISTATE_OFF}:null})},getSelectedCells:a};CKEDITOR.plugins.add("tabletools",CKEDITOR.plugins.tabletools)}(),CKEDITOR.tools.buildTableMap=function(a){for(var a=a.$.rows,e=-1,b=[],c=0;c<a.length;c++){e++;!b[e]&&(b[e]=[]);for(var f=-1,k=0;k<a[c].cells.length;k++){var i=a[c].cells[k];for(f++;b[e][f];)f++;for(var d=isNaN(i.colSpan)?1:i.colSpan,i=isNaN(i.rowSpan)?1:i.rowSpan,j=0;j<i;j++){b[e+j]||(b[e+
j]=[]);for(var h=0;h<d;h++)b[e+j][f+h]=a[c].cells[k]}f=f+(d-1)}}return b},function(){CKEDITOR.plugins.add("templates",{requires:"dialog",init:function(a){CKEDITOR.dialog.add("templates",CKEDITOR.getUrl(this.path+"dialogs/templates.js"));a.addCommand("templates",new CKEDITOR.dialogCommand("templates"));a.ui.addButton&&a.ui.addButton("Templates",{label:a.lang.templates.button,command:"templates",toolbar:"doctools,10"})}});var a={},e={};CKEDITOR.addTemplates=function(b,c){a[b]=c};CKEDITOR.getTemplates=
function(b){return a[b]};CKEDITOR.loadTemplates=function(a,c){for(var f=[],k=0,i=a.length;k<i;k++)if(!e[a[k]]){f.push(a[k]);e[a[k]]=1}f.length?CKEDITOR.scriptLoader.load(f,c):setTimeout(c,0)}}(),CKEDITOR.config.templates_files=[CKEDITOR.getUrl("plugins/templates/templates/default.js")],CKEDITOR.config.templates_replaceContent=!0,function(){function a(a){function b(){for(var g=c(),h=CKEDITOR.tools.clone(a.config.toolbarGroups)||e(a),j=0;j<h.length;j++){var k=h[j];if(k!="/"){typeof k=="string"&&(k=
h[j]={name:k});var n,l=k.groups;if(l)for(var s=0;s<l.length;s++){n=l[s];(n=g[n])&&d(k,n)}(n=g[k.name])&&d(k,n)}}return h}function c(){var b={},d,e,g;for(d in a.ui.items){e=a.ui.items[d];g=e.toolbar||"others";g=g.split(",");e=g[0];g=parseInt(g[1]||-1,10);b[e]||(b[e]=[]);b[e].push({name:d,order:g})}for(e in b)b[e]=b[e].sort(function(a,b){return a.order==b.order?0:b.order<0?-1:a.order<0?1:a.order<b.order?-1:1});return b}function d(b,c){if(c.length){b.items?b.items.push(a.ui.create("-")):b.items=[];for(var d;d=
c.shift();){d=typeof d=="string"?d:d.name;if(!h||CKEDITOR.tools.indexOf(h,d)==-1)(d=a.ui.create(d))&&a.addFeature(d)&&b.items.push(d)}}}function j(a){var b=[],c,e,f;for(c=0;c<a.length;++c){e=a[c];f={};if(e=="/")b.push(e);else if(CKEDITOR.tools.isArray(e)){d(f,CKEDITOR.tools.clone(e));b.push(f)}else if(e.items){d(f,CKEDITOR.tools.clone(e.items));f.name=e.name;b.push(f)}}return b}var h=a.config.removeButtons,h=h&&h.split(","),g=a.config.toolbar;typeof g=="string"&&(g=a.config["toolbar_"+g]);return a.toolbar=
g?j(g):b()}function e(a){return a._.toolbarGroups||(a._.toolbarGroups=[{name:"document",groups:["mode","document","doctools"]},{name:"clipboard",groups:["clipboard","undo"]},{name:"editing",groups:["find","selection","spellchecker"]},{name:"forms"},"/",{name:"basicstyles",groups:["basicstyles","cleanup"]},{name:"paragraph",groups:["list","indent","blocks","align","bidi"]},{name:"links"},{name:"insert"},"/",{name:"styles"},{name:"colors"},{name:"tools"},{name:"others"},{name:"about"}])}var b=function(){this.toolbars=
[];this.focusCommandExecuted=false};b.prototype.focus=function(){for(var a=0,b;b=this.toolbars[a++];)for(var c=0,d;d=b.items[c++];)if(d.focus){d.focus();return}};var c={modes:{wysiwyg:1,source:1},readOnly:1,exec:function(a){if(a.toolbox){a.toolbox.focusCommandExecuted=true;CKEDITOR.env.ie||CKEDITOR.env.air?setTimeout(function(){a.toolbox.focus()},100):a.toolbox.focus()}}};CKEDITOR.plugins.add("toolbar",{requires:"button",init:function(e){var k,i=function(a,b){var c,g=e.lang.dir=="rtl",m=e.config.toolbarGroupCycling,
p=g?37:39,g=g?39:37,m=m===void 0||m;switch(b){case 9:case CKEDITOR.SHIFT+9:for(;!c||!c.items.length;){c=b==9?(c?c.next:a.toolbar.next)||e.toolbox.toolbars[0]:(c?c.previous:a.toolbar.previous)||e.toolbox.toolbars[e.toolbox.toolbars.length-1];if(c.items.length)for(a=c.items[k?c.items.length-1:0];a&&!a.focus;)(a=k?a.previous:a.next)||(c=0)}a&&a.focus();return false;case p:c=a;do{c=c.next;!c&&m&&(c=a.toolbar.items[0])}while(c&&!c.focus);c?c.focus():i(a,9);return false;case 40:if(a.button&&a.button.hasArrow){e.once("panelShow",
function(a){a.data._.panel._.currentBlock.onKeyDown(40)});a.execute()}else i(a,b==40?p:g);return false;case g:case 38:c=a;do{c=c.previous;!c&&m&&(c=a.toolbar.items[a.toolbar.items.length-1])}while(c&&!c.focus);if(c)c.focus();else{k=1;i(a,CKEDITOR.SHIFT+9);k=0}return false;case 27:e.focus();return false;case 13:case 32:a.execute();return false}return true};e.on("uiSpace",function(c){if(c.data.space==e.config.toolbarLocation){c.removeListener();e.toolbox=new b;var j=CKEDITOR.tools.getNextId(),h=['<span id="',
j,'" class="cke_voice_label">',e.lang.toolbar.toolbars,"</span>",'<span id="'+e.ui.spaceId("toolbox")+'" class="cke_toolbox" role="group" aria-labelledby="',j,'" onmousedown="return false;">'],j=e.config.toolbarStartupExpanded!==false,g,k;e.config.toolbarCanCollapse&&e.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE&&h.push('<span class="cke_toolbox_main"'+(j?">":' style="display:none">'));for(var p=e.toolbox.toolbars,r=a(e),o=0;o<r.length;o++){var n,l=0,s,t=r[o],w;if(t){if(g){h.push("</span>");k=g=0}if(t===
"/")h.push('<span class="cke_toolbar_break"></span>');else{w=t.items||t;for(var u=0;u<w.length;u++){var x=w[u],v;if(x)if(x.type==CKEDITOR.UI_SEPARATOR)k=g&&x;else{v=x.canGroup!==false;if(!l){n=CKEDITOR.tools.getNextId();l={id:n,items:[]};s=t.name&&(e.lang.toolbar.toolbarGroups[t.name]||t.name);h.push('<span id="',n,'" class="cke_toolbar"',s?' aria-labelledby="'+n+'_label"':"",' role="toolbar">');s&&h.push('<span id="',n,'_label" class="cke_voice_label">',s,"</span>");h.push('<span class="cke_toolbar_start"></span>');
var q=p.push(l)-1;if(q>0){l.previous=p[q-1];l.previous.next=l}}if(v){if(!g){h.push('<span class="cke_toolgroup" role="presentation">');g=1}}else if(g){h.push("</span>");g=0}n=function(a){a=a.render(e,h);q=l.items.push(a)-1;if(q>0){a.previous=l.items[q-1];a.previous.next=a}a.toolbar=l;a.onkey=i;a.onfocus=function(){e.toolbox.focusCommandExecuted||e.focus()}};if(k){n(k);k=0}n(x)}}if(g){h.push("</span>");k=g=0}l&&h.push('<span class="cke_toolbar_end"></span></span>')}}}e.config.toolbarCanCollapse&&h.push("</span>");
if(e.config.toolbarCanCollapse&&e.elementMode!=CKEDITOR.ELEMENT_MODE_INLINE){var y=CKEDITOR.tools.addFunction(function(){e.execCommand("toolbarCollapse")});e.on("destroy",function(){CKEDITOR.tools.removeFunction(y)});e.addCommand("toolbarCollapse",{readOnly:1,exec:function(a){var b=a.ui.space("toolbar_collapser"),c=b.getPrevious(),d=a.ui.space("contents"),e=c.getParent(),f=parseInt(d.$.style.height,10),g=e.$.offsetHeight,h=b.hasClass("cke_toolbox_collapser_min");if(h){c.show();b.removeClass("cke_toolbox_collapser_min");
b.setAttribute("title",a.lang.toolbar.toolbarCollapse)}else{c.hide();b.addClass("cke_toolbox_collapser_min");b.setAttribute("title",a.lang.toolbar.toolbarExpand)}b.getFirst().setText(h?"▲":"◀");d.setStyle("height",f-(e.$.offsetHeight-g)+"px");a.fire("resize",{outerHeight:a.container.$.offsetHeight,contentsHeight:d.$.offsetHeight,outerWidth:a.container.$.offsetWidth})},modes:{wysiwyg:1,source:1}});e.setKeystroke(CKEDITOR.ALT+(CKEDITOR.env.ie||CKEDITOR.env.webkit?189:109),"toolbarCollapse");h.push('<a title="'+
(j?e.lang.toolbar.toolbarCollapse:e.lang.toolbar.toolbarExpand)+'" id="'+e.ui.spaceId("toolbar_collapser")+'" tabIndex="-1" class="cke_toolbox_collapser');j||h.push(" cke_toolbox_collapser_min");h.push('" onclick="CKEDITOR.tools.callFunction('+y+')">','<span class="cke_arrow">&#9650;</span>',"</a>")}h.push("</span>");c.data.html=c.data.html+h.join("")}});e.on("destroy",function(){if(this.toolbox){var a,b=0,c,e,f;for(a=this.toolbox.toolbars;b<a.length;b++){e=a[b].items;for(c=0;c<e.length;c++){f=e[c];
f.clickFn&&CKEDITOR.tools.removeFunction(f.clickFn);f.keyDownFn&&CKEDITOR.tools.removeFunction(f.keyDownFn)}}}});e.on("uiReady",function(){var a=e.ui.space("toolbox");a&&e.focusManager.add(a,1)});e.addCommand("toolbarFocus",c);e.setKeystroke(CKEDITOR.ALT+121,"toolbarFocus");e.ui.add("-",CKEDITOR.UI_SEPARATOR,{});e.ui.addHandler(CKEDITOR.UI_SEPARATOR,{create:function(){return{render:function(a,b){b.push('<span class="cke_toolbar_separator" role="separator"></span>');return{}}}}})}});CKEDITOR.ui.prototype.addToolbarGroup=
function(a,b,c){var d=e(this.editor),j=b===0,h={name:a};if(c){if(c=CKEDITOR.tools.search(d,function(a){return a.name==c})){!c.groups&&(c.groups=[]);if(b){b=CKEDITOR.tools.indexOf(c.groups,b);if(b>=0){c.groups.splice(b+1,0,a);return}}j?c.groups.splice(0,0,a):c.groups.push(a);return}b=null}b&&(b=CKEDITOR.tools.indexOf(d,function(a){return a.name==b}));j?d.splice(0,0,a):typeof b=="number"?d.splice(b+1,0,h):d.push(a)}}(),CKEDITOR.UI_SEPARATOR="separator",CKEDITOR.config.toolbarLocation="top","use strict",
function(){var a=[CKEDITOR.CTRL+90,CKEDITOR.CTRL+89,CKEDITOR.CTRL+CKEDITOR.SHIFT+90],e={8:1,46:1};CKEDITOR.plugins.add("undo",{init:function(c){function e(a){g.enabled&&a.data.command.canUndo!==false&&g.save()}function f(){g.enabled=c.readOnly?false:c.mode=="wysiwyg";g.onChange()}var g=c.undoManager=new b(c),i=g.editingHandler=new k(g),p=c.addCommand("undo",{exec:function(){if(g.undo()){c.selectionChange();this.fire("afterUndo")}},startDisabled:true,canUndo:false}),r=c.addCommand("redo",{exec:function(){if(g.redo()){c.selectionChange();
this.fire("afterRedo")}},startDisabled:true,canUndo:false});c.setKeystroke([[a[0],"undo"],[a[1],"redo"],[a[2],"redo"]]);g.onChange=function(){p.setState(g.undoable()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED);r.setState(g.redoable()?CKEDITOR.TRISTATE_OFF:CKEDITOR.TRISTATE_DISABLED)};c.on("beforeCommandExec",e);c.on("afterCommandExec",e);c.on("saveSnapshot",function(a){g.save(a.data&&a.data.contentOnly)});c.on("contentDom",i.attachListeners,i);c.on("instanceReady",function(){c.fire("saveSnapshot")});
c.on("beforeModeUnload",function(){c.mode=="wysiwyg"&&g.save(true)});c.on("mode",f);c.on("readOnly",f);if(c.ui.addButton){c.ui.addButton("Undo",{label:c.lang.undo.undo,command:"undo",toolbar:"undo,10"});c.ui.addButton("Redo",{label:c.lang.undo.redo,command:"redo",toolbar:"undo,20"})}c.resetUndo=function(){g.reset();c.fire("saveSnapshot")};c.on("updateSnapshot",function(){g.currentImage&&g.update()});c.on("lockSnapshot",function(a){a=a.data;g.lock(a&&a.dontUpdate,a&&a.forceUpdate)});c.on("unlockSnapshot",
g.unlock,g)}});CKEDITOR.plugins.undo={};var b=CKEDITOR.plugins.undo.UndoManager=function(a){this.strokesRecorded=[0,0];this.locked=null;this.previousKeyGroup=-1;this.limit=a.config.undoStackSize||20;this.strokesLimit=25;this.editor=a;this.reset()};b.prototype={type:function(a,c){var e=b.getKeyGroup(a),f=this.strokesRecorded[e]+1,c=c||f>=this.strokesLimit;if(!this.typing){this.hasUndo=this.typing=true;this.hasRedo=false;this.onChange()}if(c){f=0;this.editor.fire("saveSnapshot")}else this.editor.fire("change");
this.strokesRecorded[e]=f;this.previousKeyGroup=e},keyGroupChanged:function(a){return b.getKeyGroup(a)!=this.previousKeyGroup},reset:function(){this.snapshots=[];this.index=-1;this.currentImage=null;this.hasRedo=this.hasUndo=false;this.locked=null;this.resetType()},resetType:function(){this.strokesRecorded=[0,0];this.typing=false;this.previousKeyGroup=-1},refreshState:function(){this.hasUndo=!!this.getNextImage(true);this.hasRedo=!!this.getNextImage(false);this.resetType();this.onChange()},save:function(a,
b,e){var f=this.editor;if(this.locked||f.status!="ready"||f.mode!="wysiwyg")return false;var i=f.editable();if(!i||i.status!="ready")return false;i=this.snapshots;b||(b=new c(f));if(b.contents===false)return false;if(this.currentImage)if(b.equalsContent(this.currentImage)){if(a||b.equalsSelection(this.currentImage))return false}else e!==false&&f.fire("change");i.splice(this.index+1,i.length-this.index-1);i.length==this.limit&&i.shift();this.index=i.push(b)-1;this.currentImage=b;e!==false&&this.refreshState();
return true},restoreImage:function(a){var b=this.editor,c;if(a.bookmarks){b.focus();c=b.getSelection()}this.locked={level:999};this.editor.loadSnapshot(a.contents);if(a.bookmarks)c.selectBookmarks(a.bookmarks);else if(CKEDITOR.env.ie){c=this.editor.document.getBody().$.createTextRange();c.collapse(true);c.select()}this.locked=null;this.index=a.index;this.currentImage=this.snapshots[this.index];this.update();this.refreshState();b.fire("change")},getNextImage:function(a){var b=this.snapshots,c=this.currentImage,
e;if(c)if(a)for(e=this.index-1;e>=0;e--){a=b[e];if(!c.equalsContent(a)){a.index=e;return a}}else for(e=this.index+1;e<b.length;e++){a=b[e];if(!c.equalsContent(a)){a.index=e;return a}}return null},redoable:function(){return this.enabled&&this.hasRedo},undoable:function(){return this.enabled&&this.hasUndo},undo:function(){if(this.undoable()){this.save(true);var a=this.getNextImage(true);if(a)return this.restoreImage(a),true}return false},redo:function(){if(this.redoable()){this.save(true);if(this.redoable()){var a=
this.getNextImage(false);if(a)return this.restoreImage(a),true}}return false},update:function(a){if(!this.locked){a||(a=new c(this.editor));for(var b=this.index,e=this.snapshots;b>0&&this.currentImage.equalsContent(e[b-1]);)b=b-1;e.splice(b,this.index-b+1,a);this.index=b;this.currentImage=a}},updateSelection:function(a){if(!this.snapshots.length)return false;var b=this.snapshots,c=b[b.length-1];if(c.equalsContent(a)&&!c.equalsSelection(a)){this.currentImage=b[b.length-1]=a;return true}return false},
lock:function(a,b){if(this.locked)this.locked.level++;else if(a)this.locked={level:1};else{var e=null;if(b)e=true;else{var f=new c(this.editor,true);this.currentImage&&this.currentImage.equalsContent(f)&&(e=f)}this.locked={update:e,level:1}}},unlock:function(){if(this.locked&&!--this.locked.level){var a=this.locked.update;this.locked=null;if(a===true)this.update();else if(a){var b=new c(this.editor,true);a.equalsContent(b)||this.update()}}}};b.navigationKeyCodes={37:1,38:1,39:1,40:1,36:1,35:1,33:1,
34:1};b.keyGroups={PRINTABLE:0,FUNCTIONAL:1};b.isNavigationKey=function(a){return!!b.navigationKeyCodes[a]};b.getKeyGroup=function(a){var c=b.keyGroups;return e[a]?c.FUNCTIONAL:c.PRINTABLE};b.getOppositeKeyGroup=function(a){var c=b.keyGroups;return a==c.FUNCTIONAL?c.PRINTABLE:c.FUNCTIONAL};b.ieFunctionalKeysBug=function(a){return CKEDITOR.env.ie&&b.getKeyGroup(a)==b.keyGroups.FUNCTIONAL};var c=CKEDITOR.plugins.undo.Image=function(a,b){this.editor=a;a.fire("beforeUndoImage");var c=a.getSnapshot();
CKEDITOR.env.ie&&c&&(c=c.replace(/\s+data-cke-expando=".*?"/g,""));this.contents=c;if(!b)this.bookmarks=(c=c&&a.getSelection())&&c.createBookmarks2(true);a.fire("afterUndoImage")},f=/\b(?:href|src|name)="[^"]*?"/gi;c.prototype={equalsContent:function(a){var b=this.contents,a=a.contents;if(CKEDITOR.env.ie&&(CKEDITOR.env.ie7Compat||CKEDITOR.env.quirks)){b=b.replace(f,"");a=a.replace(f,"")}return b!=a?false:true},equalsSelection:function(a){var b=this.bookmarks,a=a.bookmarks;if(b||a){if(!b||!a||b.length!=
a.length)return false;for(var c=0;c<b.length;c++){var e=b[c],f=a[c];if(e.startOffset!=f.startOffset||e.endOffset!=f.endOffset||!CKEDITOR.tools.arrayCompare(e.start,f.start)||!CKEDITOR.tools.arrayCompare(e.end,f.end))return false}}return true}};var k=CKEDITOR.plugins.undo.NativeEditingHandler=function(a){this.undoManager=a;this.ignoreInputEvent=false;this.keyEventsStack=new i;this.lastKeydownImage=null};k.prototype={onKeydown:function(d){var e=d.data.getKey();if(e!==229)if(CKEDITOR.tools.indexOf(a,
d.data.getKeystroke())>-1)d.data.preventDefault();else{this.keyEventsStack.cleanUp(d);d=this.undoManager;this.keyEventsStack.getLast(e)||this.keyEventsStack.push(e);this.lastKeydownImage=new c(d.editor);if(b.isNavigationKey(e)||this.undoManager.keyGroupChanged(e))if(d.strokesRecorded[0]||d.strokesRecorded[1]){d.save(false,this.lastKeydownImage,false);d.resetType()}}},onInput:function(){if(this.ignoreInputEvent)this.ignoreInputEvent=false;else{var a=this.keyEventsStack.getLast();a||(a=this.keyEventsStack.push(0));
this.keyEventsStack.increment(a.keyCode);if(this.keyEventsStack.getTotalInputs()>=this.undoManager.strokesLimit){this.undoManager.type(a.keyCode,true);this.keyEventsStack.resetInputs()}}},onKeyup:function(a){var e=this.undoManager,a=a.data.getKey(),f=this.keyEventsStack.getTotalInputs();this.keyEventsStack.remove(a);if(!b.ieFunctionalKeysBug(a)||!this.lastKeydownImage||!this.lastKeydownImage.equalsContent(new c(e.editor,true)))if(f>0)e.type(a);else if(b.isNavigationKey(a))this.onNavigationKey(true)},
onNavigationKey:function(a){var b=this.undoManager;(a||!b.save(true,null,false))&&b.updateSelection(new c(b.editor));b.resetType()},ignoreInputEventListener:function(){this.ignoreInputEvent=true},attachListeners:function(){var a=this.undoManager.editor,c=a.editable(),e=this;c.attachListener(c,"keydown",function(a){e.onKeydown(a);if(b.ieFunctionalKeysBug(a.data.getKey()))e.onInput()},null,null,999);c.attachListener(c,CKEDITOR.env.ie?"keypress":"input",e.onInput,e,null,999);c.attachListener(c,"keyup",
e.onKeyup,e,null,999);c.attachListener(c,"paste",e.ignoreInputEventListener,e,null,999);c.attachListener(c,"drop",e.ignoreInputEventListener,e,null,999);c.attachListener(c.isInline()?c:a.document.getDocumentElement(),"click",function(){e.onNavigationKey()},null,null,999);c.attachListener(this.undoManager.editor,"blur",function(){e.keyEventsStack.remove(9)},null,null,999)}};var i=CKEDITOR.plugins.undo.KeyEventsStack=function(){this.stack=[]};i.prototype={push:function(a){return this.stack[this.stack.push({keyCode:a,
inputs:0})-1]},getLastIndex:function(a){if(typeof a!="number")return this.stack.length-1;for(var b=this.stack.length;b--;)if(this.stack[b].keyCode==a)return b;return-1},getLast:function(a){a=this.getLastIndex(a);return a!=-1?this.stack[a]:null},increment:function(a){this.getLast(a).inputs++},remove:function(a){a=this.getLastIndex(a);a!=-1&&this.stack.splice(a,1)},resetInputs:function(a){if(typeof a=="number")this.getLast(a).inputs=0;else for(a=this.stack.length;a--;)this.stack[a].inputs=0},getTotalInputs:function(){for(var a=
this.stack.length,b=0;a--;)b=b+this.stack[a].inputs;return b},cleanUp:function(a){a=a.data.$;!a.ctrlKey&&!a.metaKey&&this.remove(17);a.shiftKey||this.remove(16);a.altKey||this.remove(18)}}}(),function(){function a(a){var b=this.editor,c=a.document,d=c.body,j=c.getElementById("cke_actscrpt");j&&j.parentNode.removeChild(j);(j=c.getElementById("cke_shimscrpt"))&&j.parentNode.removeChild(j);(j=c.getElementById("cke_basetagscrpt"))&&j.parentNode.removeChild(j);d.contentEditable=true;if(CKEDITOR.env.ie){d.hideFocus=
true;d.disabled=true;d.removeAttribute("disabled")}delete this._.isLoadingData;this.$=d;c=new CKEDITOR.dom.document(c);this.setup();this.fixInitialSelection();if(CKEDITOR.env.ie){c.getDocumentElement().addClass(c.$.compatMode);b.config.enterMode!=CKEDITOR.ENTER_P&&this.attachListener(c,"selectionchange",function(){var a=c.getBody(),d=b.getSelection(),e=d&&d.getRanges()[0];e&&(a.getHtml().match(/^<p>(?:&nbsp;|<br>)<\/p>$/i)&&e.startContainer.equals(a))&&setTimeout(function(){e=b.getSelection().getRanges()[0];
if(!e.startContainer.equals("body")){a.getFirst().remove(1);e.moveToElementEditEnd(a);e.select()}},0)})}if(CKEDITOR.env.webkit||CKEDITOR.env.ie&&CKEDITOR.env.version>10)c.getDocumentElement().on("mousedown",function(a){a.data.getTarget().is("html")&&setTimeout(function(){b.editable().focus()})});e(b);try{b.document.$.execCommand("2D-position",false,true)}catch(h){}(CKEDITOR.env.gecko||CKEDITOR.env.ie&&b.document.$.compatMode=="CSS1Compat")&&this.attachListener(this,"keydown",function(a){var c=a.data.getKeystroke();
if(c==33||c==34)if(CKEDITOR.env.ie)setTimeout(function(){b.getSelection().scrollIntoView()},0);else if(b.window.$.innerHeight>this.$.offsetHeight){var d=b.createRange();d[c==33?"moveToElementEditStart":"moveToElementEditEnd"](this);d.select();a.data.preventDefault()}});CKEDITOR.env.ie&&this.attachListener(c,"blur",function(){try{c.$.selection.empty()}catch(a){}});CKEDITOR.env.iOS&&this.attachListener(c,"touchend",function(){a.focus()});d=b.document.getElementsByTag("title").getItem(0);d.data("cke-title",
d.getText());if(CKEDITOR.env.ie)b.document.$.title=this._.docTitle;CKEDITOR.tools.setTimeout(function(){if(this.status=="unloaded")this.status="ready";b.fire("contentDom");if(this._.isPendingFocus){b.focus();this._.isPendingFocus=false}setTimeout(function(){b.fire("dataReady")},0)},0,this)}function e(a){function b(){var d;a.editable().attachListener(a,"selectionChange",function(){var b=a.getSelection().getSelectedElement();if(b){if(d){d.detachEvent("onresizestart",c);d=null}b.$.attachEvent("onresizestart",
c);d=b.$}})}function c(a){a.returnValue=false}if(CKEDITOR.env.gecko)try{var d=a.document.$;d.execCommand("enableObjectResizing",false,!a.config.disableObjectResizing);d.execCommand("enableInlineTableEditing",false,!a.config.disableNativeTableHandles)}catch(e){}else CKEDITOR.env.ie&&(CKEDITOR.env.version<11&&a.config.disableObjectResizing)&&b(a)}function b(){var a=[];if(CKEDITOR.document.$.documentMode>=8){a.push("html.CSS1Compat [contenteditable=false]{min-height:0 !important}");var b=[],c;for(c in CKEDITOR.dtd.$removeEmpty)b.push("html.CSS1Compat "+
c+"[contenteditable=false]");a.push(b.join(",")+"{display:inline-block}")}else if(CKEDITOR.env.gecko){a.push("html{height:100% !important}");a.push("img:-moz-broken{-moz-force-broken-image-icon:1;min-width:24px;min-height:24px}")}a.push("html{cursor:text;*cursor:auto}");a.push("img,input,textarea{cursor:default}");return a.join("\n")}CKEDITOR.plugins.add("wysiwygarea",{init:function(a){a.config.fullPage&&a.addFeature({allowedContent:"html head title; style [media,type]; body (*)[id]; meta link [*]",
requiredContent:"body"});a.addMode("wysiwyg",function(b){function e(d){d&&d.removeListener();a.editable(new c(a,j.$.contentWindow.document.body));a.setData(a.getData(1),b)}var d="document.open();"+(CKEDITOR.env.ie?"("+CKEDITOR.tools.fixDomain+")();":"")+"document.close();",d=CKEDITOR.env.air?"javascript:void(0)":CKEDITOR.env.ie&&!CKEDITOR.env.edge?"javascript:void(function(){"+encodeURIComponent(d)+"}())":"",j=CKEDITOR.dom.element.createFromHtml('<iframe src="'+d+'" frameBorder="0"></iframe>');j.setStyles({width:"100%",
height:"100%"});j.addClass("cke_wysiwyg_frame").addClass("cke_reset");d=a.ui.space("contents");d.append(j);var h=CKEDITOR.env.ie&&!CKEDITOR.env.edge||CKEDITOR.env.gecko;if(h)j.on("load",e);var g=a.title,m=a.fire("ariaEditorHelpLabel",{}).label;if(g){CKEDITOR.env.ie&&m&&(g=g+(", "+m));j.setAttribute("title",g)}if(m){var g=CKEDITOR.tools.getNextId(),p=CKEDITOR.dom.element.createFromHtml('<span id="'+g+'" class="cke_voice_label">'+m+"</span>");d.append(p,1);j.setAttribute("aria-describedby",g)}a.on("beforeModeUnload",
function(a){a.removeListener();p&&p.remove()});j.setAttributes({tabIndex:a.tabIndex,allowTransparency:"true"});!h&&e();a.fire("ariaWidget",j)})}});CKEDITOR.editor.prototype.addContentsCss=function(a){var b=this.config,c=b.contentsCss;if(!CKEDITOR.tools.isArray(c))b.contentsCss=c?[c]:[];b.contentsCss.push(a)};var c=CKEDITOR.tools.createClass({$:function(){this.base.apply(this,arguments);this._.frameLoadedHandler=CKEDITOR.tools.addFunction(function(b){CKEDITOR.tools.setTimeout(a,0,this,b)},this);this._.docTitle=
this.getWindow().getFrame().getAttribute("title")},base:CKEDITOR.editable,proto:{setData:function(a,c){var e=this.editor;if(c){this.setHtml(a);this.fixInitialSelection();e.fire("dataReady")}else{this._.isLoadingData=true;e._.dataStore={id:1};var d=e.config,j=d.fullPage,h=d.docType,g=CKEDITOR.tools.buildStyleHtml(b()).replace(/<style>/,'<style data-cke-temp="1">');j||(g=g+CKEDITOR.tools.buildStyleHtml(e.config.contentsCss));var m=d.baseHref?'<base href="'+d.baseHref+'" data-cke-temp="1" />':"";j&&
(a=a.replace(/<!DOCTYPE[^>]*>/i,function(a){e.docType=h=a;return""}).replace(/<\?xml\s[^\?]*\?>/i,function(a){e.xmlDeclaration=a;return""}));a=e.dataProcessor.toHtml(a);if(j){/<body[\s|>]/.test(a)||(a="<body>"+a);/<html[\s|>]/.test(a)||(a="<html>"+a+"</html>");/<head[\s|>]/.test(a)?/<title[\s|>]/.test(a)||(a=a.replace(/<head[^>]*>/,"$&<title></title>")):a=a.replace(/<html[^>]*>/,"$&<head><title></title></head>");m&&(a=a.replace(/<head[^>]*?>/,"$&"+m));a=a.replace(/<\/head\s*>/,g+"$&");a=h+a}else a=
d.docType+'<html dir="'+d.contentsLangDirection+'" lang="'+(d.contentsLanguage||e.langCode)+'"><head><title>'+this._.docTitle+"</title>"+m+g+"</head><body"+(d.bodyId?' id="'+d.bodyId+'"':"")+(d.bodyClass?' class="'+d.bodyClass+'"':"")+">"+a+"</body></html>";if(CKEDITOR.env.gecko){a=a.replace(/<body/,'<body contenteditable="true" ');CKEDITOR.env.version<2E4&&(a=a.replace(/<body[^>]*>/,"$&<\!-- cke-content-start --\>"))}d='<script id="cke_actscrpt" type="text/javascript"'+(CKEDITOR.env.ie?' defer="defer" ':
"")+">var wasLoaded=0;function onload(){if(!wasLoaded)window.parent.CKEDITOR.tools.callFunction("+this._.frameLoadedHandler+",window);wasLoaded=1;}"+(CKEDITOR.env.ie?"onload();":'document.addEventListener("DOMContentLoaded", onload, false );')+"<\/script>";CKEDITOR.env.ie&&CKEDITOR.env.version<9&&(d=d+'<script id="cke_shimscrpt">window.parent.CKEDITOR.tools.enableHtml5Elements(document)<\/script>');m&&(CKEDITOR.env.ie&&CKEDITOR.env.version<10)&&(d=d+'<script id="cke_basetagscrpt">var baseTag = document.querySelector( "base" );baseTag.href = baseTag.href;<\/script>');
a=a.replace(/(?=\s*<\/(:?head)>)/,d);this.clearCustomData();this.clearListeners();e.fire("contentDomUnload");var p=this.getDocument();try{p.write(a)}catch(r){setTimeout(function(){p.write(a)},0)}}},getData:function(a){if(a)return this.getHtml();var a=this.editor,b=a.config,c=b.fullPage,d=c&&a.docType,e=c&&a.xmlDeclaration,h=this.getDocument(),c=c?h.getDocumentElement().getOuterHtml():h.getBody().getHtml();CKEDITOR.env.gecko&&b.enterMode!=CKEDITOR.ENTER_BR&&(c=c.replace(/<br>(?=\s*(:?$|<\/body>))/,
""));c=a.dataProcessor.toDataFormat(c);e&&(c=e+"\n"+c);d&&(c=d+"\n"+c);return c},focus:function(){this._.isLoadingData?this._.isPendingFocus=true:c.baseProto.focus.call(this)},detach:function(){var a=this.editor,b=a.document,a=a.window.getFrame();c.baseProto.detach.call(this);this.clearCustomData();b.getDocumentElement().clearCustomData();a.clearCustomData();CKEDITOR.tools.removeFunction(this._.frameLoadedHandler);(b=a.removeCustomData("onResize"))&&b.removeListener();a.remove()}}})}(),CKEDITOR.config.disableObjectResizing=
!1,CKEDITOR.config.disableNativeTableHandles=!0,CKEDITOR.config.disableNativeSpellChecker=!0,CKEDITOR.config.contentsCss=CKEDITOR.getUrl("contents.css"),CKEDITOR.config.plugins="dialogui,dialog,a11yhelp,about,basicstyles,bidi,blockquote,clipboard,button,panelbutton,panel,floatpanel,colorbutton,colordialog,menu,contextmenu,dialogadvtab,div,elementspath,enterkey,entities,popup,filebrowser,find,fakeobjects,flash,floatingspace,listblock,richcombo,font,format,forms,horizontalrule,htmlwriter,iframe,image,indent,indentlist,indentblock,justify,link,list,liststyle,magicline,maximize,newpage,pagebreak,pastefromword,pastetext,preview,print,removeformat,resize,save,selectall,showblocks,showborders,smiley,sourcearea,specialchar,stylescombo,tab,table,tabletools,templates,toolbar,undo,wysiwygarea",
CKEDITOR.config.skin="moono",function(){var a=function(a,b){for(var c=CKEDITOR.getUrl("plugins/"+b),a=a.split(","),f=0;f<a.length;f++)CKEDITOR.skin.icons[a[f]]={path:c,offset:-a[++f],bgsize:a[++f]}};CKEDITOR.env.hidpi?a("about,0,,bold,24,,italic,48,,strike,72,,subscript,96,,superscript,120,,underline,144,,bidiltr,168,,bidirtl,192,,blockquote,216,,copy-rtl,240,,copy,264,,cut-rtl,288,,cut,312,,paste-rtl,336,,paste,360,,codesnippet,384,,bgcolor,408,,textcolor,432,,creatediv,456,,docprops-rtl,480,,docprops,504,,embed,528,,embedsemantic,552,,find-rtl,576,,find,600,,replace,624,,flash,648,,button,672,,checkbox,696,,form,720,,hiddenfield,744,,imagebutton,768,,radio,792,,select-rtl,816,,select,840,,textarea-rtl,864,,textarea,888,,textfield-rtl,912,,textfield,936,,horizontalrule,960,,iframe,984,,image,1008,,indent-rtl,1032,,indent,1056,,outdent-rtl,1080,,outdent,1104,,justifyblock,1128,,justifycenter,1152,,justifyleft,1176,,justifyright,1200,,language,1224,,anchor-rtl,1248,,anchor,1272,,link,1296,,unlink,1320,,bulletedlist-rtl,1344,,bulletedlist,1368,,numberedlist-rtl,1392,,numberedlist,1416,,mathjax,1440,,maximize,1464,,newpage-rtl,1488,,newpage,1512,,pagebreak-rtl,1536,,pagebreak,1560,,pastefromword-rtl,1584,,pastefromword,1608,,pastetext-rtl,1632,,pastetext,1656,,placeholder,1680,,preview-rtl,1704,,preview,1728,,print,1752,,removeformat,1776,,save,1800,,selectall,1824,,showblocks-rtl,1848,,showblocks,1872,,smiley,1896,,source-rtl,1920,,source,1944,,sourcedialog-rtl,1968,,sourcedialog,1992,,specialchar,2016,,table,2040,,templates-rtl,2064,,templates,2088,,uicolor,2112,,redo-rtl,2136,,redo,2160,,undo-rtl,2184,,undo,2208,,simplebox,4464,auto",
"icons_hidpi.png"):a("about,0,auto,bold,24,auto,italic,48,auto,strike,72,auto,subscript,96,auto,superscript,120,auto,underline,144,auto,bidiltr,168,auto,bidirtl,192,auto,blockquote,216,auto,copy-rtl,240,auto,copy,264,auto,cut-rtl,288,auto,cut,312,auto,paste-rtl,336,auto,paste,360,auto,codesnippet,384,auto,bgcolor,408,auto,textcolor,432,auto,creatediv,456,auto,docprops-rtl,480,auto,docprops,504,auto,embed,528,auto,embedsemantic,552,auto,find-rtl,576,auto,find,600,auto,replace,624,auto,flash,648,auto,button,672,auto,checkbox,696,auto,form,720,auto,hiddenfield,744,auto,imagebutton,768,auto,radio,792,auto,select-rtl,816,auto,select,840,auto,textarea-rtl,864,auto,textarea,888,auto,textfield-rtl,912,auto,textfield,936,auto,horizontalrule,960,auto,iframe,984,auto,image,1008,auto,indent-rtl,1032,auto,indent,1056,auto,outdent-rtl,1080,auto,outdent,1104,auto,justifyblock,1128,auto,justifycenter,1152,auto,justifyleft,1176,auto,justifyright,1200,auto,language,1224,auto,anchor-rtl,1248,auto,anchor,1272,auto,link,1296,auto,unlink,1320,auto,bulletedlist-rtl,1344,auto,bulletedlist,1368,auto,numberedlist-rtl,1392,auto,numberedlist,1416,auto,mathjax,1440,auto,maximize,1464,auto,newpage-rtl,1488,auto,newpage,1512,auto,pagebreak-rtl,1536,auto,pagebreak,1560,auto,pastefromword-rtl,1584,auto,pastefromword,1608,auto,pastetext-rtl,1632,auto,pastetext,1656,auto,placeholder,1680,auto,preview-rtl,1704,auto,preview,1728,auto,print,1752,auto,removeformat,1776,auto,save,1800,auto,selectall,1824,auto,showblocks-rtl,1848,auto,showblocks,1872,auto,smiley,1896,auto,source-rtl,1920,auto,source,1944,auto,sourcedialog-rtl,1968,auto,sourcedialog,1992,auto,specialchar,2016,auto,table,2040,auto,templates-rtl,2064,auto,templates,2088,auto,uicolor,2112,auto,redo-rtl,2136,auto,redo,2160,auto,undo-rtl,2184,auto,undo,2208,auto,simplebox,2232,auto",
"icons.png")}()})();